@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/03/14
- *    Last                 : 2003/06/27
+ *    Last                 : 2007/10/31
  * ====================================================================
  */
 
@@ -23,7 +23,7 @@
 
 #include <gtk/gtk.h>
 #include <unistd.h>
-#include <pwd.h>
+//#include <pwd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <math.h>
@@ -40,19 +40,23 @@
 #include "List_PolyLine.h"
 #include "List_Select.h"
 #include "global.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "Draw.h"
 #include "sagcad.h"
 #include "MsgBox.h"
 #include "etc.h"
 
+#ifdef G_OS_WIN32
+#  include <windows.h>
+#endif
+
 #define _CAMPROFILE_
 #include "CamProfile.h"
 
 
 
 /* -------------------------------------------------------------------
- *  (double) ǡؤ
+ * 倍精度 (double) データの入れ替え
  *	
  */
 int Swap(double *a, double *b)
@@ -70,11 +74,11 @@ int Swap(double *a, double *b)
 
 
 /* -------------------------------------------------------------------
- * 쥯ȤƤǡ LIST  CAM ǡɤ߹
+ * セレクトされているデータを LIST の CAM データに読み込む
  *	
- * frag : ǽο޷θ
- *	   1 : 
- *	   2 : 
+ * frag : 最初の図形の向き
+ *	   1 : 正
+ *	   2 : 逆
  */
 int CamDataRead(int frag)
 {
@@ -84,14 +88,14 @@ int CamDataRead(int frag)
 
 
 	if (select_list_info.head == NULL) return 0;
-	/* ꥹȤ */
+	/* 全リストを削除 */
 	cam_list_all_free();
 
 	p = select_list_info.head;
 	while (p != NULL) {
-		/* ޷ǡ */
+		/* 図形データ */
 		if (p->select->index == 2 || p->select->index == 4) {
-			/* ȱ߸̥ǡΤ (ȱߤ̵) */
+			/* 線と円弧データのみ (点と円は無視) */
 			if (p->select->diagram_point.cad_point->code == 1 || p->select->diagram_point.cad_point->code == 2) {
 				cam.code = p->select->diagram_point.cad_point->code;
 				cam.gcode = p->select->diagram_point.cad_point->code;
@@ -103,11 +107,11 @@ int CamDataRead(int frag)
 				cam.cy = p->select->diagram_point.cad_point->cy;
 				cam.r = p->select->diagram_point.cad_point->r;
 
-				/* ߸̤ΤȤϡȤꤢϤΤޤޤ gcode = 3 */
+				/* 円弧のときは、とりあえず向きはそのままで gcode = 3 */
 				if (cam.gcode == 2 || cam.gcode == 4) {
 					cam.gcode = 3;
 
-					/* SA  */
+					/* SA を求める */
 					LAH.sx[1] = p->select->diagram_point.cad_point->cx;
 					LAH.sy[1] = p->select->diagram_point.cad_point->cy;
 					LAH.ex[1] = p->select->diagram_point.cad_point->sx;
@@ -115,7 +119,7 @@ int CamDataRead(int frag)
 					la(&LAH);
 					cam.sa = LAH.angle;
 
-					/* EA  */
+					/* EA を求める */
 					LAH.sx[1] = p->select->diagram_point.cad_point->cx;
 					LAH.sy[1] = p->select->diagram_point.cad_point->cy;
 					LAH.ex[1] = p->select->diagram_point.cad_point->ex;
@@ -123,7 +127,7 @@ int CamDataRead(int frag)
 					la(&LAH);
 					cam.ea = LAH.angle;
 
-					/* IA  */
+					/* IA を求める */
 					if (cam.sa < cam.ea) {
 						cam.ia = cam.ea - cam.sa;
 					}
@@ -132,14 +136,14 @@ int CamDataRead(int frag)
 					}
 				}
 
-				/* ǽΥǡθ(frag = 4) ΤȤ */
+				/* 最初のデータの向きが逆(frag = 4) のとき */
 				if (frag == 4 && p == select_list_info.head) {
-					/* ǡ */
+					/* 線データ */
 					if (cam.gcode == 1){
 						Swap(&cam.sx, &cam.ex);
 						Swap(&cam.sy, &cam.ey);
 					}
-					/* ߸̥ǡ */
+					/* 円弧データ */
 					else if (cam.gcode == 3){
 						cam.gcode = 2;
 						Swap(&cam.sx, &cam.ex);
@@ -148,21 +152,21 @@ int CamDataRead(int frag)
 						cam.ia = -1 * cam.ia;
 					}
 				}
-				/* CAM Data ꥹȤκǸɲ */
+				/* CAM Data をリストの最後に追加 */
 				cam_list_add_last(&cam);
 			}
 		}
 
-		/* ˡǡ */
+		/* 寸法データ */
 		if (p->select->index == 3) {
-			/* ̵ */
+			/* 無視 */
 		}
 		else {
-			/* ̵ */
+			/* 無視 */
 		}
 
 
-		/* Υ쥯ȥǡ */
+		/* 次のセレクトデータを処理 */
 		p = p->next;
 	}
 
@@ -176,17 +180,17 @@ int CamDataRead(int frag)
 /* -------------------------------------------------------------------
  * Hitohude
  *	
- * ǽΥǡϷƤ(ǽˤꡢƤ)
+ * 最初のデータだけは決めておく。(当然最初にあり、向きも決めておく)
  *	
  *	
- * ǽΥǡĤʤäƤǡ¤٤롣
+ * 最初のデータからつながっているデータを並べる。
  *	
- * 1:ꤷǡνƱĥǡõ
- * 2:ǡĤäʤСꤷǡμ褦¤ؤ롣
- * 3:Ĥäǡʤ餽ΤޤޤɡʤСν򤹤롣
- *	   ʤСȽؤ롣
- *	   ߸̤ʤСȽϳѤȽλѡؤIA (-) ˤ롣
- * 4:ǡƤĤʤʤϡ顼Ȥ롣
+ * 1:決定したデータの終点と同じ点を持つデータを探す。
+ * 2:データが見つかったならば、決定したデータの次に来るように並び替える。
+ * 3:見つかったデータが、始点ならそのままだけど、終点ならば、次の処理をする。
+ *	   ・線ならば、始点と終点を入れ替える。
+ *	   ・円弧ならば、始点と終点、開始角と終了角、を入れ替え、IA を負(-) にする。
+ * 4:データが全てつながらない場合は、エラーとする。
  *	
  */
 int Hitohude(int CamCheck)
@@ -199,7 +203,7 @@ int Hitohude(int CamCheck)
 
 
 
-	/* Ͽ޷ơOK ɤγǧ */
+	/* 開始図形を描いて、OK かどうかの確認！ */
 	if (cam_list_info.head->cam->gcode == 1) {
 		LineDraw (drawing_area, cam_list_info.head->cam->sx, cam_list_info.head->cam->sy, 
 								cam_list_info.head->cam->ex, cam_list_info.head->cam->ey, 
@@ -227,27 +231,27 @@ int Hitohude(int CamCheck)
 
 
 
-	/* ǧ */
+	/* 確認 */
 	if (CamCheck == 1) {
 		MsgBox("SagCAD", "CAM", "Check OK ?", NULL, NULL, "OK");
 	}
 
-	/* ǡĤʤ齪 */
+	/* データが１個だけなら終わり */
 	if (cam_list_info.head->next == NULL) return 1;
 
-	/* CAM DATA ǽ餫Ǹ1ޤ */
+	/* CAM DATA を最初から最後の1個前まで */
 	p_i = cam_list_info.head;
 	while (p_i->next != NULL) {
-		/* ʤä ե饰 򤿤Ƥ */
+		/* なかった フラグ をたてる */
 		K = 0;
 
-		/* CAM DATA  i μǸޤ */
+		/* CAM DATA を i の次から最後まで */
 		p_j = p_i->next;
 		while (p_j != NULL) {
 			/* ---------------------------------------------
-			 * Ȱ
+			 * 始点と一致
 			 * 
-			 * i ν j λ
+			 * i の終点と j の始点が一致
 			 */
 //			if (	sg(p_i->cam->ex, compa_digits) == sg(p_j->cam->sx, compa_digits) 
 //					&& 
@@ -260,13 +264,13 @@ int Hitohude(int CamCheck)
 					&& 
 					(p_i->cam->ey - (1/pow(10, compa_digits)) < p_j->cam->sy) )
 			{
-				/* ֤ؤ */
-				/* CAM Data ΥꥹȤ¤Ӥִ */
+				/* 順番を入れ替える */
+				/* CAM Data のリストの並びを置換 */
 				cam_dumy = p_i->next->cam;
 				p_i->next->cam = p_j->cam;
 				p_j->cam = cam_dumy;
 
-				/* Ĥ޷οѤ */
+				/* 見つけた図形の色を変える */
 				if (p_i->next->cam->gcode == 1) {
 					LineDraw(drawing_area,	p_i->next->cam->sx, p_i->next->cam->sy, 
 											p_i->next->cam->ex, p_i->next->cam->ey, 
@@ -298,14 +302,14 @@ int Hitohude(int CamCheck)
 
 
 			/* ---------------------------------------------
-			 * Ȱ
+			 * 終点と一致
 			 * 
-			 * i ν j ν
+			 * i の終点と j の終点が一致
 			 * 
-			 * ȰפϡIA ޥʥ G02 ˤʤ
-			 *	   G02ˤʤ
-			 *	   IA ޥʥˤʤ
-			 *	   (sx,sy) Ƚ(ex,ey) ؤ
+			 * 終点と一致した場合は、IA がマイナスで G02 になる
+			 *	   G02になる
+			 *	   IA がマイナスになる
+			 *	   始点(sx,sy) と終点(ex,ey) が入れ替わる
 			 * G03->G02   IA->-IA	 sx,sy,-> ex,ey
 			 * 
 			 */
@@ -321,8 +325,8 @@ int Hitohude(int CamCheck)
 						(p_i->cam->ey - (1/pow(10, compa_digits)) < p_j->cam->ey) )
 			{
 
-				/* ֤ؤ */
-				/* CAM Data ΥꥹȤ¤Ӥִ */
+				/* 順番を入れ替える */
+				/* CAM Data のリストの並びを置換 */
 				cam_dumy = p_i->next->cam;
 				p_i->next->cam = p_j->cam;
 				p_j->cam = cam_dumy;
@@ -332,7 +336,7 @@ int Hitohude(int CamCheck)
 				Swap(&p_i->next->cam->sa, &p_i->next->cam->ea);
 				p_i->next->cam->ia = -1 * (p_i->next->cam->ia);
 
-				/* Ĥ޷οѤ */
+				/* 見つけた図形の色を変える */
 				if (p_i->next->cam->gcode == 1) {
 					LineDraw(drawing_area,	p_i->next->cam->sx, p_i->next->cam->sy, 
 											p_i->next->cam->ex, p_i->next->cam->ey, 
@@ -346,7 +350,7 @@ int Hitohude(int CamCheck)
 				}
 				else if ( p_i->next->cam->gcode == 3) {
 					p_i->next->cam->gcode = 2;
-					/* IA ʤ G02 */
+					/* IA が負なら G02 */
 					ArcDraw(drawing_area,	p_i->next->cam->cx, p_i->next->cam->cy, p_i->next->cam->r, 
 											p_i->next->cam->ex, p_i->next->cam->ey, 
 											p_i->next->cam->sx, p_i->next->cam->sy, 1, sagcad_color.Back);
@@ -370,10 +374,10 @@ int Hitohude(int CamCheck)
 			return 0;
 		}
 
-		/* CamCheck  On ʤ11Ļߤ */
+		/* CamCheck が On なら1個1個止める */
 		if (CamCheck == 1) {
 			MsgBox("SagCAD", "CAM Check", "Check OK ?", NULL, NULL, "OK");
-			//MessageBox(NULL , "Check OK ?", (LPCSTR)"ã " , MB_OK);
+			//MessageBox(NULL , "Check OK ?", (LPCSTR)"ＣＡＭ ！" , MB_OK);
 		}
 		UpDate();
 	
@@ -383,7 +387,7 @@ int Hitohude(int CamCheck)
 	DX = sg(cam_list_info.tail->cam->ex - cam_list_info.head->cam->sx, 3);
 	DY = sg(cam_list_info.tail->cam->ey - cam_list_info.head->cam->sy, 3);
 
-	/* CamCheck  On ʤ11Ļߤ */
+	/* CamCheck が On なら1個1個止める */
 	if (CamCheck == 1) {
 		sprintf(Txt, "DX = %f  DY = %f", DX, DY);
 		MsgBox("SagCAD", _("Connected") , Txt, NULL, NULL, "OK");
@@ -402,24 +406,25 @@ int Hitohude(int CamCheck)
  *    0 : G90
  *    1 : G91
  * Heel
- *    0 : ɥߥ
- *    1 : ء G03+
- *    2 : ء G02+
+ *    0 : エンドミル
+ *    1 : ヘール G03+
+ *    2 : ヘール G02+
  * Modal
- *    0 : ⡼
- *    1 : 
+ *    0 : モーダル
+ *    1 : 毎回
  * RIJ
- *    0 : R 
- *    1 : IJ 
+ *    0 : R 指令
+ *    1 : IJ 指令
  * 
- * NC Ѥι¤Τ褦
+ * NC 用の構造体を作成しよう。
  */
 int NcOut(CAM_ENV CamProperty)
 {
 	CAM_LIST *p;
 	int modal_0 = 0;
 //	int len, j;
-	char command[256], path[256];
+	char path[256];
+	char *command;
 
 	double G91X = 0, G91Y = 0, G91C = 0;
 	double x = 0, y = 0;
@@ -428,7 +433,7 @@ int NcOut(CAM_ENV CamProperty)
 	char XCode[256], YCode[256], NcCode[256], NcMode[256];
 	char CCode[256], DCode[256], ECode[256], GK[256];
 	FILE *stream;
-
+	
 
 	if ( strstr(sagcad_user.NcPath, "CADPATH") != NULL )
 		sprintf(FileName, "%s/NoName.NC", sagcad_user.CadPath);
@@ -436,24 +441,18 @@ int NcOut(CAM_ENV CamProperty)
 
 
 
-	/* ե򥪡ץ */ 
+	/* ファイルをオープン */ 
 	if((stream = fopen(FileName, "w")) == NULL) {
 		g_print( _("The file could not be opened. [%s]\n") , FileName);
-		//MessageBox(NULL, "ѥե뤬ޤǤ", (LPCSTR)"ERROR", MB_OK);
-//		MessageBox(NULL, sagcad_user.CadPath, (LPCSTR)"sagcad_user.CadPath", MB_OK);
-//		MessageBox(NULL, sagcad_user.NcPath, (LPCSTR)"sagcad_user.NcPath", MB_OK);
 		return 0;
 	}
 
 
 	/* -----------------------------------------------------
-	 * ƬԤե˽񤭹
+	 * 行頭注釈行をファイルに書き込む
 	 */
 	sprintf(str, "(SAGCAD OUTPUT NC FILE)\n");
-	fputs(str, stream );
-
-//sprintf(str, "(sagcad_digits.cam_digits = %d)\n", sagcad_digits.cam_digits);
-//fputs(str, stream );
+	write_locale_from_utf8(str, stream, CHARSET_UTF8);
 
 	if(CamProperty.AbsInc == 1)
 		sprintf(str, "G91");
@@ -466,13 +465,13 @@ int NcOut(CAM_ENV CamProperty)
 	else if( CamProperty.Heel == 2)
 		strcat(str, " HEEL [G02 +] FOR BN MODE");
 	sprintf(NcMode, "(%s)\n", str);
-	/* ե˽񤭹 */
-	fputs(NcMode, stream );
+	/* ファイルに書き込む */
+	write_locale_from_utf8(NcMode, stream, CHARSET_UTF8);
 
 
 
 	/* -----------------------------------------------------
-	 * Ͼե˽񤭹
+	 * 開始条件をファイルに書き込む
 	 */
 	if (CamProperty.StartStr[0] != '\0') {
 #ifdef TEST
@@ -486,8 +485,8 @@ int NcOut(CAM_ENV CamProperty)
 		}
 		str[j] = '\0';
 #endif
-		/* ե˽񤭹 */
-		fputs(CamProperty.StartStr, stream );
+		/* ファイルに書き込む */
+		write_locale_from_utf8(CamProperty.StartStr, stream, CHARSET_UTF8);
 	}
 
 
@@ -495,7 +494,7 @@ int NcOut(CAM_ENV CamProperty)
 
 
 	/* -----------------------------------------------------
-	 * CAM DATA ǽ餫Ǹޤ 
+	 * CAM DATA を最初から最後まで 
 	 * 
 	 */
 	p = cam_list_info.head;
@@ -505,14 +504,14 @@ int NcOut(CAM_ENV CamProperty)
 		 * 
 		 */
 		if(p->cam->gcode == 1) {
-			/* 󥯥Ȼ */
+			/* インクリメント指令 */
 			if (CamProperty.AbsInc == 1) {
 				x = sg(sg(p->cam->ex, sagcad_digits.cam_digits) - sg(p->cam->sx, sagcad_digits.cam_digits), sagcad_digits.cam_digits);
 				y = sg(sg(p->cam->ey, sagcad_digits.cam_digits) - sg(p->cam->sy, sagcad_digits.cam_digits), sagcad_digits.cam_digits);
 				G91X = sg((G91X + x), sagcad_digits.cam_digits);
 				G91Y = sg((G91Y + y), sagcad_digits.cam_digits);
 			}
-			/* ֥塼Ȼ */
+			/* アブソリュート指令 */
 			if (CamProperty.AbsInc == 0) {
 				x = sg(p->cam->ex, sagcad_digits.cam_digits);
 				y = sg(p->cam->ey, sagcad_digits.cam_digits);
@@ -525,22 +524,22 @@ int NcOut(CAM_ENV CamProperty)
 			FloatOut_n(str, y, sagcad_digits.cam_digits, 1);
 			sprintf(YCode, "Y%s", str);
 
-			/* G01 Υ⡼ */
+			/* G01 のモーダル */
 			sprintf(GK, "G01");
 			if (p != cam_list_info.head && CamProperty.Modal == 1 && modal_0 == 1) {
 				strcpy(GK, "");
 			}
 
-			/* G90 & G91 Υ⡼ */
+			/* G90 & G91 のモーダル */
 			if (CamProperty.AbsInc == 1 && (p == cam_list_info.head || CamProperty.Modal == 0)) {
 				strcat(GK, "G91");
 			}
 			if (CamProperty.AbsInc == 0 && (p == cam_list_info.head || CamProperty.Modal == 0)) {
 				strcat(GK, "G90");
 			}
-			/* ե˽񤭹 */
+			/* ファイルに書き込む */
 			sprintf(NcCode, "%s%s%s\n", GK, XCode, YCode);
-			fputs(NcCode, stream );
+			write_locale_from_utf8(NcCode, stream, CHARSET_UTF8);
 			
 			modal_0 = 1;
 		}
@@ -554,14 +553,14 @@ int NcOut(CAM_ENV CamProperty)
 		 * 
 		 */
 		if (p->cam->gcode == 2 || p->cam->gcode == 3) {
-			/* 󥯥Ȼ */
+			/* インクリメント指令 */
 			if (CamProperty.AbsInc == 1) {
 				x = sg(sg(p->cam->ex, sagcad_digits.cam_digits) - sg(p->cam->sx, sagcad_digits.cam_digits), sagcad_digits.cam_digits);
 				y = sg(sg(p->cam->ey, sagcad_digits.cam_digits) - sg(p->cam->sy, sagcad_digits.cam_digits), sagcad_digits.cam_digits);
 				G91X = sg((G91X + x), sagcad_digits.cam_digits);
 				G91Y = sg((G91Y + y), sagcad_digits.cam_digits);
 			}
-			/* ֥塼Ȼ */
+			/* アブソリュート指令 */
 			if (CamProperty.AbsInc == 0) {
 				x = sg(p->cam->ex, sagcad_digits.cam_digits);
 				y = sg(p->cam->ey, sagcad_digits.cam_digits);
@@ -615,19 +614,19 @@ int NcOut(CAM_ENV CamProperty)
 			else if(p->cam->gcode == 2) 
 				sprintf(GK, "G02");
 
-			/* G02 & G03 Υ⡼ */
+			/* G02 & G03 のモーダル */
 			if (p != cam_list_info.head && CamProperty.Modal == 1 && modal_0 == p->cam->gcode) 
 				GK[0] = '\0';
-			/* G90 & G91 Υ⡼ */
+			/* G90 & G91 のモーダル */
 			if (CamProperty.AbsInc == 1 && (p == cam_list_info.head || CamProperty.Modal == 0)) 
 				strcat(GK, "G91");
 			else if(CamProperty.AbsInc == 0 && (p == cam_list_info.head || CamProperty.Modal == 0)) 
 				strcat(GK, "G90");
 
-			/* ե˽񤭹 */
+			/* ファイルに書き込む */
 			/* G02-X--Y--C--IR-J- */
 			sprintf(NcCode, "%s%s%s%s%s%s\n", GK, XCode, YCode, DCode, ECode, CCode);
-			fputs(NcCode, stream );
+			write_locale_from_utf8(NcCode, stream, CHARSET_UTF8);
 
 			modal_0 = p->cam->gcode;
 		}
@@ -638,60 +637,60 @@ int NcOut(CAM_ENV CamProperty)
 
 
 
-	/* G90 ץबȽλƱɤΥå */
+	/* G90 プログラムが開始点と終了点が同じかどうかのチェック */
 	if (CamProperty.AbsInc == 0) {
-		/* ե˽񤭹 */
+		/* ファイルに書き込む */
 		FloatOut_n(str, cam_list_info.head->cam->sx, sagcad_digits.cam_digits, 1);
 		FloatOut_n(DumyStr, cam_list_info.head->cam->sy, sagcad_digits.cam_digits, 1);
 		sprintf(NcCode, "(START X%s Y%s)\n", str, DumyStr);
-		fputs(NcCode, stream );
+		write_locale_from_utf8(NcCode, stream, CHARSET_UTF8);
 
-		/* ե˽񤭹 */
+		/* ファイルに書き込む */
 		FloatOut_n(str, cam_list_info.tail->cam->ex, sagcad_digits.cam_digits, 1);
 		FloatOut_n(DumyStr, cam_list_info.tail->cam->ey, sagcad_digits.cam_digits, 1);
 		sprintf(NcCode, "(END X%s Y%s)\n", str, DumyStr);
-		fputs(NcCode, stream );
+		write_locale_from_utf8(NcCode, stream, CHARSET_UTF8);
 
 		if (sg(cam_list_info.tail->cam->ex - cam_list_info.head->cam->sx, sagcad_digits.cam_digits) != 0 
 				|| sg(cam_list_info.tail->cam->ey - cam_list_info.head->cam->sy, sagcad_digits.cam_digits) != 0)
-			/* ե˽񤭹 */
-			fputs("(START-END NO RETURN)\n", stream );
+			/* ファイルに書き込む */
+			write_locale_from_utf8("(START-END NO RETURN)\n", stream, CHARSET_UTF8);
 		if (sg(cam_list_info.tail->cam->ex - cam_list_info.head->cam->sx, sagcad_digits.cam_digits) == 0 
 				&& sg(cam_list_info.tail->cam->ey - cam_list_info.head->cam->sy, sagcad_digits.cam_digits) == 0)
-			/* ե˽񤭹 */
-			fputs("(START-END 0 RETURN OK)\n", stream );
+			/* ファイルに書き込む */
+			write_locale_from_utf8("(START-END 0 RETURN OK)\n", stream, CHARSET_UTF8);
 	}
 
 
-	/* G91 ץबȽλƱɤΥå */
+	/* G91 プログラムが開始点と終了点が同じかどうかのチェック */
 	if (CamProperty.AbsInc == 1) {
 		FloatOut_n(str, G91X, sagcad_digits.cam_digits, 1);
 		FloatOut_n(DumyStr, G91Y, sagcad_digits.cam_digits, 1);
 		sprintf(NcCode, "(START-END X%s Y%s)\n", str, DumyStr);
-		fputs(NcCode, stream );
+		write_locale_from_utf8(NcCode, stream, CHARSET_UTF8);
 
 		if (sg(G91X, sagcad_digits.cam_digits) != 0 || sg(G91Y, sagcad_digits.cam_digits) != 0)
-			fputs("(X-Y NO RETURN)\n", stream );
+			write_locale_from_utf8("(X-Y NO RETURN)\n", stream, CHARSET_UTF8);
 		if (sg(G91X, sagcad_digits.cam_digits) == 0 && sg(G91Y, sagcad_digits.cam_digits) == 0)
-			fputs("(X-Y 0 RETURN OK)\n", stream );
+			write_locale_from_utf8("(X-Y 0 RETURN OK)\n", stream, CHARSET_UTF8);
 	}
 
-	/* Heel Mode  1 360٤ǽäƤ뤫å */
+	/* Heel Mode で 1周して 360度で終わっているかをチェック */
 	if (CamProperty.Heel > 0) {
-		/* Ϥ齪λޤǤγ */
+		/* 開始から終了までの角度 */
 		FloatOut_n(str, G91C, sagcad_digits.cam_digits, 1);
 		sprintf(NcCode, "(1 CYCLE %s)\n", str);
-		fputs(NcCode, stream );
+		write_locale_from_utf8(NcCode, stream, CHARSET_UTF8);
 
 		if (sg(G91C, sagcad_digits.cam_digits) != 360 && sg(G91C, sagcad_digits.cam_digits) != -360)
-			fputs("(C-NOT 360 RETURN)\n", stream );
+			write_locale_from_utf8("(C-NOT 360 RETURN)\n", stream, CHARSET_UTF8);
 		if (sg(G91C, sagcad_digits.cam_digits) == 360 || sg(G91C, sagcad_digits.cam_digits) == -360)
-			fputs("(C-360 RETURN OK)\n", stream );
+			write_locale_from_utf8("(C-360 RETURN OK)\n", stream, CHARSET_UTF8);
 	}
 
 
 	/* -----------------------------------------------------
-	 * λե˽񤭹
+	 * 終了条件をファイルに書き込む
 	 */
 	if (CamProperty.EndStr[0] != '\0') {
 #ifdef TEST
@@ -705,32 +704,29 @@ int NcOut(CAM_ENV CamProperty)
 		}
 		str[j] = '\0';
 #endif
-		/* ե˽񤭹 */
-		fputs(CamProperty.EndStr, stream );
+		/* ファイルに書き込む */
+		write_locale_from_utf8(CamProperty.EndStr, stream, CHARSET_UTF8);
 	}
 
-	/* ե򥯥 */ 
+	/* ファイルをクローズ */ 
 	fclose(stream);
 
-
-
-
-
 	/* Editor command */
+
+#ifdef G_OS_WIN32
+	strcpy(path, FileName);
+	command = g_locale_from_utf8(path, -1, NULL, NULL, NULL);
+	ShellExecute(0, "Open", command, "", "", 1); 	
+	g_free(command);
+#else
 	strcpy(path, sagcad_user.editor_command);
 	replace(path, "&", "");
-
-	if (strstr(path, "%s") != NULL) {
-		replace(path, "%s", FileName);
-	}
-//	else {
-//		sprintf(path , "%s %s", sagcad_user.editor_command, FileName);
-//	}
-
-	sprintf(command, "%s &", path);
-	g_print("%s\n", command);
+	replace(path, "%s", FileName);
+	
+	command = g_locale_from_utf8(path, -1, NULL, NULL, NULL);
 	system(command);
-
+	g_free(command);
+#endif
 	return 1;
 }
 
@@ -739,7 +735,7 @@ int NcOut(CAM_ENV CamProperty)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : CamProfile.c
