@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/04/17
- *    Last                 : 2003/04/17
+ *    Last                 : 2007/10/15
  * ====================================================================
  */
 
@@ -197,7 +197,6 @@ int NCJ_read(CAM_SET_DLG *cam_set_dlg)
 		/*NC START */
 		if ( strstr(str, "NC START {") != NULL ) {
 			if (cam_set_dlg->start_str != NULL) {
-//g_print("START\n");
 				frag = 0;
 				strcpy(cam_set_dlg->start_str, "");
 				while (1) {
@@ -217,21 +216,30 @@ int NCJ_read(CAM_SET_DLG *cam_set_dlg)
 							strcat(cam_set_dlg->start_str, "\n");
 						}
 						strcat(cam_set_dlg->start_str, str);
-//g_print("%s\n", str);
 					}
 				}
 			}
 
 
 			if (cam_set_dlg->start_str != NULL) {
-//g_print("Before gtk_text_insert()\n");
+				GtkTextIter p, start, end ;
+				
+				GtkTextBuffer *textbuf = gtk_text_view_get_buffer((GtkTextView *)cam_set_dlg->start_text) ;
+				// Clear buffer 
+				gtk_text_buffer_get_start_iter ( textbuf, &start ) ;
+				gtk_text_buffer_get_end_iter ( textbuf, &end ) ;
+				gtk_text_buffer_delete ( textbuf, &start, &end ) ;
+				
+				gtk_text_buffer_insert (textbuf, &p, cam_set_dlg->start_str, -1) ;
+
+				/*
 				gtk_text_insert(GTK_TEXT(cam_set_dlg->start_text), 
 								NULL, // GdkFont    *font,
 								NULL, // GdkColor   *fore,
 								NULL, // GdkColor   *back,
 								cam_set_dlg->start_str, // const char *chars,
 								-1);  // gint        length );
-//g_print("After gtk_text_insert()\n");
+				*/
 				xfree(cam_set_dlg->start_str);
 				cam_set_dlg->start_str = NULL;
 			}
@@ -240,7 +248,6 @@ int NCJ_read(CAM_SET_DLG *cam_set_dlg)
 		/* NC END */
 		if ( strstr(str, "NC END {") != NULL ) {
 			if (cam_set_dlg->end_str != NULL) {
-//g_print("END\n");
 				frag = 0;
 				strcpy(cam_set_dlg->end_str, "");
 				while(1) {
@@ -260,21 +267,30 @@ int NCJ_read(CAM_SET_DLG *cam_set_dlg)
 							strcat(cam_set_dlg->end_str, "\n");
 						}
 						strcat(cam_set_dlg->end_str, str);
-//g_print("%s\n", str);
 					}
 				}
 			}
 
 
 			if (cam_set_dlg->end_str != NULL) {
-//g_print("Before gtk_text_insert()\n");
+				GtkTextIter p, start, end ;
+				
+				GtkTextBuffer *textbuf = gtk_text_view_get_buffer((GtkTextView *)cam_set_dlg->end_text) ;
+				// Clear buffer 
+				gtk_text_buffer_get_start_iter ( textbuf, &start ) ;
+				gtk_text_buffer_get_end_iter ( textbuf, &end ) ;
+				gtk_text_buffer_delete ( textbuf, &start, &end ) ;
+				
+				gtk_text_buffer_insert (textbuf, &p, cam_set_dlg->end_str, -1) ;
+				
+				/*
 				gtk_text_insert(GTK_TEXT(cam_set_dlg->end_text), 
 								NULL, // GdkFont    *font,
 								NULL, // GdkColor   *fore,
 								NULL, // GdkColor   *back,
 								cam_set_dlg->end_str, // const char *chars,
 								-1);  // gint        length );
-//g_print("After gtk_text_insert()\n");
+				*/
 				xfree(cam_set_dlg->end_str);
 				cam_set_dlg->end_str = NULL;
 			}
@@ -298,23 +314,6 @@ int NCJ_read(CAM_SET_DLG *cam_set_dlg)
  */
 void cam_set_dlg_condition_read_pushed(GtkWidget *widget, CAM_SET_DLG *cam_set_dlg)
 {
-	guint length;
-
-
-	/* ʸ */
-	length = gtk_text_get_length(GTK_TEXT(cam_set_dlg->start_text));
-	/* ֤ */
-	gtk_text_set_point(GTK_TEXT(cam_set_dlg->start_text), 0);
-	/* θ length ʸ */
-	gtk_text_forward_delete(GTK_TEXT(cam_set_dlg->start_text), length);
-
-	/* ʸ */
-	length = gtk_text_get_length(GTK_TEXT(cam_set_dlg->end_text));
-	/* ֤ */
-	gtk_text_set_point(GTK_TEXT(cam_set_dlg->end_text), 0);
-	/* θ length ʸ */
-	gtk_text_forward_delete(GTK_TEXT(cam_set_dlg->end_text), length);
-
 	NCJ_read(cam_set_dlg);
 }
 
@@ -333,7 +332,7 @@ int NCJ_save(CAM_SET_DLG *cam_set_dlg)
 
 	GetConfigPath(str);
 	sprintf(FileName, "%s/NoName.NCJ", str);
-	if (save_file_name_get(FileName) == 0) {
+	if (save_file_name_get(FileName) == -1) {
 		return 0;
 	}
 	if (FileName == NULL) {
@@ -391,24 +390,44 @@ int NCJ_save(CAM_SET_DLG *cam_set_dlg)
  */
 void cam_set_dlg_condition_write_pushed(GtkWidget *widget, CAM_SET_DLG *cam_set_dlg)
 {
-	guint length;
-
-
-	/* ƥȥȥ꡼ʸ */
+	/* テキストエントリーから文字列を取得 */
 	/* Start Code */
-	cam_set_dlg->start_str = NULL;
-	length = gtk_text_get_length(GTK_TEXT(cam_set_dlg->start_text));
-	if (length > 0) {
-		cam_set_dlg->start_str = gtk_editable_get_chars(GTK_EDITABLE(cam_set_dlg->start_text), 0, length);
-	}
-
+	
+	/* Get Text Buffer */
+	GtkTextView *textview;
+	GtkTextBuffer *textbuf;
+	gint textbuf_size;
+	GtkTextIter start, end;
+	
+	textview = (GtkTextView *)cam_set_dlg->start_text;
+	textbuf = gtk_text_view_get_buffer(textview);
+	
+	/* Get textbuf size[byte] */
+	textbuf_size = gtk_text_buffer_get_char_count(textbuf);
+	
+	/* Get save start point and end point */
+	gtk_text_buffer_get_iter_at_offset(textbuf, &start, 0) ;
+	gtk_text_buffer_get_iter_at_offset(textbuf, &end, textbuf_size) ;
+	/* Get save utf-8 string */
+	cam_set_dlg->start_str = gtk_text_buffer_get_text(textbuf, &start, &end, FALSE);
+	
+	
+	
 	/* End Code */
-	cam_set_dlg->end_str = NULL;
-	length = gtk_text_get_length(GTK_TEXT(cam_set_dlg->end_text));
-	if (length > 0) {
-		cam_set_dlg->end_str = gtk_editable_get_chars(GTK_EDITABLE(cam_set_dlg->end_text), 0, length);
-	}
-
+	textview = (GtkTextView *)cam_set_dlg->end_text ;
+	textbuf = gtk_text_view_get_buffer(textview) ;
+	
+	/* Get textbuf size[byte] */
+	textbuf_size = gtk_text_buffer_get_char_count(textbuf);
+	
+	/* Get save start point and end point */
+	gtk_text_buffer_get_iter_at_offset(textbuf, &start, 0) ;
+	gtk_text_buffer_get_iter_at_offset(textbuf, &end, textbuf_size) ;
+	/* Get save utf-8 string */
+	cam_set_dlg->end_str = gtk_text_buffer_get_text (textbuf, &start, &end, FALSE);
+	
+	
+	
 	/* ABS INC */
 	if (GTK_TOGGLE_BUTTON(cam_set_dlg->inc_check)->active) {
 		cam_set_dlg->AbsInc = 1;
@@ -435,12 +454,16 @@ void cam_set_dlg_condition_write_pushed(GtkWidget *widget, CAM_SET_DLG *cam_set_
 
 	cam_set_dlg->Heel = 0;
 	NCJ_save(cam_set_dlg);
+	
+	/* Free Buffer */
+	g_free(cam_set_dlg->start_str);
+	g_free(cam_set_dlg->end_str);
 }
 
 
 
 /* -------------------------------------------------------------------
- * ABS(G90) INC(G91) ܥ ٥
+ * ABS(G90) INC(G91) ボタン イベント
  */
 void abs_inc_button_toggled(GtkWidget *widget, CAM_SET_DLG *cam_set_dlg)
 {
@@ -466,7 +489,7 @@ void abs_inc_button_toggled(GtkWidget *widget, CAM_SET_DLG *cam_set_dlg)
 
 
 /* -------------------------------------------------------------------
- * [R]  [IJ]  ܥ ٥
+ * [R]  [IJ]  ボタン イベント
  */
 void rij_button_toggled(GtkWidget *widget, CAM_SET_DLG *cam_set_dlg)
 {
@@ -492,7 +515,7 @@ void rij_button_toggled(GtkWidget *widget, CAM_SET_DLG *cam_set_dlg)
 
 
 /* -------------------------------------------------------------------
- * Modal [ON] [OFF]  ܥ ٥
+ * Modal [ON] [OFF]  ボタン イベント
  */
 void modal_button_toggled(GtkWidget *widget, CAM_SET_DLG *cam_set_dlg)
 {
@@ -532,26 +555,45 @@ void cam_set_dlg_cancel_pushed(GtkWidget *widget, CAM_SET_DLG *cam_set_dlg)
  */
 void cam_set_dlg_ok_pushed(GtkWidget *widget, CAM_SET_DLG *cam_set_dlg)
 {
-	guint length;
-
-
+	/* Get Text Buffer */
+	GtkTextView *textview;
+	GtkTextBuffer *textbuf;
+	gint textbuf_size;
+	GtkTextIter start, end;
+	
+	/* テキストエントリーから文字列を取得 */
+	
 //g_print("Start Code\n");
-	/* ƥȥȥ꡼ʸ */
 	/* Start Code */
-	cam_set_dlg->start_str = NULL;
-	length = gtk_text_get_length(GTK_TEXT(cam_set_dlg->start_text));
-	if (length > 0) {
-		cam_set_dlg->start_str = gtk_editable_get_chars(GTK_EDITABLE(cam_set_dlg->start_text), 0, length);
-	}
-
+	textview = (GtkTextView *)cam_set_dlg->start_text;
+	textbuf = gtk_text_view_get_buffer(textview);
+	
+	/* Get textbuf size[byte] */
+	textbuf_size = gtk_text_buffer_get_char_count(textbuf);
+	
+	/* Get save start point and end point */
+	gtk_text_buffer_get_iter_at_offset(textbuf, &start, 0) ;
+	gtk_text_buffer_get_iter_at_offset(textbuf, &end, textbuf_size) ;
+	/* Get save utf-8 string */
+	cam_set_dlg->start_str = gtk_text_buffer_get_text(textbuf, &start, &end, FALSE);
+	
+	
+	
 //g_print("End Code\n");
 	/* End Code */
-	cam_set_dlg->end_str = NULL;
-	length = gtk_text_get_length(GTK_TEXT(cam_set_dlg->end_text));
-	if (length > 0) {
-		cam_set_dlg->end_str = gtk_editable_get_chars(GTK_EDITABLE(cam_set_dlg->end_text), 0, length);
-	}
-
+	textview = (GtkTextView *)cam_set_dlg->end_text ;
+	textbuf = gtk_text_view_get_buffer(textview) ;
+	
+	/* Get textbuf size[byte] */
+	textbuf_size = gtk_text_buffer_get_char_count(textbuf);
+	
+	/* Get save start point and end point */
+	gtk_text_buffer_get_iter_at_offset(textbuf, &start, 0) ;
+	gtk_text_buffer_get_iter_at_offset(textbuf, &end, textbuf_size) ;
+	/* Get save utf-8 string */
+	cam_set_dlg->end_str = gtk_text_buffer_get_text (textbuf, &start, &end, FALSE);
+	
+	
 //g_print("ABS INC\n");
 	/* ABS INC */
 	if (GTK_TOGGLE_BUTTON(cam_set_dlg->inc_check)->active) {
@@ -578,15 +620,13 @@ void cam_set_dlg_ok_pushed(GtkWidget *widget, CAM_SET_DLG *cam_set_dlg)
 	}
 
 	cam_set_dlg->Heel = 0;
-
-
 	cam_set_dlg->value = 1;
 }
 
 
 
 /* -------------------------------------------------------------------
- * 줿٥
+ * キーが押されたイベント
  * key_press_event
  */
 static gint cam_set_dlg_key_press_event(GtkWidget *widget, GdkEventKey *event, CAM_SET_DLG *cam_set_dlg)
@@ -599,13 +639,13 @@ static gint cam_set_dlg_key_press_event(GtkWidget *widget, GdkEventKey *event, C
 //		cam_set_dlg_ok_pushed(widget, cam_set_dlg);
 //		gtk_main_quit();
 //	}
-	return TRUE; 
+	return FALSE; 
 }
 
 
 
 /* -------------------------------------------------------------------
- * CAM 
+ * CAM 設定
  * 
  */
 gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
@@ -637,9 +677,11 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 //			GtkWidget *separator;
 
 			GtkWidget *start_vbox;
+				GtkWidget *start_scrolledwindow;
 //				GtkWidget *label;
 //				GtkWidget *start_text;
 			GtkWidget *end_vbox;
+				GtkWidget *end_scrolledwindow;
 //				GtkWidget *label;
 //				GtkWidget *end_text;
 
@@ -654,34 +696,31 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 
 	cam_set_dlg->toggle_frag = 0;
 
-
-
-	/* (cam_set_dlg->dialog) */
-	cam_set_dlg->dialog = gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_position(GTK_WINDOW(cam_set_dlg->dialog), GTK_WIN_POS_CENTER);
+	/* ダイアログ(cam_set_dlg->dialog)生成 */
+	cam_set_dlg->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(cam_set_dlg->dialog), _("CAM Setting") );
-	gtk_signal_connect( GTK_OBJECT(cam_set_dlg->dialog), "key_press_event",
-						GTK_SIGNAL_FUNC(cam_set_dlg_key_press_event), cam_set_dlg);
+	gtk_window_set_position(GTK_WINDOW(cam_set_dlg->dialog), GTK_WIN_POS_CENTER);
+	/* ダイアログを最前面に表示する */
+	gtk_window_set_modal(GTK_WINDOW(cam_set_dlg->dialog), TRUE);
+	/* メインウィンドウを操作できないように設定 */
+	gtk_window_set_transient_for(GTK_WINDOW(cam_set_dlg->dialog), GTK_WINDOW(cam_set_dlg->parent));
+	
+	g_signal_connect( G_OBJECT(cam_set_dlg->dialog), "key_press_event",
+						G_CALLBACK(cam_set_dlg_key_press_event), cam_set_dlg);
 
-
-
-		/* ѥå󥰥ܥå(main_vbox) */
+		/* パッキングボックス(main_vbox)を作成 */
 		main_vbox = gtk_vbox_new(0, 5);
 		gtk_container_add(GTK_CONTAINER(cam_set_dlg->dialog), main_vbox);
-		gtk_container_border_width(GTK_CONTAINER(cam_set_dlg->dialog), 5);
+		gtk_container_set_border_width(GTK_CONTAINER(cam_set_dlg->dialog), 5);
 		gtk_widget_show(main_vbox);
 
-
-
-
-
 			/* label */
 			label = gtk_button_new_with_label( _("ABS or INC") );
-//			gtk_widget_set_usize (label, 100, 20);
+//			gtk_widget_set_size_request(label, 100, 20);
 			gtk_box_pack_start((GtkBox *)GTK_BOX(main_vbox), label, TRUE, TRUE, 0);
 			gtk_widget_show(label);
 
-			/* ѥå󥰥ܥå(abs_inc_vbox)  */
+			/* パッキングボックス(abs_inc_vbox) を作成 */
 			abs_inc_vbox = gtk_hbox_new(FALSE, 2);
 			gtk_box_pack_start( (GtkBox *)GTK_BOX(main_vbox), abs_inc_vbox, TRUE, TRUE, 0);
 			gtk_widget_show(abs_inc_vbox);
@@ -698,9 +737,9 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cam_set_dlg->abs_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(cam_set_dlg->abs_check), 
+				g_signal_connect (G_OBJECT(cam_set_dlg->abs_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(abs_inc_button_toggled), 
+									G_CALLBACK(abs_inc_button_toggled), 
 									cam_set_dlg);
 				gtk_widget_show(cam_set_dlg->abs_check);
 
@@ -713,28 +752,24 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cam_set_dlg->inc_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(cam_set_dlg->inc_check), 
+				g_signal_connect (G_OBJECT(cam_set_dlg->inc_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(abs_inc_button_toggled), 
+									G_CALLBACK(abs_inc_button_toggled), 
 									cam_set_dlg);
 				gtk_widget_show(cam_set_dlg->inc_check);
 
-			/* ѥ졼(separator) */
+			/* セパレーター(separator) */
 			separator = gtk_hseparator_new();
 			gtk_box_pack_start( GTK_BOX(main_vbox), separator, TRUE, TRUE, 0);
 			gtk_widget_show(separator);
 
-
-
-
-
 			/* label */
 			label = gtk_button_new_with_label( _("R or IJ") );
-//			gtk_widget_set_usize (label, 100, 20);
+//			gtk_widget_set_size_request(label, 100, 20);
 			gtk_box_pack_start((GtkBox *)GTK_BOX(main_vbox), label, TRUE, TRUE, 0);
 			gtk_widget_show(label);
 
-			/* ѥå󥰥ܥå(arc_vbox)  */
+			/* パッキングボックス(arc_vbox) を作成 */
 			arc_vbox = gtk_hbox_new(FALSE, 2);
 			gtk_box_pack_start( (GtkBox *)GTK_BOX(main_vbox), arc_vbox, TRUE, TRUE, 0);
 			gtk_widget_show(arc_vbox);
@@ -751,9 +786,9 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cam_set_dlg->r_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(cam_set_dlg->r_check), 
+				g_signal_connect (G_OBJECT(cam_set_dlg->r_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(rij_button_toggled), 
+									G_CALLBACK(rij_button_toggled), 
 									cam_set_dlg);
 				gtk_widget_show(cam_set_dlg->r_check);
 
@@ -766,27 +801,23 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cam_set_dlg->ij_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(cam_set_dlg->ij_check), 
+				g_signal_connect (G_OBJECT(cam_set_dlg->ij_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(rij_button_toggled), 
+									G_CALLBACK(rij_button_toggled), 
 									cam_set_dlg);
 				gtk_widget_show(cam_set_dlg->ij_check);
 
-			/* ѥ졼(separator) */
+			/* セパレーター(separator) */
 			separator = gtk_hseparator_new();
 			gtk_box_pack_start( GTK_BOX(main_vbox), separator, TRUE, TRUE, 0);
 			gtk_widget_show(separator);
 
-
-
-
-
 			label = gtk_button_new_with_label(" Modal");
-			//gtk_widget_set_usize (label, 100, 20);
+			//gtk_widget_set_size_request(label, 100, 20);
 			gtk_box_pack_start((GtkBox *)GTK_BOX(main_vbox), label, TRUE, TRUE, 0);
 			gtk_widget_show(label);
 
-			/* ѥå󥰥ܥå(modal_vbox)  */
+			/* パッキングボックス(modal_vbox) を作成 */
 			modal_vbox = gtk_hbox_new(FALSE, 2);
 			gtk_box_pack_start( (GtkBox *)GTK_BOX(main_vbox), modal_vbox, TRUE, TRUE, 0);
 			gtk_widget_show(modal_vbox);
@@ -803,9 +834,9 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cam_set_dlg->modal_on_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(cam_set_dlg->modal_on_check), 
+				g_signal_connect (G_OBJECT(cam_set_dlg->modal_on_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(modal_button_toggled), 
+									G_CALLBACK(modal_button_toggled), 
 									cam_set_dlg);
 				gtk_widget_show(cam_set_dlg->modal_on_check);
 
@@ -818,37 +849,64 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cam_set_dlg->modal_off_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(cam_set_dlg->modal_off_check), 
+				g_signal_connect (G_OBJECT(cam_set_dlg->modal_off_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(modal_button_toggled), 
+									G_CALLBACK(modal_button_toggled), 
 									cam_set_dlg);
 				gtk_widget_show(cam_set_dlg->modal_off_check);
 
-			/* ѥ졼(separator) */
+			/* セパレーター(separator) */
 			separator = gtk_hseparator_new();
 			gtk_box_pack_start( GTK_BOX(main_vbox), separator, TRUE, TRUE, 0);
 			gtk_widget_show(separator);
 
-
-
-
-
-			/* ѥå󥰥ܥå(start_vbox)  */
+			/* パッキングボックス(start_vbox) を作成 */
 			start_vbox = gtk_vbox_new(FALSE, 2);
 			gtk_box_pack_start( (GtkBox *)GTK_BOX(main_vbox), start_vbox, TRUE, TRUE, 0);
 			gtk_widget_show(start_vbox);
 
 				label = gtk_button_new_with_label(" Start Code");
-//				gtk_widget_set_usize (label, 100, 20);
+//				gtk_widget_set_size_request(label, 100, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(start_vbox), label, TRUE, TRUE, 0);
 				gtk_widget_show(label);
-
-				/* ƥȥȥ꡼ */
+				
+				
+				// Create edit widget 
+				start_scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
+				gtk_widget_show(start_scrolledwindow) ;
+				// Container add to main window 
+				gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(start_scrolledwindow), 
+											   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+				gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(start_scrolledwindow), 
+													GTK_SHADOW_IN);
+				gtk_box_pack_start((GtkBox *)GTK_BOX(start_vbox), start_scrolledwindow, TRUE, TRUE, 1);
+				
+				cam_set_dlg->start_text = gtk_text_view_new();
+				gtk_widget_show(cam_set_dlg->start_text);
+				gtk_container_add(GTK_CONTAINER(start_scrolledwindow), cam_set_dlg->start_text);
+				
+				/* 初期値設定 */
+				if (cam_set_dlg->start_str != NULL) {
+					GtkTextIter p, start, end ;
+					
+					GtkTextBuffer *textbuf = gtk_text_view_get_buffer((GtkTextView *)cam_set_dlg->start_text) ;
+					// Clear buffer 
+					gtk_text_buffer_get_start_iter ( textbuf, &start ) ;
+					gtk_text_buffer_get_end_iter ( textbuf, &end ) ;
+					gtk_text_buffer_delete ( textbuf, &start, &end ) ;
+					
+					gtk_text_buffer_insert (textbuf, &p, cam_set_dlg->start_str, -1) ;
+				}
+				
+				
+				
+				/*
+				// テキストエントリー生成 
 				cam_set_dlg->start_text = gtk_text_new(NULL, NULL);
 				gtk_text_set_editable(GTK_TEXT(cam_set_dlg->start_text), TRUE);
-//				gtk_widget_set_usize (cam_set_dlg->up_scale_entry, 80, 20);
+				//gtk_widget_set_size_request(cam_set_dlg->up_scale_entry, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(start_vbox), cam_set_dlg->start_text, TRUE, TRUE, 1);
-				/*  */
+				// 初期値設定 
 				if (cam_set_dlg->start_str != NULL) {
 					gtk_text_insert(GTK_TEXT(cam_set_dlg->start_text), 
 									NULL, // GdkFont    *font,
@@ -856,14 +914,15 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 									NULL, // GdkColor   *back,
 									cam_set_dlg->start_str, // const char *chars,
 									-1);  // gint        length );
-//					cam_set_dlg->start_str = NULL;
+					//cam_set_dlg->start_str = NULL;
 				}
 				gtk_widget_show(cam_set_dlg->start_text);
+				*/
 
 
 
 
-			/* ѥ졼(separator) */
+			/* セパレーター(separator) */
 			separator = gtk_hseparator_new();
 			gtk_box_pack_start( GTK_BOX(main_vbox), separator, TRUE, TRUE, 0);
 			gtk_widget_show(separator);
@@ -872,22 +931,64 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 
 
 
-			/* ѥå󥰥ܥå(end_vbox)  */
+			/* パッキングボックス(end_vbox) を作成 */
 			end_vbox = gtk_vbox_new(FALSE, 2);
 			gtk_box_pack_start( (GtkBox *)GTK_BOX(main_vbox), end_vbox, TRUE, TRUE, 0);
 			gtk_widget_show(end_vbox);
 
 				label = gtk_button_new_with_label(" End Code");
-//				gtk_widget_set_usize (label, 100, 20);
+//				gtk_widget_set_size_request(label, 100, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(end_vbox), label, TRUE, TRUE, 0);
 				gtk_widget_show(label);
 
-				/* ƥȥȥ꡼ */
+
+
+
+
+				// Create edit widget 
+				end_scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
+				gtk_widget_show(end_scrolledwindow) ;
+				// Container add to main window 
+				gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(end_scrolledwindow), 
+											   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+				gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(end_scrolledwindow), 
+													GTK_SHADOW_IN);
+				gtk_box_pack_start((GtkBox *)GTK_BOX(end_vbox), end_scrolledwindow, TRUE, TRUE, 1);
+				
+				
+				cam_set_dlg->end_text = gtk_text_view_new();
+				gtk_widget_show(cam_set_dlg->end_text);
+				gtk_container_add(GTK_CONTAINER(end_scrolledwindow), cam_set_dlg->end_text);
+				
+				/* 初期値設定 */
+				if (cam_set_dlg->end_str != NULL) {
+					GtkTextIter p, start, end ;
+					
+					GtkTextBuffer *textbuf = gtk_text_view_get_buffer((GtkTextView *)cam_set_dlg->end_text) ;
+					// Clear buffer 
+					gtk_text_buffer_get_start_iter ( textbuf, &start ) ;
+					gtk_text_buffer_get_end_iter ( textbuf, &end ) ;
+					gtk_text_buffer_delete ( textbuf, &start, &end ) ;
+					
+					gtk_text_buffer_insert (textbuf, &p, cam_set_dlg->end_str, -1) ;
+				}
+
+
+
+
+
+
+				
+				
+				
+				
+				/*
+				// テキストエントリー生成 
 				cam_set_dlg->end_text = gtk_text_new(NULL, NULL);
 				gtk_text_set_editable(GTK_TEXT(cam_set_dlg->end_text), TRUE);
-//				gtk_widget_set_usize (cam_set_dlg->up_scale_entry, 80, 20);
+				//gtk_widget_set_size_request(cam_set_dlg->up_scale_entry, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(end_vbox), cam_set_dlg->end_text, TRUE, TRUE, 1);
-				/*  */
+				// 初期値設定 
 				if (cam_set_dlg->end_str != NULL) {
 					gtk_text_insert(GTK_TEXT(cam_set_dlg->end_text), 
 									NULL, // GdkFont    *font,
@@ -895,11 +996,13 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 									NULL, // GdkColor   *back,
 									cam_set_dlg->end_str, // const char *chars,
 									-1);  // gint        length );
-//					cam_set_dlg->end_str = NULL;
+					//cam_set_dlg->end_str = NULL;
 				}
 				gtk_widget_show(cam_set_dlg->end_text);
-
-			/* ѥ졼(separator) */
+				*/
+				
+				
+			/* セパレーター(separator) */
 			separator = gtk_hseparator_new();
 			gtk_box_pack_start( GTK_BOX(main_vbox), separator, TRUE, TRUE, 0);
 			gtk_widget_show(separator);
@@ -908,34 +1011,34 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 
 
 
-			/* ѥå󥰥ܥå(action_hbox1) */
+			/* パッキングボックス(action_hbox1) */
 			action_hbox1 = gtk_hbox_new(FALSE, 2);
 			gtk_box_pack_start( GTK_BOX(main_vbox), action_hbox1, TRUE, TRUE, 0);
 			gtk_widget_show(action_hbox1);
 
 
 				/* -----------------------------------------------------
-				 * ѥå󥰥ܥå(action_hbox) 
-				 * ܥ(cancel_buttun & ok_buttun) 
-				 * Ǽ
+				 * パッキングボックス(action_hbox) に入れる
+				 * ボタン(cancel_buttun & ok_buttun) を作成し
+				 * 格納する
 				 */
-				/* condition_read ܥ */
+				/* condition_read ボタンの生成 */
 				condition_read_buttun = gtk_button_new_with_label("Read");
-				gtk_widget_set_usize (condition_read_buttun, 80, 20);
+				gtk_widget_set_size_request(condition_read_buttun, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox1), condition_read_buttun, TRUE, TRUE, 2);
-				gtk_signal_connect( GTK_OBJECT(condition_read_buttun), 
+				g_signal_connect( G_OBJECT(condition_read_buttun), 
 									"clicked", 
-									GTK_SIGNAL_FUNC(cam_set_dlg_condition_read_pushed), 
+									G_CALLBACK(cam_set_dlg_condition_read_pushed), 
 									cam_set_dlg);
 				gtk_widget_show(condition_read_buttun);
 
-				/* condition_write ܥ */
+				/* condition_write ボタンの生成 */
 				condition_write_buttun = gtk_button_new_with_label("Write");
-				gtk_widget_set_usize (condition_write_buttun, 80, 20);
+				gtk_widget_set_size_request(condition_write_buttun, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox1), condition_write_buttun, TRUE, TRUE, 2);
-				gtk_signal_connect( GTK_OBJECT(condition_write_buttun), 
+				g_signal_connect( G_OBJECT(condition_write_buttun), 
 									"clicked", 
-									GTK_SIGNAL_FUNC(cam_set_dlg_condition_write_pushed), 
+									G_CALLBACK(cam_set_dlg_condition_write_pushed), 
 									cam_set_dlg);
 				gtk_widget_show(condition_write_buttun);
 
@@ -943,51 +1046,47 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 
 
 
-			/* ѥå󥰥ܥå(action_hbox2) */
+			/* パッキングボックス(action_hbox2) */
 			action_hbox2 = gtk_hbox_new(FALSE, 2);
 			gtk_box_pack_start( GTK_BOX(main_vbox), action_hbox2, TRUE, TRUE, 0);
 			gtk_widget_show(action_hbox2);
 
 				/* -----------------------------------------------------
-				 * ѥå󥰥ܥå(action_hbox) 
-				 * ܥ(cancel_buttun & ok_buttun) 
-				 * Ǽ
+				 * パッキングボックス(action_hbox) に入れる
+				 * ボタン(cancel_buttun & ok_buttun) を作成し
+				 * 格納する
 				 */
-				/* CANCELܥ */
+				/* CANCELボタンの生成 */
 				cancel_buttun = gtk_button_new_with_label("CANCEL");
-				gtk_widget_set_usize (cancel_buttun, 80, 20);
+				gtk_widget_set_size_request(cancel_buttun, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox2), cancel_buttun, TRUE, TRUE, 2);
-				gtk_signal_connect( GTK_OBJECT(cancel_buttun), "clicked", GTK_SIGNAL_FUNC(cam_set_dlg_cancel_pushed), cam_set_dlg);
-				gtk_signal_connect( GTK_OBJECT(cancel_buttun), "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+				g_signal_connect( G_OBJECT(cancel_buttun), "clicked", 
+							G_CALLBACK(cam_set_dlg_cancel_pushed), cam_set_dlg);
+				g_signal_connect( G_OBJECT(cancel_buttun), "clicked", 
+							G_CALLBACK(gtk_main_quit), NULL);
 				gtk_widget_show(cancel_buttun);
 
-				/* OKܥ */
+				/* OKボタンの生成 */
 				ok_buttun = gtk_button_new_with_label("OK");
-				gtk_widget_set_usize (ok_buttun, 80, 20);
+				gtk_widget_set_size_request(ok_buttun, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox2), ok_buttun, TRUE, TRUE, 2);
-				gtk_signal_connect(GTK_OBJECT(ok_buttun), "clicked", GTK_SIGNAL_FUNC(cam_set_dlg_ok_pushed), cam_set_dlg);
-				gtk_signal_connect(GTK_OBJECT(ok_buttun), "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
-			//	  GTK_WIDGET_SET_FLAGS(ok_buttun, GTK_CAN_DEFAULT);
-			//	  gtk_widget_grab_default(ok_buttun);
+				g_signal_connect(G_OBJECT(ok_buttun), "clicked", G_CALLBACK(cam_set_dlg_ok_pushed), cam_set_dlg);
+				g_signal_connect(G_OBJECT(ok_buttun), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 				gtk_widget_show(ok_buttun);
 
 
 
 
 
-	/*  ե x_pitch_entry  */
+	/*  フォーカスを x_pitch_entry に設定 */
 //	gtk_window_set_focus(GTK_WINDOW(cam_set_dlg->dialog), cam_set_dlg->x_pitch_entry);
 
 
-	/* ̤ɽ */
-	gtk_window_set_modal(GTK_WINDOW(cam_set_dlg->dialog), TRUE);
-	/* ᥤ󥦥ɥǤʤ褦 */
-	gtk_window_set_transient_for(GTK_WINDOW(cam_set_dlg->dialog), GTK_WINDOW(cam_set_dlg->parent));
 
 
-	/* Ļ֤ */
+	/* ダイアログを可視状態へ */
 	gtk_widget_show(cam_set_dlg->dialog);
-	/* ᥤ󥤥٥ȥ롼 */
+	/* メインイベントループ */
 	gtk_main();
 	gtk_widget_destroy(cam_set_dlg->dialog);
 	return 0; 
@@ -998,7 +1097,7 @@ gint CamSetDialog(CAM_SET_DLG *cam_set_dlg)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : CamSetDlg.c
