@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/02/07
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/28
  * ====================================================================
  */
 
@@ -23,11 +23,11 @@
 
 #include <gtk/gtk.h>
 #include <unistd.h>
-#include <pwd.h>
+//#include <pwd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include <langinfo.h>
+//#include <langinfo.h>
 #include <iconv.h>
 
 #include <string.h>
@@ -49,7 +49,7 @@
 #include "toolbar.h"
 #include "Mouse.h"
 #include "etc.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "Ellipse.h"
 #include "sagcad.h"
 #include "Draw.h"
@@ -66,7 +66,6 @@
 #include "Dimension.h"
 #include "B_spline.h"
 #include "spline.h"
-#include "fileselect.h"
 #include "CopyFunc.h"
 #include "CopyDlg.h"
 #include "TurnDlg.h"
@@ -86,6 +85,10 @@
 #include "CulcInputDlg.h"
 #include "OutsideProcess.h"
 
+#ifdef G_OS_WIN32
+#  include <windows.h>
+#endif
+
 #define _COMMAND_
 #include "Command.h"
 
@@ -94,148 +97,17 @@
 
 
 /* -------------------------------------------------------------------
- * ƥ key 't' 
+ * テスト用 key 't' に設定
  */
 void test(void)
 {
-	char str[256], command[256];
-	char *envvalue;
-	int Ret, lang, language = 0;
-
-
-	iconv_t cd;
-	char *inbuf, *outbuf, *inptr, *outptr;
-	size_t inbyteleft, outbyteleft, ret;
-
-
-	g_print("CODE is %s\n", nl_langinfo(CODESET));
-
-	strcpy(str, " ë yutaka");
-
-	inbuf = strdup(str);
-	inbyteleft = strlen(inbuf);
-	outbuf = malloc(inbyteleft * 4 + 1);
-	outbyteleft = inbyteleft * 4;
-
-
-	inbyteleft = strlen(inbuf)+1;
-
-
-	if (!outbuf) {
-		g_print("error in malloc\n");
-	return;
-	}
-
-	outptr = outbuf;
-	inptr = inbuf;
-
-//	cd = iconv_open("UTF-16BE", nl_langinfo(CODESET));
-	cd = iconv_open("UTF-16", nl_langinfo(CODESET));
-	if ((iconv_t)(-1) == cd) {
-		g_print("error in iconv_open\n");
-	return;
-	}
-
-	ret = iconv(cd, &inptr, &inbyteleft, &outptr, &outbyteleft);
-	g_print("ret = %d\n", ret);
-	if ((size_t)(-1) != ret) {
-		ret = iconv(cd, NULL, NULL, &outptr, &outbyteleft);
-		g_print("ret = %d\n", ret);
-	}
-
-	g_print("outbuf = %s(%d)\n", outbuf, outbyteleft);
-	g_print("[0x%x]  ", outbuf[0]);
-	g_print("[0x%x]  ", outbuf[1]);
-	g_print("[0x%x]  ", outbuf[2]);
-	g_print("[0x%x]  ", outbuf[3]);
-	g_print("[0x%x]  ", outbuf[4]);
-	g_print("[0x%x]  ", outbuf[5]);
-	g_print("[0x%x]  ", outbuf[6]);
-	g_print("[0x%x]  ", outbuf[7]);
-	g_print("[0x%x]  ", outbuf[8]);
-	g_print("[0x%x]  ", outbuf[9]);
-	g_print("[0x%x]  ", outbuf[10]);
-	
-	iconv_close(cd);
-//	return;
-
-
-
-
-	/* getenv */
-	envvalue = getenv("LANGUAGE");
-	if (envvalue != NULL) {
-		language = 1;
-		sprintf(command, "OLD LANGUAGE = %s", envvalue);
-	}
-	else {
-		envvalue = getenv("LANG");
-		if (envvalue != NULL) {
-			language = 0;
-			sprintf(command, "OLD LANG = %s", envvalue);
-		}
-		else {
-			sprintf(command, "OLD LANG = No Setting");
-		}
-	}
-
-
-
-	strcpy(str, "1");
-	Ret = InputBox("locale set", command, "1:ja_JP.eucJP  2:C  3:de", str);
-	if (Ret == 1) {
-		lang = atoi(str);
-		if (lang == 1) {
-			strcpy(str, "ja_JP.eucJP");
-		}
-		else if (lang == 2) {
-			strcpy(str, "C");
-		}
-		else if (lang == 3) {
-			strcpy(str, "de_DE@euro");
-		}
-		else {
-			strcpy(str, "C");
-		}
-
-		/* putenv */
-		if (language  == 1) {
-			sprintf(command, "LANG=%s", str);
-		}
-		else if (language  == 0) {
-			sprintf(command, "LANGUAGE=%s", str);
-		}
-		else {
-			return;
-		}
-
-		putenv(command);
-
-
-
-		/* getenv */
-		envvalue = getenv("LANGUAGE");
-		if (envvalue != NULL) {
-			MsgBox("SagCAD", "LANGUAGE", envvalue, NULL, NULL, "OK");
-		}
-		else {
-			envvalue = getenv("LANG");
-			if (envvalue != NULL) {
-				language = 0;
-				MsgBox("SagCAD", "LANG", envvalue, NULL, NULL, "OK");
-			}
-			else {
-				MsgBox("SagCAD", "LANG", "No Setting", NULL, NULL, "OK");
-			}
-		}
-	}
 	return;
 }
 
 
 
 /* ---------------------------------------------------------
- *  (Outside Proces)
+ * 外部処理 (Outside Proces)
  * 
  */
 void cmd_outside_process(void)
@@ -247,7 +119,7 @@ void cmd_outside_process(void)
 
 
 /* ---------------------------------------------------------
- * ʱߺ
+ * 楕円作図
  * 
  */
 void cmd_Ellipse_Draw(void)
@@ -282,10 +154,10 @@ void cmd_Ellipse_Draw(void)
 
 #ifdef TEST
 	if (ellipse_set_dlg.value == 0) {
-		g_print("Cancel ޤ\n");
+		g_print("Cancel されました\n");
 	}
 	else {
-		g_print ("濴(%f,%f) L = %f   S = %f   angle = %f   sa = %f   ea = %f\n", 
+		g_print ("中心(%f,%f) L = %f   S = %f   angle = %f   sa = %f   ea = %f\n", 
 				 ellipse_set_dlg.cx, 
 				 ellipse_set_dlg.cy, 
 				 ellipse_set_dlg.long_r, 
@@ -308,7 +180,7 @@ void cmd_Ellipse_Draw(void)
 	ellipse.ea = ellipse_set_dlg.ea;
 
 	/* -------------------------------------------------------------------
-	 * pap : [6] ȳ٤ȵΥľν
+	 * pap : [6] 始点と角度と距離で直線の終点を求める
 	 */
 	PAPH.sx[1] = ellipse_set_dlg.cx;
 	PAPH.sy[1] = ellipse_set_dlg.cy;
@@ -332,7 +204,7 @@ void cmd_Ellipse_Draw(void)
 
 
 /* ---------------------------------------------------------
- * 
+ * 印刷設定
  * 
  */
 void cmd_print_set(void)
@@ -386,7 +258,7 @@ void cmd_print_set(void)
 
 
 /* ---------------------------------------------------------
- *  (ID_PRINT)
+ * 印刷 (ID_PRINT)
  *	
  */
 void cmd_print(void)
@@ -396,7 +268,7 @@ void cmd_print(void)
 	int Ret;
 
 #ifdef TEST
-	Ret = MsgBox("ps or eps", "ps File Ǥ", "Ȥ eps FileǤ", "ps", "eps", "CANCEL");
+	Ret = MsgBox("ps or eps", "ps File ですか", "それとも eps Fileですか", "ps", "eps", "CANCEL");
 	
 	/* ps */
 	if (Ret == 1) {
@@ -418,12 +290,12 @@ void cmd_print(void)
 
 	sprintf(str, "%s/NoName.ps", sagcad_user.CadPath);
 	Ret = save_file_name_get(str);
-	/* ե򥭥󥻥 */
-	if (Ret == 0 || str == NULL) {
+	/* ファイルの選択をキャンセル */
+	if (Ret == -1 || str == NULL) {
 		//g_print("save_file : str = NULL\n");
 		return;
 	}
-	if (Ret == 1 && str != NULL){
+	if (Ret == 0 && str != NULL){
 		PostScript(str);
 	}
 
@@ -447,14 +319,14 @@ void cmd_print(void)
 
 #ifdef OLD
 	sprintf(command,  _("The file saved. [%s]\n") , str);
-	Ret = MsgBox(" / GhostView", command,  _("Which does it execute?") , "GhostView",  _("Print") , "λ");
+	Ret = MsgBox("印刷 / GhostView", command,  _("Which does it execute?") , "GhostView",  _("Print") , "終了");
 
 	/* GhostView */
 	if (Ret == 1) {
 		sprintf(command, "ghostview %s &", str);
 		system(command);
 	}
-	/*  */
+	/* 印刷 */
 	else if (Ret == 0) {
 		sprintf(command, "lpr %s &", str);
 		system(command);
@@ -467,7 +339,7 @@ void cmd_print(void)
 
 
 /* -------------------------------------------------------------------
- * Ϣ³
+ * 連続線
  */
 void cmd_polyline(void)
 {
@@ -483,7 +355,7 @@ void cmd_polyline(void)
 
 
 /* -------------------------------------------------------------------
- * 쥤䡼
+ * レイヤー設定
  */
 void cmd_LayerSet(void)
 {
@@ -499,20 +371,22 @@ void cmd_LayerSet(void)
 	layerset_dlg.parent = MainWindow;
 	layerset_dlg.dialog = NULL;
 
+	//g_print("LayerSetDialog() : START !\n");
 	LayerSetDialog(&layerset_dlg);
-
+	//g_print("LayerSetDialog() : END !\n");
+	
 	return;
 }
 
 
 
 /* -------------------------------------------------------------------
- * Help ɽ
+ * Help 表示
  */
 void cmd_help(void)
 {
 	FILE *stream;
-	char str[256], path[256], BrowserPath[256];
+	char str[256], path[256], *command, BrowserPath[256];
 
 	char *envvalue, str_locale[256];
 
@@ -621,16 +495,38 @@ void cmd_help(void)
 		strcpy(str_locale, "ja");
 	}
 
-	/* إץեѥǧ */
+	/* ヘルプファイルパス確認 */
 	strcpy(path, DOCDIR);
 	sprintf(str, "%s/%s/index.html", path, str_locale);
+	g_print("search 1 %s\n", str);
 	if ( (stream  = fopen( str, "r" )) == NULL ) {
-		//g_print("إץե [ %s ] ʤ\n", str);
-		MsgBox("SagCAD", _("Can't Find Help File.") , str, "OK", NULL, NULL);
-		return;
+		g_print("Can't Find Help File. 1 [ %s ] \n", str);
+		
+		/* ../doc/locale/ (インストールしないとき用) */
+		sprintf(str, "../doc/%s/index.html", str_locale);
+		g_print("search 2 %s\n", str);
+		if ( (stream  = fopen( str, "r" )) == NULL ) {
+			g_print("Can't Find Help File. 2 [ %s ] \n", str);
+			
+			/* カレント */
+			sprintf(str, "./%s/index.html", str_locale);
+			g_print("search 3 %s\n", str);
+			if ( (stream  = fopen( str, "r" )) == NULL ) {
+				g_print("Can't Find Help File. 3 [ %s ] \n", str);
+				MsgBox("SagCAD", _("Can't Find Help File.") , str, "OK", NULL, NULL);
+				return;
+			}
+		}
 	}
 	fclose(stream);
+	g_print("Help file find. [%s]\n", str);
 
+#ifdef G_OS_WIN32
+	strcpy(path, str);
+	command = g_locale_from_utf8(path, -1, NULL, NULL, NULL);
+	ShellExecute(0, "Open", command, "", "", 1); 	
+	g_free(command);
+#else
 
 	strcpy(path, sagcad_user.browser_command);
 	replace(path, "&", "");
@@ -647,12 +543,13 @@ void cmd_help(void)
 	if ( system(BrowserPath) ) {
 		MsgBox("SagCAD", _("Can't Open Browser.") , _("The path setting will be how.") , "OK", NULL, NULL);
 	}
+#endif
 }
 
 
 
 /* ---------------------------------------------------------
- * Ķ
+ * 環境設定
  */
 void cmd_env_set(void)
 {
@@ -787,10 +684,10 @@ void cmd_env_set(void)
 	envset_dlg.dialog = NULL;
 
 
-	/* Ķɽ */
+	/* 環境設定ダイアログ表示 */
 	EnvSetDialog(&envset_dlg);
-	if (envset_dlg.Value == 0) {
-		return;	// 0:CANCEL  1:OK
+	if (envset_dlg.Value == -1) {
+		return;	// -1:CANCEL  0:OK
 	}
 
 
@@ -868,7 +765,7 @@ void cmd_env_set(void)
 
 
 /* -------------------------------------------------------------------
- * ޤǤƤʤɽ
+ * まだできてない表示
  */
 void not_make(void)
 {
@@ -879,7 +776,7 @@ void not_make(void)
 
 
 /* -------------------------------------------------------
- * SagCAD νλ
+ * SagCAD の終了
  */
 void cmd_end(void)
 {
@@ -903,7 +800,7 @@ void cmd_end(void)
 	}
 
 	ending();
-	gtk_exit(0); 
+	gtk_main_quit(); 
 }
 
 
@@ -911,12 +808,12 @@ void cmd_end(void)
 
 
 /* =====================================================================
- * << ɽ >>
+ * << 設定表示＆入力 >>
  * =====================================================================
  */
 
 /* -------------------------------------------------------
- * Ψ(Mag)
+ * 倍率(Mag)の設定
  */
 void mag_box_click(GtkWidget *widget, GtkWidget *data)
 {
@@ -925,9 +822,9 @@ void mag_box_click(GtkWidget *widget, GtkWidget *data)
 	int Ret;
 
 	dbl=Mag;
-	FloatOut6(str, dbl, 0); /* () */
+	FloatOut6(str, dbl, 0); /* 数値(小数点)出力用 */
 	Ret = InputBox( _("Setting of magnification") , _("Input a magnification.") , _("(0 is hopeless!)"), str);
-	if(Ret == 1) {
+	if (Ret != -1) {
 		dbl = atof(str);
 		if(dbl == 0) {
 			MsgBox("SagCAD", "Error", _("It is impossible to set 0.") , NULL, NULL, "OK");
@@ -942,7 +839,7 @@ void mag_box_click(GtkWidget *widget, GtkWidget *data)
 
 
 /* -------------------------------------------------------
- * filletRC 
+ * filletRC の設定
  */
 void fillet_box_click(GtkWidget *widget, GtkWidget *data)
 {
@@ -951,9 +848,9 @@ void fillet_box_click(GtkWidget *widget, GtkWidget *data)
 	int Ret;
 
 	dbl=sagcad_system.FilletRC;
-	FloatOut6(str, dbl, 0); /* () */
+	FloatOut6(str, dbl, 0); /* 数値(小数点)出力用 */
 	Ret = InputBox("R or C", _("Set R of Fillet.") , _("Or Set C of Chamfer.") , str);
-	if(Ret == 1) {
+	if(Ret != -1) {
 		dbl = atof(str);
 		if(dbl == 0) {
 			MsgBox("SagCAD", "Error", _("It is impossible to set 0.") , NULL, NULL, "OK");
@@ -963,7 +860,7 @@ void fillet_box_click(GtkWidget *widget, GtkWidget *data)
 			sagcad_system.FilletRC = dbl;
 			FloatOut(str, dbl, 0);
 			sprintf(DumyStr," R %s ",str);
-			gtk_label_set(GTK_LABEL(fillet), DumyStr);
+			gtk_label_set_text(GTK_LABEL(fillet), DumyStr);
 		}
 	}
 }
@@ -971,7 +868,7 @@ void fillet_box_click(GtkWidget *widget, GtkWidget *data)
 
 
 /* -------------------------------------------------------
- * length 
+ * length の設定
  */
 void length_box_click(GtkWidget *widget, GtkWidget *data)
 {
@@ -980,9 +877,9 @@ void length_box_click(GtkWidget *widget, GtkWidget *data)
 	int Ret;
 
 	dbl = sagcad_system.Length;
-	FloatOut6(str, dbl, 0); /* () */
+	FloatOut6(str, dbl, 0); /* 数値(小数点)出力用 */
 	Ret = InputBox( _("Basic Length Setting") , " ", _("Input basic length.") , str);
-	if(Ret == 1) {
+	if(Ret != -1) {
 		dbl = atof(str);
 		if(dbl == 0) {
 			MsgBox("SagCAD", "Error", _("It is impossible to set 0.") , NULL, NULL, "OK");
@@ -992,7 +889,7 @@ void length_box_click(GtkWidget *widget, GtkWidget *data)
 			sagcad_system.Length = atof(str);
 			FloatOut(str, sagcad_system.Length, 0);
 			sprintf(DumyStr," L %s ",str);
-			gtk_label_set(GTK_LABEL(length), DumyStr);
+			gtk_label_set_text(GTK_LABEL(length), DumyStr);
 			dbl = sagcad_system.Length;
 		}
 	}
@@ -1001,7 +898,7 @@ void length_box_click(GtkWidget *widget, GtkWidget *data)
 
 
 /* -------------------------------------------------------
- * ScrollPitch 
+ * ScrollPitch の設定
  */
 void scroll_pitch_box_click(GtkWidget *widget, GtkWidget *data)
 {
@@ -1010,9 +907,9 @@ void scroll_pitch_box_click(GtkWidget *widget, GtkWidget *data)
 	int Ret;
 
 	dbl = sagcad_system.ScrollPitch;
-	FloatOut6(str, dbl, 0); /* () */
+	FloatOut6(str, dbl, 0); /* 数値(小数点)出力用 */
 	Ret = InputBox( _("Scroll Pitch Setting") , "", _("Input Scroll Pitch") , str);
-	if(Ret == 1) {
+	if(Ret != -1) {
 		dbl = atof(str);
 		if(dbl==0) {
 			MsgBox("SagCAD", "Error", _("It is impossible to set 0.") , NULL, NULL, "OK");
@@ -1022,7 +919,7 @@ void scroll_pitch_box_click(GtkWidget *widget, GtkWidget *data)
 			sagcad_system.ScrollPitch = atof(str);
 			FloatOut(str, sagcad_system.ScrollPitch, 0);
 			sprintf(DumyStr," SP %s ",str);
-			gtk_label_set(GTK_LABEL(scroll_pitch), DumyStr);
+			gtk_label_set_text(GTK_LABEL(scroll_pitch), DumyStr);
 			dbl = sagcad_system.ScrollPitch;
 		}
 	}
@@ -1033,7 +930,7 @@ void scroll_pitch_box_click(GtkWidget *widget, GtkWidget *data)
 
 
 /* -------------------------------------------------------------------
- * ⡼ɥ󥻥
+ * モードキャンセル
  */
 void cmd_all_cancel(void)
 {
@@ -1049,7 +946,7 @@ void cmd_all_cancel(void)
 
 
 /* -------------------------------------------------------------------
- * С
+ * バージョン情報
  */
 void cmd_version(void)
 {
@@ -1059,45 +956,80 @@ void cmd_version(void)
 
 
 /* -------------------------------------------------------------------
- * ¸ǡե̾
+ * 保存データファイル名の選択
  * 
  */
 int save_file_name_get(char *save_filename)
 {
-	char *str;
-
-	str = GetFilename ( _("Save") , save_filename);
-	if (str == NULL) {
-		save_filename = NULL;
-		//g_print("save_file_name_get : Get FileName = NULL\n");
-		return 0;
+	GtkWidget *dialog;
+	char path[1024];
+	gint ret = -1;
+	
+	dialog = gtk_file_chooser_dialog_new ("Save File",
+						NULL,
+						GTK_FILE_CHOOSER_ACTION_SAVE,
+						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+						NULL);
+	
+#if GTK_CHECK_VERSION(2,8,0)
+ 	// GTK >= 2.8 code...
+ 	g_print("GTK >= 2.8\n");
+	gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
+#else
+	// GTK < 2.8 code...
+ 	g_print("GTK < 2.8\n");
+#endif
+	//gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
+	
+	
+	strcpy(path, save_filename);
+	cutFileName(path);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), path);
+	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), getFileName(save_filename));
+	
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+		char *filename;
+		
+		/* filename (UTF-8) */
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		strcpy (save_filename, filename);
+		g_free (filename);
+		ret = 0;
 	}
-
-	strcpy (save_filename, str);
-	//g_print("save_file_name_get : Get FileName = [%s]\n", save_filename);
-	return 1;
+	gtk_widget_destroy (dialog);
+	return ret;
 }
 
 
 
 /* -------------------------------------------------------------------
- * ɤ߹ߥǡե̾
+ * 読み込みデータファイル名の選択
  * 
  */
 int read_file_name_get(char *read_filename)
 {
-	char *str;
-
-	str = GetFilename ( _("Read") , read_filename);
-	if (str == NULL) {
-		read_filename = NULL;
-		//g_print("read_file_name_get : Get FileName = NULL\n");
-		return 0;
+	GtkWidget *dialog;
+	gint ret = -1;
+	
+	dialog = gtk_file_chooser_dialog_new ("Open File",
+						NULL,
+						GTK_FILE_CHOOSER_ACTION_OPEN,
+						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+						NULL);
+	
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+		char *filename;
+		
+		/* filename (UTF-8) */
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		strcpy(read_filename, filename);
+		g_free (filename);
+		ret = 0;
 	}
-
-	strcpy (read_filename, str);
-	//g_print("read_file_name_get : Get FileName = [%s]\n", read_filename);
-	return 1;
+	gtk_widget_destroy (dialog);
+	return ret;
 }
 
 
@@ -1105,85 +1037,90 @@ int read_file_name_get(char *read_filename)
 
 
 /* =====================================================================
- * << ե >>
+ * << ファイル >>
  * =====================================================================
  */
 
-/* ̥ե򳫤 */
+/* 図面ファイルを開く */
 void cmd_open(void)
 {
 	char str[256], check_str[256], msg[256];
 	int Ret;
-
-
+	char *locale_str;
+	
 	if (Undo_index != 0) {
-		//                                                                          1     0        -1
 		Ret = MsgBox("SagCAD", _("A drawing is changed!") , _("Does it save?") , "Yes", "No", "Cancel");
-		/* Yes : (Save) */
-		if (Ret == 1) {
-			cmd_save();
-		}
-		/* No : (No Save) */
-		else if (Ret == 0) {
-		}
-		/* Cancel : (return) */
-		else {
-			return;
-		}
+		if (Ret == 1) cmd_save();		/* Yes : (Save) */
+		else if (Ret == -1) return;		/* Cancel : (return) */
 	}
-
-	sprintf(check_str, "%s/NoName.dxf", sagcad_user.CadPath);
+	
+	sprintf(check_str, "%s/Untitled.sgy", sagcad_user.CadPath);
 	if (strcmp(check_str, NowFile) == 0) {
 		sprintf (str, "%s/", sagcad_user.CadPath);
 	}
 	else {
 		strcpy (str, NowFile);
 	}
-
-
+	
+	
 	Ret = read_file_name_get(str);
-	/* ե򥭥󥻥 */
-	if (Ret == 0) {
+	/* ファイルの選択をキャンセル */
+	if (Ret == -1) {
+		g_print("File select cancel !\n");
 		return;
 	}
-	if (Ret == 1 && str != NULL){
+	g_print("File select OK !\n");
+	if (str == NULL) g_print("str == NULL !\n");
+	
+	
+	if (Ret == 0 && str != NULL){
 		if (strstr(str, ".sgy") != NULL || strstr(str, ".SGY") != NULL) {
-
-//			StartData = NULL;
 			cad_list_all_free(&cad_list_info);
 			dimension_list_all_free(&dimension_list_info);
 			polyline_list_all_free(&polyline_list_info);
 			insert_list_all_free(&insert_list_info);
 			block_list_all_free(&block_list_info);
-			/* ɥ */
+			/* アンドゥを削除 */
 			undo_list_all_free();
 
-			sprintf(msg, "Reading SGY       ");
+			sprintf(msg, "Reading SGY       ■□□□□□□");
 			StatusMsg(msg);
 			UpDate_widget(MainWindow);
-			sgyFileOpen(str);
+			
+			locale_str = g_locale_from_utf8(str, -1, NULL, NULL, NULL);
+			if (locale_str == NULL) {
+				g_print("cmd_open() : g_locale_from_utf8 error !\n");
+				return;
+			}
+			strcpy(NowFile, str);
+			sgyFileOpen(locale_str);
 		}
 		else if(strstr(str, ".dxf") != NULL || strstr(str, ".DXF") != NULL) {
-
-//			StartData = NULL;
 			cad_list_all_free(&cad_list_info);
 			dimension_list_all_free(&dimension_list_info);
 			polyline_list_all_free(&polyline_list_info);
 			ellipse_list_all_free(&ellipse_list_info);
 			insert_list_all_free(&insert_list_info);
 			block_list_all_free(&block_list_info);
-			/* ɥ */
+			/* アンドゥを削除 */
 			undo_list_all_free();
 
-			sprintf(msg, "Reading DXF       ");
+			sprintf(msg, "Reading DXF       ■□□□□□□");
 			StatusMsg(msg);
 			//g_print("%s\n", msg);
 			UpDate_widget(MainWindow);
-			Ret = DxfFileOpen(str, 0, 0);
+			
+			locale_str = g_locale_from_utf8(str, -1, NULL, NULL, NULL);
+			if (locale_str == NULL) {
+				g_print("cmd_open() : g_locale_from_utf8 error !\n");
+				return;
+			}
+			strcpy(NowFile, str);
+			Ret = DxfFileOpen(locale_str, 0, 0);
 		}
 
-		strcpy(NowFile, str);
-		/* ȥ */
+		//strcpy(NowFile, str);
+		/* タイトルを設定 */
 		SetTitle(NowFile);
 		undo_buttun(0);
 		redo_buttun(0);
@@ -1201,9 +1138,10 @@ void cmd_open(void)
 
 
 
-/* ̤ե¸ */
+/* 図面をファイルに保存 */
 void cmd_rename(void)
 {
+	char *locale_str;
 	char str[256];
 	int Ret;
 
@@ -1225,30 +1163,34 @@ void cmd_rename(void)
 
 	strcpy (str, NowFile);
 	Ret = save_file_name_get(str);
-	/* ե򥭥󥻥 */
-	if (Ret == 0) {
+	/* ファイルの選択をキャンセル */
+	if (Ret == -1) {
 		//g_print("save_file : str = NULL\n");
 		return;
 	}
-	if(Ret == 1 && str != NULL){
+	if(Ret == 0 && str != NULL){
+		locale_str = g_locale_from_utf8(str, -1, NULL, NULL, NULL);
+		if (locale_str == NULL) {
+			return;
+		}
 		if (strstr(str, ".sgy") != NULL || strstr(str, ".SGY") != NULL) {
-			sgyFileSave(str);
+			sgyFileSave(locale_str);
 		}
 		else if(strstr(str, ".igs") != NULL || strstr(str, ".IGS") != NULL) {
-			igesFileSave(str);
+			igesFileSave(locale_str);
 		}
 		else if(strstr(str, ".dxf") != NULL || strstr(str, ".DXF") != NULL) {
-			DxfFileSave(str);
+			DxfFileSave(locale_str);
 		}
 
 		strcpy(NowFile, str);
-		/* ȥ */
+		/* タイトルを設定 */
 		SetTitle(NowFile);
 
 		undo_buttun(0);
 		redo_buttun(0);
 
-		/* ɥ */
+		/* アンドゥを削除 */
 		undo_list_all_free();
 	}
 	return;
@@ -1256,28 +1198,33 @@ void cmd_rename(void)
 
 
 
-/* ¸ */
+/* 上書き保存 */
 void cmd_save(void)
 {
+	char *locale_str;
 	char str[256];
 
 
 	strcpy (str, NowFile);
+	locale_str = g_locale_from_utf8(str, -1, NULL, NULL, NULL);
+	if (locale_str == NULL) {
+		return;
+	}
 	if(str != NULL){
 		if (strstr(str, ".sgy") != NULL || strstr(str, ".SGY") != NULL) {
-			sgyFileSave(str);
+			sgyFileSave(locale_str);
 		}
 		else if(strstr(str, ".igs") != NULL || strstr(str, ".IGS") != NULL) {
-			igesFileSave(str);
+			igesFileSave(locale_str);
 		}
 		else if(strstr(str, ".dxf") != NULL || strstr(str, ".DXF") != NULL) {
-			DxfFileSave(str);
+			DxfFileSave(locale_str);
 		}
 
-		/* ɥ */
+		/* アンドゥを削除 */
 		undo_list_all_free();
 
-		/* ȥ */
+		/* タイトルを設定 */
 		SetTitle(NowFile);
 
 		undo_buttun(0);
@@ -1289,7 +1236,7 @@ void cmd_save(void)
 
 
 
-/* ޷ */ 
+/* 選択図形削除 */ 
 void cmd_delete(void)
 {
 	if (select_list_info.head == NULL) {
@@ -1301,7 +1248,7 @@ void cmd_delete(void)
 
 
 
-/* ޷󥻥 */ 
+/* 選択図形キャンセル */ 
 void cmd_cancel(void)
 {
 	SelectCancel(drawing_area);
@@ -1309,7 +1256,7 @@ void cmd_cancel(void)
 
 
 
-/* 쥤䡼ư */ 
+/* レイヤー移動 */ 
 void cmd_layer_move(void)
 {
 	if (select_list_info.head == NULL) {
@@ -1322,7 +1269,7 @@ void cmd_layer_move(void)
 
 
 
-/* 쥤䡼ʣ */ 
+/* レイヤー複写 */ 
 void cmd_layer_copy(void)
 {
 	if (select_list_info.head == NULL) {
@@ -1335,7 +1282,7 @@ void cmd_layer_copy(void)
 
 
 
-/* ѹ */ 
+/* 線種変更 */ 
 void cmd_line_style_change(void)
 {
 	Change_Line_Style();
@@ -1363,10 +1310,10 @@ int cmd_view(GtkWidget *widget, GdkEventButton *event, gint i)
 
 
 
-/* View 0 - 5  */
+/* View 0 - 5 の制御 */
 void view_func(int save0_or_view1, int number)
 {
-	/* ɽξ֤¸ */
+	/* 表示の状態を保存 */
 	if (save0_or_view1 == 0)
 	{
 		GamenMag[number]  = Mag;
@@ -1376,7 +1323,7 @@ void view_func(int save0_or_view1, int number)
 		return;
 	}
 
-	/* ɽξ֤ */
+	/* 表示の状態を復元 */
 	else 
 	{
 		Mag = GamenMag[number];
@@ -1384,7 +1331,7 @@ void view_func(int save0_or_view1, int number)
 		MagY = GamenMagY[number];
 //		g_print("Mag = %f\n", Mag);
 		SetMag(Mag);
-		/*  */
+		/* 再描画 */
 		Redraw();
 		return;
 	}
@@ -1392,7 +1339,7 @@ void view_func(int save0_or_view1, int number)
 
 
 
-/* 濴 */
+/* 中心設定 */
 void cmd_center(void)
 {
 	char str[256];
@@ -1406,7 +1353,7 @@ void cmd_center(void)
 
 
 /* -------------------------------------------------------------------
- *  
+ * 選択 
  */
 void cmd_select(void)
 {
@@ -1437,13 +1384,13 @@ void cmd_select(void)
 
 
 /* -------------------------------------------------------------------
- * ϰ
+ * 範囲選択
  */
 void cmd_rect_select(void)
 {
 	if (outside_process_on == 1) {
 		if (outside_process.Work[outside_process.now].work == OPS_SELECT_ONE) {
-			MsgBox("SagCADOutside Process", 
+			MsgBox("SagCAD　Outside Process", 
 				   _("Now SELECT ONE Mode") , 
 				   _("So this feature Can't use Now.") , NULL, NULL, "OK");
 			return;
@@ -1476,13 +1423,13 @@ void cmd_rect_select(void)
 
 
 /* =====================================================================
- * <<  >>
+ * << 作図 >>
  * =====================================================================
  */
 
 
 /* -------------------------------------------------------------------
- * 
+ * 作図
  */
 void cmd_draw(void)
 {
@@ -1498,24 +1445,24 @@ void cmd_draw(void)
 
 
 /* -------------------------------------------------------------------
- * 
+ * チェイン
  */
 void cmd_select_chain(void)
 {
 	SelectChainFrag = 1;
 	SelectColorFrag = 0;
 
-	/* ߣİʾ奻쥯ȤƤ */
+	/* 現在２個以上セレクトされている */
 	if (select_list_info.tail != NULL) {
 		OP_SelectList = select_list_info.tail;
 	}
 
-	/* ߣĥ쥯ȤƤ */
+	/* 現在１個セレクトされている */
 	else if (select_list_info.head != NULL) {
 		OP_SelectList = select_list_info.head;
 	}
 
-	/* ߣĤ⥻쥯ȤƤʤ */
+	/* 現在１個もセレクトされていない */
 	else if (select_list_info.head == NULL) {
 		OP_SelectList = NULL;
 	}
@@ -1526,24 +1473,24 @@ void cmd_select_chain(void)
 
 
 /* -------------------------------------------------------------------
- * ɮ
+ * 一筆チェイン
  */
 void cmd_select_chain2(void)
 {
 	SelectChainFrag = 2;
 	SelectColorFrag = 0;
 
-	/* ߣİʾ奻쥯ȤƤ */
+	/* 現在２個以上セレクトされている */
 	if (select_list_info.tail != NULL) {
 		OP_SelectList = select_list_info.tail;
 	}
 
-	/* ߣĥ쥯ȤƤ */
+	/* 現在１個セレクトされている */
 	else if (select_list_info.head != NULL) {
 		OP_SelectList = select_list_info.head;
 	}
 
-	/* ߣĤ⥻쥯ȤƤʤ */
+	/* 現在１個もセレクトされていない */
 	else if (select_list_info.head == NULL) {
 		OP_SelectList = NULL;
 	}
@@ -1554,7 +1501,7 @@ void cmd_select_chain2(void)
 
 
 /* -------------------------------------------------------------------
- * 顼
+ * カラー
  */
 void cmd_select_color(void)
 {
@@ -1573,7 +1520,7 @@ void cmd_select_color(void)
 
 
 /* -------------------------------------------------------------------
- * ȥ
+ * 片方トリム
  */
 void cmd_trim(void)
 {
@@ -1589,7 +1536,7 @@ void cmd_trim(void)
 
 
 /* -------------------------------------------------------------------
- * ξȥ
+ * 両方トリム
  */
 void cmd_both_trim(void) 
 {
@@ -1605,7 +1552,7 @@ void cmd_both_trim(void)
 
 
 /* -------------------------------------------------------------------
- * ʬ
+ * 分割
  */
 void cmd_split(void) 
 {
@@ -1621,7 +1568,7 @@ void cmd_split(void)
 
 
 /* -----------------------------------------------------------------------
- * եå
+ * フィレット
  */
 void cmd_fillet(void)
 {
@@ -1637,7 +1584,7 @@ void cmd_fillet(void)
 
 
 /* -------------------------------------------------------------------
- * ̼
+ * Ｃ面取り
  */
 void cmd_Chamfering(void)
 {
@@ -1653,7 +1600,7 @@ void cmd_Chamfering(void)
 
 
 /* -------------------------------------------------------------------
- * Ϣ³
+ * 連続線
  */
 void cmd_cont_line(void)
 {
@@ -1669,7 +1616,7 @@ void cmd_cont_line(void)
 
 
 /* -------------------------------------------------------------------
- * Ǳ
+ * ３点で円
  */
 void cmd_3point(void)
 {
@@ -1685,7 +1632,7 @@ void cmd_3point(void)
 
 
 /* -------------------------------------------------------------------
- * դǱ
+ * ３辺で円
  */
 void cmd_3line(void)
 {
@@ -1701,7 +1648,7 @@ void cmd_3line(void)
 
 
 /* -------------------------------------------------------------------
- * ɸ
+ * 点座標入力
  */
 void cmd_point(void)
 {
@@ -1713,19 +1660,19 @@ void cmd_point(void)
 
 
 	while(1) {
-		/* ϥܥåɽ */
+		/* 数値入力ダイアログボックス表示 */
 //		plaX = 100;
 //		plaY = 105;
 		Ret = InputBox( _("Make Point - Input Coordinates") , _("Input the coordinates of X.") , "", str);
 		if (Ret == -1) return;
 		x = atof(str);
 
-		/* ϥܥåɽ */
+		/* 数値入力ダイアログボックス表示 */
 		Ret = InputBox( _("Make Point - Input Coordinates") , _("Input the coordinates of Y") , "", str);
 		if (Ret == -1) return;
 		y = atof(str);
 
-		/* ǡϿ */
+		/* 点データを登録 */
 		cad.code = 0;
 		cad.layer = NowLayer;
 		cad.style = NowStyle;
@@ -1748,7 +1695,7 @@ void cmd_point(void)
 
 
 
-/*  */
+/* 再描画 */
 void cmd_redraw(void)
 {
 	Redraw();
@@ -1758,7 +1705,7 @@ void cmd_redraw(void)
 
 
 /* -------------------------------------------------------------------
- * ʿ
+ * 平行
  */
 void cmd_parallel_copy(void)
 {
@@ -1778,7 +1725,7 @@ void cmd_parallel_copy(void)
 
 
 /* -------------------------------------------------------------------
- * ž
+ * 回転
  */
 void cmd_turn(void)
 {
@@ -1798,7 +1745,7 @@ void cmd_turn(void)
 
 
 /* -------------------------------------------------------------------
- * о
+ * 対称
  */
 void cmd_mirr(void)
 {
@@ -1818,7 +1765,7 @@ void cmd_mirr(void)
 
 
 /* -------------------------------------------------------------------
- * 
+ * スケーリング
  */
 void cmd_scaling(void)
 {
@@ -1834,6 +1781,7 @@ void cmd_scaling(void)
 	StatusMsg(str);
 
 	/* ScalingDialog */
+	scaling_dlg.value = 1;
 	scaling_dlg.x_pos = 0;
 	scaling_dlg.y_pos = 0;
 	scaling_dlg.coefficient = 1;
@@ -1843,14 +1791,18 @@ void cmd_scaling(void)
 	scaling_dlg.parent = MainWindow;
 	scaling_dlg.dialog = NULL;
 
+	//g_print("ScalingDialog() : START !\n");
 	ScalingDialog(&scaling_dlg);
-	CopyScaling(scaling_dlg.x_pos, scaling_dlg.y_pos, scaling_dlg.coefficient, 1);
-
-	/* mode ⡼ 300  */
+	//g_print("ScalingDialog() : END !\n");
+	if (scaling_dlg.value != -1) {
+		CopyScaling(scaling_dlg.x_pos, scaling_dlg.y_pos, scaling_dlg.coefficient, 1);
+	}
+	
+	/* mode を選択モード 300 に */
 	ReturnFunc = MouseRet_Select;
 	DcObj = 15;
 	mode = 300;
-	/* åɽ */
+	/* メッセージ表示 */
 	(*ReturnFunc)(drawing_area, 1, 0, 0);
 
 	return;
@@ -1859,22 +1811,23 @@ void cmd_scaling(void)
 
 
 /* -------------------------------------------------------------------
- * ʣ
+ * 行列複写
  */
 void cmd_grid_copy(void)
 {
 	GRIDCOPY_DLG gridcopy_dlg;
 	char str[256];
-
+	
 	if (select_list_num() == 0) {
 		MsgBox("SagCAD", _("Execute after selecting a diagram.") , "", NULL, NULL, "OK");
 		return;
 	}
-
+	
 	sprintf(str, _("Procession Copy Setting") );
 	StatusMsg(str);
-
+	
 	/* GridCopyDialog */
+	gridcopy_dlg.value = 1;
 	gridcopy_dlg.x_pitch = 0;
 	gridcopy_dlg.y_pitch = 0;
 	gridcopy_dlg.x_repeats = 1;
@@ -1885,15 +1838,20 @@ void cmd_grid_copy(void)
 	gridcopy_dlg.y_repeats_entry = NULL;
 	gridcopy_dlg.parent = MainWindow;
 	gridcopy_dlg.dialog = NULL;
-
+	
+	//g_print("GridCopyDialog() : START !\n");
 	GridCopyDialog(&gridcopy_dlg);
-	CopyKousi(gridcopy_dlg.x_pitch, gridcopy_dlg.y_pitch, gridcopy_dlg.x_repeats, gridcopy_dlg.y_repeats);
-
-	/* mode ⡼ 300  */
+	if (gridcopy_dlg.value != -1) {
+		//g_print("(%f, %f),(%d, %d)\n", gridcopy_dlg.x_pitch, gridcopy_dlg.y_pitch, 
+		//			gridcopy_dlg.x_repeats, gridcopy_dlg.y_repeats);
+		CopyKousi(gridcopy_dlg.x_pitch, gridcopy_dlg.y_pitch, gridcopy_dlg.x_repeats, gridcopy_dlg.y_repeats);
+	}
+	
+	/* mode を選択モード 300 に */
 	ReturnFunc = MouseRet_Select;
 	DcObj = 15;
 	mode = 300;
-	/* åɽ */
+	/* メッセージ表示 */
 	(*ReturnFunc)(drawing_area, 1, 0, 0);
 	return;
 }
@@ -1901,11 +1859,11 @@ void cmd_grid_copy(void)
 
 
 /* =====================================================================
- * << ˡ >>
+ * << 寸法 >>
  * =====================================================================
  */
 /* -------------------------------------------------------------------
- * ˡ X
+ * 寸法 X
  */
 void cmd_x_dimension(void)
 {
@@ -1952,7 +1910,7 @@ void cmd_x_dimension(void)
 
 
 /* -------------------------------------------------------------------
- * ˡ Y
+ * 寸法 Y
  */
 void cmd_y_dimension(void)
 {
@@ -1996,7 +1954,7 @@ void cmd_y_dimension(void)
 
 
 /* -------------------------------------------------------------------
- * ˡ Υ
+ * 寸法 距離
  */
 void cmd_p_dimension(void)
 {
@@ -2040,7 +1998,7 @@ void cmd_p_dimension(void)
 
 
 /* -------------------------------------------------------------------
- * ˡ Ⱦ
+ * 寸法 半径
  */
 void cmd_r_dimension(void)
 {
@@ -2085,7 +2043,7 @@ void cmd_r_dimension(void)
 
 
 /* -------------------------------------------------------------------
- * ˡ ľ
+ * 寸法 直径
  */
 void cmd_d_dimension(void)
 {
@@ -2130,7 +2088,7 @@ void cmd_d_dimension(void)
 
 
 /* -------------------------------------------------------------------
- * ˡ 
+ * 寸法 角度
  */
 void cmd_a_dimension(void)
 {
@@ -2174,7 +2132,7 @@ void cmd_a_dimension(void)
 
 
 /* -------------------------------------------------------------------
- * ˡ ɸ
+ * 寸法 座標
  */
 void cmd_pt_dimension(void)
 {
@@ -2218,7 +2176,7 @@ void cmd_pt_dimension(void)
 
 
 /* -------------------------------------------------------------------
- * ˡ 
+ * 寸法 引出
  */
 void cmd_hd_dimension(void)
 {
@@ -2309,7 +2267,7 @@ void cmd_hd_dimension(void)
 
 
 /* -------------------------------------------------------------------
- * ˡ 
+ * 寸法 注釈
  */
 void cmd_at_dimension(void)
 {
@@ -2319,7 +2277,7 @@ void cmd_at_dimension(void)
 
 
 	SelectCancel(drawing_area);
-	/* ޥɥ饤ɽ */
+	/* コマンドラインに表示 */
 	sprintf(mstr, _(" [Drawer Line Dimension] Text Setting") );
 	StatusMsg(mstr);
 
@@ -2402,7 +2360,7 @@ void cmd_at_dimension(void)
 
 
 /* -------------------------------------------------------------------
- * ˡ Խ
+ * 寸法 編集
  */
 void cmd_edt_dimension(void)
 {
@@ -2460,7 +2418,7 @@ void cmd_Redo(void)
 
 
 /* -------------------------------------------------------------------
- * å
+ * カット
  */
 void cmd_cut(void)
 {
@@ -2476,7 +2434,7 @@ void cmd_cut(void)
 
 
 /* -------------------------------------------------------------------
- * ԡ
+ * コピー
  */
 void cmd_copy(void)
 {
@@ -2491,13 +2449,13 @@ void cmd_copy(void)
 
 
 /* -------------------------------------------------------------------
- * ڡ
+ * ペースト
  */
 void cmd_paste(void)
 {
 	ReadClipFile();
 	ModifiedFlag = 1;
-	/*  */
+	/* 再描画処理 */
 	Redraw();
 }
 
@@ -2506,7 +2464,7 @@ void cmd_paste(void)
 
 
 /* -------------------------------------------------------------------
- * ʿ
+ * 部品図挿入
  */
 void cmd_parts_in(void)
 {
@@ -2516,11 +2474,11 @@ void cmd_parts_in(void)
 
 	sprintf(PartsFile, "%s/NoName.dxf", sagcad_user.CadPath);
 	Ret = read_file_name_get(PartsFile);
-	/* ե򥭥󥻥 */
-	if (Ret == 0) {
+	/* ファイルの選択をキャンセル */
+	if (Ret == -1) {
 		return;
 	}
-	if(Ret == 1 && PartsFile != NULL){
+	if(Ret == 0 && PartsFile != NULL){
 		if (strstr(PartsFile, ".sgy") != NULL || strstr(PartsFile, ".SGY") != NULL) {
 			//
 		}
@@ -2536,7 +2494,7 @@ void cmd_parts_in(void)
 
 	SelectCancel(drawing_area);
 	ReturnFunc = MouseRet_PartsRead;
-	/* ޥɥ饤ɽ */
+	/* コマンドラインに表示 */
 	sprintf(mstr, _(" [Part Insert] Select Starting Point") );
 	StatusMsg(mstr);
 	mode = 110;
@@ -2569,7 +2527,7 @@ void cmd_profile(void)
 
 
 /* ---------------------------------------------------------
- * NC 
+ * NC 作図
  * 
  */
 void cmd_NcDraw(void)
@@ -2605,19 +2563,19 @@ void DUMMY_____________________________1(void) {}
 
 
 
-/* CAM ݥå (ID_POKET) */
+/* CAM ポケット (ID_POKET) */
 void cmd_poket(void)
 {
 	char str[256];
 
 	if(select_list_num() == 0) {
-		sprintf(str, "޷쥯ȤƤޤ");
+		sprintf(str, "図形がセレクトされていません。");
 		MsgBox("Boo !", str);
 		return;
 	}
 
-//	sprintf(str, "ϤޤƥǤ\nե꡼ǽ礭Τ\nи礷Ʋ");
-//	MsgBox("᤿å", str);
+//	sprintf(str, "これはまだテスト中です。\nフリーズする可能性が大きいので\n覚悟して下さい。");
+//	MsgBox("やめた方がいいよメッセージ", str);
 
 
 	ReturnFunc = MouseRet_offset;
@@ -2630,7 +2588,7 @@ void cmd_poket(void)
 
 
 /* -------------------------------------------------------------------
- * Key  (ID_ESC_PUSH)
+ * Key 設定 (ID_ESC_PUSH)
  */
 void cmd_key_ESC(void)
 {
@@ -2645,7 +2603,7 @@ void cmd_key_ESC(void)
 
 
 /* -------------------------------------------------------------------
- * Key  (ID_SPACE_PUSH)
+ * Key 設定 (ID_SPACE_PUSH)
  */
 void cmd_key_SPACE(void)
 {
@@ -2657,7 +2615,7 @@ void cmd_key_SPACE(void)
 
 
 /* -------------------------------------------------------------------
- * Key  (ID_RETURN_PUSH)
+ * Key 設定 (ID_RETURN_PUSH)
  */
 void cmd_key_RETURN(void)
 {
@@ -2672,7 +2630,7 @@ void cmd_key_RETURN(void)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : Command.c
