@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2002/12/24
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/14
  * ====================================================================
  */
 
@@ -37,7 +37,7 @@
 #include "List_Undo.h"
 #include "List_Select.h"
 #include "global.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "etc.h"
 #include "sagcad.h"
 #include "Assistance.h"
@@ -90,7 +90,7 @@ int DxfFileSave(char *SaveFileName)
 
 
 /* -------------------------------------------------------------------
- * إå
+ * ヘッダ・セクション
  * header_section_write
  *	
  */
@@ -110,7 +110,7 @@ int header_section_write(FILE *stream)
 	sprintf(str, "HEADER\n");
 	fputs(str, stream );
 
-	/* DXF ΥС */
+	/* DXF のバージョン */
 	sprintf(str, "  9\n");
 	fputs(str, stream );
 	sprintf(str, "$ACADVER\n");
@@ -121,7 +121,7 @@ int header_section_write(FILE *stream)
 	fputs(str, stream );
 
 #ifdef TEST
-	/* ꥳޥɤꤵ */
+	/* 基点設定コマンドで設定される挿入基点 */
 	sprintf(str, "  9\n");
 	fputs(str, stream );
 	sprintf(str, "$INSBASE\n");
@@ -139,7 +139,7 @@ int header_section_write(FILE *stream)
 	sprintf(str, "0.0\n");
 	fputs(str, stream );
 
-	/* ޷ϰϤκ */
+	/* 図形範囲の左下 */
 	left   =	MagX - ((sagcad_system.ViewX/Mag)/2);
 	top	   =	MagY + (((sagcad_system.ViewX/Mag)/2)*sagcad_system.Aspect);
 	right  =	MagX + ((sagcad_system.ViewX/Mag)/2);
@@ -170,7 +170,7 @@ int header_section_write(FILE *stream)
 	sprintf(str, "%f\n", top);
 	fputs(str, stream );
 
-	/* XY ϰϺ */
+	/* XY 図面範囲左下 */
 	sprintf(str, "  9\n");
 	fputs(str, stream );
 	sprintf(str, "$LIMMIN\n");
@@ -197,7 +197,7 @@ int header_section_write(FILE *stream)
 	sprintf(str, "%f\n", top);
 	fputs(str, stream );
 
-	/* ΥХʥ */
+	/* 線種のグローバルなスケール */
 	sprintf(str, "  9\n");
 	fputs(str, stream );
 	sprintf(str, "$LTSCALE\n");
@@ -242,13 +242,13 @@ int tables_section_write(FILE *stream)
 	fputs(str, stream );
 
 
-	/* ơ֥륻 */
+	/* テーブルセクション　線種設定 */
 	tables_section_LTYPE_write(stream);
 
-	/* ơ֥륻󡡥쥤䡼 */
+	/* テーブルセクション　レイヤー設定 */
 	tables_section_LAYER_write(stream);
 
-	/* ơ֥륻󡡥 */
+	/* テーブルセクション　スタイル設定 */
 	tables_section_STYLE_write(stream);
 
 	/* < TABLES STYLE start > */
@@ -270,7 +270,7 @@ int tables_section_write(FILE *stream)
 /* -------------------------------------------------------------------
  * tables_section_LTYPE_write
  *	
- * ơ֥륻
+ * テーブルセクション　線種設定
  */
 int tables_section_LTYPE_write(FILE *stream)
 {
@@ -294,7 +294,7 @@ int tables_section_LTYPE_write(FILE *stream)
 	fputs(str, stream );
 
 
-	/* CONTINUOUS () */
+	/* CONTINUOUS (実線) */
 	sprintf(str, "  0\n");
 	fputs(str, stream );
 	sprintf(str, "LTYPE\n");
@@ -309,7 +309,7 @@ int tables_section_LTYPE_write(FILE *stream)
 	fputs(str, stream );
 	sprintf(str, "  3\n");
 	fputs(str, stream );
-	sprintf(str, "\n");
+	sprintf(str, "実線\n");
 	fputs(str, stream );
 	sprintf(str, " 72\n");
 	fputs(str, stream );
@@ -325,7 +325,7 @@ int tables_section_LTYPE_write(FILE *stream)
 	fputs(str, stream );
 
 
-	/* HIDDEN () */
+	/* HIDDEN (破線) */
 	sprintf(str, "  0\n");
 	fputs(str, stream );
 	sprintf(str, "LTYPE\n");
@@ -340,7 +340,7 @@ int tables_section_LTYPE_write(FILE *stream)
 	fputs(str, stream );
 	sprintf(str, "  3\n");
 	fputs(str, stream );
-	sprintf(str, "\n");
+	sprintf(str, "破線\n");
 	fputs(str, stream );
 	sprintf(str, " 72\n");
 	fputs(str, stream );
@@ -364,7 +364,7 @@ int tables_section_LTYPE_write(FILE *stream)
 	fputs(str, stream );
 
 
-	/* DASHDOT () */
+	/* DASHDOT (１点鎖線) */
 	sprintf(str, "  0\n");
 	fputs(str, stream );
 	sprintf(str, "LTYPE\n");
@@ -379,7 +379,7 @@ int tables_section_LTYPE_write(FILE *stream)
 	fputs(str, stream );
 	sprintf(str, "  3\n");
 	fputs(str, stream );
-	sprintf(str, "\n");
+	sprintf(str, "１点鎖線\n");
 	fputs(str, stream );
 	sprintf(str, " 72\n");
 	fputs(str, stream );
@@ -411,7 +411,7 @@ int tables_section_LTYPE_write(FILE *stream)
 	fputs(str, stream );
 
 
-	/* DIVIDE () */
+	/* DIVIDE (２点鎖線) */
 	sprintf(str, "  0\n");
 	fputs(str, stream );
 	sprintf(str, "LTYPE\n");
@@ -426,7 +426,7 @@ int tables_section_LTYPE_write(FILE *stream)
 	fputs(str, stream );
 	sprintf(str, "  3\n");
 	fputs(str, stream );
-	sprintf(str, "\n");
+	sprintf(str, "２点鎖線\n");
 	fputs(str, stream );
 	sprintf(str, " 72\n");
 	fputs(str, stream );
@@ -482,7 +482,7 @@ int tables_section_LTYPE_write(FILE *stream)
 /* -------------------------------------------------------------------
  * tables_section_LAYER_write
  *	
- * ơ֥륻󡡥쥤䡼
+ * テーブルセクション　レイヤー設定
  */
 int tables_section_LAYER_write(FILE *stream)
 {
@@ -509,8 +509,8 @@ int tables_section_LAYER_write(FILE *stream)
 	fputs(str, stream );
 
 
-	/* Layer_Data ν */
-	/* 쥤䡼̾ѹƤСϤ */
+	/* Layer_Data 配列の初期化 */
+	/* レイヤー名が変更されていれば、出力する */
 	for (i=0 ; i < 256 ; i++) {
 		sprintf(dummy, "%d", i);
 		if (search(Layer[i].name, dummy) != NULL && strlen(Layer[i].name) == strlen(dummy)) {
@@ -521,31 +521,31 @@ int tables_section_LAYER_write(FILE *stream)
 		}
 	}
 
-	/* ޷ǡ 1 */
-	/* ƿ޷ */
+	/* 図形データがあれば 1 */
+	/* 各図形要素 */
 	p = cad_list_info.head;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL) {
-		/* ɽ */
+		/* 表示 */
 		if (Layer[p->cad->layer].draw != 0 || NowLayer == p->cad->layer) {
 			Layer_Data[p->cad->layer] = 1;
 		}
-		/* ɽ */
+		/* 非表示 */
 		else if (Layer[p->cad->layer].draw == 0 && NowLayer != p->cad->layer) {
 			Layer_Data[p->cad->layer] = -1;
 		}
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
-	/* ˡǡ 1 */
-	/* ˡ */
+	/* 寸法データがあれば 1 */
+	/* 各寸法要素 */
 	pd = dimension_list_info.head;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(pd != NULL) {
 		if (Layer[pd->dimension->Layer].draw != 0 || NowLayer == pd->dimension->Layer) {
@@ -554,23 +554,23 @@ int tables_section_LAYER_write(FILE *stream)
 		else if (Layer[pd->dimension->Layer].draw == 0 && NowLayer != pd->dimension->Layer) {
 			Layer_Data[pd->dimension->Layer] = -1;
 		}
-		pd = pd->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pd = pd->next;	/* ポインタを次のデータに移す */
 	}
 
 
-	/* ѤƤ쥤䡼θĿ */
+	/* 使用しているレイヤーの個数を数える */
 	n = 0;
 	for ( i = 0 ; i < 256 ; i++ ) {
 		if (Layer_Data[i] == 1 || Layer_Data[i] == -1) {
 			n++;
 		}
 	}
-	/* ѤƤ쥤䡼θĿ񤭹 */
+	/* 使用しているレイヤーの個数を書き込む */
 	sprintf(str, "  %d\n", n);
 	fputs(str, stream );
 
 
-	/* ƥ쥤䡼򵭽 */
+	/* 各レイヤー情報を記述 */
 	for ( i = 0 ; i < 256 ; i++ ) {
 		if (Layer_Data[i] == 1 || Layer_Data[i] == -1) {
 			sprintf(str, "  0\n");
@@ -588,7 +588,7 @@ int tables_section_LAYER_write(FILE *stream)
 			
 			sprintf(str, " 62\n");
 			fputs(str, stream );
-			/* ɽ */
+			/* 表示 */
 			dxf_color = SgyToDxf_color(Layer[i].color);
 			if (Layer_Data[i] == 1) {
 				if (dxf_color < 10) {
@@ -601,7 +601,7 @@ int tables_section_LAYER_write(FILE *stream)
 					sprintf(str, "   %d\n", dxf_color);
 				}
 			}
-			/* ɽ */
+			/* 非表示 */
 			else if (Layer_Data[i] == -1) {
 				if (dxf_color < 10) {
 					sprintf(str, "    -%d\n", dxf_color);
@@ -638,7 +638,7 @@ int tables_section_LAYER_write(FILE *stream)
 /* -------------------------------------------------------------------
  * tables_section_STYLE_write
  *	
- * ơ֥륻󡡥
+ * テーブルセクション　スタイル設定
  */
 int tables_section_STYLE_write(FILE *stream)
 {
@@ -663,46 +663,46 @@ int tables_section_STYLE_write(FILE *stream)
 	fputs(str, stream );
 
 
-	/* STYLE  start */
+	/* STYLE １個目 start */
 	sprintf(str, "  0\n");
 	fputs(str, stream );
 	sprintf(str, "STYLE\n");
 	fputs(str, stream );
-	sprintf(str, "  2\n");			// Τ̾
+	sprintf(str, "  2\n");			// ┓字体の名前
 	fputs(str, stream );
-	sprintf(str, "STANDARD\n");		// "STANDARD"
+	sprintf(str, "STANDARD\n");		// ┛　"STANDARD"
 	fputs(str, stream );
-	sprintf(str, " 70\n");			// ΤΥե饰
+	sprintf(str, " 70\n");			// ┓字体のフラグ
 	fputs(str, stream );
-	sprintf(str, "     0\n");		// ̾ 0 or 64
+	sprintf(str, "     0\n");		// ┛　通常は 0 or 64
 	fputs(str, stream );
-	sprintf(str, " 40\n");			// ꤵ줿ʸ⤵ꤵƤʤ 0.0
+	sprintf(str, " 40\n");			// ┓固定された文字高さ　指定されていない場合は 0.0
 	fputs(str, stream );
-	sprintf(str, "0.0\n");			// 
+	sprintf(str, "0.0\n");			// ┛　
 	fputs(str, stream );
-	sprintf(str, " 41\n");			// ⤵Фηǥեͤ 1.0
+	sprintf(str, " 41\n");			// ┓高さに対する幅の係数　デフォルト値は 1.0
 	fputs(str, stream );
-	sprintf(str, "1.0\n");			// 
+	sprintf(str, "1.0\n");			// ┛　
 	fputs(str, stream );
-	sprintf(str, " 50\n");			// г١ǥեͤ 0.0
+	sprintf(str, " 50\n");			// ┓傾斜角度　デフォルト値は 0.0
 	fputs(str, stream );
-	sprintf(str, "0.0\n");			// 
+	sprintf(str, "0.0\n");			// ┛　
 	fputs(str, stream );
-	sprintf(str, " 71\n");			// ʸե饰ǥեͤ 0.0
+	sprintf(str, " 71\n");			// ┓文字作成フラグ　デフォルト値は 0.0
 	fputs(str, stream );
-	sprintf(str, "     0\n");		// 
+	sprintf(str, "     0\n");		// ┛　
 	fputs(str, stream );
-	sprintf(str, " 42\n");			// Ǹ˻Ѥ줿ʸ⤵
+	sprintf(str, " 42\n");			// ┓最後に使用された文字高さ
 	fputs(str, stream );
-	sprintf(str, "2.5\n");			// 
+	sprintf(str, "2.5\n");			// ┛　
 	fputs(str, stream );
-	sprintf(str, "  3\n");			// ХȥɤФե̾
+	sprintf(str, "  3\n");			// ┓１バイトコードに対するフォント名
 	fputs(str, stream );
-	sprintf(str, "txt\n");			// ǥեͤ txt
+	sprintf(str, "txt\n");			// ┛　デフォルト値は txt
 	fputs(str, stream );
-	sprintf(str, "  4\n");			// ХȥɤФե̾
+	sprintf(str, "  4\n");			// ┓２バイトコードに対するフォント名
 	fputs(str, stream );
-	sprintf(str, "bigfont\n");		// ǥեͤ ʤԤƬ˥꥿󥳡
+	sprintf(str, "bigfont\n");		// ┛　デフォルト値は なし　行の先頭にリターンコード
 	fputs(str, stream );
 
 
@@ -848,11 +848,11 @@ int entities_section_write(FILE *stream)
 	fputs(str, stream );
 
 
-	/* ƿ޷ */
+	/* 各図形要素 */
 	p = cad_list_info.head;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL) {
 		/* POINT */
@@ -871,15 +871,15 @@ int entities_section_write(FILE *stream)
 		else if (p->cad->code == 4) {
 			entities_section_circle_write(p->cad, stream);
 		}
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 
-	/* ˡ */
+	/* 寸法要素 */
 	dp = dimension_list_info.head;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(dp != NULL) {
 		/* Assistant */
@@ -887,12 +887,12 @@ int entities_section_write(FILE *stream)
 		/* Text */
 		entities_section_dimension_Text_write(dp->dimension, stream);
 
-		dp = dp->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		dp = dp->next;	/* ポインタを次のデータに移す */
 	}
 
 
 //#ifdef TEST
-	/* ݥ饤 */
+	/* ポリライン */
 	pp = polyline_list_info.head;
 	while(pp != NULL) {
 		entities_section_polyline_write(pp->polyline, stream);
@@ -900,7 +900,7 @@ int entities_section_write(FILE *stream)
 	}
 
 
-	/* ʱ */
+	/* 楕円 */
 	ep = ellipse_list_info.head;
 	while(ep != NULL) {
 		entities_section_ellipse_write(ep->ellipse, stream);
@@ -1223,7 +1223,7 @@ int entities_section_polyline_write(POLYLINE *polyline, FILE *stream)
 	sprintf(str, "     %d\n", polyline->frag);
 	fputs(str, stream );
 
-	/* ץ饤 */
+	/* スプライン */
 	sprintf(str, " 75\n");
 	fputs(str, stream );
 	if (polyline->code == 8) {
@@ -1331,51 +1331,51 @@ int entities_section_ellipse_write(ELLIPSE *ellipse, FILE *stream)
 	sprintf(str, "    %d\n", SgyToDxf_color(ellipse->color));
 	fputs(str, stream );
 
-	/* 濴 X */
+	/* 中心 X */
 	sprintf(str, " 10\n");
 	fputs(str, stream );
 	sprintf(str, "%f\n", ellipse->cx);
 	fputs(str, stream );
-	/* 濴 Y */
+	/* 中心 Y */
 	sprintf(str, " 20\n");
 	fputs(str, stream );
 	sprintf(str, "%f\n", ellipse->cy);
 	fputs(str, stream );
-	/* 濴 Z */
+	/* 中心 Z */
 	sprintf(str, " 30\n");
 	fputs(str, stream );
 	sprintf(str, "0.0\n");
 	fputs(str, stream );
 
-	/* Ĺΰü X (濴Ȥߤʤкɸ) X */
+	/* 長軸の一方の端点 X (中心を原点とみなした相対座標) X */
 	sprintf(str, " 11\n");
 	fputs(str, stream );
 	sprintf(str, "%f\n", ellipse->dx);
 	fputs(str, stream );
-	/* Ĺΰü X (濴Ȥߤʤкɸ) Y */
+	/* 長軸の一方の端点 X (中心を原点とみなした相対座標) Y */
 	sprintf(str, " 21\n");
 	fputs(str, stream );
 	sprintf(str, "%f\n", ellipse->dy);
 	fputs(str, stream );
-	/* Ĺΰü X (濴Ȥߤʤкɸ) Z */
+	/* 長軸の一方の端点 X (中心を原点とみなした相対座標) Z */
 	sprintf(str, " 31\n");
 	fputs(str, stream );
 	sprintf(str, "0.0\n");
 	fputs(str, stream );
 
-	/* ûĹ(ĹĹФΨ) */
+	/* 短軸の長さ(長軸の長さに対する比率) */
 	sprintf(str, " 40\n");
 	fputs(str, stream );
 	sprintf(str, "%f\n", ellipse->k);
 	fputs(str, stream );
 
-	/* ϳ (饸) */
+	/* 開始角度 (ラジアン) */
 	sprintf(str, " 41\n");
 	fputs(str, stream );
 	sprintf(str, "%f\n", degrad(ellipse->sa));
 	fputs(str, stream );
 
-	/* λ (饸) */
+	/* 終了角度 (ラジアン) */
 	sprintf(str, " 42\n");
 	fputs(str, stream );
 	sprintf(str, "%f\n", degrad(ellipse->ea));
@@ -1402,11 +1402,11 @@ int entities_section_dimension_AssistLine_write(DIMENSION *a, FILE *stream)
 	if (a->index > 0 && a->AssistLine != NULL) {
 		for (i = 0 ; i < a->index ; i++) {
 			switch (a->AssistLine[i].defin) {
-				/*  */
+				/* 点 */
 				case 0:
 					//PointBasic(hDC, a->AssistLine[i].sx, a->AssistLine[i].sy, color);
 					break;
-				/*  */
+				/* 線 */
 				case 1:
 					//LineBasic(hDC,	a->AssistLine[i].sx, a->AssistLine[i].sy, 
 					//				a->AssistLine[i].ex, a->AssistLine[i].ey, 5);
@@ -1424,68 +1424,68 @@ int entities_section_dimension_AssistLine_write(DIMENSION *a, FILE *stream)
 					cad.OnScreen = 0;
 					entities_section_line_write(&cad, stream);
 					break;
-				/* ߸ */
+				/* 円弧 */
 				case 2:
 					//ArcBasic(hDC,	a->AssistLine[i].cx, a->AssistLine[i].cy, a->AssistLine[i].r, 
 					//				a->AssistLine[i].sx, a->AssistLine[i].sy, 
 					//				a->AssistLine[i].ex, a->AssistLine[i].ey, 5);
 					break;
-				/*  */
+				/* 円 */
 				case 4:
 					//CircleBasic(hDC, a->AssistLine[i].cx, a->AssistLine[i].cy, a->AssistLine[i].r, 5);
 					break;
-				/* () */
+				/* 終点に矢印(線) */
 				case 10:
 					DXF_LineEndArrow(	stream, a->Layer, a->AssistLine[i].sx, a->AssistLine[i].sy, 
 										a->AssistLine[i].ex, a->AssistLine[i].ey, 0, a->DrawType);
 					break;
-				/* () */
+				/* 終点に矢印(線) */
 				case 11:
 					DXF_LineEndArrow(	stream, a->Layer, a->AssistLine[i].sx, a->AssistLine[i].sy, 
 										a->AssistLine[i].ex, a->AssistLine[i].ey, 1, a->DrawType);
 					break;
-				/* ξü() */
+				/* 両端に矢印(線) */
 				case 20:
 					DXF_LineBothArrow(	stream, a->Layer, a->AssistLine[i].sx, a->AssistLine[i].sy, 
 										a->AssistLine[i].ex, a->AssistLine[i].ey, 0, a->DrawType);
 					break;
-				/* ξü() */
+				/* 両端に矢印(線) */
 				case 21:
 					DXF_LineBothArrow(	stream, a->Layer, a->AssistLine[i].sx, a->AssistLine[i].sy, 
 										a->AssistLine[i].ex, a->AssistLine[i].ey, 1, a->DrawType);
 					break;
-				/* ξü˵() */
+				/* 両端に逆矢印(線) */
 				case 30:
 					DXF_LineBothConverseArrow(	stream, a->Layer, a->AssistLine[i].sx, a->AssistLine[i].sy, 
 												a->AssistLine[i].ex, a->AssistLine[i].ey, 0, a->DrawType);
 					break;
-				/* ξü˵() */
+				/* 両端に逆矢印(線) */
 				case 31:
 					DXF_LineBothConverseArrow(	stream, a->Layer, a->AssistLine[i].sx, a->AssistLine[i].sy, 
 												a->AssistLine[i].ex, a->AssistLine[i].ey, 1, a->DrawType);
 					break;
-				/* (߸) */
+				/* 始点に矢印(円弧) */
 	//			case 40:
-				/* (߸) */
+				/* 終点に矢印(円弧) */
 	//			case 50:
-				/* ξü(߸) */
+				/* 両端に矢印(円弧) */
 				case 60:
 					DXF_ArcBothArrow(	stream, a->Layer, a->AssistLine[i].cx, a->AssistLine[i].cy, a->AssistLine[i].r, 
 										a->AssistLine[i].sx, a->AssistLine[i].sy, 
 										a->AssistLine[i].ex, a->AssistLine[i].ey, 0, a->DrawType);
 					break;
-				/* ξü(߸) */
+				/* 両端に矢印(円弧) */
 				case 61:
 					DXF_ArcBothArrow(	stream, a->Layer, a->AssistLine[i].cx, a->AssistLine[i].cy, a->AssistLine[i].r, 
 										a->AssistLine[i].sx, a->AssistLine[i].sy, 
 										a->AssistLine[i].ex, a->AssistLine[i].ey, 1, a->DrawType);
 					break;
-				/*  */
+				/* 補助線 */
 				case 70:
 					DXF_AssistanceLine(	stream, a->Layer, a->AssistLine[i].sx, a->AssistLine[i].sy, 
 										a->AssistLine[i].ex, a->AssistLine[i].ey, a->DrawType);
 					break;
-				/* ()αĹ */
+				/* (矢印)補助線の延長 */
 				case 80:
 					DXF_LineEndExtension(	stream, a->Layer, a->AssistLine[i].sx, a->AssistLine[i].sy, 
 											a->AssistLine[i].ex, a->AssistLine[i].ey, a->DrawType);
@@ -1494,7 +1494,7 @@ int entities_section_dimension_AssistLine_write(DIMENSION *a, FILE *stream)
 		}
 	}
 	else if (a->index > 0 && a->AssistLine == NULL) {
-		OneShotLog("ˡ index > 0 ʤΤ AssistLine  NULL Ǥ\n");
+		OneShotLog("寸法線で index > 0 なのに AssistLine が NULL です。\n");
 	}
 
 	return 1;
@@ -1544,20 +1544,20 @@ int entities_section_dimension_Text_write(DIMENSION *a, FILE *stream)
 
 
 
-	/* ʸ⤵ */
+	/* 文字高さ */
 	/* -----------------------------------------------------
-	 * ɽˤĴ
+	 * 表示設定による調整
 	 * 
 	 */
-	/* ɽ */
+	/* 実寸表示 */
 	if (a->DrawType == DRAW_REAL){
 		height = a->FontHeight;
 	}
-	/* ̤ν̼ɽ */
+	/* 図面の縮尺表示 */
 	else if (a->DrawType == DRAW_DISP) {
 		height = a->FontHeight / printer.scale;
 	}
-	/* ʸɽ */
+	/* 文字サイズ固定表示 */
 	else if (a->DrawType == DRAW_CONST){
 		height = a->FontHeight / Mag;
 	}
@@ -1565,7 +1565,7 @@ int entities_section_dimension_Text_write(DIMENSION *a, FILE *stream)
 		height = a->FontHeight;
 	}
 
-	/* ʸ⤵ */
+	/* 文字高さ */
 	sprintf(str, " 40\n");
 	fputs(str, stream );
 	sprintf(str, "%f\n", a->FontHeight);
@@ -1573,19 +1573,19 @@ int entities_section_dimension_Text_write(DIMENSION *a, FILE *stream)
 
 
 
-	/* ž */
+	/* 回転角度 */
 	sprintf(str, " 50\n");
 	fputs(str, stream );
 	sprintf(str, "%f\n", a->Angle);
 	fputs(str, stream );
 
-	/* ʸ */
+	/* 文字列 */
 	sprintf(str, "  1\n");
 	fputs(str, stream );
 	sprintf(str, "%s\n", a->Text);
 	fputs(str, stream );
 
-	/* ֹ碌 */
+	/* 位置合わせＸ */
 	if (a->StartPoint > 9) {
 		point = a->StartPoint - 10;
 	}
@@ -1614,7 +1614,7 @@ int entities_section_dimension_Text_write(DIMENSION *a, FILE *stream)
 		fputs(str, stream );
 	}
 
-	/* ֹ碌 */
+	/* 位置合わせＹ */
 	if (a->StartPoint > 9) {
 		sprintf(str, " 73\n");
 		fputs(str, stream );
@@ -1690,11 +1690,11 @@ int SagToDXF_Style(int style, char *str)
 
 
 /* -------------------------------------------------------------------
- *  (defin = 10)
+ * 終点に矢印 (defin = 10)
  *	
  * LineFrag
- *	   0	  : Τ
- *	   0 ʳ : ľ
+ *	   0	  : 矢印のみ
+ *	   0 以外 : 矢印と直線
  *	
  */
 int DXF_LineEndArrow(FILE *stream, int LAYER, double SX, double SY, double EX, double EY, int LineFrag, int DrawType)
@@ -1705,7 +1705,7 @@ int DXF_LineEndArrow(FILE *stream, int LAYER, double SX, double SY, double EX, d
 
 
 	/* -----------------------------------------------------
-	 * LA	ľγ
+	 * LA	直線の角度
 	 *		 (A.sx[1],A.SY[1]),(A.ex[1],A.EY[1])
 	 *				 Ans A.ANGLE
 	 */
@@ -1715,7 +1715,7 @@ int DXF_LineEndArrow(FILE *stream, int LAYER, double SX, double SY, double EX, d
 	LAH.ey[1] = SY;
 	la(&LAH);
 	/* -----------------------------------------------------
-	 * PAP	ȳ٤ȵΥľν
+	 * PAP	始点と角度と距離で直線の終点を求める
 	 *		 (A.sx[1] , A.sy[1]) , A.ANGLE , A.l
 	 *				 Ans  (A.ex[1] , A.EY[1])
 	 */
@@ -1792,11 +1792,11 @@ int DXF_LineEndArrow(FILE *stream, int LAYER, double SX, double SY, double EX, d
 
 
 /* -------------------------------------------------------------------
- * ξü (defin = 20)
+ * 両端に矢印 (defin = 20)
  *	
  * LineFrag
- *	   0	  : Τ
- *	   0 ʳ : ľ
+ *	   0	  : 矢印のみ
+ *	   0 以外 : 矢印と直線
  */
 int DXF_LineBothArrow(FILE *stream, int LAYER, double SX, double SY, double EX, double EY, int LineFrag, int DrawType)
 {
@@ -1805,13 +1805,13 @@ int DXF_LineBothArrow(FILE *stream, int LAYER, double SX, double SY, double EX,
 	CAD cad;
 
 
-	/* LA	ľγ */
+	/* LA	直線の角度 */
 	LAH.sx[1] = EX;
 	LAH.sy[1] = EY;
 	LAH.ex[1] = SX;
 	LAH.ey[1] = SY;
 	la(&LAH);
-	/* PAP	ȳ٤ȵΥľν */
+	/* PAP	始点と角度と距離で直線の終点を求める */
 	PAPH.sx[1] = EX;
 	PAPH.sy[1] = EY;
 	PAPH.angle = LAH.angle + sagcad_dimension.arrow_angle;
@@ -1858,14 +1858,14 @@ int DXF_LineBothArrow(FILE *stream, int LAYER, double SX, double SY, double EX,
 	cad.OnScreen = 0;
 	entities_section_line_write(&cad, stream);
 
-	/* LA	ľγ */
+	/* LA	直線の角度 */
 	LAH.sx[1] = SX;
 	LAH.sy[1] = SY;
 	LAH.ex[1] = EX;
 	LAH.ey[1] = EY;
 	la(&LAH);
 
-	/* PAP	ȳ٤ȵΥľν */
+	/* PAP	始点と角度と距離で直線の終点を求める */
 	PAPH.sx[1] = SX;
 	PAPH.sy[1] = SY;
 	PAPH.angle = LAH.angle + sagcad_dimension.arrow_angle;
@@ -1937,11 +1937,11 @@ int DXF_LineBothArrow(FILE *stream, int LAYER, double SX, double SY, double EX,
 
 
 /* -------------------------------------------------------------------
- * ξü˵ (defin = 30)
+ * 両端に逆矢印 (defin = 30)
  *	
  * LineFrag
- *	   0	  : Τ
- *	   0 ʳ : ľ
+ *	   0	  : 矢印のみ
+ *	   0 以外 : 矢印と直線
  */
 int DXF_LineBothConverseArrow(FILE *stream, int LAYER, double SX, double SY, double EX, double EY, int LineFrag, int DrawType)
 {
@@ -1950,14 +1950,14 @@ int DXF_LineBothConverseArrow(FILE *stream, int LAYER, double SX, double SY, dou
 	CAD cad;
 
 
-	/* LA	ľγ */
+	/* LA	直線の角度 */
 	LAH.sx[1] = EX;
 	LAH.sy[1] = EY;
 	LAH.ex[1] = SX;
 	LAH.ey[1] = SY;
 	la(&LAH);
 
-	/* PAP	ȳ٤ȵΥľν */
+	/* PAP	始点と角度と距離で直線の終点を求める */
 	PAPH.sx[1] = SX;
 	PAPH.sy[1] = SY;
 	PAPH.angle = LAH.angle + sagcad_dimension.arrow_angle;
@@ -2004,13 +2004,13 @@ int DXF_LineBothConverseArrow(FILE *stream, int LAYER, double SX, double SY, dou
 	cad.OnScreen = 0;
 	entities_section_line_write(&cad, stream);
 
-	/* LA	ľγ */
+	/* LA	直線の角度 */
 	LAH.sx[1] = SX;
 	LAH.sy[1] = SY;
 	LAH.ex[1] = EX;
 	LAH.ey[1] = EY;
 	la(&LAH);
-	/* PAP	ȳ٤ȵΥľν */
+	/* PAP	始点と角度と距離で直線の終点を求める */
 	PAPH.sx[1] = EX;
 	PAPH.sy[1] = EY;
 	PAPH.angle = LAH.angle + sagcad_dimension.arrow_angle;
@@ -2082,11 +2082,11 @@ int DXF_LineBothConverseArrow(FILE *stream, int LAYER, double SX, double SY, dou
 
 
 /* -------------------------------------------------------------------
- * ξü(߸) (defin = 60)
+ * 両端に矢印(円弧) (defin = 60)
  *	
  * ArcFrag
- *	   0	  : Τ
- *	   0 ʳ : ľ
+ *	   0	  : 矢印のみ
+ *	   0 以外 : 矢印と直線
  */
 int DXF_ArcBothArrow(FILE *stream, int LAYER, double CX, double CY, double R, double SX, double SY, double EX, double EY, int ArcFrag, int DrawType)
 {
@@ -2099,8 +2099,8 @@ int DXF_ArcBothArrow(FILE *stream, int LAYER, double CX, double CY, double R, do
 	CAD cad;
 
 
-	/* 濴γ SA 롣 */
-	/* LA	  ľγ */
+	/* 中心点から始点の線の角度 SA を求める。 */
+	/* LA	  直線の角度 */
 	LAH.sx[1] = CX;
 	LAH.sy[1] = CY;
 	LAH.ex[1] = SX;
@@ -2157,8 +2157,8 @@ int DXF_ArcBothArrow(FILE *stream, int LAYER, double CX, double CY, double R, do
 
 
 
-	/* 濴齪γ EA 롣 */
-	/* LA	  ľγ */
+	/* 中心点から終点の線の角度 EA を求める。 */
+	/* LA	  直線の角度 */
 	LAH.sx[1] = CX;
 	LAH.sy[1] = CY;
 	LAH.ex[1] = EX;
@@ -2238,13 +2238,13 @@ int DXF_ArcBothArrow(FILE *stream, int LAYER, double CX, double CY, double R, do
 
 
 /* -------------------------------------------------------------------
- *    ¦:з	¦:бĹ (defin = 70)
+ * 補助線を描画   始点側:引出隙間	終点側:引出延長 (defin = 70)
  *	
- * 1 γ(Angle) 롣
- * 2 Ĺ(LineLen) 롣
- * 3 start_point 롣
- * 4 end_point 롣
- * 5 
+ * 1 線の角度(Angle) を求める。
+ * 2 線の長さ(LineLen) を求める。
+ * 3 start_point を求める。
+ * 4 end_point を求める。
+ * 5 補助線を描画
  *	
  */
 int DXF_AssistanceLine(FILE *stream, int LAYER, double SX, double SY, double EX, double EY, int DrawType)
@@ -2254,7 +2254,7 @@ int DXF_AssistanceLine(FILE *stream, int LAYER, double SX, double SY, double EX,
 	CAD cad;
 	int Ret;
 
-	/* 1 γ(Angle) 롣*/
+	/* 1 線の角度(Angle) を求める。*/
 	a.sx[1] = SX;
 	a.sy[1] = SY;
 	a.ex[1] = EX;
@@ -2262,7 +2262,7 @@ int DXF_AssistanceLine(FILE *stream, int LAYER, double SX, double SY, double EX,
 	Ret = la(&a);
 	Angle = a.angle;
 
-	/* 2 Ĺ(LineLen) 롣*/
+	/* 2 線の長さ(LineLen) を求める。*/
 	a.sx[1] = SX;
 	a.sy[1] = SY;
 	a.ex[1] = EX;
@@ -2270,18 +2270,18 @@ int DXF_AssistanceLine(FILE *stream, int LAYER, double SX, double SY, double EX,
 	Ret = pp(&a);
 	LineLen = a.l;
 
-	/* 3 start_point 롣*/
+	/* 3 start_point を求める。*/
 	a.sx[1] = SX;
 	a.sy[1] = SY;
 	a.angle = Angle;
 
-	/* ̤ν̼ɽ (ץ󥿡᡼) */
+	/* 図面の縮尺表示 (プリンターイメージ) */
 	if (DrawType == DRAW_DISP)
 		a.l = sagcad_dimension.assistance_line_space / printer.scale;
-	/* ʸɽ */
+	/* 文字サイズ固定表示 */
 	else if (DrawType == DRAW_CONST) 
 		a.l = (sagcad_dimension.assistance_line_space / Mag);
-	/* ꤷ礭򤽤Τޤɽ */
+	/* 設定した大きさをそのまま表示 */
 	else if (DrawType == DRAW_REAL) 
 		a.l = sagcad_dimension.assistance_line_space;
 	else 
@@ -2290,18 +2290,18 @@ int DXF_AssistanceLine(FILE *stream, int LAYER, double SX, double SY, double EX,
 	start_pointX = a.ex[1];
 	start_pointY = a.ey[1];
 
-	/* 4 end_point 롣*/
+	/* 4 end_point を求める。*/
 	a.sx[1] = SX;
 	a.sy[1] = SY;
 	a.angle = Angle;
 
-	/* ̤ν̼ɽ (ץ󥿡᡼) */
+	/* 図面の縮尺表示 (プリンターイメージ) */
 	if (DrawType == DRAW_DISP)
 		a.l = LineLen + sagcad_dimension.assistance_line_extension / printer.scale;
-	/* ʸɽ */
+	/* 文字サイズ固定表示 */
 	else if (DrawType == DRAW_CONST) 
 		a.l = LineLen + (sagcad_dimension.assistance_line_extension / Mag);
-	/* ꤷ礭򤽤Τޤɽ */
+	/* 設定した大きさをそのまま表示 */
 	else if (DrawType == DRAW_REAL) 
 		a.l = LineLen + sagcad_dimension.assistance_line_extension;
 	else 
@@ -2310,7 +2310,7 @@ int DXF_AssistanceLine(FILE *stream, int LAYER, double SX, double SY, double EX,
 	end_pointX = a.ex[1];
 	end_pointY = a.ey[1];
 
-	/* 5 */
+	/* 5 補助線を描画*/
 //	LineBasic(hDC, start_pointX, start_pointY, end_pointX, end_pointY, 1);
 	cad.layer = LAYER;
 	cad.code = 1;
@@ -2334,15 +2334,15 @@ int DXF_AssistanceLine(FILE *stream, int LAYER, double SX, double SY, double EX,
 
 
 /* -------------------------------------------------------------------
- * ()αĹ (defin = 80)
+ * (矢印)補助線の延長を描画 (defin = 80)
  *	
- * (SX,SY)-(EX,EY) ǻꤵ줿ľ sagcad_dimension.arrow_line_extension 
- * ǻꤵ줿ĹĹ롣
+ * (SX,SY)-(EX,EY) で指定された直線を sagcad_dimension.arrow_line_extension 
+ * で指定された長さだけ終点を延長する。
  *	
- * 1 γ(Angle) 롣
- * 2 Ĺ(LineLen) 롣
- * 3 end_point 롣
- * 4 
+ * 1 線の角度(Angle) を求める。
+ * 2 線の長さ(LineLen) を求める。
+ * 3 end_point を求める。
+ * 4 補助線を描画
  *	
  */
 int DXF_LineEndExtension(FILE *stream, int LAYER, double SX, double SY, double EX, double EY, int DrawType)
@@ -2352,7 +2352,7 @@ int DXF_LineEndExtension(FILE *stream, int LAYER, double SX, double SY, double E
 	CAD cad;
 	int Ret;
 
-	/* 1 γ(Angle) 롣*/
+	/* 1 線の角度(Angle) を求める。*/
 	a.sx[1] = SX;
 	a.sy[1] = SY;
 	a.ex[1] = EX;
@@ -2360,7 +2360,7 @@ int DXF_LineEndExtension(FILE *stream, int LAYER, double SX, double SY, double E
 	Ret = la(&a);
 	Angle = a.angle;
 
-	/* 2 Ĺ(LineLen) 롣*/
+	/* 2 線の長さ(LineLen) を求める。*/
 	a.sx[1] = SX;
 	a.sy[1] = SY;
 	a.ex[1] = EX;
@@ -2368,18 +2368,18 @@ int DXF_LineEndExtension(FILE *stream, int LAYER, double SX, double SY, double E
 	Ret = pp(&a);
 	LineLen = a.l;
 
-	/* 3 end_point 롣*/
+	/* 3 end_point を求める。*/
 	a.sx[1] = SX;
 	a.sy[1] = SY;
 	a.angle = Angle;
 
-	/* ̤ν̼ɽ (ץ󥿡᡼) */
+	/* 図面の縮尺表示 (プリンターイメージ) */
 	if (DrawType == DRAW_DISP)
 		a.l = LineLen + (sagcad_dimension.arrow_line_extension / printer.scale);
-	/* ʸɽ */
+	/* 文字サイズ固定表示 */
 	else if (DrawType == DRAW_CONST) 
 		a.l = LineLen + (sagcad_dimension.arrow_line_extension / Mag);
-	/* ꤷ礭򤽤Τޤɽ */
+	/* 設定した大きさをそのまま表示 */
 	else if (DrawType == DRAW_REAL) 
 		a.l = LineLen + sagcad_dimension.arrow_line_extension;
 	else 
@@ -2389,7 +2389,7 @@ int DXF_LineEndExtension(FILE *stream, int LAYER, double SX, double SY, double E
 	end_pointX = a.ex[1];
 	end_pointY = a.ey[1];
 
-	/* 4 */
+	/* 4 補助線を描画*/
 //	LineBasic(hDC, SX, SY, end_pointX, end_pointY, 1);
 	cad.layer = LAYER;
 	cad.code = 1;
@@ -2412,7 +2412,7 @@ int DXF_LineEndExtension(FILE *stream, int LAYER, double SX, double SY, double E
 
 
 /* ====================================================================
- * ===	Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===	Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *	  Project			   : SagCAD
  *	  Source			   : DXF_write.cpp
@@ -2426,7 +2426,7 @@ int DXF_LineEndExtension(FILE *stream, int LAYER, double SX, double SY, double E
 /* -------------------------------------------------------------------
  * SgyToDxf_color
  *	
- *	SGY Υ顼 DXF Υ顼ѹ
+ *	SGY のカラーを DXF のカラーに変更
  *	
  */
 int SgyToDxf_color(long SgyColor)
@@ -2706,7 +2706,7 @@ int SgyToDxf_color(long SgyColor)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : DXF_write.c
