@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/01/16
- *    Last                 : 2003/02/07
+ *    Last                 : 2007/10/14
  * ====================================================================
  */
 
@@ -39,7 +39,7 @@
 #include "List_Undo.h"
 #include "List_Select.h"
 #include "global.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "spline.h"
 #include "B_spline.h"
 #include "Select.h"
@@ -53,17 +53,17 @@
 
 
 /* -------------------------------------------------------------------
- * ӥ塼ݡ(ǥХɸ)
+ * ビューポート(デバイス座標系)の設定
  * 
  *                     (WX2,WY2)                 (SX2,SY2)
- *                   
- *                                         
- *       (WXp,WYp)                    (SXp,SYp)
- *                                             
- *                                             
- *                   
+ *      ┌────────┐             ┌─────┐
+ *      │   ・           │             │  ・      │
+ *      │ (WXp,WYp)      │             │ (SXp,SYp)│
+ *      │                │             │          │
+ *      │                │             │          │
+ *      └────────┘             └─────┘
  *   (WX1,WY1)                       (SX1,SY1)         
- *           ɥ                    ӥ塼ݡ
+ *           ウインドウ                    ビューポート
  * 
  */
 gint view_port_set(gdouble vx1, gdouble vy1, gdouble vx2, gdouble vy2)
@@ -88,19 +88,19 @@ g_print("ViewPort(%f,%f)-(%f,%f)  ViewPortAspect = %f\n", SX1, SY1, SX2, SY2, Vi
 
 
 /* -------------------------------------------------------------------
- * ɥ(ɺɸ)
+ * ウインドウ(ワールド座標系)の設定
  * 
- * ViewPort ꤷƤꤹ
+ * ViewPort を設定してから設定する
  * 
  *                     (WX2,WY2)                 (SX2,SY2)
- *                   
- *                                         
- *       (WXp,WYp)                    (SXp,SYp)
- *                                             
- *                                             
- *                   
+ *      ┌────────┐             ┌─────┐
+ *      │   ・           │             │  ・      │
+ *      │ (WXp,WYp)      │             │ (SXp,SYp)│
+ *      │                │             │          │
+ *      │                │             │          │
+ *      └────────┘             └─────┘
  *   (WX1,WY1)                       (SX1,SY1)         
- *           ɥ                    ӥ塼ݡ
+ *           ウインドウ                    ビューポート
  * 
  */
 gint world_window_set_center(gdouble mag, gdouble mag_x, gdouble mag_y, gdouble view_x)
@@ -130,9 +130,9 @@ gint world_window_set_center(gdouble mag, gdouble mag_x, gdouble mag_y, gdouble
 
 
 /* ---------------------------------------------------------------------
+ * 描画処理
  * 
- * 
- * δؿľܸƤִؿ
+ * この関数を直接呼ぶ関数は
  *     Draw.c : Redraw()
  *     DrawArea.c : configure_event()
  * 
@@ -153,95 +153,95 @@ void Draw(GtkWidget *widget)
 
 
 	/* -----------------------------------------------------------------
-	 * ޷ 
+	 * 図形描画 
 	 */
 	p = cad_list_info.head;
 	while(p != NULL) {
 		if(Layer[p->cad->layer].draw == 1) {
 			switch (p->cad->code) {
-				case 0: /* ΤȤ */
+				case 0: /* 点のとき */
 					PointDraw(widget, p->cad->sx, p->cad->sy, p->cad->style, p->cad->color);
 					break;
-				case 1: /* ľΤȤ */
+				case 1: /* 直線のとき */
 					LineDraw(widget,	
 							 p->cad->sx, p->cad->sy, p->cad->ex, p->cad->ey, 
 							 p->cad->style, p->cad->color);
 					break;
-				case 2: /* ߸̤ΤȤ */
+				case 2: /* 円弧のとき */
 					ArcDraw(widget, 
 							p->cad->cx, p->cad->cy, p->cad->r, 
 							p->cad->sx, p->cad->sy, p->cad->ex, p->cad->ey, 
 							p->cad->style, p->cad->color);
 					break;
-				case 4: /* ߤΤȤ */
+				case 4: /* 円のとき */
 					CircleDraw(widget,	
 							p->cad->cx, p->cad->cy, p->cad->r, 
 							p->cad->style, p->cad->color);
 					break;
 			}
 		}
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 
 
 	/* -----------------------------------------------------------------
-	 * ˡ
+	 * 寸法描画
 	 */
-	/* ˡ */
+	/* 各寸法要素 */
 	pd = dimension_list_info.head;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(pd != NULL) {
 		if(Layer[pd->dimension->Layer].draw == 1) {
 			DimensionDraw(widget, pd->dimension, SCD_ORG);
 		}
-		pd = pd->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pd = pd->next;	/* ポインタを次のデータに移す */
 	}
 
 
 
 	/* -----------------------------------------------------------------
-	 * ݥ饤
+	 * ポリライン描画
 	 */
-	/* ƥݥ饤 */
+	/* 各ポリライン要素 */
 	pld = polyline_list_info.head;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(pld != NULL) {
 		if(Layer[pld->polyline->layer].draw == 1) {
 			PolyLineDraw(widget, pld->polyline, SCD_ORG);
 		}
-		pld = pld->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pld = pld->next;	/* ポインタを次のデータに移す */
 	}
 
 
 
 	/* -----------------------------------------------------------------
-	 * ʱ
+	 * 楕円描画
 	 */
 	pe = ellipse_list_info.head;
 	while (pe != NULL) {
 		if(Layer[pe->ellipse->layer].draw == 1) {
 			EllipseDraw(widget, pe->ellipse, SCD_ORG);
 		}
-		pe = pe->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pe = pe->next;	/* ポインタを次のデータに移す */
 	}
 
 
 
 	/* -----------------------------------------------------------------
-	 * ޷
+	 * 選択図形作図
 	 */
 	if (select_list_info.head != NULL) {
 		ps = select_list_info.head;
 		while (ps != NULL) {
 			SelectDraw(widget, ps->select, SCD_SELECT, UPDATE_OFF);
-			ps = ps->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			ps = ps->next;	/* ポインタを次のデータに移す */
 		}
 	}
 
@@ -267,12 +267,12 @@ void Draw(GtkWidget *widget)
 
 
 /* -------------------------------------------------------------------
- * CAD Data ǥХɸ(ǥץ쥤ޤϥץ󥿡)Ѵ (X)
+ * CAD Data をデバイス座標(ディスプレイまたはプリンター)に変換 (X)
  *	
  *	
- * < ץ󥿡 >
- * Printer_width 	: ΰβ mm Ȥ뤫(ºݤ礭ǤϤʤ)
- * Horzres 			: ΰβ礭 (ԥñ)
+ * < プリンター >
+ * Printer_width 	: 印刷領域の横を何 mm とするか(実際の大きさではない)
+ * Horzres 			: 印刷領域の横の大きさ (ピクセル単位)
  * p_dpiX			: dpi
  *	
  */
@@ -295,12 +295,12 @@ int ToDeviceX(double x)
 
 
 /* -------------------------------------------------------------------
- * CAD Data ǥץ쥤ɸޤϥץ󥿡ɸѴ (Y)
+ * CAD Data をディスプレイ座標またはプリンター座標に変換 (Y)
  *	
  *	
- * < ץ󥿡 >
- * Printer_height 	: ΰνĤ mm Ȥ뤫(ºݤ礭ǤϤʤ)
- * Vertres 			: ΰνĤ礭 (ԥñ)
+ * < プリンター >
+ * Printer_height 	: 印刷領域の縦を何 mm とするか(実際の大きさではない)
+ * Vertres 			: 印刷領域の縦の大きさ (ピクセル単位)
  * p_dpiY			: dpi
  *	
  */
@@ -323,9 +323,9 @@ int ToDeviceY(double y)
 
 
 /* -------------------------------------------------------------------
- * ǥХɸ(ǥץ쥤) CAD Data Υ꡼ɸѴ (X)
+ * デバイス座標(ディスプレイ)から CAD Data のスクリーン座標に変換 (X)
  *	
- *	ToViewK  window_set Ѥ
+ *	ToViewK は window_set で設定済み
  */
 double ToViewX(int x)
 {
@@ -346,9 +346,9 @@ double ToViewX(int x)
 
 
 /* -------------------------------------------------------------------
- * ǥХɸ(ǥץ쥤) CAD Data Υ꡼ɸѴ (Y)
+ * デバイス座標(ディスプレイ)から CAD Data のスクリーン座標に変換 (Y)
  *	
- *	ToViewK  window_set Ѥ
+ *	ToViewK は window_set で設定済み
  */
 double ToViewY(int y)
 {
@@ -369,7 +369,7 @@ double ToViewY(int y)
 
 
 /* ------------------------------------------------------------------
- * GC 
+ * GC 作成
  */
 GdkGC *create_gc(GtkWidget *widget)
 {	return gdk_gc_new(widget->window); }
@@ -379,7 +379,7 @@ GdkGC *create_gc(GtkWidget *widget)
 
 
 /* ------------------------------------------------------------------
- * GC 
+ * GC 開放
  */
 void delete_gc(GdkGC *gc)
 {	gdk_gc_destroy(gc); }
@@ -389,10 +389,10 @@ void delete_gc(GdkGC *gc)
 
 
 /* -------------------------------------------------------------------
- * ڥ
+ * ペンを選ぶ
  * 
- * WIN32 ʤ HDC
- * LINUX ʤ GC
+ * WIN32 なら HDC
+ * LINUX なら GC
  * 
  */
 int PenSet(GdkGC *gc, int style, long color)
@@ -420,7 +420,7 @@ int PenSet(GdkGC *gc, int style, long color)
 
 
 /* ------------------------------------------------------------------
- * GC   (BackColor )
+ * GC を設定  (BackColor も設定)
  * GC Setting
  */
 int PenSet_with_back(GdkGC *gc, int style, long color, long backcolor)
@@ -446,17 +446,17 @@ int PenSet_with_back(GdkGC *gc, int style, long color, long backcolor)
 	else if(style == 1) {
 		gdk_gc_set_line_attributes(gc, 1, GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
 	}
-	/*  */
+	/* 点線 */
 	else if(style == 2) {
 		gdk_gc_set_line_attributes(gc, 1, GDK_LINE_DOUBLE_DASH, GDK_CAP_BUTT, GDK_JOIN_MITER);
 		gdk_gc_set_dashes(gc, 0, dash, 2);
 	}
-	/*  */
+	/* １点鎖線 */
 	else if(style == 3) {
 		gdk_gc_set_line_attributes(gc, 1, GDK_LINE_DOUBLE_DASH, GDK_CAP_BUTT, GDK_JOIN_MITER);
 		gdk_gc_set_dashes(gc, 0, dash1, 4);
 	}
-	/*  */
+	/* ２点鎖線 */
 	else if(style == 4) {
 		gdk_gc_set_line_attributes(gc, 1, GDK_LINE_DOUBLE_DASH, GDK_CAP_BUTT, GDK_JOIN_MITER);
 		gdk_gc_set_dashes(gc, 0, dash2, 6);
@@ -472,7 +472,7 @@ int PenSet_with_back(GdkGC *gc, int style, long color, long backcolor)
 
 
 /* -------------------------------------------------------------------
- * ڥ
+ * ペンを削除
  *	
  */
 int PenDelete(GdkGC *gc)
@@ -485,7 +485,7 @@ int PenDelete(GdkGC *gc)
 
 
 /* ---------------------------------------------------------------------
- * ߤ
+ * 円を描画
  */
 int CircleDraw(GtkWidget *widget, double CX, double CY, double R, int Style, long color)
 {
@@ -503,7 +503,7 @@ int CircleDraw(GtkWidget *widget, double CX, double CY, double R, int Style, lon
 
 
 /* ---------------------------------------------------------------------
- * ߸̤
+ * 円弧を描画
  */
 int ArcDraw(GtkWidget *widget, double CX, double CY, double R, double SX, double SY, double EX, double EY, int Style, long color)
 {
@@ -532,7 +532,7 @@ int ArcDraw(GtkWidget *widget, double CX, double CY, double R, double SX, double
 
 
 /* ---------------------------------------------------------------------
- * ľ
+ * 直線を描画
  */
 int LineDraw(GtkWidget *widget, double SX, double SY, double EX, double EY, int Style, long color)
 {
@@ -551,7 +551,7 @@ int LineDraw(GtkWidget *widget, double SX, double SY, double EX, double EY, int
 
 
 /* ---------------------------------------------------------------------
- * 
+ * 点を描画
  */
 int PointDraw(GtkWidget *widget, double x, double y, int Style, long color)
 {
@@ -593,9 +593,9 @@ int PointDraw(GtkWidget *widget, double x, double y, int Style, long color)
 
 
 /* -------------------------------------------------------------------
- * ץ饤
- * 
+ * スプライン補間
  * 
+ * 開曲線
  * 
  */
 int open_spline_Basic(GtkWidget *widget, int n, VERTEX *vertex, int split, int style, long color)
@@ -673,9 +673,9 @@ int open_spline_Basic(GtkWidget *widget, int n, VERTEX *vertex, int split, int s
 
 
 /* -------------------------------------------------------------------
- * ץ饤
+ * スプライン補間
  * 
- * Ķ
+ * 閉曲線
  * 
  */
 int close_spline_Basic(GtkWidget *widget, int n, VERTEX *vertex, int split, int style, long color)
@@ -753,11 +753,11 @@ int close_spline_Basic(GtkWidget *widget, int n, VERTEX *vertex, int split, int
 
 
 /* -------------------------------------------------------------------
- * ¥ץ饤
+ * ３次Ｂスプライン
  * 
- * ǡο㣷ĤɬפȤʤ롣
- *     ǡοĤξ硢ʬ
- *     ǡοĤ飶Ĥξ硢ʬ
+ * データの数が最低７個は必要となる。
+ *     データの数が３個の場合、中間点を３分割
+ *     データの数が４個から６個の場合、中間点を２分割
  * 
  */
 int b_spline_Basic(GtkWidget *widget, int n, VERTEX *vertex, double pitch, int style, long color)
@@ -830,23 +830,23 @@ int b_spline_Basic(GtkWidget *widget, int n, VERTEX *vertex, double pitch, int s
 
 	for (i = 0 ; i < n-3 ; i++) {
 		for (u = 0.0 ; u <= 1.0 + pitch/2 ; u = u + pitch) {
-			/* ǽζ */
+			/* 最初の区間 */
 			if (i == 0) {
 				spl1(u, &s1, &s2, &s3, &s4);
 			}
-			/* ܤζ */
+			/* ２番目の区間 */
 			else if (i == 1) {
 				spl2(u, &s1, &s2, &s3, &s4);
 			}
-			/* ֤ζ */
+			/* 中間の区間 */
 			else if (i > 1 && i < n-5) {
 				spl3(u, &s1, &s2, &s3, &s4);
 			}
-			/* Ǹ夫飲ܤζ */
+			/* 最後から２番目の区間 */
 			else if (i > 1 && i == n-5) {
 				spl4(u, &s1, &s2, &s3, &s4);
 			}
-			/* Ǹζ */
+			/* 最後の区間 */
 			else if (i > 2 && i == n-4) {
 				spl5(u, &s1, &s2, &s3, &s4);
 			}
@@ -879,11 +879,11 @@ int b_spline_Basic(GtkWidget *widget, int n, VERTEX *vertex, double pitch, int s
 
 
 /* -------------------------------------------------------------------
- * ݥ饤
+ * ポリライン描画
  *	
- * 		 DrawType = 1  SCD_SELECT
- * ο	 DrawType = 0  SCD_ORG
- * 		 DrawType = 2  SCD_HIDE
+ * 選択		： DrawType = 1  SCD_SELECT
+ * 元の色	： DrawType = 0  SCD_ORG
+ * 消		： DrawType = 2  SCD_HIDE
  */
 int PolyLineDraw(GtkWidget *widget, POLYLINE *a, int frag)
 {
@@ -911,9 +911,9 @@ int PolyLineDraw(GtkWidget *widget, POLYLINE *a, int frag)
 
 	if (Layer[a->layer].draw == 1) {
 
-		/* ݥ饤(ޤ) */
+		/* ポリライン(折れ線) */
 		if (a->code == 8) {
-			if (debug > 0) g_print ("PolyLineDraw() : ݥ饤(ޤ) in\n");
+			if (debug > 0) g_print ("PolyLineDraw() : ポリライン(折れ線) in\n");
 			v = a->vertex_list_info.head;
 			i = 0;
 			while (v != NULL) {
@@ -932,7 +932,7 @@ int PolyLineDraw(GtkWidget *widget, POLYLINE *a, int frag)
 				v = v->next;
 			}
 
-			/* ĤƤȤ */
+			/* 閉じているとき */
 			if ((a->frag & 1) == 1) {
 				LineDraw(widget, first.x, first.y, old.x, old.y, a->style, color);
 			}
@@ -941,15 +941,15 @@ int PolyLineDraw(GtkWidget *widget, POLYLINE *a, int frag)
 
 
 
-		/* ץ饤 */
+		/* スプライン補間 */
 		else if (a->code == 16) {
-			if (debug > 0) g_print ("PolyLineDraw() : ץ饤 in\n");
+			if (debug > 0) g_print ("PolyLineDraw() : スプライン補間 in\n");
 			if (debug > 0) g_print ("PolyLineDraw() : index = %d   frag = %d\n", a->index, a->frag);
 
 			if (a->index > 0) {
 				vertex = (VERTEX *) xmalloc( (a->index + 1) * sizeof(VERTEX) );
 
-				if (debug > 0) g_print ("PolyLineDraw() : ץ饤 0\n");
+				if (debug > 0) g_print ("PolyLineDraw() : スプライン補間 0\n");
 
 				v = a->vertex_list_info.head;
 				i = 0;
@@ -959,30 +959,30 @@ int PolyLineDraw(GtkWidget *widget, POLYLINE *a, int frag)
 					v = v->next;
 				}
 
-				if (debug > 0) g_print ("PolyLineDraw() : ץ饤 1\n");
+				if (debug > 0) g_print ("PolyLineDraw() : スプライン補間 1\n");
 
-				/* ĤƤȤ(Ķ) */
+				/* 閉じているとき(閉曲線) */
 				if ((a->frag & 1) == 1) {
-					if (debug > 0) g_print ("PolyLineDraw() : ץ饤 2\n");
+					if (debug > 0) g_print ("PolyLineDraw() : スプライン補間 2\n");
 					vertex[i] = vertex[0];
 					close_spline_Basic(widget, a->index, vertex, a->index * a->split, a->style, color);
 				}
-				/* () */
+				/* (開曲線) */
 				else {
-					if (debug > 0) g_print ("PolyLineDraw() : ץ饤 3\n");
+					if (debug > 0) g_print ("PolyLineDraw() : スプライン補間 3\n");
 					open_spline_Basic(widget, a->index, vertex, a->index * a->split, a->style, color);
 				}
 
-				if (debug > 0) g_print ("PolyLineDraw() : ץ饤 4\n");
+				if (debug > 0) g_print ("PolyLineDraw() : スプライン補間 4\n");
 
 				xfree(vertex);
 			}
 		}
 
 
-		/* ¥ץ饤 */
+		/* Ｂスプライン曲線 */
 		else if (a->code == 32) {
-			if (debug > 0) g_print ("PolyLineDraw() : ¥ץ饤 in\n");
+			if (debug > 0) g_print ("PolyLineDraw() : Ｂスプライン曲線 in\n");
 			if (a->index > 0) {
 				vertex = (VERTEX *) xmalloc( a->index * sizeof(VERTEX) );
 
@@ -1008,11 +1008,11 @@ int PolyLineDraw(GtkWidget *widget, POLYLINE *a, int frag)
 
 
 /* -------------------------------------------------------------------
- * ʱ (ELLIPSE)
+ * 楕円描画 (ELLIPSE)
  *	
- * 		 DrawType = 1  SCD_SELECT
- * ο	 DrawType = 0  SCD_ORG
- * 		 DrawType = 2  SCD_HIDE
+ * 選択		： DrawType = 1  SCD_SELECT
+ * 元の色	： DrawType = 0  SCD_ORG
+ * 消		： DrawType = 2  SCD_HIDE
  */
 int EllipseDraw(GtkWidget *widget, ELLIPSE *ellipse, int frag)
 {
@@ -1041,10 +1041,10 @@ int EllipseDraw(GtkWidget *widget, ELLIPSE *ellipse, int frag)
 
 
 /* -------------------------------------------------------------------
- * Ȥκɸ֤
+ * 点を枠の中だけの座標を返す
  *	
  *	
- * ͡ int    0:ԲĻ    1:Ļ
+ * 戻値　： int    0:不可視    1:可視
  *	
  */
 int PointCheckDraw(double *SX, double *SY)
@@ -1053,7 +1053,7 @@ int PointCheckDraw(double *SX, double *SY)
 	int s_bit = 0;
 
 
-	/* ǥץ쥤 */
+	/* ディスプレイ */
 	if (DrawObject == 0) {
 //		left   =	MagX - ((sagcad_system.ViewX/Mag)/2);
 //		top	   =	MagY + (((sagcad_system.ViewX/Mag)/2)*sagcad_system.Aspect);
@@ -1067,7 +1067,7 @@ int PointCheckDraw(double *SX, double *SY)
 	}
 
 #ifdef TEST
-	/* ץ󥿡 */
+	/* プリンター */
 	else if (DrawObject == 1) {
 		left   =	MagX - (sagcad_printer.Printer_width/2);
 		top	   =	MagY + ((sagcad_printer.Printer_width/2)*sagcad_printer.Printer_Aspect);
@@ -1083,7 +1083,7 @@ int PointCheckDraw(double *SX, double *SY)
 #endif
 
 
-	/* Ļ */
+	/* 可視 */
 	if(s_bit == 0) return 1;
 	return 0;
 }
@@ -1093,10 +1093,10 @@ int PointCheckDraw(double *SX, double *SY)
 
 
 /* -------------------------------------------------------------------
- * ߤȤκɸ֤
+ * 円を枠の中だけの座標を返す
  *	
  *	
- * ͡ int    0:ԲĻ    1:Ļ
+ * 戻値　： int    0:不可視    1:可視
  *	
  */
 int CircleCheckDraw(double *CX, double *CY, double *R)
@@ -1105,7 +1105,7 @@ int CircleCheckDraw(double *CX, double *CY, double *R)
 	int s_bit = 0;
 
 
-	/* ǥץ쥤 */
+	/* ディスプレイ */
 	if (DrawObject == 0) {
 //		left   =	(MagX - ((sagcad_system.ViewX/Mag)/2)) - *R;
 //		top	   =	(MagY + (((sagcad_system.ViewX/Mag)/2)*sagcad_system.Aspect)) + *R;
@@ -1122,7 +1122,7 @@ int CircleCheckDraw(double *CX, double *CY, double *R)
 
 
 #ifdef TEST
-	/* ץ󥿡 */
+	/* プリンター */
 	else if (DrawObject == 1) {
 		left   =	(MagX - (sagcad_printer.Printer_width/2)) - *R;
 		top	   =	(MagY + ((sagcad_printer.Printer_width/2)*sagcad_printer.Printer_Aspect)) + *R;
@@ -1137,7 +1137,7 @@ int CircleCheckDraw(double *CX, double *CY, double *R)
 #endif
 
 
-	/* Ļ */
+	/* 可視 */
 	if(s_bit == 0) return 1;
 	return 0;
 }
@@ -1147,10 +1147,10 @@ int CircleCheckDraw(double *CX, double *CY, double *R)
 
 
 /* -------------------------------------------------------------------
- * ľȤκɸ֤
+ * 直線を枠の中だけの座標を返す
  *	
  *	
- * ͡ int    0:ԲĻ    1:Ѵ OK	2:Ѵ̵Ļ
+ * 戻値　： int    0:不可視    1:変換 OK	2:変換無し可視
  *	
  */
 int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
@@ -1168,7 +1168,7 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 	ex = *EX;
 	ey = *EY;
 
-	/* ǥץ쥤 */
+	/* ディスプレイ */
 	if (DrawObject == 0) {
 //		left   = MagX - ((sagcad_system.ViewX / Mag) / 2);
 //		top    = MagY + (((sagcad_system.ViewX / Mag) / 2) * sagcad_system.Aspect);
@@ -1183,7 +1183,7 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 
 
 #ifdef TEST
-	/* ץ󥿡 */
+	/* プリンター */
 	else if (DrawObject == 1) {
 		left   = MagX - (sagcad_printer.Printer_width / 2);
 		top    = MagY + ((sagcad_printer.Printer_width / 2) * sagcad_printer.Printer_Aspect);
@@ -1211,13 +1211,13 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 
 
 
-	/*  */
+	/* 始点 */
 	if(sy > top)	s_bit = s_bit + 8;
 	if(sy < bottom) s_bit = s_bit + 4;
 	if(sx > right)	s_bit = s_bit + 2;
 	if(sx < left)	s_bit = s_bit + 1;
 
-	/*  */
+	/* 終点 */
 	if(ey > top)	e_bit = e_bit + 8;
 	if(ey < bottom) e_bit = e_bit + 4;
 	if(ex > right)	e_bit = e_bit + 2;
@@ -1226,7 +1226,7 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 
 
 	/* ---------------------------------------------------------------
-	 * ˲Ļ
+	 * 完全に可視
 	 */
 	if(s_bit == 0 && e_bit == 0) {
 		return 2;
@@ -1235,7 +1235,7 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 
 
 	/* ---------------------------------------------------------------
-	 * ԲĻ
+	 * 完全に不可視
 	 */
 	if ((s_bit & e_bit) != 0) {
 		return 0;
@@ -1244,7 +1244,7 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 
 
 	/* ---------------------------------------------------------------
-	 * Ļβǽ (1)
+	 * 可視の可能性がある (1)
 	 */
 	if ( ((s_bit && e_bit) == 0) 
 		 || 
@@ -1257,14 +1257,14 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 		 ( s_bit == 0x1 && e_bit == 0x2 ) ) 
 	{
 		/* -----------------------------------------------------------
-		 * ζȸ뤫
+		 * 上の境界線と交点があるか
 		 */
 		if ( (s_bit & 8) == 8 || (e_bit & 8) == 8 ) {
-			/* ľȾζȤθ */
+			/* 直線と上の境界線との交点を求める */
 			LLPH.sx[1] = sx;	LLPH.sy[1] = sy;	LLPH.ex[1] = ex;	LLPH.ey[1] = ey;
 			LLPH.sx[2] = left;	LLPH.sy[2] = top;	LLPH.ex[2] = right;	LLPH.ey[2] = top;
 			llp(&LLPH);
-			/*  */
+			/* 交点がある */
 			if (LLPH.sx[3] > left && LLPH.sx[3] < right) {
 				if ((s_bit & 8) == 8) {
 					*SX = LLPH.sx[3];
@@ -1280,14 +1280,14 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 		}
 
 		/* -----------------------------------------------------------
-		 * ζȸ뤫
+		 * 下の境界線と交点があるか
 		 */
 		if ( (s_bit & 4) == 4 || (e_bit & 4) == 4 ) {
-			/* ľȲζȤθ */
+			/* 直線と下の境界線との交点を求める */
 			LLPH.sx[1] = sx;	LLPH.sy[1] = sy;	LLPH.ex[1] = ex;	LLPH.ey[1] = ey;
 			LLPH.sx[2] = left;	LLPH.sy[2] = bottom;	LLPH.ex[2] = right;	LLPH.ey[2] = bottom;
 			llp(&LLPH);
-			/*  */
+			/* 交点がある */
 			if (LLPH.sx[3] > left && LLPH.sx[3] < right) {
 				if ( (s_bit & 4) == 4 ) {
 					*SX = LLPH.sx[3];
@@ -1303,14 +1303,14 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 		}
 
 		/* -----------------------------------------------------------
-		 * ζȸ뤫
+		 * 右の境界線と交点があるか
 		 */
 		if ( (s_bit & 2) == 2 || (e_bit & 2) == 2 ) {
-			/* ľȱζȤθ */
+			/* 直線と右の境界線との交点を求める */
 			LLPH.sx[1] = sx;	LLPH.sy[1] = sy;	LLPH.ex[1] = ex;	LLPH.ey[1] = ey;
 			LLPH.sx[2] = right;	LLPH.sy[2] = top;	LLPH.ex[2] = right;	LLPH.ey[2] = bottom;
 			llp(&LLPH);
-			/*  */
+			/* 交点がある */
 			if (LLPH.sy[3] > bottom && LLPH.sy[3] < top) {
 				if ( ( s_bit & 2) == 2 ) {
 					*SX = LLPH.sx[3];
@@ -1326,14 +1326,14 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 		}
 
 		/* -----------------------------------------------------------
-		 * ζȸ뤫
+		 * 左の境界線と交点があるか
 		 */
 		if ( (s_bit & 1) == 1 || (e_bit & 1) == 1 ) {
-			/* ľȺζȤθ */
+			/* 直線と左の境界線との交点を求める */
 			LLPH.sx[1] = sx;	LLPH.sy[1] = sy;	LLPH.ex[1] = ex;	LLPH.ey[1] = ey;
 			LLPH.sx[2] = left;	LLPH.sy[2] = top;	LLPH.ex[2] = left;	LLPH.ey[2] = bottom;
 			llp(&LLPH);
-			/*  */
+			/* 交点がある */
 			if (LLPH.sy[3] > bottom && LLPH.sy[3] < top) {
 				if ( (s_bit & 1) == 1 ) {
 					*SX = LLPH.sx[3];
@@ -1360,8 +1360,8 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 
 
 	/* ---------------------------------------------------------------
-	 * Ļβǽ (2)
-	 * ȤȳʤΤǡͭвĻ
+	 * 可視の可能性がある (2)
+	 * 始点終点とも枠外なので、交点が２個有れば可視
 	 */
 	if(	( (s_bit & 8) == 8 && (e_bit & 1) == 1 ) 
 		|| 
@@ -1382,11 +1382,11 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 		CP = 0;
 
 		/* -------------------------------------------------
-		 * ζȸ뤫
+		 * 上の境界線と交点があるか
 		 */
 		LLPH.sx[1] = sx;	LLPH.sy[1] = sy;	LLPH.ex[1] = ex;	LLPH.ey[1] = ey;
 		LLPH.sx[2] = left;	LLPH.sy[2] = top;	LLPH.ex[2] = right;	LLPH.ey[2] = top;
-		/*  */
+		/* 交点がある */
 		if (Act_llp(&LLPH) == 1) {
 			CP++;
 			if(CP == 1) {
@@ -1398,11 +1398,11 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 		}
 
 		/* -------------------------------------------------
-		 * ζȸ뤫
+		 * 下の境界線と交点があるか
 		 */
 		LLPH.sx[1] = sx;	LLPH.sy[1] = sy;	LLPH.ex[1] = ex;	LLPH.ey[1] = ey;
 		LLPH.sx[2] = left;	LLPH.sy[2] = bottom;	LLPH.ex[2] = right;	LLPH.ey[2] = bottom;
-		/*  */
+		/* 交点がある */
 		if (Act_llp(&LLPH) == 1) {
 			CP++;
 			if(CP == 1) {
@@ -1414,11 +1414,11 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 		}
 
 		/* -------------------------------------------------
-		 * ζȸ뤫
+		 * 右の境界線と交点があるか
 		 */
 		LLPH.sx[1] = sx;	LLPH.sy[1] = sy;	LLPH.ex[1] = ex;	LLPH.ey[1] = ey;
 		LLPH.sx[2] = right;	LLPH.sy[2] = top;	LLPH.ex[2] = right;	LLPH.ey[2] = bottom;
-		/*  */
+		/* 交点がある */
 		if (Act_llp(&LLPH) == 1) {
 			CP++;
 			if(CP == 1) {
@@ -1430,11 +1430,11 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 		}
 
 		/* -------------------------------------------------
-		 * ζȸ뤫
+		 * 左の境界線と交点があるか
 		 */
 		LLPH.sx[1] = sx;	LLPH.sy[1] = sy;	LLPH.ex[1] = ex;	LLPH.ey[1] = ey;
 		LLPH.sx[2] = left;	LLPH.sy[2] = top;	LLPH.ex[2] = left;	LLPH.ey[2] = bottom;
-		/*  */
+		/* 交点がある */
 		if (Act_llp(&LLPH) == 1) {
 			CP++;
 			if(CP == 1) {
@@ -1459,7 +1459,7 @@ int LineCheckDraw(double *SX,double *SY,double *EX,double *EY)
 
 
 /* ---------------------------------------------------------------------
- * ޤ˰ư
+ * 図を上に移動
  */
 void MoveUp(void)
 {
@@ -1470,14 +1470,14 @@ void MoveUp(void)
 		MagY = MagY + sagcad_system.ScrollPitch;
 	}
 	SetMag(Mag);
-	/* --- <  > --- */
+	/* --- < 再描画処理 > --- */
 //	Redraw();
 }
 
 
 
 /* ---------------------------------------------------------------------
- * ޤ򲼤˰ư
+ * 図を下に移動
  */
 void MoveDown(void)
 {
@@ -1488,14 +1488,14 @@ void MoveDown(void)
 		MagY = MagY - sagcad_system.ScrollPitch;
 	}
 	SetMag(Mag);
-	/* --- <  > --- */
+	/* --- < 再描画処理 > --- */
 //	Redraw();
 }
 
 
 
 /* ---------------------------------------------------------------------
- * ޤ򱦤˰ư
+ * 図を右に移動
  */
 void MoveRight(void)
 {
@@ -1506,14 +1506,14 @@ void MoveRight(void)
 		MagX = MagX + sagcad_system.ScrollPitch;
 	}
 	SetMag(Mag);
-	/* --- <  > --- */
+	/* --- < 再描画処理 > --- */
 //	Redraw();
 }
 
 
 
 /* ---------------------------------------------------------------------
- * ޤ򺸤˰ư 
+ * 図を左に移動 
  */
 void MoveLeft(void)
 {
@@ -1524,22 +1524,22 @@ void MoveLeft(void)
 		MagX = MagX - sagcad_system.ScrollPitch;
 	}
 	SetMag(Mag);
-	/* --- <  > --- */
+	/* --- < 再描画処理 > --- */
 //	Redraw();
 }
 
 
 
 /* ---------------------------------------------------------------------
- * 
+ * 再描画
  */
 void Redraw(void)
 {
-	GdkRectangle update_rect;
-	update_rect.x = 0;
-	update_rect.y = 0;
-	update_rect.width = sagcad_system.DeviceX;
-	update_rect.height = sagcad_system.DeviceY;
+//	GdkRectangle update_rect;
+//	update_rect.x = 0;
+//	update_rect.y = 0;
+//	update_rect.width = sagcad_system.DeviceX;
+//	update_rect.height = sagcad_system.DeviceY;
 
 	PenSet(gc, 1, sagcad_color.Back);
 	gdk_draw_rectangle (pixmap/*drawing_area->window*/, gc, TRUE, 0, 0, sagcad_system.DeviceX, sagcad_system.DeviceY);
@@ -1547,24 +1547,19 @@ void Redraw(void)
 //g_print("Draw.c : Redraw() : Draw\n");
 	Draw(drawing_area);
 	//g_print("Redraw Mag = %f  MagX = %f  MagY = %f\n", Mag, MagX, MagY);
-	gtk_widget_draw (drawing_area, &update_rect);
+	//gtk_widget_draw (drawing_area, &update_rect);
+	gtk_widget_queue_draw_area (drawing_area, 0, 0, sagcad_system.DeviceX, sagcad_system.DeviceY);
 	return;
 }
 
 
 
 /* ---------------------------------------------------------------------
- * 
+ * 再描画
  */
 void UpDate(void)
 {
-	GdkRectangle update_rect;
-	update_rect.x = 0;
-	update_rect.y = 0;
-	update_rect.width = sagcad_system.DeviceX;
-	update_rect.height = sagcad_system.DeviceY;
-
-	gtk_widget_draw (drawing_area, &update_rect);
+	gtk_widget_queue_draw_area (drawing_area, 0, 0, sagcad_system.DeviceX, sagcad_system.DeviceY);
 
 //	g_print("Draw.c : UpDate() : UpDate\n");
 }
@@ -1574,18 +1569,11 @@ void UpDate(void)
 
 
 /* ---------------------------------------------------------------------
- * 
+ * 再描画
  */
 void UpDate_widget(GtkWidget *widget)
 {
-	GdkRectangle update_rect;
-
-	update_rect.x = 0;
-	update_rect.y = 0;
-	update_rect.width = widget->allocation.width;
-	update_rect.height = widget->allocation.height;
-
-	gtk_widget_draw (widget, &update_rect);
+	gtk_widget_queue_draw_area (widget, 0, 0, widget->allocation.width, widget->allocation.height);
 }
 
 
@@ -1593,7 +1581,7 @@ void UpDate_widget(GtkWidget *widget)
 
 
 /* ---------------------------------------------------------------------
- * ̾
+ * 縮小
  */
 void ZoomDown(void)
 {
@@ -1609,7 +1597,7 @@ void ZoomDown(void)
 
 
 /* ---------------------------------------------------------------------
- * 
+ * 拡大
  */
 void ZoomUp(void)
 {
@@ -1628,14 +1616,14 @@ void ZoomUp(void)
  * window_set
  * 
  * 
- * window_set ϡ
- *     ɥΥޤϡ礭ѹäȤ˸Ƥ֡
- *     WIN32 Ǥ WM_PAINT ΤȤ
- *     LINUX Ǥ expose_event ΤȤ
+ * window_set は、
+ *     ウインドウのサイズまたは、大きさの変更があったときに呼ぶ。
+ *     WIN32 では WM_PAINT のとこ
+ *     LINUX では expose_event のとこ
  * 
  *     SetMag()
- *     岼˰ư
- *     ̾ϡSetMag Ƥ֤ΤǤʤ
+ *     上下左右に移動
+ *     拡大縮小は、SetMag を呼ぶのでいらない。
  * 
  */
 void window_set(void)
@@ -1663,7 +1651,7 @@ void window_set(void)
 
 
 /* ---------------------------------------------------------------------
- * Ψ
+ * 倍率設定
  */
 void SetMag(double MagData)
 {
@@ -1679,7 +1667,7 @@ void SetMag(double MagData)
 							sagcad_system.ViewX * 3);
 
 	DC = (double)(sagcad_system.Search / Mag);
-	/* --- < Ψ > --- */
+	/* --- < 倍率 > --- */
 	sagcad_system.ScrollPitch = (float)(sg((sagcad_system.ViewX/abs(sagcad_system.Splits))/Mag, 2));
 	FloatOut(str, sagcad_system.ScrollPitch, 0);
 	sprintf(DumyStr, "SP %s", str);
@@ -1687,10 +1675,10 @@ void SetMag(double MagData)
 
 //	window_set();
 
-	/*  */
+	/* 再描画 */
 	Redraw();
 
-	/* Ψ */
+	/* 倍率 */
 	FloatOut(str, MagData, 0);
 	sprintf(DumyStr,"Mag %s",str);
 	set_label_text(mag, DumyStr);
@@ -1703,7 +1691,7 @@ void SetMag(double MagData)
 
 
 /* -------------------------------------------------------------------
- * ľ style 
+ * 直線を style で描く
  *	
  */
 int LineK(GtkWidget *widget, double SX, double SY, double EX, double EY, int style, long color)
@@ -1722,7 +1710,7 @@ int LineK(GtkWidget *widget, double SX, double SY, double EX, double EY, int sty
 	Now_SY = SY;
 	mm = 1 / Mag;
 
-	/* ֤εΥ */
+	/* ２点間の距離 */
 	PPH.sx[1] = SX;
 	PPH.sy[1] = SY;
 	PPH.ex[1] = EX;
@@ -1730,7 +1718,7 @@ int LineK(GtkWidget *widget, double SX, double SY, double EX, double EY, int sty
 	pp(&PPH);
 	Total_Len = PPH.l;
 
-	/* ľγ */
+	/* 直線の角度 */
 	LAH.sx[1] = SX;
 	LAH.sy[1] = SY;
 	LAH.ex[1] = EX;
@@ -1741,7 +1729,7 @@ int LineK(GtkWidget *widget, double SX, double SY, double EX, double EY, int sty
 
 	//MoveToEx(gc, ToDeviceX(SX), ToDeviceY(SY), NULL);
 
-	/*  */
+	/* 実線 */
 	if (sagcad_line_style[style].style == 1) {
 		gdk_draw_line(pixmap/*widget->window*/, gc, ToDeviceX(SX), ToDeviceY(SY), ToDeviceX(EX), ToDeviceY(EY));
 		//LineTo(gc, ToDeviceX(EX), ToDeviceY(EY));
@@ -1750,7 +1738,7 @@ int LineK(GtkWidget *widget, double SX, double SY, double EX, double EY, int sty
 
 
 
-	/*  */
+	/* 点線 */
 	else if (sagcad_line_style[style].style == 2) {
 		while (1) {
 			PAPH.sx[1] = Now_SX;
@@ -1803,7 +1791,7 @@ int LineK(GtkWidget *widget, double SX, double SY, double EX, double EY, int sty
 
 
 
-	/*  */
+	/* １点鎖線 */
 	else if (sagcad_line_style[style].style == 3) {
 		while (1) {
 			PAPH.sx[1] = Now_SX;
@@ -1903,7 +1891,7 @@ int LineK(GtkWidget *widget, double SX, double SY, double EX, double EY, int sty
 	}
 
 
-	/*  */
+	/* 二点鎖線 */
 	else if (sagcad_line_style[style].style == 4) {
 		while (1) {
 			PAPH.sx[1] = Now_SX;
@@ -2053,7 +2041,7 @@ int LineK(GtkWidget *widget, double SX, double SY, double EX, double EY, int sty
 
 
 /* -------------------------------------------------------------------
- * ߤɽ
+ * 円の表示
  * 
  */
 int CircleK(GtkWidget *widget, double CX, double CY, double R, double SA, double EA, int style, long color)
@@ -2068,7 +2056,7 @@ int CircleK(GtkWidget *widget, double CX, double CY, double R, double SA, double
 	step = (mm * 360) / (2 * PI * R);
 
 	if(SA < EA) {
-		/*  */
+		/* 実線 */
 		if (sagcad_line_style[style].style == 1) {
 			for(i = SA ; i <= EA ; i = i + step) {
 				X = R * cos(degrad(i)) + CX;
@@ -2084,7 +2072,7 @@ int CircleK(GtkWidget *widget, double CX, double CY, double R, double SA, double
 
 
 
-		/*  */
+		/* 点線 */
 		if (sagcad_line_style[style].style == 2) {
 			k = 0;
 			for(i = SA ; i < EA ; i = i + step ) {
@@ -2110,7 +2098,7 @@ int CircleK(GtkWidget *widget, double CX, double CY, double R, double SA, double
 
 
 
-		/*  */
+		/* 一点鎖線 */
 		if (sagcad_line_style[style].style == 3) {
 			k = 0;
 			for(i = SA ; i < EA ; i = i + step ) {
@@ -2139,7 +2127,7 @@ int CircleK(GtkWidget *widget, double CX, double CY, double R, double SA, double
 
 
 
-		/*  */
+		/* 二点鎖線 */
 		if (sagcad_line_style[style].style == 4) {
 			k = 0;
 			for(i = SA ; i < EA ; i = i + step ) {
@@ -2188,7 +2176,7 @@ int CircleK(GtkWidget *widget, double CX, double CY, double R, double SA, double
 
 
 /* -------------------------------------------------------------------
- * ʱߤɽ
+ * 楕円の表示
  * 
  */
 int EllipseK(GtkWidget *widget, ELLIPSE ellipse, int style, long color)
@@ -2197,7 +2185,7 @@ int EllipseK(GtkWidget *widget, ELLIPSE ellipse, int style, long color)
 	double mm;
 	double i, step;
 	int k;
-	POINT new_point, old_point;
+	SAG_POINT new_point, old_point;
 	ELLIPSE ellipse_sub;
 
 
@@ -2207,7 +2195,7 @@ int EllipseK(GtkWidget *widget, ELLIPSE ellipse, int style, long color)
 //	g_print("sa = %f   ea = %f   step = %f\n", ellipse.sa, ellipse.ea, step);
 
 	if (ellipse.sa < ellipse.ea) {
-		/*  */
+		/* 実線 */
 		if (sagcad_line_style[style].style == 1) {
 			for (i = ellipse.sa ; i < ellipse.ea ; i = i + step) {
 				new_point.x = 0;
@@ -2225,7 +2213,7 @@ int EllipseK(GtkWidget *widget, ELLIPSE ellipse, int style, long color)
 
 
 
-		/*  */
+		/* 点線 */
 		else if (sagcad_line_style[style].style == 2) {
 			k = 0;
 			for(i = ellipse.sa ; i < ellipse.ea ; i = i + step ) {
@@ -2249,7 +2237,7 @@ int EllipseK(GtkWidget *widget, ELLIPSE ellipse, int style, long color)
 
 
 
-		/*  */
+		/* 一点鎖線 */
 		else if (sagcad_line_style[style].style == 3) {
 			k = 0;
 			for(i = ellipse.sa ; i < ellipse.ea ; i = i + step ) {
@@ -2276,7 +2264,7 @@ int EllipseK(GtkWidget *widget, ELLIPSE ellipse, int style, long color)
 
 
 
-		/*  */
+		/* 二点鎖線 */
 		else if (sagcad_line_style[style].style == 4) {
 			k = 0;
 			for (i = ellipse.sa ; i < ellipse.ea ; i = i + step ) {
@@ -2327,7 +2315,7 @@ int EllipseK(GtkWidget *widget, ELLIPSE ellipse, int style, long color)
 
 #ifdef TEST
 /* -------------------------------------------------------------------
- * ʱߤɽ
+ * 楕円の表示
  * 
  */
 int EllipseK(GtkWidget *widget, 
@@ -2346,11 +2334,11 @@ int EllipseK(GtkWidget *widget,
 
 	mm = 1/Mag;
 	step = (mm * 360) / (2 * PI * a);
-	/* ư٥ȥ */
+	/* 移動ベクトル */
 	RAD = degrad(angle);
 
 	if (sa < ea) {
-		/*  */
+		/* 実線 */
 		if (sagcad_line_style[style].style == 1) {
 			for (i = sa ; i <= ea ; i = i + step) {
 				X = a * cos(degrad(i)) + cx;
@@ -2377,7 +2365,7 @@ int EllipseK(GtkWidget *widget,
 
 
 
-		/*  */
+		/* 点線 */
 		if (sagcad_line_style[style].style == 2) {
 			k = 0;
 			for(i = sa ; i < ea ; i = i + step ) {
@@ -2415,7 +2403,7 @@ int EllipseK(GtkWidget *widget,
 
 
 
-		/*  */
+		/* 一点鎖線 */
 		if (sagcad_line_style[style].style == 3) {
 			k = 0;
 			for(i = sa ; i < ea ; i = i + step ) {
@@ -2457,7 +2445,7 @@ int EllipseK(GtkWidget *widget,
 
 
 
-		/*  */
+		/* 二点鎖線 */
 		if (sagcad_line_style[style].style == 4) {
 			k = 0;
 			for (i = sa ; i < ea ; i = i + step ) {
@@ -2519,7 +2507,7 @@ int EllipseK(GtkWidget *widget,
 
 
 /* -------------------------------------------------------------------
- * ΰϰϤ
+ * 実寸印刷時の印刷範囲を描画
  * 
  *      Points       mm
  * A3 : 842 x 1191   297.039 x 420.159
@@ -2621,7 +2609,7 @@ int WakuWakuDraw(GtkWidget *widget)
 
 #ifdef TEST
 /* ------------------------------------------------------------------
- * GC 
+ * GC を設定
  * GC Setting
  */
 int PenSet(GdkGC *gc, int style, long color)
@@ -2642,34 +2630,34 @@ int PenSet(GdkGC *gc, int style, long color)
 	gdk_gc_set_background(gc, &for_gdk_backgroundcolor);
 
 
-	/*  */
+	/* 実線（太） */
 	if(style == 0) {
 		gdk_gc_set_line_attributes(gc, 3, GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
 	}
-	/* ʺ١ */
+	/* 実線（細） */
 	else if(style == 1) {
 		gdk_gc_set_line_attributes(gc, 2, GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
 	}
-	/*  */
+	/* 点線 */
 	else if(style == 2) {
 		gdk_gc_set_line_attributes(gc, 2, GDK_LINE_DOUBLE_DASH, GDK_CAP_BUTT, GDK_JOIN_MITER);
 		gdk_gc_set_dashes(gc, 0, dash, 2);
 	}
-	/*  */
+	/* １点鎖線 */
 	else if(style == 3) {
 		gdk_gc_set_line_attributes(gc, 2, GDK_LINE_DOUBLE_DASH, GDK_CAP_BUTT, GDK_JOIN_MITER);
 		gdk_gc_set_dashes(gc, 0, dash1, 4);
 	}
-	/*  */
+	/* ２点鎖線 */
 	else if(style == 4) {
 		gdk_gc_set_line_attributes(gc, 2, GDK_LINE_DOUBLE_DASH, GDK_CAP_BUTT, GDK_JOIN_MITER);
 		gdk_gc_set_dashes(gc, 0, dash2, 6);
 	}
-	/* ˡѼ */
+	/* 寸法線用実線 */
 	else if(style == 5) {
 		gdk_gc_set_line_attributes(gc, 1, GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
 	}
-	/* LineStyleBox & Layer_dlg ꥽Ѽ */
+	/* LineStyleBox & Layer_dlg リソース用実線 */
 	else if(style == 10) {
 		gdk_gc_set_line_attributes(gc, 1, GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
 	}
@@ -2684,7 +2672,7 @@ int PenSet(GdkGC *gc, int style, long color)
 
 
 /* ------------------------------------------------------------------
- * GC  RGB 
+ * GC を RGB で設定
  * GC Setting RGB
  */
 int PenSet_rgb(GdkGC *gc, gushort red, gushort green, gushort blue, int style)
@@ -2709,7 +2697,7 @@ int PenSet_rgb(GdkGC *gc, gushort red, gushort green, gushort blue, int style)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : Draw.c
