@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/02/07
- *    Last                 : 2003/02/07
+ *    Last                 : 2007/10/18
  * ====================================================================
  */
 
@@ -23,7 +23,7 @@
 
 #include <gtk/gtk.h>
 #include <unistd.h>
-#include <pwd.h>
+//#include <pwd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -47,8 +47,8 @@
 
 
 /* ------------------------------------------------------------------
- * ɥ󥰥ꥢ
- * expose () ٥ȥϥɥ
+ * ドローイングエリア
+ * expose (再描画) イベントハンドラ
  * 
  */
 int expose_event(GtkWidget *widget, GdkEventExpose *event)
@@ -59,6 +59,10 @@ int expose_event(GtkWidget *widget, GdkEventExpose *event)
 					 sagcad_system.DeviceX + event->area.x, sagcad_system.DeviceY + event->area.y,  
 					 event->area.x, event->area.y,  
 					 event->area.width, event->area.height);
+	
+	/* カーソル GDK_CROSS GDK_CROSSHAIR GDK_TCROSS */
+	cursor = gdk_cursor_new (GDK_TCROSS);
+	gdk_window_set_cursor (GTK_WIDGET(drawing_area)->window, cursor);
 
 	return FALSE;
 }
@@ -66,8 +70,36 @@ int expose_event(GtkWidget *widget, GdkEventExpose *event)
 
 
 /* ------------------------------------------------------------------
- * ɥ󥰥ꥢ
- * "motion_notify_event (ɥå)" ٥ȥϥɥ
+ * ドローイングエリア
+ * "scroll_event (スクロール)" イベントハンドラ
+ */
+gint scroll_event(GtkWidget *widget, GdkEventScroll *event, gpointer data)
+{
+	gint WithButton = 0, Button = 0;
+	gint i_event = MOUSE_PRESS;
+
+	if (event->direction == GDK_SCROLL_UP) {
+		i_event = MOUSE_WHEEL_UP;
+	} 
+	else if (event->direction == GDK_SCROLL_DOWN) {
+		i_event = MOUSE_WHEEL_DOWN;
+	}
+
+	MouseEvent(widget, 
+			   (gpointer)event, 
+			   i_event, 
+			   Button, WithButton, 
+			   (int) sagcad_system.DeviceX + event->x, 
+			   (int) sagcad_system.DeviceY + event->y);
+
+	return TRUE;
+}
+
+
+
+/* ------------------------------------------------------------------
+ * ドローイングエリア
+ * "motion_notify_event (ドラッグ)" イベントハンドラ
  */
 int motion_notify_event(GtkWidget *widget, GdkEventMotion *event)
 {
@@ -76,7 +108,7 @@ int motion_notify_event(GtkWidget *widget, GdkEventMotion *event)
 	char str[64];
 	int Button = 0, Shift = 0;
 
-	/* event κɸĴ٤ */
+	/* event の座標を調べる */
 	if (event->is_hint) {
 		gdk_window_get_pointer (event->window, &x, &y, &state);
 		x = x + sagcad_system.DeviceX;
@@ -88,22 +120,22 @@ int motion_notify_event(GtkWidget *widget, GdkEventMotion *event)
 		state = event->state;
 	}
 
-	/* ޥκɸɽ */
+	/* マウスの座標を表示 */
 	sprintf(str, "x %.2f  ", ToViewX(x));
-	gtk_label_set(GTK_LABEL(MouseX), str);
+	gtk_label_set_text(GTK_LABEL(MouseX), str);
 
 	sprintf(str, "y %.2f", ToViewY(y));
-	gtk_label_set(GTK_LABEL(MouseY), str);
+	gtk_label_set_text(GTK_LABEL(MouseY), str);
 
 	if ((state & GDK_SHIFT_MASK) == GDK_SHIFT_MASK) Shift = 1;
 	if ((state & GDK_MOD1_MASK) == GDK_MOD1_MASK) Shift = 2;
 	if ((state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK) Shift = 4;
 
-	/* ܥ */
+	/* 左ボタン */
 	if ((state & GDK_BUTTON1_MASK) == GDK_BUTTON1_MASK) Button = 1;
-	/* ܥ */
+	/* 中ボタン */
 	if ((state & GDK_BUTTON2_MASK) == GDK_BUTTON2_MASK) Button = 4;
-	/* ܥ */
+	/* 右ボタン */
 	if ((state & GDK_BUTTON3_MASK) == GDK_BUTTON3_MASK) Button = 2;
 
 	//g_print ("motion_notify_event : event  x = %d  y = %d\n", x, y);
@@ -119,8 +151,8 @@ int motion_notify_event(GtkWidget *widget, GdkEventMotion *event)
 
 
 /* ------------------------------------------------------------------
- * ɥ󥰥ꥢ
- * "button_press (å)" ٥ȥϥɥ
+ * ドローイングエリア
+ * "button_press (クリック)" イベントハンドラ
  */
 int button_press_event(GtkWidget *widget, GdkEventButton *event)
 {
@@ -130,18 +162,18 @@ int button_press_event(GtkWidget *widget, GdkEventButton *event)
 	if ((event->state & GDK_MOD1_MASK) == GDK_MOD1_MASK) Shift = 2;
 	if ((event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK) Shift = 4;
 
-	/* ܥ */
+	/* 左ボタン */
 	if (event->button == 1) Button = 1;
-	/* ܥ */
+	/* 中ボタン */
 	else if (event->button == 2) Button = 4;
-	/* ܥ */
+	/* 右ボタン */
 	else if (event->button == 3) Button = 2;
-	/* ۥ */
+	/* ホイール上 */
 	else if (event->button == 4) {
 		ZoomUp();
 		//Button = 8;
 	}
-	/* ۥ벼 */
+	/* ホイール下 */
 	else if (event->button == 5) {
 		ZoomDown();
 		//Button = 16;
@@ -161,8 +193,8 @@ int button_press_event(GtkWidget *widget, GdkEventButton *event)
 
 
 /* ------------------------------------------------------------------
- * ɥ󥰥ꥢ
- * "release_event (꡼)" ٥ȥϥɥ
+ * ドローイングエリア
+ * "release_event (リリース)" イベントハンドラ
  * 
  */
 int button_release_event(GtkWidget *widget, GdkEventButton *event)
@@ -173,11 +205,11 @@ int button_release_event(GtkWidget *widget, GdkEventButton *event)
 	if ((event->state & GDK_MOD1_MASK) == GDK_MOD1_MASK) Shift = 2;
 	if ((event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK) Shift = 4;
 
-	/* ܥ */
+	/* 左ボタン */
 	if (event->button == 1) Button = 1;
-	/* ܥ */
+	/* 中ボタン */
 	else if (event->button == 2) Button = 4;
-	/* ܥ */
+	/* 右ボタン */
 	else if (event->button == 3) Button = 2;
 
 	//g_print ("button_release_event : event  x = %f  y = %f\n", event->x, event->y);
@@ -196,19 +228,18 @@ int button_release_event(GtkWidget *widget, GdkEventButton *event)
 
 int configure_event (GtkWidget *widget, GdkEventConfigure *event)
 {
-
 	if (sagcad_system.DeviceX == widget->allocation.width && sagcad_system.DeviceY == widget->allocation.height) {
 		return 0;
 	}
 
 
-	/* ɥ󥰥쥢礭 */
+	/* ドローイングアレアの大きさ取得 */
 	sagcad_system.DeviceX = widget->allocation.width;
 	sagcad_system.DeviceY = widget->allocation.height;
 
-	/* ڥ */
+	/* アスペクト比 */
 	sagcad_system.Aspect = (double)sagcad_system.DeviceY / (double)sagcad_system.DeviceX;
-	/* sagcad_system.ViewX ǥץ쥤μºݤΥˤ */
+	/* sagcad_system.ViewX をディスプレイの実際のサイズにする */
 	//sagcad_system.ViewX = 200;//sagcad_system.DeviceX;
 //	window_set();
 
@@ -217,7 +248,7 @@ int configure_event (GtkWidget *widget, GdkEventConfigure *event)
 	world_window_set_center(Mag, MagX, MagY, sagcad_system.ViewX * 3);
 
 
-	/* GC */
+	/* GC作成 */
 	if (gc == NULL) {
 		gc = create_gc(widget);
 	}
@@ -237,6 +268,7 @@ int configure_event (GtkWidget *widget, GdkEventConfigure *event)
 //g_print("DrawArea.c : configure_event() : Draw\n");
 	Draw(widget);
 
+
 	return TRUE;
 }
 
@@ -245,40 +277,49 @@ int configure_event (GtkWidget *widget, GdkEventConfigure *event)
 
 
 /* ------------------------------------------------------------------
- * ɥ󥰥ꥢ
+ * ドローイングエリアの生成
  * 
  */
 GtkWidget *create_drawing_area(void)
 {
 	GtkWidget *drawing_area;
 
-	/* ɥ󥰥ꥢ */
+	/* ドローイングエリア生成 */
 	drawing_area = gtk_drawing_area_new();
-	/* ɥ󥰥ꥢΥ */
-	gtk_drawing_area_size( GTK_DRAWING_AREA(drawing_area), PICTURE_WIDTH, PICTURE_HEIGHT);
+	/* ドローイングエリアのサイズ設定 */
+	gtk_widget_set_size_request( GTK_WIDGET(drawing_area), PICTURE_WIDTH, PICTURE_HEIGHT);
 
-	/* "configure_event"٥ȥϥɥ */
-	gtk_signal_connect(GTK_OBJECT(drawing_area), "configure_event",
-				 (GtkSignalFunc) configure_event, NULL);
-	/* "expose_event"٥ȥϥɥ */
-	gtk_signal_connect(GTK_OBJECT(drawing_area), "expose_event",
-				 (GtkSignalFunc) expose_event, NULL);
-	/* "motion_notify_event"٥ȥϥɥ */
-	gtk_signal_connect(GTK_OBJECT(drawing_area), "motion_notify_event",
-				 (GtkSignalFunc) motion_notify_event, NULL);
-	/* "button_press_event"٥ȥϥɥ */
-	gtk_signal_connect(GTK_OBJECT(drawing_area), "button_press_event",
-				 (GtkSignalFunc) button_press_event, NULL);
-	/* "button_release_event"٥ȥϥɥ */
-	gtk_signal_connect(GTK_OBJECT(drawing_area), "button_release_event",
-				 (GtkSignalFunc) button_release_event, NULL);
-	/* ٥ȥޥ */
-	gtk_widget_set_events(drawing_area, GDK_EXPOSURE_MASK
+	/* "configure_event"イベントハンドラ設定 */
+	g_signal_connect(G_OBJECT(drawing_area), "configure_event",
+				 G_CALLBACK(configure_event), NULL);
+	/* "expose_event"イベントハンドラ設定 */
+	g_signal_connect(G_OBJECT(drawing_area), "expose_event",
+				 G_CALLBACK(expose_event), NULL);
+	/* "motion_notify_event"イベントハンドラ設定 */
+	g_signal_connect(G_OBJECT(drawing_area), "motion_notify_event",
+				 G_CALLBACK(motion_notify_event), NULL);
+	/* "button_press_event"イベントハンドラ設定 */
+	g_signal_connect(G_OBJECT(drawing_area), "button_press_event",
+				 G_CALLBACK(button_press_event), NULL);
+	/* "button_release_event"イベントハンドラ設定 */
+	g_signal_connect(G_OBJECT(drawing_area), "button_release_event",
+				 G_CALLBACK(button_release_event), NULL);
+	/* "scroll_event"イベントハンドラ設定 */
+	g_signal_connect(G_OBJECT(drawing_area), "scroll_event",
+				 G_CALLBACK(scroll_event), NULL);
+	/* イベントマスク設定 */
+	gtk_widget_set_events(drawing_area,  GDK_EXPOSURE_MASK
 										 | GDK_LEAVE_NOTIFY_MASK
 										 | GDK_BUTTON_PRESS_MASK
 										 | GDK_BUTTON_RELEASE_MASK
 										 | GDK_POINTER_MOTION_MASK
-										 | GDK_POINTER_MOTION_HINT_MASK);
+										 | GDK_POINTER_MOTION_HINT_MASK
+										 | GDK_SCROLL_MASK);
+
+
+	/* カーソル */
+	//cursor = gdk_cursor_new (GDK_CROSSHAIR);
+	//gdk_window_set_cursor (GTK_WIDGET(drawing_area)->window, cursor);
 
 	return drawing_area;
 }
@@ -288,7 +329,7 @@ GtkWidget *create_drawing_area(void)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : DrawArea.c
@@ -316,15 +357,15 @@ gint Pan(GtkWidget *widget, gint event, gint Button, gint WithButton, gint x, gi
 			dx = x - press_x;
 			dy = y - press_y;
 			
-			gdk_draw_pixmap (widget->window, 				// drawable : GdkDrawable (GdkWindow ޤ GdkPixmap) 
+			gdk_draw_pixmap (widget->window, 				// drawable : GdkDrawable (GdkWindow または GdkPixmap) 
 							 gc, 		// gc       : GdkGC 
-							 pixmap, 	// src      : 褹 GdkPixmap 
-							 sagcad_system.DeviceX - dx, // xsrc     : src ΤϤΰκü Xɸ 
-							 sagcad_system.DeviceY - dy, // ysrc     : src ΤϤΰξü Yɸ 
-							 0, // xdest    : drawable Ϥΰ Xɸ 
-							 0, // ydest    : drawable Ϥΰ Yɸ 
-							 sagcad_system.DeviceX, 			// width    : 褹ΰ 
-							 sagcad_system.DeviceY);			// height   : 褹ΰι⤵ 
+							 pixmap, 	// src      : 描画する GdkPixmap 
+							 sagcad_system.DeviceX - dx, // xsrc     : src 全体を囲む矩形領域の左端の X座標 
+							 sagcad_system.DeviceY - dy, // ysrc     : src 全体を囲む矩形領域の上端の Y座標 
+							 0, // xdest    : drawable を囲む矩形領域の X座標 
+							 0, // ydest    : drawable を囲む矩形領域の Y座標 
+							 sagcad_system.DeviceX, 			// width    : 描画する領域の幅 
+							 sagcad_system.DeviceY);			// height   : 描画する領域の高さ 
 		return 0;
 		}
 	}
@@ -343,7 +384,7 @@ gint Pan(GtkWidget *widget, gint event, gint Button, gint WithButton, gint x, gi
 		MagY = MagY - (ToViewY(dy) - ToViewY(0));
 		SetMag(Mag);
 		
-		/*  */
+		/* 再描画 */
 		Redraw();
 		press_x = 0;
 		press_y = 0;
@@ -383,21 +424,29 @@ gint Pan(GtkWidget *widget, gint event, gint Button, gint WithButton, gint x, gi
  *     gint y                   
  * 
  * RETURN VALUE:
- *     ｪλ               LIST *
- *     ۾ｪλ               NULL
+ *     正常終了               LIST *
+ *     異常終了               NULL
  * 
  * USAGE: 
  * --------------------------------------------------------------------------
  */
 gint MouseEvent(GtkWidget *widget, GdkEvent *event, gint i_event, gint Button, gint WithButton, gint x, gint y)
 {
-	/* ܥɥåǥѥ Pan */
+	/* 右ボタンドラッグでパン Pan */
 	if (Button == 4) {
 		if (Pan(widget, i_event, Button, WithButton, x, y) == 1) {
 			SagCad_MouseDown(widget, Button, WithButton, x, y);
 		}
 	}
 
+	if (i_event == MOUSE_WHEEL_UP) {
+		ZoomUp();
+	}
+	if (i_event == MOUSE_WHEEL_DOWN) {
+		ZoomDown();
+	}
+
+
 	if (i_event == MOUSE_PRESS && Button != 4) {
 		SagCad_MouseDown(widget, Button, WithButton, x, y);
 	}
@@ -410,6 +459,9 @@ gint MouseEvent(GtkWidget *widget, GdkEvent *event, gint i_event, gint Button, g
 		SagCad_MouseUp(widget, Button, WithButton, x, y);
 	}
 
+
+
+
 	return 0;
 }
 
