@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/02/07
- *    Last                 : 2003/02/07
+ *    Last                 : 2007/10/24
  * ====================================================================
  */
 #ifndef __DRAWAREA_H__
@@ -26,7 +26,7 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 1 :   (struct #define etc)
+ * 1 : 前処理  (struct #define etc)
  * -------------------------------------------------------
  */
 #define PICTURE_WIDTH  600
@@ -40,16 +40,16 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 2 : ѿ (global)
+ * 2 : 外部変数 (global)
  * -------------------------------------------------------
  */
 #ifdef _DRAWAREA_
 #define   GLOBAL
-// 
+// 初期値設定
 #define   GLOBAL_VAL(v)  = (v)
 #else
 #define   GLOBAL	extern
-// ʬ̵
+// 初期値設定の代入部分を無くす
 #define   GLOBAL_VAL(v)  /* */
 #endif
 
@@ -63,10 +63,11 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 3 : ؿ (Function)
+ * 3 : 外部関数 (Function)
  * -------------------------------------------------------
  */
 int configure_event(GtkWidget *widget, GdkEventConfigure *event);
+gint scroll_event(GtkWidget *widget, GdkEventScroll *event, gpointer data);
 int expose_event(GtkWidget *widget, GdkEventExpose *event);
 int motion_notify_event(GtkWidget *widget, GdkEventMotion *event);
 int button_press_event(GtkWidget *widget, GdkEventButton *event);
@@ -82,7 +83,7 @@ gint MouseEvent(GtkWidget *widget, GdkEvent *event, gint i_event, gint Button, g
 #endif /* __cplusplus */
 #endif /* __DRAWAREA_H__ */
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : DrawArea.h
