@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2002 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : sagcad
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2002 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/01/18
- *    Last                 : 2002/09/22
+ *    Last                 : 2007/10/14
  * ====================================================================
  */
 
@@ -23,7 +23,7 @@
 
 #include <gtk/gtk.h>
 #include <unistd.h>
-#include <pwd.h>
+//#include <pwd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -40,7 +40,7 @@
 #include "List_Block.h"
 #include "List_Undo.h"
 #include "List_Select.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "Dimension.h"
 #include "etc.h"
 #include "global.h"
@@ -61,7 +61,7 @@
 
 
 /* -------------------------------------------------------------------
- * -> 
+ * 点->点 
  * 
  * 
  */
@@ -75,19 +75,19 @@ int p_p(void)
 
 
 
-	/* ϥܥåɽ */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, _("The relative point") , _("X The coordinates") , _("(Relative)") , str);
 	if (Ret == -1) return 0;
 	x = atof(str);
 
-	/* ϥܥåɽ */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, _("The relative point") , _("Y The coordinates") , _("(Relative)") , str);
 	if (Ret == -1) return 0;
 	y = atof(str);
 
-	/* ǡϿ */
+	/* 点データを登録 */
 	cad.code = 0;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -110,7 +110,7 @@ int p_p(void)
 
 
 /* -------------------------------------------------------------------
- *    㤦   
+ * 点と点で点   ２点が違う   中点
  * 
  * 
  */
@@ -128,7 +128,7 @@ int pp_p(void)
 	rtn.ex[2] = 1;
 	ppp(&rtn);
 
-	/* ǡϿ */
+	/* 点データを登録 */
 	cad.code = 0;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -151,7 +151,7 @@ int pp_p(void)
 
 
 /* -------------------------------------------------------------------
- *    Ƕ
+ * 点と線で点   最近点
  * 
  * 
  */
@@ -179,7 +179,7 @@ int pl_p(void)
 	}
 	plp(&rtn);
 
-	/* ǡϿ */
+	/* 点データを登録 */
 	cad.code = 0;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -202,7 +202,7 @@ int pl_p(void)
 
 
 /* -------------------------------------------------------------------
- * ȱߤ   Ƕ
+ * 点と円で点   最近点
  * 
  * 
  */
@@ -239,19 +239,19 @@ int pc_p(void)
 	}
 
 
-	/* ߤ濴˸γ٣롣*/
+	/* 円の中心から点に向かう線の角度Ａを求める。*/
 	rtn.sx[1] = circle.cx;
 	rtn.sy[1] = circle.cy;
 	rtn.ex[1] = point.sx;
 	rtn.ey[1] = point.sy;
 	la(&rtn);
 
-	/* ߤ濴٣Ⱦ¤εΥˤ */
+	/* 円の中心から角度Ａに半径の距離にある点 */
 	rtn.l = circle.r;
 	pap(&rtn);
 	/* (rtn.ex[1],rtn.ey[1]) */
 
-	/* ǡϿ */
+	/* 点データを登録 */
 	cad.code = 0;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -274,7 +274,7 @@ int pc_p(void)
 
 
 /* -------------------------------------------------------------------
- *    l_p   Ʊ   ü
+ * 線と線で点   l_p   ２線が同一   線の端点
  * 
  * 
  */
@@ -283,7 +283,7 @@ int l_p(void)
 	CAD cad;
 
 
-	/* ǡϿ */
+	/* 点データを登録 */
 	cad.code = 0;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -321,7 +321,7 @@ int l_p(void)
 
 
 /* -------------------------------------------------------------------
- *    ll_p   㤦   ľθ
+ * 線と線で点   ll_p   ２線が違う   ２直線の交点
  * 
  * 
  */
@@ -346,7 +346,7 @@ int ll_p(void)
 		return 0;
 	}
 	
-	/* ǡϿ */
+	/* 点データを登録 */
 	cad.code = 0;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -369,7 +369,7 @@ int ll_p(void)
 
 
 /* -------------------------------------------------------------------
- * ȱߤ   lc_p   ߤľθ
+ * 線と円で点   lc_p   円と直線の交点
  * 
  * 
  */
@@ -403,7 +403,7 @@ int lc_p(void)
 		MsgBox("SagCAD", _("There is not a point of intersection.") , " " , NULL, NULL, "OK");
 		return 0;
 	}
-	/* ǡϿ */
+	/* 点データを登録 */
 	cad.code = 0;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -422,7 +422,7 @@ int lc_p(void)
 
 
 	if (rtn.type == 2) {
-		/* ǡϿ */
+		/* 点データを登録 */
 		cad.code = 0;
 		cad.layer = NowLayer;
 		cad.style = NowStyle;
@@ -440,7 +440,7 @@ int lc_p(void)
 	}
 
 	if (rtn.type == 1) {
-		//MsgBox("ա", "ĤǤ", " " , NULL, NULL, "OK");
+		//MsgBox("注意　！", "交点が１個です。", " " , NULL, NULL, "OK");
 	}
 	return 1;
 }
@@ -448,7 +448,7 @@ int lc_p(void)
 
 
 /* -------------------------------------------------------------------
- * ߤȱߤ   c_p   ߤƱ   濴
+ * 円と円で点   c_p   ２円が同一   中心点
  * 
  * 
  */
@@ -457,7 +457,7 @@ int c_p(void)
 	CAD cad;
 
 
-	/* ǡϿ */
+	/* 点データを登録 */
 	cad.code = 0;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -480,7 +480,7 @@ int c_p(void)
 
 
 /* -------------------------------------------------------------------
- * ߤȱߤ   cc_p   ߤ㤦   ߤθ
+ * 円と円で点   cc_p   ２円が違う   ２円の交点
  * 
  * 
  */
@@ -503,7 +503,7 @@ int cc_p(void)
 		return 0;
 	}
 	
-	/* ǡϿ */
+	/* 点データを登録 */
 	cad.code = 0;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -521,7 +521,7 @@ int cc_p(void)
 	SelectCadDraw(drawing_area, &cad, SCD_ORG);
 
 	if (rtn.type == 2) {
-		/* ǡϿ */
+		/* 点データを登録 */
 		cad.code = 0;
 		cad.layer = NowLayer;
 		cad.style = NowStyle;
@@ -539,7 +539,7 @@ int cc_p(void)
 	}
 	
 	if (rtn.type == 1) {
-		//MsgBox("ա", "ĤǤ", " " , NULL, NULL, "OK");
+		//MsgBox("注意　！", "交点が１個です。", " " , NULL, NULL, "OK");
 	}
 	return 1;
 }
@@ -547,7 +547,7 @@ int cc_p(void)
 
 
 /* -------------------------------------------------------------------
- * ʱߤ   le_p
+ * 楕円と線で点   le_p
  * 
  * 
  */
@@ -561,7 +561,7 @@ int le_p(void)
 	sel_1 = select_search_num(1)->select;
 	sel_2 = select_search_num(2)->select;
 
-	/* sel_1 ʱߤȤʤ褦ˤ */
+	/* sel_1 が楕円となるようにする */
 	if (sel_1->index == 2) {
 		sel = sel_1;
 		sel_1 = sel_2;
@@ -582,7 +582,7 @@ int le_p(void)
 		MsgBox("SagCAD", _("There is not a point of intersection.") , " " , NULL, NULL, "OK");
 		return 0;
 	}
-	/* ǡϿ */
+	/* 点データを登録 */
 	cad.code = 0;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -601,7 +601,7 @@ int le_p(void)
 
 
 	if (rtn.type == 2) {
-		/* ǡϿ */
+		/* 点データを登録 */
 		cad.code = 0;
 		cad.layer = NowLayer;
 		cad.style = NowStyle;
@@ -619,7 +619,7 @@ int le_p(void)
 	}
 
 	if (rtn.type == 1) {
-		//MsgBox("ա", "ĤǤ", " " , NULL, NULL, "OK");
+		//MsgBox("注意　！", "交点が１個です。", " " , NULL, NULL, "OK");
 	}
 	return 1;
 }
@@ -627,7 +627,7 @@ int le_p(void)
 
 
 /* -------------------------------------------------------------------
- * ʱߤȱߤ   ce_p
+ * 楕円と円で点   ce_p
  * 
  * 
  */
@@ -643,7 +643,7 @@ int ce_p(void)
 	sel_1 = select_search_num(1)->select;
 	sel_2 = select_search_num(2)->select;
 
-	/* sel_1 ʱߤȤʤ褦ˤ */
+	/* sel_1 が楕円となるようにする */
 	if (sel_1->index == 2) {
 		sel = sel_1;
 		sel_1 = sel_2;
@@ -665,7 +665,7 @@ int ce_p(void)
 		MsgBox("SagCAD", _("There is not a point of intersection.") , " " , NULL, NULL, "OK");
 		return 0;
 	}
-	/* ǡϿ */
+	/* 点データを登録 */
 	if (rtn.type > 0) {
 		undo_index_plus();
 		for (i = 1 ; i < rtn.type + 1 ; i++) {
@@ -692,7 +692,7 @@ int ce_p(void)
 
 
 /* -------------------------------------------------------------------
- * ʱߤʱߤ   ee_p
+ * 楕円と楕円で点   ee_p
  * 
  * 
  */
@@ -713,7 +713,7 @@ int ee_p(void)
 		MsgBox("SagCAD", _("There is not a point of intersection.") , " " , NULL, NULL, "OK");
 		return 0;
 	}
-	/* ǡϿ */
+	/* 点データを登録 */
 	if (rtn.type > 0) {
 		undo_index_plus();
 		for (i = 1 ; i < rtn.type + 1 ; i++) {
@@ -740,7 +740,7 @@ int ee_p(void)
 
 
 /* ---------------------------------------------------------------------
- * ޥɤ򤷤Ȥ
+ * 点コマンドを選択したとき
  * 
  */
 int CreatePoint(GtkWidget *widget)
@@ -753,19 +753,19 @@ int CreatePoint(GtkWidget *widget)
 
 
 
-	/* ,,߸,ߤΤߤΤȤ */
+	/* 点,線,円弧,円のみのとき */
 	if (sel_1->index == 2 
 		&& 
 		sel_2->index == 2 ) 
 	{
 
-		/*  */
+		/* 点と点 */
 		if (	sel_1->diagram_point.cad_point->code == 0 
 				&& 
 				sel_2->diagram_point.cad_point->code == 0
 			) 
 		{
-			/* Ʊ   p_p    */
+			/* ２点が同一   p_p   相対点 */
 			if (sel_1->diagram_point.cad_point 
 					== sel_2->diagram_point.cad_point 
 				|| 
@@ -780,7 +780,7 @@ int CreatePoint(GtkWidget *widget)
 				p_p();
 				return 1;
 			}
-			/* 㤦   pp_p    */
+			/* ２点が違う   pp_p   中点 */
 			if (sel_1->diagram_point.cad_point != sel_2->diagram_point.cad_point) {
 				pp_p();
 				return 1;
@@ -788,7 +788,7 @@ int CreatePoint(GtkWidget *widget)
 		}
 
 
-		/*    pl_p   Ƕ */
+		/* 点と線   pl_p   最近点 */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 0 
 					&& 
@@ -806,7 +806,7 @@ int CreatePoint(GtkWidget *widget)
 		}
 
 
-		/* ȱ   pc_p   Ƕ */
+		/* 点と円   pc_p   最近点 */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 0 
 					&& 
@@ -836,19 +836,19 @@ int CreatePoint(GtkWidget *widget)
 		}
 
 
-		/*  */
+		/* 線と線 */
 		else if (sel_1->diagram_point.cad_point->code == 1 
 				 && 
 				 sel_2->diagram_point.cad_point->code == 1) 
 		{
-			/* Ʊ   l_p   ü */
+			/* ２線が同一   l_p   線の端点 */
 			if (sel_1->diagram_point.cad_point == sel_2->diagram_point.cad_point) 
 			{
 				l_p();
 				return 1;
 			}
 
-			/* 㤦   ll_p   ľθ */
+			/* ２線が違う   ll_p   ２直線の交点 */
 			if (sel_1->diagram_point.cad_point != sel_2->diagram_point.cad_point) 
 			{
 				ll_p();
@@ -857,7 +857,7 @@ int CreatePoint(GtkWidget *widget)
 		}
 
 
-		/* ȱ   lc_p   ߤľθ */
+		/* 線と円   lc_p   円と直線の交点 */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 1 
 					&& 
@@ -887,7 +887,7 @@ int CreatePoint(GtkWidget *widget)
 		}
 
 
-		/* ߤȱ */
+		/* 円と円 */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 2 
 					&& 
@@ -912,13 +912,13 @@ int CreatePoint(GtkWidget *widget)
 					sel_2->diagram_point.cad_point->code == 2
 					)	) 
 		{
-			/* ߤƱ   c_p   濴 */
+			/* ２円が同一   c_p   中心点 */
 			if (sel_1->diagram_point.cad_point == sel_2->diagram_point.cad_point) {
 				c_p();
 				return 1;
 			}
 
-			/* ߤ㤦   cc_p   ߤθ */
+			/* ２円が違う   cc_p   ２円の交点 */
 			if (sel_1->diagram_point.cad_point != sel_2->diagram_point.cad_point) {
 				cc_p();
 				return 1;
@@ -928,12 +928,12 @@ int CreatePoint(GtkWidget *widget)
 
 
 
-	/* ʱߤȤ */
+	/* 楕円があるとき */
 	else if (sel_1->index == 16 
 			|| 
 			sel_2->index == 16 ) 
 	{
-		/* sel_1 ʱߤȤʤ褦ˤ */
+		/* sel_1 が楕円となるようにする */
 		if (sel_1->index == 2) {
 			sel = sel_1;
 			sel_1 = sel_2;
@@ -941,15 +941,15 @@ int CreatePoint(GtkWidget *widget)
 		}
 
 
-		/* ʱߤ */
+		/* 楕円と点 */
 		if (sel_2->index == 2) {
 			if (sel_2->diagram_point.cad_point->code == 0) {
-				// ̵
+				// 無し
 				return 0;
 			}
 		}
 
-		/* ʱߤ */
+		/* 楕円と線 */
 		if (sel_2->index == 2) {
 			if (sel_2->diagram_point.cad_point->code == 1) {
 				le_p();
@@ -957,7 +957,7 @@ int CreatePoint(GtkWidget *widget)
 			}
 		}
 
-		/* ʱߤȱ(߸) */
+		/* 楕円と円(円弧) */
 		if (sel_2->index == 2) {
 			if (sel_2->diagram_point.cad_point->code == 2 || sel_2->diagram_point.cad_point->code == 4) {
 				ce_p();
@@ -965,7 +965,7 @@ int CreatePoint(GtkWidget *widget)
 			}
 		}
 
-		/* ʱߤʱ */
+		/* 楕円と楕円 */
 		if (sel_2->index == 16) {
 			ee_p();
 			return 1;
@@ -982,7 +982,7 @@ int CreatePoint(GtkWidget *widget)
 
 
 /* ---------------------------------------------------------------------
- *    p_l   Ʊ   ٤Ĺ
+ * 点と点で線   p_l   ２点が同一   角度と長さ
  * 
  */
 int p_l(void)
@@ -993,7 +993,7 @@ int p_l(void)
 	char str[256];
 
 
-	/* ϥܥåɽ */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("It makes a line with point and angle.") , 
@@ -1008,7 +1008,7 @@ int p_l(void)
 	rtn.l = sagcad_system.Length;
 	pap(&rtn);
 	
-	/* ǡϿ */
+	/* 線データを登録 */
 	cad.code = 1;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -1032,7 +1032,7 @@ int p_l(void)
 
 
 /* ---------------------------------------------------------------------
- *    pp_l   㤦   ȽȤľ
+ * 点と点で線   pp_l   ２点が違う   ２点を始点と終点とする直線
  * 
  */
 int pp_l(void)
@@ -1040,7 +1040,7 @@ int pp_l(void)
 	CAD cad;
 
 
-	/* ǡϿ */
+	/* 線データを登録 */
 	cad.code = 1;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -1064,7 +1064,7 @@ int pp_l(void)
 
 
 /* ---------------------------------------------------------------------
- *    pl_l   ̤ľʿԤľ
+ * 点と線で線   pl_l   点を通る直線に平行な直線
  * 
  */
 int pl_l(void)
@@ -1083,13 +1083,13 @@ int pl_l(void)
 		*select_search_num(2)->select = DumySelect;
 	}
 	
-	/* ϥܥåɽ */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, _("Makes a line with point and line.") , _("Input an angle (DEG)") , "", str);
 	if (Ret == -1) return 0;
 	Angle1 = atof(str);
 
-	/* ľγ */
+	/* 選択直線の角度 */
 	rtn.sx[1] = select_search_num(2)->select->diagram_point.cad_point->sx;
 	rtn.sy[1] = select_search_num(2)->select->diagram_point.cad_point->sy;
 	rtn.ex[1] = select_search_num(2)->select->diagram_point.cad_point->ex;
@@ -1101,13 +1101,13 @@ int pl_l(void)
 	if (rtn.angle > 360)	rtn.angle = rtn.angle - 360;
 	if (rtn.angle < 0)		rtn.angle = rtn.angle + 360;
 	
-	/* Angle1+Angle2γ٤ */
+	/* 選択点からAngle1+Angle2の角度の線 */
 	rtn.sx[1] = select_search_num(1)->select->diagram_point.cad_point->sx;
 	rtn.sy[1] = select_search_num(1)->select->diagram_point.cad_point->sy;
 	rtn.l = sagcad_system.Length;
 	pap(&rtn);
 	
-	/* ǡϿ */
+	/* 線データを登録 */
 	cad.code = 1;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -1131,7 +1131,7 @@ int pl_l(void)
 
 
 /* ---------------------------------------------------------------------
- * ȱߤ   pc_l   ̤ߤ
+ * 点と円で線   pc_l   点を通る円の接線
  * 
  */
 int pc_l(void)
@@ -1178,7 +1178,7 @@ int pc_l(void)
 		return 1;
 	}
 	else if (rtn.type == 1) {
-		/* ǡϿ */
+		/* 線データを登録 */
 		cad.code = 1;
 		cad.layer = NowLayer;
 		cad.style = NowStyle;
@@ -1204,7 +1204,7 @@ int pc_l(void)
 
 
 /* ---------------------------------------------------------------------
- *    l_l   Ʊ   ľΥեå
+ * 線と線で線   l_l   ２線が同一   直線のオフセット
  * 
  */
 int l_l(void)
@@ -1214,7 +1214,7 @@ int l_l(void)
 	char str[256];
 
 
-	/* ϥܥåɽ */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("Makes an offset line by the line and the offset.") , 
@@ -1253,7 +1253,7 @@ int l_l(void)
 
 
 /* ---------------------------------------------------------------------
- *    ll_l   㤦   ʬ
+ * 線と線で線   ll_l   ２線が違う   ２等分線
  * 
  */
 int ll_l(void)
@@ -1275,7 +1275,7 @@ int ll_l(void)
 		MsgBox("SagCAD", "Error !", _("2 straight lines are parallel.") , NULL, NULL, "OK");
 		return 0;
 	}
-	/* ǡϿ */
+	/* 線データを登録 */
 	cad.code = 1;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -1298,7 +1298,7 @@ int ll_l(void)
 
 
 /* ---------------------------------------------------------------------
- * ȱߤ   lc_l   ߤܤľʿԤľ (1)
+ * 線と円で線   lc_l   円に接し、直線に平行な直線 (1)
  * 
  */
 int lc_l(void)
@@ -1316,14 +1316,14 @@ int lc_l(void)
 		circle = *select_search_num(1)->select->diagram_point.cad_point;
 	}
 
-	/* LA	ľγ */
+	/* LA	直線の角度 */
 	rtn.sx[1] = sen.sx;
 	rtn.sy[1] = sen.sy;
 	rtn.ex[1] = sen.ex;
 	rtn.ey[1] = sen.ey;
 	la(&rtn);
 	
-	/* CAL	 ߤܤ٣ */
+	/* CAL	 円に接する角度Ａの接線 */
 	rtn.cx[1] = circle.cx;
 	rtn.cy[1] = circle.cy;
 	rtn.r[1] = circle.r;
@@ -1357,7 +1357,7 @@ int lc_l(void)
 
 
 /* ---------------------------------------------------------------------
- * ߤȱߤ   cc_l   ߤ㤦  ߤܤ (1)
+ * 円と円で線   cc_l   ２円が違う  ２円に接する接線 (1)
  * 
  */
 int cc_l(void)
@@ -1409,7 +1409,7 @@ int cc_l(void)
 
 
 /* ---------------------------------------------------------------------
- * ߤȱߤ   c_l   ߤƱ   ߤ˳ ANGLE ܤ
+ * 円と円で線   c_l   ２円が同一   円に角度 ANGLE で接する接線
  * 
  */
 int c_l(void)
@@ -1419,7 +1419,7 @@ int c_l(void)
 	char str[256];
 
 
-	/* ϥܥåɽ */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("Makes a tangent by the circle and the angle.") , 
@@ -1429,7 +1429,7 @@ int c_l(void)
 	if (Ret == -1) return 0;
 	rtn.angle = atof(str);
 
-	/* CAL	 ߤܤ٣ */
+	/* CAL	 円に接する角度Ａの接線 */
 	rtn.cx[1] = select_search_num(1)->select->diagram_point.cad_point->cx;
 	rtn.cy[1] = select_search_num(1)->select->diagram_point.cad_point->cy;
 	rtn.r[1] = select_search_num(1)->select->diagram_point.cad_point->r;
@@ -1463,7 +1463,7 @@ int c_l(void)
 
 
 /* -------------------------------------------------------------------
- * ʱߤ   pe_l
+ * 点と楕円で線   pe_l
  */
 int pe_l(void)
 {
@@ -1475,7 +1475,7 @@ int pe_l(void)
 	sel_1 = select_search_num(1)->select;
 	sel_2 = select_search_num(2)->select;
 
-	/* sel_1 ʱߤȤʤ褦ˤ */
+	/* sel_1 が楕円となるようにする */
 	if (sel_1->index == 2) {
 		sel = sel_1;
 		sel_1 = sel_2;
@@ -1521,7 +1521,7 @@ int pe_l(void)
 
 
 /* -------------------------------------------------------------------
- * ߤʱߤ   ce_l
+ * 円と楕円で線   ce_l
  */
 int ce_l(void)
 {
@@ -1534,7 +1534,7 @@ int ce_l(void)
 	sel_1 = select_search_num(1)->select;
 	sel_2 = select_search_num(2)->select;
 
-	/* sel_1 ʱߤȤʤ褦ˤ */
+	/* sel_1 が楕円となるようにする */
 	if (sel_1->index == 2) {
 		sel = sel_1;
 		sel_1 = sel_2;
@@ -1585,7 +1585,7 @@ int ce_l(void)
 
 
 /* -------------------------------------------------------------------
- * ʱߤʱߤ   ee_l
+ * 楕円と楕円で線   ee_l
  */
 int ee_l(void)
 {
@@ -1635,7 +1635,7 @@ int ee_l(void)
 
 
 /* ---------------------------------------------------------------------
- * ޥɤ򤷤Ȥ
+ * 線コマンドを選択したとき
  * 
  */
 int CreateLine(GtkWidget *widget)
@@ -1649,26 +1649,26 @@ int CreateLine(GtkWidget *widget)
 	debug = 1;
 #endif
 
-	if (debug > 0) g_print("DrawMode.c : CreateLine() : ޥ in\n");
+	if (debug > 0) g_print("DrawMode.c : CreateLine() : 線コマンド in\n");
 
 
 	sel_1 = select_search_num(1)->select;
 	sel_2 = select_search_num(2)->select;
 
 
-	/* ,,߸,ߤΤߤΤȤ */
+	/* 点,線,円弧,円のみのとき */
 	if (sel_1->index == 2 
 		&& 
 		sel_2->index == 2 ) 
 	{
 
-		/*  */
+		/* 点と点で線 */
 		if (	sel_1->diagram_point.cad_point->code == 0 
 				&& 
 				sel_2->diagram_point.cad_point->code == 0
 			) 
 		{
-			/* Ʊ   p_l   ٤Ĺ */
+			/* ２点が同一   p_l   角度と長さ */
 			if (	sel_1->diagram_point.cad_point 
 						== sel_2->diagram_point.cad_point 
 					|| 
@@ -1684,7 +1684,7 @@ int CreateLine(GtkWidget *widget)
 				p_l();
 				return 1;
 			}
-			/* 㤦   pp_l   ȽȤľ */
+			/* ２点が違う   pp_l   ２点を始点と終点とする直線 */
 			if (sel_1->diagram_point.cad_point 
 					!= sel_2->diagram_point.cad_point) 
 			{
@@ -1694,7 +1694,7 @@ int CreateLine(GtkWidget *widget)
 		}
 
 
-		/*    pl_l   ̤ľʿԤľ */
+		/* 点と線で線   pl_l   点を通る直線に平行な直線 */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 0 
 					&& 
@@ -1713,7 +1713,7 @@ int CreateLine(GtkWidget *widget)
 		}
 
 
-		/* ȱߤ   pc_l   ̤ߤ (1) */
+		/* 点と円で線   pc_l   点を通る円の接線 (1) */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 0 
 					&& 
@@ -1731,7 +1731,7 @@ int CreateLine(GtkWidget *widget)
 			return 1;
 		}
 
-		/* ȱߤ   pc_l   ̤ߤ (2) */
+		/* 点と円で線   pc_l   点を通る円の接線 (2) */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 2 
 					&& 
@@ -1754,18 +1754,18 @@ int CreateLine(GtkWidget *widget)
 		// if (cad[MODE200).code = 4 && cad[MODE201).code = 0){}
 
 
-		/*  */
+		/* 線と線で線 */
 		else if (sel_1->diagram_point.cad_point->code == 1 
 				 && 
 				 sel_2->diagram_point.cad_point->code == 1
 				 ) 
 		{
-			/* Ʊ   l_l   ľΥեå */
+			/* ２線が同一   l_l   直線のオフセット */
 			if (sel_1->diagram_point.cad_point == sel_2->diagram_point.cad_point) {
 				l_l();
 				return 1;
 			}
-			/* 㤦  ll_l   ʬ */
+			/* ２線が違う  ll_l   ２等分線 */
 			if (sel_1->diagram_point.cad_point != sel_2->diagram_point.cad_point) {
 				ll_l();
 				return 1;
@@ -1773,7 +1773,7 @@ int CreateLine(GtkWidget *widget)
 		}
 
 
-		/* ȱߤ   lc_l   ߤܤľʿԤľ (1) */
+		/* 線と円で線   lc_l   円に接し、直線に平行な直線 (1) */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 1 
 					&& 
@@ -1792,7 +1792,7 @@ int CreateLine(GtkWidget *widget)
 		}
 
 
-		/* ȱߤ  ߤܤľʿԤľ (2) */
+		/* 線と円で線  円に接し、直線に平行な直線 (2) */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 2 
 					&& 
@@ -1811,15 +1811,15 @@ int CreateLine(GtkWidget *widget)
 		}
 
 
-		/* ߤȱߤ */
-		/* ߤ㤦  ߤܤ (1) */
+		/* 円と円で線 */
+		/* ２円が違う  ２円に接する接線 (1) */
 	//	if ((sel_1->diagram_point.cad_point->code == 2 && sel_2->diagram_point.cad_point->code == 4)
 	//		|| (sel_1->diagram_point.cad_point->code == 4 && sel_2->diagram_point.cad_point->code == 2))
 	//	{
 	//	}
 
 
-		/* ߤ㤦  ߤܤ (2) */
+		/* ２円が違う  ２円に接する接線 (2) */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 2 
 					&& 
@@ -1845,14 +1845,14 @@ int CreateLine(GtkWidget *widget)
 					)
 				)
 		{
-			/* ߤƱ  ߤ˳ANGLEܤ */
+			/* ２円が同一  円に角度ANGLEで接する接線 */
 			if (sel_1->diagram_point.cad_point == sel_2->diagram_point.cad_point) {
-				if (debug > 0) g_print("ߤƱ  ߤ˳ANGLEܤ\n");
+				if (debug > 0) g_print("２円が同一  円に角度ANGLEで接する接線\n");
 				c_l();
 			}
-			/* ߤ㤦  ߤܤ */
+			/* ２円が違う  ２円に接する接線 */
 			if (sel_1->diagram_point.cad_point != sel_2->diagram_point.cad_point) {
-				if (debug > 0) g_print("ߤ㤦  ߤܤ\n");
+				if (debug > 0) g_print("２円が違う  ２円に接する接線\n");
 				cc_l();
 			}
 		}
@@ -1860,16 +1860,16 @@ int CreateLine(GtkWidget *widget)
 
 
 
-	/* ʱߤȤ */
+	/* 楕円があるとき */
 	else if (sel_1->index == 16 || sel_2->index == 16 ) {
-		/* sel_1 ʱߤȤʤ褦ˤ */
+		/* sel_1 が楕円となるようにする */
 		if (sel_1->index == 2) {
 			sel = sel_1;
 			sel_1 = sel_2;
 			sel_2 = sel;
 		}
 
-		/* ʱߤ */
+		/* 楕円と点 */
 		if (sel_2->index == 2) {
 			if (sel_2->diagram_point.cad_point->code == 0) {
 				pe_l();
@@ -1877,15 +1877,15 @@ int CreateLine(GtkWidget *widget)
 			}
 		}
 
-		/* ʱߤ */
+		/* 楕円と線 */
 		if (sel_2->index == 2) {
 			if (sel_2->diagram_point.cad_point->code == 1) {
-				// ̵
+				// 無し
 				return 0;
 			}
 		}
 
-		/* ʱߤȱ(߸) */
+		/* 楕円と円(円弧) */
 		if (sel_2->index == 2) {
 			if (sel_2->diagram_point.cad_point->code == 2 || sel_2->diagram_point.cad_point->code == 4) {
 				ce_l();
@@ -1893,7 +1893,7 @@ int CreateLine(GtkWidget *widget)
 			}
 		}
 
-		/* ʱߤʱ */
+		/* 楕円と楕円 */
 		if (sel_2->index == 16) {
 			ee_l();
 			return 1;
@@ -1910,7 +1910,7 @@ int CreateLine(GtkWidget *widget)
 
 
 /* ---------------------------------------------------------------------
- * Ǳ   Ʊ   p_c   濴ȤȾ£Ҥα
+ * 点と点で円   ２点が同一   p_c   点を中心とする半径Ｒの円
  * 
  */
 int p_c(void)
@@ -1921,7 +1921,7 @@ int p_c(void)
 	char str[256];
 
 
-	/* ϥܥåɽ */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("Makes a circle by the circle and the radius."), 
@@ -1931,7 +1931,7 @@ int p_c(void)
 	if (Ret == -1) return 0;
 	rtn.r[1] = atof(str);
 
-	/* ߥǡϿ */
+	/* 円データを登録 */
 	cad.code = 4;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -1954,7 +1954,7 @@ int p_c(void)
 
 
 /* ---------------------------------------------------------------------
- * Ǳ   㤦   pp_c   ̤Ⱦ£Ҥα
+ * 点と点で円   ２点が違う   pp_c   ２点を通る半径Ｒの円
  * 
  */
 int pp_c(void)
@@ -1970,7 +1970,7 @@ int pp_c(void)
 	rtn.sx[2] = select_search_num(2)->select->diagram_point.cad_point->sx;
 	rtn.sy[2] = select_search_num(2)->select->diagram_point.cad_point->sy;
 
-	/* ϥܥåɽ */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("The circle with the radius R which passes two points.") , 
@@ -1983,7 +1983,7 @@ int pp_c(void)
 	ppc(&rtn);
 
 	if (rtn.type == 1) {
-		/* ߥǡϿ */
+		/* 円データを登録 */
 		cad.code = 4;
 		cad.layer = NowLayer;
 		cad.style = NowStyle;
@@ -2030,7 +2030,7 @@ int pp_c(void)
 
 
 /* ---------------------------------------------------------------------
- * Ǳ   pl_c   ̤ꡢľܤȾ£Ҥα (1)
+ * 点と線で円   pl_c   １点を通り、直線に接する半径Ｒの円 (1)
  * 
  */
 int pl_c(void)
@@ -2050,8 +2050,8 @@ int pl_c(void)
 		sen = *select_search_num(1)->select->diagram_point.cad_point;
 	}
 
-	/* PLC		̤ľܤ */
-	/* ϥܥåɽ */
+	/* PLC		１点を通り直線に接する円 */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("Circle with the radius R which comes in touch with a straight line through the point"), 
@@ -2075,7 +2075,7 @@ int pl_c(void)
 	}
 	
 	if (rtn.type == 1) {
-		/* ߥǡϿ */
+		/* 円データを登録 */
 		cad.code = 4;
 		cad.layer = NowLayer;
 		cad.style = NowStyle;
@@ -2103,7 +2103,7 @@ int pl_c(void)
 		OnlyOneCAD[2].cx = sg(rtn.cx[4],6);
 		OnlyOneCAD[2].cy = sg(rtn.cy[4],6);
 		OnlyOneCAD[2].r = sg(rtn.r[4],6);
-		/*  */
+		/* 円選択 */
 		OnlyOneIndex = 1;
 		OnlyOneEntry = 2;
 		OnlyOneKeepReturnFunc = ReturnFunc;
@@ -2119,7 +2119,7 @@ int pl_c(void)
 
 
 /* ---------------------------------------------------------------------
- * ȱߤǱ   pc_c   ̤ꡢߤܤ
+ * 点と円で円   pc_c   １点を通り、円に接する円
  * 
  */
 int pc_c(void)
@@ -2140,8 +2140,8 @@ int pc_c(void)
 	}
 
 
-	/* PCC		̤ߤܤ */
-	/* ϥܥåɽ */
+	/* PCC		１点を通り円に接する円 */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("Circle with the radius R which comes in touch with a circle through the point") , 
@@ -2181,7 +2181,7 @@ int pc_c(void)
 			OnlyOneCAD[4].cy = sg(rtn.cy[5], 6);
 			OnlyOneCAD[4].r = sg(rtn.r[5], 6);
 		}
-		/*  */
+		/* 円選択 */
 		OnlyOneIndex = 1;
 		OnlyOneEntry = rtn.type;
 		OnlyOneKeepReturnFunc = ReturnFunc;
@@ -2202,7 +2202,7 @@ int pc_c(void)
 
 
 /* ---------------------------------------------------------------------
- * Ǳ   ll_c   㤦   ľܤȾ£Ҥα
+ * 線と線で円   ll_c   ２線が違う   ２直線に接する半径Ｒの円
  * 
  */
 int ll_c(void)
@@ -2212,7 +2212,7 @@ int ll_c(void)
 	char str[256];
 
 
-	/* ϥܥåɽ */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("Circle with the radius R which comes in touch with 2 straight lines") , 
@@ -2253,7 +2253,7 @@ int ll_c(void)
 	OnlyOneCAD[4].cx = sg(rtn.cx[4],6);
 	OnlyOneCAD[4].cy = sg(rtn.cy[4],6);
 	OnlyOneCAD[4].r = sg(rtn.r[1],6);
-	/*  */
+	/* 円選択 */
 	OnlyOneIndex = 1;
 	OnlyOneEntry = 4;
 	OnlyOneKeepReturnFunc = ReturnFunc;
@@ -2267,7 +2267,7 @@ int ll_c(void)
 
 
 /* ---------------------------------------------------------------------
- * ȱߤǱ   lc_c   ľȱߤܤȾ£Ҥα
+ * 線と円で円   lc_c   直線と円に接する半径Ｒの円
  * 
  */
 int lc_c(void)
@@ -2287,8 +2287,8 @@ int lc_c(void)
 		circle = *select_search_num(1)->select->diagram_point.cad_point;
 	}
 
-	/* LCC		ľȱߤܤ */
-	/* ϥܥåɽ */
+	/* LCC		直線と円に接する円 */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("The circle of the radius R which touches a straight line and a circle") , 
@@ -2316,7 +2316,7 @@ int lc_c(void)
 			OnlyOneCAD[i].r = sg(rtn.r[i+1],6);
 			i++;
 		}
-		/*  */
+		/* 円選択 */
 		OnlyOneIndex = 1;
 		OnlyOneEntry = rtn.type;
 		OnlyOneKeepReturnFunc = ReturnFunc;
@@ -2328,7 +2328,7 @@ int lc_c(void)
 	}
 
 	else if (rtn.type == 1) {
-		/* ߥǡϿ */
+		/* 円データを登録 */
 		cad.code = 4;
 		cad.layer = NowLayer;
 		cad.style = NowStyle;
@@ -2357,7 +2357,7 @@ int lc_c(void)
 
 
 /* ---------------------------------------------------------------------
- * ߤȱߤǱ   c_c   ߤƱ   Ʊ
+ * 円と円で円   c_c   ２円が同一   同心円
  * 
  */
 int c_c(void)
@@ -2369,7 +2369,7 @@ int c_c(void)
 	CAD cad;
 
 
-	/* ϥܥåɽ */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("Concentric circle") , 
@@ -2380,7 +2380,7 @@ int c_c(void)
 	rtn.r[1] = atof(str);
 
 
-	/* ޥʥͤʤиˤʤߤȾ¤κ */
+	/* マイナス値ならば元になる円の半径の差 */
 	if (rtn.r[1] < 0) {
 		rtn.r[1] = -1 * rtn.r[1];
 		
@@ -2474,7 +2474,7 @@ int c_c(void)
 				OnlyOneCAD[2].ex = PAPH.ex[1];
 				OnlyOneCAD[2].ey = PAPH.ey[1];
 			}
-			/*  */
+			/* 円選択 */
 			OnlyOneIndex = 1;
 			OnlyOneEntry = 2;
 			OnlyOneKeepReturnFunc = ReturnFunc;
@@ -2486,11 +2486,11 @@ int c_c(void)
 		}
 
 
-		/* 礭ʤȤ */
+		/* 大きい方しかないとき */
 		else if (select_search_num(1)->select->diagram_point.cad_point->r <= rtn.r[1]) {
-			/* ߥǡϿ */
+			/* 円データを登録 */
 			if(select_search_num(1)->select->diagram_point.cad_point->code == 4) {
-				/* ߥǡϿ */
+				/* 円データを登録 */
 				cad.code = 4;
 				cad.layer = NowLayer;
 				cad.style = NowStyle;
@@ -2508,7 +2508,7 @@ int c_c(void)
 				SelectCadDraw(drawing_area, &cad, SCD_ORG);
 			}
 
-			/* ߸̥ǡϿ */
+			/* 円弧データを登録 */
 			else if(select_search_num(1)->select->diagram_point.cad_point->code == 2) {
 				/* SA */
 				LAH.sx[1] = select_search_num(1)->select->diagram_point.cad_point->cx;
@@ -2542,7 +2542,7 @@ int c_c(void)
 				ex = PAPH.ex[1];
 				ey = PAPH.ey[1];
 
-				/* ߥǡϿ */
+				/* 円データを登録 */
 				cad.code = 4;
 				cad.layer = NowLayer;
 				cad.style = NowStyle;
@@ -2562,7 +2562,7 @@ int c_c(void)
 			return 1;
 		}
 	}
-	/* ߥǡϿ */
+	/* 円データを登録 */
 	cad.code = 4;
 	cad.layer = NowLayer;
 	cad.style = NowStyle;
@@ -2585,7 +2585,7 @@ int c_c(void)
 
 
 /* ---------------------------------------------------------------------
- * ߤȱߤǱ   cc_c   ߤ㤦   ߤܤ
+ * 円と円で円   cc_c   ２円が違う   ２円に接する円
  * 
  */
 int cc_c(void)
@@ -2604,8 +2604,8 @@ int cc_c(void)
 		return 0;
 	}
 
-	/* CCC		ߤܤ */
-	/* ϥܥåɽ */
+	/* CCC		２円に接する円 */
+	/* 数値入力ダイアログボックス表示 */
 	strcpy(str, "");
 	Ret = CulcInputBox(MainWindow, 
 					   _("Circle which touches 2 circle") , 
@@ -2633,7 +2633,7 @@ int cc_c(void)
 			i++;
 		}
 		
-		/*  */
+		/* 円選択 */
 		OnlyOneIndex = 1;
 		OnlyOneEntry = rtn.type;
 		OnlyOneKeepReturnFunc = ReturnFunc;
@@ -2644,7 +2644,7 @@ int cc_c(void)
 		return 1;
 	}
 	else if (rtn.type == 1) {
-		/* ߥǡϿ */
+		/* 円データを登録 */
 		cad.code = 4;
 		cad.layer = NowLayer;
 		cad.style = NowStyle;
@@ -2674,7 +2674,7 @@ int cc_c(void)
 
 
 /* ---------------------------------------------------------------------
- * ߥޥɤ򤷤Ȥ
+ * 円コマンドを選択したとき
  * 
  */
 int CreateCircle(GtkWidget *widget)
@@ -2686,19 +2686,19 @@ int CreateCircle(GtkWidget *widget)
 	sel_2 = select_search_num(2)->select;
 
 
-	/* ,,߸,ߤΤߤΤȤ */
+	/* 点,線,円弧,円のみのとき */
 	if (sel_1->index == 2 
 		&& 
 		sel_2->index == 2 ) 
 	{
 
-		/* Ǳ */
+		/* 点と点で円 */
 		if (sel_1->diagram_point.cad_point->code == 0 
 			&& 
 			sel_2->diagram_point.cad_point->code == 0
 			) 
 		{
-			/* Ʊ   p_c   濴ȤȾ£Ҥα */
+			/* ２点が同一   p_c   点を中心とする半径Ｒの円 */
 			if (	(
 					sel_1->diagram_point.cad_point->sx 
 						== sel_2->diagram_point.cad_point->sx
@@ -2713,7 +2713,7 @@ int CreateCircle(GtkWidget *widget)
 				p_c();
 				return 1;
 			}
-			/* 㤦   pp_c   ̤Ⱦ£Ҥα */
+			/* ２点が違う   pp_c   ２点を通る半径Ｒの円 */
 			else {
 				pp_c();
 				return 1;
@@ -2721,7 +2721,7 @@ int CreateCircle(GtkWidget *widget)
 		}
 
 
-		/* Ǳ   pl_c   ̤ꡢľܤȾ£Ҥα */
+		/* 点と線で円   pl_c   １点を通り、直線に接する半径Ｒの円 */
 		else if (	(
 					sel_1->diagram_point.cad_point->code == 0 
 					&& 
@@ -2740,7 +2740,7 @@ int CreateCircle(GtkWidget *widget)
 		}
 
 
-		/* ȱߤǱ   pc_c   ̤ꡢߤܤ */
+		/* 点と円で円   pc_c   １点を通り、円に接する円 */
 		else if (	(
 						(
 						sel_1->diagram_point.cad_point->code == 0 
@@ -2775,16 +2775,16 @@ int CreateCircle(GtkWidget *widget)
 		}
 
 
-		/* Ǳ */
+		/* 線と線で円 */
 		else if (sel_1->diagram_point.cad_point->code == 1 
 				 && sel_2->diagram_point.cad_point->code == 1
 				 ) 
 		{
-			/* Ʊ   ̵ */
+			/* ２線が同一   無し */
 			if (sel_1->diagram_point.cad_point == sel_2->diagram_point.cad_point) {
 				return 0;
 			}
-			/* 㤦   ll_c   ľܤȾ£Ҥα */
+			/* ２線が違う   ll_c   ２直線に接する半径Ｒの円 */
 			if (sel_1->diagram_point.cad_point != sel_2->diagram_point.cad_point) {
 				ll_c();
 				return 1;
@@ -2792,7 +2792,7 @@ int CreateCircle(GtkWidget *widget)
 		}
 
 
-		/* ȱߤǱ   lc_c   ľȱߤܤȾ£Ҥα */
+		/* 線と円で円   lc_c   直線と円に接する半径Ｒの円 */
 		else if (
 					(
 						(
@@ -2828,7 +2828,7 @@ int CreateCircle(GtkWidget *widget)
 		}
 
 
-		/* ߤȱߤǱ */
+		/* 円と円で円 */
 		else if (
 					(
 					sel_1->diagram_point.cad_point->code == 2 
@@ -2855,7 +2855,7 @@ int CreateCircle(GtkWidget *widget)
 					)
 				)
 		{
-			/* ߤƱ   c_c   Ʊ */
+			/* ２円が同一   c_c   同心円 */
 			if (sg(sel_1->diagram_point.cad_point->cx, 6) 
 					== sg(sel_2->diagram_point.cad_point->cx, 6)
 				&& 
@@ -2877,7 +2877,7 @@ int CreateCircle(GtkWidget *widget)
 					return 0;
 				}
 			}
-			/* ߤ㤦   cc_c   ߤܤ */
+			/* ２円が違う   cc_c   ２円に接する円 */
 			else {
 				cc_c();
 				return 1;
@@ -2887,12 +2887,12 @@ int CreateCircle(GtkWidget *widget)
 
 
 
-	/* ʱߤȤ */
+	/* 楕円があるとき */
 	else if (sel_1->index == 16 
 			|| 
 			sel_2->index == 16 ) 
 	{
-		/* sel_1 ʱߤȤʤ褦ˤ */
+		/* sel_1 が楕円となるようにする */
 		if (sel_1->index == 2) {
 			sel = sel_1;
 			sel_1 = sel_2;
@@ -2900,7 +2900,7 @@ int CreateCircle(GtkWidget *widget)
 		}
 
 
-		/* ʱߤ */
+		/* 楕円と点 */
 		if (sel_2->index == 2) {
 			if (sel_2->diagram_point.cad_point->code == 0) {
 				
@@ -2910,7 +2910,7 @@ int CreateCircle(GtkWidget *widget)
 		}
 
 
-		/* ʱߤ */
+		/* 楕円と線 */
 		if (sel_2->index == 2) {
 			if (sel_2->diagram_point.cad_point->code == 1) {
 				
@@ -2920,7 +2920,7 @@ int CreateCircle(GtkWidget *widget)
 		}
 
 
-		/* ʱߤȱ(߸) */
+		/* 楕円と円(円弧) */
 		if (sel_2->index == 2) {
 			if (sel_2->diagram_point.cad_point->code == 2 || sel_2->diagram_point.cad_point->code == 4) {
 				
@@ -2930,7 +2930,7 @@ int CreateCircle(GtkWidget *widget)
 		}
 
 
-		/* ʱߤʱ */
+		/* 楕円と楕円 */
 		if (sel_2->index == 16) {
 			
 			
@@ -2950,7 +2950,7 @@ int CreateCircle(GtkWidget *widget)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2002 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : sagcad
  *    Source               : DrawMode.c
