@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/04/22
- *    Last                 : 2003/04/22
+ *    Last                 : 2007/10/14
  * ====================================================================
  */
 
@@ -30,7 +30,7 @@
 #include "List_cad.h"
 #include "List_Ellipse.h"
 //#include "CopyFunc.h"
-#include "Trace.h"
+#include "culcfunc.h"
 
 #define _ELLIPSE_
 #include "Ellipse.h"
@@ -40,7 +40,7 @@
 
 
 /* -------------------------------------------------------------------
- * Ĺ a 
+ * 長軸 a を求める
  * 
  */
 double get_ellipse_a(ELLIPSE ellipse)
@@ -57,7 +57,7 @@ double get_ellipse_a(ELLIPSE ellipse)
 
 
 /* -------------------------------------------------------------------
- * û b 
+ * 短軸 b を求める
  * 
  */
 double get_ellipse_b(ELLIPSE ellipse)
@@ -67,7 +67,7 @@ double get_ellipse_b(ELLIPSE ellipse)
 
 
 /* -------------------------------------------------------------------
- * ʱߤη
+ * 楕円の傾きを求める
  * 
  */
 double get_ellipse_angle(ELLIPSE ellipse)
@@ -86,17 +86,17 @@ double get_ellipse_angle(ELLIPSE ellipse)
 
 
 /* -------------------------------------------------------------------
- * ʱߤλȽ
+ * 楕円の始点と終点を求める
  * 
  */
-int get_ellipse_se_point(ELLIPSE ellipse, POINT *s_point, POINT *e_point)
+int get_ellipse_se_point(ELLIPSE ellipse, SAG_POINT *s_point, SAG_POINT *e_point)
 {
 	double RAD, DX, DY;
 
 
 
 
-	/*  */
+	/* 始点 */
 	RAD = degrad(get_ellipse_angle(ellipse));
 
 	s_point->x = get_ellipse_a(ellipse) * cos(degrad(ellipse.sa)) + ellipse.cx;
@@ -108,7 +108,7 @@ int get_ellipse_se_point(ELLIPSE ellipse, POINT *s_point, POINT *e_point)
 	s_point->y = sg((DY * cos(RAD) + DX * sin(RAD)) + ellipse.cy, calcu_digits);
 
 
-	/*  */
+	/* 終点 */
 	RAD = degrad(get_ellipse_angle(ellipse));
 
 	e_point->x = get_ellipse_a(ellipse) * cos(degrad(ellipse.ea)) + ellipse.cx;
@@ -124,10 +124,10 @@ int get_ellipse_se_point(ELLIPSE ellipse, POINT *s_point, POINT *e_point)
 
 
 /* -------------------------------------------------------------------
- * ʱߤξ
+ * 楕円の焦点を求める
  * 
  */
-int get_ellipse_focus(ELLIPSE ellipse, POINT *focus1, POINT *focus2)
+int get_ellipse_focus(ELLIPSE ellipse, SAG_POINT *focus1, SAG_POINT *focus2)
 {
 	double a, b, angle;
 
@@ -136,7 +136,7 @@ int get_ellipse_focus(ELLIPSE ellipse, POINT *focus1, POINT *focus2)
 	b = get_ellipse_b(ellipse);
 	angle = get_ellipse_angle(ellipse);
 
-	/*  */
+	/* 焦点を求める */
 	focus1->x = -1 * (sqrt(a*a - b*b)) + ellipse.cx;
 	focus1->y = 0 + ellipse.cy;
 	focus2->x = sqrt(a*a - b*b) + ellipse.cx;
@@ -153,14 +153,14 @@ int get_ellipse_focus(ELLIPSE ellipse, POINT *focus1, POINT *focus2)
 
 
 /* -------------------------------------------------------------------
- * ʱߤȳ٤ʱ߾
+ * 楕円と角度で楕円上の点を求める
  * 
  */
-int get_ellipse_point_from_angle (ELLIPSE ellipse, double angle, POINT *point)
+int get_ellipse_point_from_angle (ELLIPSE ellipse, double angle, SAG_POINT *point)
 {
 //#define GET_ELLIPSE_POINT_FROM_ANGLE
 	struct RtnDat rtn;
-	POINT point1, point2;
+	SAG_POINT point1, point2;
 	double angle1, angle2;
 	ELLIPSE eps;
 	int debug = 0;
@@ -237,10 +237,10 @@ int get_ellipse_point_from_angle (ELLIPSE ellipse, double angle, POINT *point)
 
 
 /* -------------------------------------------------------------------
- * ʱߤʱ߾γ٤
+ * 楕円と点で楕円上の角度を求める
  * 
  */
-double get_ellipse_angle_from_point (ELLIPSE ellipse, POINT point)
+double get_ellipse_angle_from_point (ELLIPSE ellipse, SAG_POINT point)
 {
 	struct RtnDat rtn;
 
@@ -248,7 +248,7 @@ double get_ellipse_angle_from_point (ELLIPSE ellipse, POINT point)
 	rotation(&point.x, &point.y, ellipse.cx, ellipse.cy, (-1 * get_ellipse_angle(ellipse)));
 
 	/* -------------------------------------------------------------------
-	 * la : ľγ
+	 * la : 直線の角度
 	 */
 	rtn.sx[1] = ellipse.cx;
 	rtn.sy[1] = ellipse.cy;
@@ -265,7 +265,7 @@ double get_ellipse_angle_from_point (ELLIPSE ellipse, POINT point)
 
 
 /* -------------------------------------------------------
- *  (px, py) ϡʱ߾Ǥ뤫Ƚ
+ * 点 (px, py) は、楕円上の点であるかの判定
  * 
  */
 int point_on_ellipse (ELLIPSE *ellipse, double px, double py)
@@ -283,16 +283,16 @@ int point_on_ellipse (ELLIPSE *ellipse, double px, double py)
 #endif
 
 
-	/* ʱ߾ˤ뤫 */
+	/* 点が楕円上にあるか */
 	if (point_in_ellipse(ellipse, px, py, 0.000001) != 3) {
 		return 0;
 	}
 
 
-	/* ϳѡλѤȽ */
-	/* ԥåʱߤФ٤ */
+	/* 開始角・終了角で判定 */
+	/* ピック点の楕円に対する角度を求める */
 	/* -------------------------------------------------------------------
-	 * la : [8] ľγ
+	 * la : [8] 直線の角度
 	 */
 	rtn.sx[1] = ellipse->cx;
 	rtn.sy[1] = ellipse->cy;
@@ -341,11 +341,11 @@ int point_on_ellipse (ELLIPSE *ellipse, double px, double py)
 
 
 /* -------------------------------------------------------
- * ʱߤˤ뤫ˤ뤫Ƚ
+ * 点が楕円の中にあるか外にあるかの判定
  * 
  * 
  * 
- * value : Ƚϰ()    0.001 Ȥ 0.5 Ȥ
+ * value : 判定範囲(誤差)    0.001 とか 0.5 とか
  * 
  * return : 1 : IN
  *          2 : OUT
@@ -357,7 +357,7 @@ int point_in_ellipse (ELLIPSE *ellipse, double px, double py, double value)
 	struct RtnDat rtn;
 	double a, b, angle;
 	double l1, l2;
-	POINT focus1, focus2;
+	SAG_POINT focus1, focus2;
 	int debug = 0;
 
 
@@ -369,24 +369,24 @@ int point_in_ellipse (ELLIPSE *ellipse, double px, double py, double value)
 
 
 	/* -----------------------------------------------------
-	 * ʱߤǤ
+	 * 楕円の要素を求める
 	 */
-	/* 濴Ĺΰ֤γ٤ȵΥ */
+	/* 中心から長軸の位置の角度と距離を求める */
 	angle = get_ellipse_angle(*ellipse);
 	a = get_ellipse_a(*ellipse);
 	b = get_ellipse_b(*ellipse);
 	get_ellipse_focus(*ellipse, &focus1, &focus2);
 
 	if (debug > 0) {
-		g_print("Ellipse.c : point_in_ellipse() : a = %f  b = %f  angle = %f   (%f,%f) (%f,%f)\n", 
+		g_print("Ellipse.c : point_in_ellipse() : a = %f  b = %f  angle = %f  焦点 (%f,%f) (%f,%f)\n", 
 				 a, b, angle, focus1.x, focus1.y, focus2.x, focus2.y);
 	}
 
 
 
-	/* (px,py)  εΥδطǡ(1/pow(10, compa_digits)) Ƚ */
+	/* (px,py) と 焦点の距離の関係で、(1/pow(10, compa_digits)) で判定 */
 	/* -------------------------------------------------------------------
-	 * pp : [9] ֤εΥ
+	 * pp : [9] ２点間の距離
 	 */
 	rtn.sx[1] = focus1.x;
 	rtn.sy[1] = focus1.y;
@@ -406,19 +406,19 @@ int point_in_ellipse (ELLIPSE *ellipse, double px, double py, double value)
 
 
 
-	/* (l1 + l2) = 2a ʤ Ellipse α߼ */
+	/* (l1 + l2) = 2a なら Ellipse の円周上の点 */
 	if ( (l1 + l2) + (value) > (2*a) && (l1 + l2) - (value) < (2*a) ) {
 		if (debug > 0) g_print("Ellipse.c : point_in_ellipse() : on Ellipse\n");
 		return 3;
 	}
 
-	/* Ellipse  */
+	/* Ellipse の中の点 */
 	else if (l1 + l2 < (2*a)) {
 		if (debug > 0) g_print("Ellipse.c : point_in_ellipse() : in Ellipse\n");
 		return 1;
 	}
 
-	/* Ellipse γ */
+	/* Ellipse の外の点 */
 	else if (l1 + l2 > (2*a)) {
 		if (debug > 0) g_print("Ellipse.c : point_in_ellipse() : out Ellipse\n");
 		return 2;
@@ -432,7 +432,7 @@ int point_in_ellipse (ELLIPSE *ellipse, double px, double py, double value)
 
 
 /* -------------------------------------------------------------------
- * ʱߤθ
+ * 点から楕円の接線の交点
  * 
  * in :
  *      Point (a->sx[1],a->sy[1])
@@ -452,7 +452,7 @@ int pel(struct RtnDat *rtn, ELLIPSE ellipse)
 
 
 	/* -----------------------------------------------------
-	 * ΰ֤ǧ
+	 * 点の位置を確認
 	 */
 	eps = ellipse;
 	Ret = point_in_ellipse (&eps, rtn->sx[1], rtn->sy[1], 0.0000001);
@@ -476,9 +476,9 @@ int pel(struct RtnDat *rtn, ELLIPSE ellipse)
 
 
 	/* -----------------------------------------------------
-	 * ޤʱߤ濴 (0,0) ǡ٤ 0 ˤʤ褦ʺɸѴ
+	 * まず、楕円の中心が (0,0) で、角度が 0 になるような座標に変換。
 	 */
-	/*  */
+	/* 点 */
 	init_cad(&cad);
 	cad.sx = rtn->sx[1];
 	cad.sy = rtn->sy[1];
@@ -488,8 +488,8 @@ int pel(struct RtnDat *rtn, ELLIPSE ellipse)
 
 
 
-	/*  */
-	/* ʱߤμμ */
+	/* 交点を求める */
+	/* 楕円の式と接線の式から */
 	a = get_ellipse_a(eps);
 	b = get_ellipse_b(eps);
 
@@ -505,7 +505,7 @@ int pel(struct RtnDat *rtn, ELLIPSE ellipse)
 
 
 	/* -----------------------------------------------------
-	 * Ǹˡ򸵤κɸ᤹
+	 * 最後に、交点を元の座標に戻す
 	 */
 	rtn->type = 2;
 	rtn->ex[1] = X1;
@@ -526,15 +526,15 @@ int pel(struct RtnDat *rtn, ELLIPSE ellipse)
 
 
 /* -------------------------------------------------------------------
- * ʱߤθ
+ * 楕円と線の交点
  * lep
  * RtnDat
- *      : (sx[1],sy[1]) - (ex[1],ey[1])
- *   ʱ : 
+ *   線   : (sx[1],sy[1]) - (ex[1],ey[1])
+ *   楕円 : 
  * RtnDat
  *   type	0 , 1 , 2
- *    1	(sx[2],sy[2])
- *    2	(sx[3],sy[3])
+ *   点 1	(sx[2],sy[2])
+ *   点 2	(sx[3],sy[3])
  */
 int lep(struct RtnDat *rtn, ELLIPSE ellipse, int dgt)
 {
@@ -562,9 +562,9 @@ int lep(struct RtnDat *rtn, ELLIPSE ellipse, int dgt)
 
 
 	/* -----------------------------------------------------
-	 * ޤʱߤ濴 (0,0) ǡ٤ 0 ˤʤ褦ʺɸѴ
+	 * まず、楕円の中心が (0,0) で、角度が 0 になるような座標に変換。
 	 */
-	/*  */
+	/* 点 */
 	init_cad(&cad);
 	cad.sx = rtn->sx[1];
 	cad.sy = rtn->sy[1];
@@ -585,29 +585,29 @@ int lep(struct RtnDat *rtn, ELLIPSE ellipse, int dgt)
 
 	/* y = mx + n  */
 
-	/* ľ */
+	/* 垂直 */
 	if (cad.ex > cad.sx - (1/pow(10, dgt)) && cad.ex < cad.sx + (1/pow(10, dgt))) {
-		if (debug > 0) g_print("ľ\n");
+		if (debug > 0) g_print("垂直\n");
 
-		/* -a ܤ */
+		/* -a で接する */
 		if (cad.sx > -a - (1/pow(10, dgt)) && cad.sx < -a + (1/pow(10, dgt))) {
-			if (debug > 0) g_print("-a ܤ\n");
+			if (debug > 0) g_print("-a で接する\n");
 			rtn->type = 1;
 			X1 = -a;
 			Y1 = 0;
 		}
 
-		/* a ܤ */
+		/* a で接する */
 		else if (cad.sx > a - (1/pow(10, dgt)) && cad.sx < a + (1/pow(10, dgt))) {
-			if (debug > 0) g_print("a ܤ\n");
+			if (debug > 0) g_print("a で接する\n");
 			rtn->type = 1;
 			X1 = a;
 			Y1 = 0;
 		}
 
-		/* Ťʤ */
+		/* 重なる */
 		else if (cad.sx > -a && cad.sx < a) {
-			if (debug > 0) g_print("Ťʤ\n");
+			if (debug > 0) g_print("重なる\n");
 			rtn->type = 2;
 
 			angle = acos(cad.sx / a);
@@ -618,7 +618,7 @@ int lep(struct RtnDat *rtn, ELLIPSE ellipse, int dgt)
 		}
 
 		else {
-			if (debug > 0) g_print("̵\n");
+			if (debug > 0) g_print("交点無し\n");
 			rtn->type = 0;
 			return 0;
 		}
@@ -626,25 +626,25 @@ int lep(struct RtnDat *rtn, ELLIPSE ellipse, int dgt)
 
 
 
-	/* ʿ */
+	/* 水平 */
 	else if (cad.ey > cad.sy - (1/pow(10, dgt)) && cad.ey < cad.sy + (1/pow(10, dgt))) {
-		if (debug > 0) g_print("ʿ\n");
+		if (debug > 0) g_print("水平\n");
 
-		/* -b ܤ */
+		/* -b で接する */
 		if (cad.sy > -b - (1/pow(10, dgt)) && cad.sy < -b + (1/pow(10, dgt))) {
 			rtn->type = 1;
 			X1 = 0;
 			Y1 = -b;
 		}
 
-		/* b ܤ */
+		/* b で接する */
 		else if (cad.sy > b - (1/pow(10, dgt)) && cad.sy < b + (1/pow(10, dgt))) {
 			rtn->type = 1;
 			X1 = 0;
 			Y1 = b;
 		}
 
-		/* Ťʤ */
+		/* 重なる */
 		else if (cad.sy > -b && cad.sy < b) {
 			rtn->type = 2;
 			
@@ -663,7 +663,7 @@ int lep(struct RtnDat *rtn, ELLIPSE ellipse, int dgt)
 
 
 
-	/* ̤ */
+	/* 普通の線 */
 	else {
 		m = (cad.ey - cad.sy) / (cad.ex - cad.sx);
 		n = cad.sy - (m * cad.sx);
@@ -675,18 +675,18 @@ int lep(struct RtnDat *rtn, ELLIPSE ellipse, int dgt)
 		D = (B*B) - (4*A*C);
 
 
-		/* ʱߤܤƤ() */
+		/* 線と楕円は接している(交点が１個) */
 		if (D < (1/pow(10, dgt)) && D > -(1/pow(10, dgt)) ) {
-			if (debug > 0) g_print("ܤƤ D = %f\n", D);
+			if (debug > 0) g_print("接している D = %f\n", D);
 			rtn->type = 1;
 
 			X1 = (-B / (2*A));
 			Y1 = m * X1 + n;
 		}
 
-		/* ŤʤäƤ() */
+		/* 重なっている(交点が２個) */
 		else if (D > 0) {
-			if (debug > 0) g_print("ŤʤäƤ D = %f\n", D);
+			if (debug > 0) g_print("重なっている D = %f\n", D);
 			rtn->type = 2;
 
 			X1 = (-B-sqrt(B*B-4*A*C)) / (2*A);
@@ -695,15 +695,15 @@ int lep(struct RtnDat *rtn, ELLIPSE ellipse, int dgt)
 			Y2 = m * X2 + n;
 		}
 
-		/* ΥƤ() */
+		/* 離れている(交点が０個) */
 		else if (D < 0) {
-			if (debug > 0) g_print("ΥƤ D = %f\n", D);
+			if (debug > 0) g_print("離れている D = %f\n", D);
 			rtn->type = 0;
 			return 0;
 		}
 
 		else {
-			if (debug > 0) g_print(" D = %f\n", D);
+			if (debug > 0) g_print("アレ D = %f\n", D);
 			return -1;
 		}
 	}
@@ -738,7 +738,7 @@ int lep(struct RtnDat *rtn, ELLIPSE ellipse, int dgt)
 
 
 /* -------------------------------------------------------------------
- * ʱ߾(angle)Ǥ
+ * 楕円上の点(angle)での接線を求める
  * 
  */
 int ellipse_tangent(struct RtnDat *rtn, ELLIPSE ellipse, double angle)
@@ -746,8 +746,8 @@ int ellipse_tangent(struct RtnDat *rtn, ELLIPSE ellipse, double angle)
 	double a, b;
 
 
-	/* ʱ߾ angle  */
-	/* 濴 (0,0) Ƿ 0 ٤ʱߤκɸ */
+	/* 楕円上の点を angle から求める */
+	/* 中心 (0,0) で傾き 0 度の楕円の座標を求める */
 	a = get_ellipse_a(ellipse);
 	b = get_ellipse_b(ellipse);
 
@@ -775,7 +775,7 @@ int ellipse_tangent(struct RtnDat *rtn, ELLIPSE ellipse, double angle)
 
 
 	/* -----------------------------------------------------
-	 * Ǹˡ򸵤κɸ᤹
+	 * 最後に、交点を元の座標に戻す
 	 */
 	rtn->type = 1;
 	if (get_ellipse_angle(ellipse) != 0) {
@@ -795,18 +795,18 @@ int ellipse_tangent(struct RtnDat *rtn, ELLIPSE ellipse, double angle)
 
 
 /* -------------------------------------------------------------------
- * cc_check : ߤΰִطĴ٤
+ * cc_check : ２円の位置関係を調べる
  * 
  *     : rtndat
- *     :      1	(cx[1] , cy[1]) ,r[1]
- *     :      2	(cx[2] , cy[2]) ,r[2]
+ *     :     円 1	(cx[1] , cy[1]) ,r[1]
+ *     :     円 2	(cx[2] , cy[2]) ,r[2]
  * 
- * return = type : 0 顼
- *                 1 ߤΥƤ
- *                 2 ߤܤƤ
- *                 3 ߤŤʤäƤ
- *                 4 ߤŤʤäܤƤ
- *                 5 ߤŤʤäΥƤ
+ * return = type : 0 エラー
+ *                 1 ２円が離れている
+ *                 2 ２円が接している
+ *                 3 ２円が重なっている
+ *                 4 ２円が重なって接している
+ *                 5 ２円が重なって離れている
  * 
  */
 int cc_check(struct RtnDat *rtn)
@@ -833,17 +833,17 @@ int cc_check(struct RtnDat *rtn)
 
 
 	if (debug > 1) {
-		/* ߤΥƤ롣 */
+		/* ２円が離れている。接線４本 */
 		g_print("type 4 : dist > r1pr2 = %d\n", dist > r1pr2);
-		/* ߤܤƤ롣 */
+		/* ２円が接している。接線３本 */
 		g_print("type 3 : dist == r1pr2 = %d\n", dist == r1pr2);
-		/* ߤŤʤäƤ롣 */
+		/* ２円が重なっている。接線２本 */
 		g_print("type 2 : dist < r1pr2 && dist > r1mr2 = %d\n", (dist < r1pr2 && dist > r1mr2));
 		g_print("  type 2-1 : dist < r1pr2 = %d\n", (dist < r1pr2));
 		g_print("  type 2-2 : dist > r1mr2 = %d\n", (dist > r1mr2));
-		/* ߤŤʤäܤƤ롣 */
+		/* ２円が重なって接している。接線１本 */
 		g_print("type 1 : dist == r1mr2 = %d\n", (dist == r1mr2));
-		/* ߤŤʤäΥƤ롣 0  */
+		/* ２円が重なって離れている。接線 0 本 */
 		g_print("type 0 : (dist < r1mr2 && sg(rtn->l, compa_digits) > 0) = %d\n", 
 				(dist < r1mr2 && sg(rtn->l, compa_digits) > 0));
 		g_print("  type 0-1 : (dist < r1mr2) = %d\n", (dist < r1mr2));
@@ -851,37 +851,37 @@ int cc_check(struct RtnDat *rtn)
 	}
 
 
-	/* ߤΥƤ롣 */
+	/* ２円が離れている。接線４本 */
 	if (dist > r1pr2) {
-		if (debug > 0) g_print("type 1 : ߤΥƤ\n");
+		if (debug > 0) g_print("type 1 : ２円が離れている\n");
 		rtn->type = 1;
 		return 1;
 	}
 
-	/* ߤܤƤ롣 */
+	/* ２円が接している。接線３本 */
 	else if (dist == r1pr2) {
-		if (debug > 0) g_print("type 2 : ߤܤƤ\n");
+		if (debug > 0) g_print("type 2 : ２円が接している\n");
 		rtn->type = 2;
 		return 2;
 	}
 
-	/* ߤŤʤäƤ롣 */
+	/* ２円が重なっている。接線２本 */
 	else if (dist < r1pr2 && dist > r1mr2) {
-		if (debug > 0) g_print("type 2 : ߤŤʤäƤ\n");
+		if (debug > 0) g_print("type 2 : ２円が重なっている\n");
 		rtn->type = 3;
 		return 3;
 	}
 
-	/* ߤŤʤäܤƤ롣 */
+	/* ２円が重なって接している。接線１本 */
 	else if (dist == r1mr2) {
-		if (debug > 0) g_print("type 4 : ߤŤʤäܤƤ\n");
+		if (debug > 0) g_print("type 4 : ２円が重なって接している\n");
 		rtn->type = 4;
 		return 4;
 	}
 
-	/* ߤŤʤäΥƤ롣 0  */
+	/* ２円が重なって離れている。接線 0 本 */
 	else if (dist < r1mr2 && sg(rtn->l, compa_digits) > 0) {
-		if (debug > 0) g_print("type 5 : ߤŤʤäΥƤ\n");
+		if (debug > 0) g_print("type 5 : ２円が重なって離れている\n");
 		rtn->type = 5;
 		return 5;
 	}
@@ -894,23 +894,23 @@ int cc_check(struct RtnDat *rtn)
 
 
 /* -------------------------------------------------------
- * ʱߤʱ()θ (MAIN)
+ * 楕円と楕円(円)の交点 (MAIN)
  * 
- * ʱߤϣĤ⤢ꤨ
+ * 楕円は４個もありえる
  * 
- * rtn->type : 0 ̵
- *             1   (rtn->sx[1],rtn->sy[1])
- *             2   (rtn->sx[2],rtn->sy[2])
- *             3   (rtn->sx[3],rtn->sy[3])
- *             4   (rtn->sx[4],rtn->sy[4])
+ * rtn->type : 0 交点無し
+ *             1 交点１個  (rtn->sx[1],rtn->sy[1])
+ *             2 交点２個  (rtn->sx[2],rtn->sy[2])
+ *             3 交点３個  (rtn->sx[3],rtn->sy[3])
+ *             4 交点４個  (rtn->sx[4],rtn->sy[4])
  * 
- *          ʱߤΰִطĴ٤
- *  return : 0 : 顼
- *           1 : ΥƤ
- *           2 : ¤ܤƤ
- *           3 : ŤʤäƤ
- *           4 : ŤʤäܤƤ
- *           5 : ŤʤäΥƤ
+ *          楕円の位置関係も調べたい。
+ *  return : 0 : エラー
+ *           1 : 離れている
+ *           2 : 並んで接している
+ *           3 : 重なっている
+ *           4 : 重なって接している
+ *           5 : 重なって離れている
  */
 int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 {
@@ -922,7 +922,7 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 	int AinB = 0, BinA = 0, start_frag = 0;
 	double sa[5], ea[5];
 	double sa1, ea1, sa2, ea2;
-	POINT point1, point2;
+	SAG_POINT point1, point2;
 	int BeforeRet = 0;
 	int debug = 0;
 
@@ -936,12 +936,12 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 
 
 	/* -----------------------------------------------------
-	 * ǡμ
+	 * データの収集
 	 * 
 	 */
-	/* ʱߣ1٤Ȥ˥ǡ */
+	/* 楕円Ａを1度ごとにデータを収集 */
 	value = (2 * PI * get_ellipse_a(ellipseA)) / (360*2);
-	if (debug > 0) g_print ("ʱߣβ\n");
+	if (debug > 0) g_print ("楕円Ａの解析\n");
 	for (i = 0 ; i < 360 ; i++) {
 		get_ellipse_point_from_angle (ellipseA, (double)i, &point1);
 		Ret = point_in_ellipse (&ellipseB, point1.x, point1.y, value);
@@ -953,9 +953,9 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 		A_data[i] = Ret;
 	}
 
-	/* ʱߣ¤1٤Ȥ˥ǡ */
+	/* 楕円Ｂを1度ごとにデータを収集 */
 	value = (2 * PI * get_ellipse_a(ellipseB)) / (360*2);
-	if (debug > 0) g_print ("ʱߣ¤β\n");
+	if (debug > 0) g_print ("楕円Ｂの解析\n");
 	for (i = 0 ; i < 360 ; i++) {
 		get_ellipse_point_from_angle (ellipseB, (double)i, &point1);
 		Ret = point_in_ellipse (&ellipseA, point1.x, point1.y, value);
@@ -968,10 +968,10 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 	}
 
 
-	/* ʱߣ¤濴ʱߣ */
+	/* 楕円Ｂの中心は楕円Ａの中 */
 	Ret = point_in_ellipse (&ellipseA, ellipseB.cx, ellipseB.cy, 0.0000001);
 	if (Ret == 1) BinA = 1;
-	/* ʱߣ濴ʱߣ¤ */
+	/* 楕円Ａの中心は楕円Ｂの中 */
 	Ret = point_in_ellipse (&ellipseB, ellipseA.cx, ellipseA.cy, 0.0000001);
 	if (Ret == 1) AinB = 1;
 
@@ -980,7 +980,7 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 
 
 	/* -----------------------------------------------------
-	 * SA(out->in) or EA(in->out)  
+	 * SA(out->in) or EA(in->out) 情報を解析 
 	 * 
 	 */
 	for (i = 0 ; i < 5 ; i++) {
@@ -1024,13 +1024,13 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 
 
 	/* -----------------------------------------------------
-	 * SA(out->in) or EA(in->out) 󤫤õ 
+	 * SA(out->in) or EA(in->out) 情報から交点を探索 
 	 * 
 	 */
 	for (i = 0 ; i < j ; i++) {
 		/*  */
 		if (sa[i] == 0 && ea[i] == 0) {
-			if (debug > 0) g_print("Ellipse.c : ellipse_on_ellipse_rect() : sa[i] == 0 && ea[i] == 0 ǽλ\n");
+			if (debug > 0) g_print("Ellipse.c : ellipse_on_ellipse_rect() : sa[i] == 0 && ea[i] == 0 で終了\n");
 			return 0;
 		}
 
@@ -1038,13 +1038,13 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 		else if (sa[i] < ea[i]) {
 			if (debug > 0) g_print("Ellipse.c : ellipse_on_ellipse_rect() : sa[i] < ea[i]\n");
 
-			/* õϰϤ */
+			/* 探索範囲を初期設定 */
 			sa1 = sa[i];
 			ea1 = ((ea[i] - sa[i]) / 2) + sa[i];
 			sa2 = ((ea[i] - sa[i]) / 2) + sa[i];
 			ea2 = ea[i];
 
-			/* ΰκǽ */
+			/* 領域の最初 */
 			if (debug > 0) g_print("Ellipse.c : ellipse_on_ellipse_rect() : sa1 = %f  ea1 = %f\n", sa1, ea1);
 			Ret1 = ellipse_on_ellipse_point(ellipseA, ellipseB, &sa1, &ea1, ((ea[i] - sa[i]) / 10), 0.0000001);
 			if (Ret1 == 1) {
@@ -1055,7 +1055,7 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 				if (debug > 0) g_print("Ellipse.c : ellipse_on_ellipse_rect() : (%f,%f)\n", point1.x, point1.y);
 			}
 
-			/* ΰκǸ */
+			/* 領域の最後 */
 			if (debug > 0) g_print("Ellipse.c : ellipse_on_ellipse_rect() : sa2 = %f  ea2 = %f\n", sa2, ea2);
 			Ret2 = ellipse_on_ellipse_point(ellipseA, ellipseB, &sa2, &ea2, ((ea[i] - sa[i]) / 10), 0.0000001);
 			if (Ret2 == 1) {
@@ -1080,7 +1080,7 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 		/* EA < SA */
 		else if (sa[i] > ea[i]) {
 			if (debug > 0) g_print("Ellipse.c : ellipse_on_ellipse_rect() : sa[i] > ea[i]\n");
-			/* õϰϤ */
+			/* 探索範囲を初期設定 */
 			sa1 = sa[i];
 			ea1 = sa[i] + (360-sa[i]+ea[i])/2;
 			if (ea1 <= 0) ea1 = ea1 + 360;
@@ -1091,7 +1091,7 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 			ea2 = ea[i];
 
 
-			/* ΰκǽ */
+			/* 領域の最初 */
 			if (debug > 0) g_print("Ellipse.c : ellipse_on_ellipse_rect() : sa1 = %f  ea1 = %f\n", sa1, ea1);
 			Ret1 = ellipse_on_ellipse_point(ellipseA, ellipseB, &sa1, &ea1, ((360-sa[i]+ea[i])/20), 0.0000001);
 			if (Ret1 == 1) {
@@ -1102,7 +1102,7 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 				if (debug > 0) g_print("Ellipse.c : ellipse_on_ellipse_rect() : (%f,%f)\n", point1.x, point1.y);
 			}
 
-			/* ΰκǸ */
+			/* 領域の最後 */
 			if (debug > 0) g_print("Ellipse.c : ellipse_on_ellipse_rect() : sa2 = %f  ea2 = %f\n", sa2, ea2);
 			Ret2 = ellipse_on_ellipse_point(ellipseA, ellipseB, &sa2, &ea2, ((360-sa[i]+ea[i])/20), 0.0000001);
 			if (Ret2 == 1) {
@@ -1123,27 +1123,27 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 		}
 	}
 
-	/* ΥƤ */
+	/* 離れている */
 	if (rtn->type == 0 && BinA == 0 && AinB == 0) {
 		if (debug > 0) g_print ("ellipse_on_ellipse() : out 1\n");
 		return 1;
 	}
-	/* ¤ܤƤ */
+	/* 並んで接している */
 	else if (rtn->type == 1 && BinA == 0 && AinB == 0) {
 		if (debug > 0) g_print ("ellipse_on_ellipse() : out 2\n");
 		return 2;
 	}
-	/* ŤʤäƤ */
+	/* 重なっている */
 	else if (rtn->type > 1) {
 		if (debug > 0) g_print ("ellipse_on_ellipse() : out 3\n");
 		return 3;
 	}
-	/* ŤʤäܤƤ */
+	/* 重なって接している */
 	else if (rtn->type == 1 && (BinA == 1 || AinB == 1)) {
 		if (debug > 0) g_print ("ellipse_on_ellipse() : out 4\n");
 		return 4;
 	}
-	/* ŤʤäΥƤ */
+	/* 重なって離れている */
 	else if (rtn->type == 0 && (BinA == 1 || AinB == 1)) {
 		if (debug > 0) g_print ("ellipse_on_ellipse() : out 5\n");
 		return 5;
@@ -1158,7 +1158,7 @@ int ellipse_on_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 
 
 /* -------------------------------------------------------------------
- * ʱߣʱߣ¤θȤʤ롢ʱߣγ٤ϰ 
+ * 楕円Ａと楕円Ｂの交点となる、楕円Ａの角度の範囲 
  * 
  */
 int ellipse_on_ellipse_point(ELLIPSE ellipseA, 
@@ -1173,7 +1173,7 @@ int ellipse_on_ellipse_point(ELLIPSE ellipseA,
 	int Ret = 0, BeforeRet = 0, End = 0;
 	double dgt, value;
 	double min = 0, max = 0;
-	POINT point;
+	SAG_POINT point;
 	int debug = 0;
 
 
@@ -1390,10 +1390,10 @@ int ellipse_on_ellipse_point(ELLIPSE ellipseA,
 
 
 /* -------------------------------------------------------
- * ʱߤʱ() (Main)
+ * 楕円から楕円(円)の接線 (Main)
  * 
  * 
- * return : 0 : ʤ
+ * return : 0 : 接線なし
  *          1 : 
  *          2 : 
  *          3 : 
@@ -1406,18 +1406,18 @@ int ellipse_to_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 	int A_data[360];
 	double sp[5], ep[5], AnsAngle;
 	struct RtnDat lo_rtn;
-	POINT point;
+	SAG_POINT point;
 	int debug = 0;
 
 
 	/* -----------------------------------------------------
-	 * ǡμ
+	 * データの収集
 	 * 
-	 * ʱߣ 1 ٤Ȥ˵ᡢ
-	 * ʱߣ¤ΰִط A_data[] 롣
+	 * 楕円Ａの接線を 1 度ごとに求め、その接線と
+	 * 楕円Ｂの位置関係を A_data[] の配列に入れる。
 	 */
-	/* ʱߣ1٤Ȥ˥ǡ */
-	if (debug > 0) g_print ("ʱߣβ\n");
+	/* 楕円Ａを1度ごとにデータを収集 */
+	if (debug > 0) g_print ("楕円Ａの解析\n");
 	for (i = 0 ; i < 360 ; i++) {
 		ellipse_tangent(rtn, ellipseA, (double)i);
 		lep(rtn, ellipseB, 4);
@@ -1433,16 +1433,16 @@ int ellipse_to_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 
 
 	/* -----------------------------------------------------
-	 *  
+	 * 情報を解析 
 	 * 
 	 */
-	/* Ȼפ٤ϰϤǼ */
+	/* 接線があると思われる角度の範囲を格納する配列を初期化 */
 	for (i = 0 ; i < 5 ; i++) {
 		sp[i] = 0;
 		ep[i] = 0;
 	}
 
-	/* Ȼפ٤ϰϤ */
+	/* 接線があると思われる角度の範囲を解析 */
 	j = 0;
 	BeforeRet = 1;
 	for (i = 0 ; i < 360 ; i++) {
@@ -1468,7 +1468,7 @@ int ellipse_to_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 		}
 	}
 
-	/* Ȼפ٤ϰϤΥǡǧ */
+	/* 接線があると思われる角度の範囲のデータを確認 */
 	if (debug > 0) {
 		for (i = 0 ; i < j ; i++) {
 			g_print ("sp[%d] = %f  ep[%d] = %f\n", i, sp[i], i, ep[i]);
@@ -1478,10 +1478,10 @@ int ellipse_to_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 
 
 	/* -----------------------------------------------------
+	 * 接線を求める
 	 * 
-	 * 
-	 * Ȼפ٤ϰϤǼƤγƥǡ
-	 * ٤٤ᡢ롣
+	 * 接線があると思われる角度の範囲を格納している配列の各データから
+	 * さらに精度を細かくして接線を求め、交点を求める。
 	 */
 	rtn->type = 0;
 	for (i = 0 ; i < j ; i++) {
@@ -1521,25 +1521,25 @@ int ellipse_to_ellipse(struct RtnDat *rtn, ELLIPSE ellipseA, ELLIPSE ellipseB)
 
 
 /* -------------------------------------------------------
- * ʱߣ sp ep ʱߣ()õ (Ƶؿ)
+ * 楕円Ａの sp ep から楕円Ｂ(円)の接線を探す (再帰関数)
  * 
  * 
- * ʱߣ sp  ep γ٤δ֤򥹥ƥå angle_degits ᡢ
+ * 楕円Ａの sp から ep の角度の間をステップ angle_degits で接線を求め、
  * 
- * ʱߣ¤椫鳰ȴ֤ sp ep ϰϤäȶ
- * ޤ
- * ʱߣ¤γ֤ sp ep ϰϤäȶ
- * ơƵƤӽФˤƤޤ ellipse_to_ellipse_search() Ƥ֡
+ * 楕円Ｂの中から外へ抜ける区間の sp ep の範囲をもっと狭く
+ * または
+ * 楕円Ｂの外から中へ入る区間の sp ep の範囲をもっと狭く
+ * して、再帰呼び出しにてまた ellipse_to_ellipse_search() を呼ぶ。
  * 
- * λϡsp ep ϰϤ last_degits ⾮ʤäȤ
- * sp ep ϰϤѤʤȤ
+ * 終了条件は、sp ep の範囲が last_degits よりも小さくなったときか、
+ * sp ep の範囲が変わらないとき。
  * 
  */
 int ellipse_to_ellipse_search (ELLIPSE ellipseA, 
 							   ELLIPSE ellipseB, 
 							   double *sp, 
 							   double *ep, 
-							   POINT *point, 
+							   SAG_POINT *point, 
 							   double angle_degits, 
 							   double last_degits 
 							   )
@@ -1559,8 +1559,8 @@ int ellipse_to_ellipse_search (ELLIPSE ellipseA,
 
 
 	/* -----------------------------------------------------
-	 * ʱߣʱߣ¤椫鳰ޤϳ
-	 * ڤؤϰϤõ
+	 * 楕円Ａの接線が、楕円Ｂの中から外、または外から中に
+	 * 切り替わる範囲を探す。
 	 */
 	BeforeRet = 1;
 	for (i = *sp ; i < *ep + angle_degits; i = i + angle_degits) {
@@ -1573,7 +1573,7 @@ int ellipse_to_ellipse_search (ELLIPSE ellipseA,
 			if (debug > 0) g_print("point : Ret = %d   i = %f\n", Ret, i);
 		}
 		Ret = rtn.type;
-		/*  1 ĤǤ 2 ĤȤƹͤ */
+		/* 交点が 1 個でも 2 個として考える */
 		if (Ret == 1) Ret = 2;
 		if (debug > 0) g_print ("i = %f   Ret = %d\n", i, Ret);
 
@@ -1600,19 +1600,19 @@ int ellipse_to_ellipse_search (ELLIPSE ellipseA,
 
 
 	/* -----------------------------------------------------
-	 * ᤿ϰϤˤäƼν櫓롣
+	 * 求めた範囲によって次の処理をわける。
 	 */
-	/*  */
+	/* 誤差を求める */
 	dgt = (*ep - *sp);
 	if (debug > 0) g_print("    X10000 : ep[%f] - sp[%f] = dgt[%f]\n\n\n", 10000*(*ep), 10000*(*sp), 10000*dgt);
 
-	/* sp ep Ѳ̵ʤ̵Ȥƽλ */
+	/* sp ep が変化無しなら接線無しとして終了 */
 	if (osp == *sp && oep == *ep) {
-		if (debug > 0) g_print("osp == *sp && oep == *ep ˤäƥ󥻥\n");
+		if (debug > 0) g_print("osp == *sp && oep == *ep によってキャンセル\n");
 		return 0;
 	}
 
-	/*  last_degits 꾮нλ */
+	/* 誤差が last_degits より小さければ終了 */
 	else if (dgt < last_degits) {
 		//if (debug > 0) g_print("dgt < last_degits\n");
 		if (point->frag != 1) {
@@ -1625,7 +1625,7 @@ int ellipse_to_ellipse_search (ELLIPSE ellipseA,
 					point->y = rtn.sy[2];
 				}
 				else {
-					if (debug > 0) g_print("ellipse_to_ellipse_search() : 1 : ǤϸФʤä\n");
+					if (debug > 0) g_print("ellipse_to_ellipse_search() : 1 : の中では交点が出せなかった。\n");
 				}
 			}
 			if (point->frag != 1) {
@@ -1637,14 +1637,14 @@ int ellipse_to_ellipse_search (ELLIPSE ellipseA,
 					point->y = rtn.sy[2];
 				}
 				else {
-					if (debug > 0) g_print("ellipse_to_ellipse_search() : 2 : ǤϸФʤä\n");
+					if (debug > 0) g_print("ellipse_to_ellipse_search() : 2 : の中では交点が出せなかった。\n");
 				}
 			}
 		}
 		return 1;  // Ans (max + min) / 2
 	}
 
-	/*  last_degits 礭ФäȺ٤õ ellipse_to_ellipse_search() Ƥ */
+	/* 誤差が last_degits より大きければもっと細かく探すために ellipse_to_ellipse_search() を呼ぶ */
 	else {
 		//if (debug > 0) g_print("dgt > last_degits\n");
 		return ellipse_to_ellipse_search(ellipseA, ellipseB, sp, ep, point, (dgt / 10), last_degits);
@@ -1658,7 +1658,7 @@ int ellipse_to_ellipse_search (ELLIPSE ellipseA,
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : Ellipse.c
