@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/03/18
- *    Last                 : 2003/03/21
+ *    Last                 : 2007/10/26
  * ====================================================================
  */
 
@@ -46,7 +46,7 @@
 
 
 /* -------------------------------------------------------------------
- * sample_table "expose ()" ٥ȥϥɥ
+ * sample_table "expose (再描画)" イベントハンドラ
  * 
  */
 gint sample_table_expose_event(GtkWidget *widget, GdkEventExpose *event, LAYERSET_DLG *layerset_dlg)
@@ -56,10 +56,12 @@ gint sample_table_expose_event(GtkWidget *widget, GdkEventExpose *event, LAYERSE
 	long BackCol = 0;
 
 
-	/* widget ͤ */
-	key = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(widget), "value"));
+	/* widget の値を取得 */
+	//g_print("sample_table_expose_event() : 1 !\n");
+	key = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "value"));
+	//g_print("sample_table_expose_event() : 1 !\n");
 
-	/* طʿ */
+	/* 背景色設定 */
 	/*  */
 	if (key == 0) BackCol = 0xff0000;
 	else if (key == 1) BackCol = 0xffff00;
@@ -68,10 +70,10 @@ gint sample_table_expose_event(GtkWidget *widget, GdkEventExpose *event, LAYERSE
 	else if (key == 4) BackCol = 0x000080;
 	else BackCol = 0xffffff;
 
-	/* GC  */
+	/* GC 作成 */
 	lds_gc = create_gc(widget);
 
-	/* ɥ󥰥쥢礭 */
+	/* ドローイングアレアの大きさ取得 */
 	w = widget->allocation.width;
 	h = widget->allocation.height;
 
@@ -90,7 +92,7 @@ gint sample_table_expose_event(GtkWidget *widget, GdkEventExpose *event, LAYERSE
 	gdk_draw_line(widget->window, lds_gc, 1, 1, 1, h-1);
 	gdk_draw_line(widget->window, lds_gc, w-1, 1, w-1, h-1);
 
-	/* GC  */
+	/* GC 開放 */
 	delete_gc(lds_gc);
 
 	return FALSE;
@@ -112,10 +114,21 @@ void layerset_dlg_ok_pushed(GtkWidget *widget, LAYERSET_DLG *layerset_dlg)
 
 
 
+int layer_no_check(GtkWidget *widget, LAYERSET_DLG *layerset_dlg)
+{
+	int i;
+	for (i = 0; i < layerset_dlg->use_layer; i++) {
+		if (layerset_dlg->Layer_widget[i] == widget) {
+			return i;
+		}
+	}
+	return -1;
+}
+
 
 
 /* -------------------------------------------------------------------
- * layer_box "expose ()"
+ * layer_box "expose (再描画)"
  * 
  */
 int layer_area_draw(GtkWidget *widget, LAYERSET_DLG *layerset_dlg)
@@ -125,19 +138,34 @@ int layer_area_draw(GtkWidget *widget, LAYERSET_DLG *layerset_dlg)
 	long BackCol = 0, TextCol = 0;
 	GdkFont *font;
 	char str[256];
-	int locateX = 3;
+	int locateX = 3, locateY = 18;
+	
+	
+	layerNo = layer_no_check(widget, layerset_dlg);
+	if (layerNo < 0) {
+		g_print("error : check no = %d !\n", layerNo);
+		return FALSE;
+	}
+	else if (layerNo > layerset_dlg->use_layer && layerNo < 256) {
+		//g_print("error : use_layer  : check no = %d !\n", layerNo);
+		return FALSE;
+	}
+	else {
+		//g_print("check no = %d !\n", layerNo);
+	}
+	
+	/* widget の値を取得 */
+	//g_print("layer_area_draw() : 1 !\n");
+	//layerNo = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "value"));
+	//g_print("layer_area_draw() : 2 !\n");
 
 
-	/* widget ͤ */
-	layerNo = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(widget), "value"));
+	/* 表示文字列設定 */
+	if (layerNo < 10) sprintf(str, "0%d", layerNo);
+	else sprintf(str, "%d", layerNo);
 
 
-	/* ɽʸ */
-	if (layerNo < 16) sprintf(str, "0%X", layerNo);
-	else sprintf(str, "%X", layerNo);
-
-
-	/* طʿʸ */
+	/* 背景色と文字色の設定 */
 	if (Layer[layerNo].draw == 1 && Layer[layerNo].data == 1) {
 		TextCol = 0x000000;
 		BackCol = 0xffff00;
@@ -160,14 +188,14 @@ int layer_area_draw(GtkWidget *widget, LAYERSET_DLG *layerset_dlg)
 		BackCol = 0xff0000;
 	}
 
-	/* GC  */
+	/* GC 作成 */
 	ld_gc = gdk_gc_new(widget->window);
 
 	font = gdk_font_load(
 		"-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*");
 
 
-	/* ɥ󥰥쥢礭 */
+	/* ドローイングアレアの大きさ取得 */
 	w = widget->allocation.width;
 	h = widget->allocation.height;
 
@@ -186,11 +214,18 @@ int layer_area_draw(GtkWidget *widget, LAYERSET_DLG *layerset_dlg)
 	gdk_draw_line(widget->window, ld_gc, 1, 1, 1, h-1);
 	gdk_draw_line(widget->window, ld_gc, w-1, 1, w-1, h-1);
 
-	/* Хå顼 */
+	/* バックカラーも指定 */
 	PenSet_with_back(ld_gc, 1, TextCol, BackCol);
-	gdk_draw_string(widget->window, font, ld_gc, locateX, 15, str);
+	if (layerset_dlg->use_layer < 101) {
+		locateX = 5;
+	}
+	else if (w == 33 && layerNo < 100) {
+		locateX = 8;
+	}
+	gdk_draw_string(widget->window, font, ld_gc, locateX, locateY, str);
+	//g_print("w = %d  locate (%d,%d)\n", w, locateX, locateY);
 
-	/* GC  */
+	/* GC 開放 */
 	gdk_gc_destroy(ld_gc);
 
 	return FALSE;
@@ -244,7 +279,7 @@ void layerset_dlg_off_pushed(GtkWidget *widget, LAYERSET_DLG *layerset_dlg)
 
 
 /* -------------------------------------------------------------------
- * layer_area "button_press_event (ޥå)" ٥ȥϥɥ
+ * layer_area "button_press_event (マウスクリック)" イベントハンドラ
  * 
  */
 int layer_area_button_press_event(GtkWidget *widget, GdkEventButton *event, LAYERSET_DLG *layerset_dlg)
@@ -253,18 +288,20 @@ int layer_area_button_press_event(GtkWidget *widget, GdkEventButton *event, LAYE
 	char str[256];
 
 
-	/* widget ͤ */
-	layerNo = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(widget), "value"));
+	/* widget の値を取得 */
+	//g_print("layer_area_button_press_event() : 1 !\n");
+	layerNo = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "value"));
+	//g_print("layer_area_button_press_event() : 2 !\n");
 
 
-	/* ܥ */
+	/* 左ボタン */
 	if (event->button == 1) {
 		if (layerNo != NowLayer) {
 			if (Layer[layerNo].draw == 1) Layer[layerNo].draw = 0;
 			else if (Layer[layerNo].draw == 0) Layer[layerNo].draw = 1;
 		}
 	}
-	/* ܥ */
+	/* 右ボタン */
 	else if (event->button == 3) {
 		old = NowLayer;
 		Layer[old].draw = sagcad_system.LostCurrent;
@@ -272,19 +309,19 @@ int layer_area_button_press_event(GtkWidget *widget, GdkEventButton *event, LAYE
 		NowLayer = layerNo;
 		Layer[layerNo].draw = 1; 
 
-		/* ƥȥȥ꡼ʸ */
+		/* テキストエントリーから文字列を取得 */
 		strcpy(str, gtk_entry_get_text(GTK_ENTRY(layerset_dlg->entry)));
 		strcpy(Layer[old].name ,str);
 
 
 		gtk_entry_set_text(GTK_ENTRY(layerset_dlg->entry), Layer[NowLayer].name);
-		sprintf(str,"Layer-%X [ %s ]", NowLayer, Layer[NowLayer].name);
-		gtk_label_set(GTK_LABEL(layer), str);
+		sprintf(str,"Layer-%d [ %s ]", NowLayer, Layer[NowLayer].name);
+		gtk_label_set_text(GTK_LABEL(layer), str);
 
 		layer_area_draw(layerset_dlg->Layer_widget[old], layerset_dlg);
 	}
 
-	/* ܥ */
+	/* 中ボタン */
 //	else if (event->button == 3) ;
 
 	layer_area_draw(layerset_dlg->Layer_widget[layerNo], layerset_dlg);
@@ -298,7 +335,7 @@ int layer_area_button_press_event(GtkWidget *widget, GdkEventButton *event, LAYE
 
 
 /* -------------------------------------------------------------------
- * layer_area "expose ()" ٥ȥϥɥ
+ * layer_area "expose (再描画)" イベントハンドラ
  * 
  */
 gint layer_area_expose_event(GtkWidget *widget, GdkEventExpose *event, LAYERSET_DLG *layerset_dlg)
@@ -312,12 +349,12 @@ gint layer_area_expose_event(GtkWidget *widget, GdkEventExpose *event, LAYERSET_
 
 
 /* -------------------------------------------------------------------
- * 쥤䡼
+ * レイヤー設定
  * 
  */
 gint LayerSetDialog(LAYERSET_DLG *layerset_dlg)
 {
-	gint i, x, y, l;
+	gint i, j, k, max, x, y, l, parent_x, parent_y;
 	gchar str[20];
 	CAD_LIST *p;
 	DIMENSION_LIST *pd;
@@ -348,283 +385,300 @@ gint LayerSetDialog(LAYERSET_DLG *layerset_dlg)
 					GtkWidget *ok_buttun;
 
 
-	/*  */
+	/* 初期化 */
 	i = 0;
 	while (i < 256 ) {
 		Layer[i].data = 0;
 		i++;
 	}
-	/* ޷ǡ 1 */
+	/* 図形データがあれば 1 */
 	p = cad_list_info.head;
 	while (p != NULL) {
 		Layer[p->cad->layer].data = 1;
 		p = p->next;
 	}
-	/* ˡǡ 1 */
+	/* 寸法データがあれば 1 */
 	pd = dimension_list_info.head;
 	while (pd != NULL) {
 		Layer[pd->dimension->Layer].data = 1;
 		pd = pd->next;
 	}
-	/* ݥ饤ǡ 1 */
+	/* ポリラインデータがあれば 1 */
 	pld = polyline_list_info.head;
 	while(pld != NULL) {
 		Layer[pld->polyline->layer].data = 1;
 		pld = pld->next;
 	}
+	
+	/* (use_layer < max) の処理 -> use_layer を増やす */
+	i = 0;
+	max = 0;
+	while (i < 256 ) {
+		if (Layer[i].data == 1) {
+			if (max < i) max = i;
+		}
+		i++;
+	}
+	if (use_layer < max) {
+		layerset_dlg->use_layer = max + 1;
+		g_print("over use_layer !\n");
+	}
+	else {
+		layerset_dlg->use_layer = use_layer;
+		//g_print("in use_layer !\n");
+	}
+	
+	/* カレントレイヤーが layerset_dlg->use_layer を超えている */
+	if (NowLayer > layerset_dlg->use_layer - 1) {
+		NowLayer = 0;
+		//Redraw();
+	}
 
 
-
-	/* (copy_dlg->dialog) (GTK_WIN_POS_MOUSE  GTK_WIN_POS_CENTER) */
-	layerset_dlg->dialog = gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_position(GTK_WINDOW(layerset_dlg->dialog), GTK_WIN_POS_MOUSE);
+	/* ダイアログ(copy_dlg->dialog)生成 (GTK_WIN_POS_MOUSE  GTK_WIN_POS_CENTER) */
+	layerset_dlg->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(layerset_dlg->dialog), _("Layer Setting") );
-//	gtk_signal_connect( GTK_OBJECT(layerset_dlg->dialog), "key_press_event",
-//						GTK_SIGNAL_FUNC(layerset_dlg_key_press_event), layerset_dlg);
+	//gtk_window_set_position(GTK_WINDOW(layerset_dlg->dialog), GTK_WIN_POS_MOUSE);
+	gtk_window_get_position(GTK_WINDOW(MainWindow), &parent_x, &parent_y);
+	gtk_window_move(GTK_WINDOW(layerset_dlg->dialog), parent_x + 72, parent_y + 89);
+
+	//gtk_window_set_keep_above (GTK_WINDOW(layerset_dlg->dialog), FALSE);
+	/* ダイアログを最前面に表示する */
+	gtk_window_set_modal(GTK_WINDOW(layerset_dlg->dialog), TRUE);
+	/* メインウィンドウを操作できないように設定 */
+	gtk_window_set_transient_for(GTK_WINDOW(layerset_dlg->dialog), 
+				GTK_WINDOW(layerset_dlg->parent));
 
 
-		/* ˤޤѥå󥰥ܥå(main_vbox) */
-		main_vbox = gtk_vbox_new(0, 2);
+		/* ダイアログの中にまず、パッキングボックス(main_vbox)を作成 */
+		main_vbox = gtk_vbox_new(FALSE, 2);
 		gtk_container_add(GTK_CONTAINER(layerset_dlg->dialog), main_vbox);
-		gtk_container_border_width(GTK_CONTAINER(layerset_dlg->dialog), 5);
+		gtk_container_set_border_width(GTK_CONTAINER(layerset_dlg->dialog), 5);
 		gtk_widget_show(main_vbox);
-
-
-			/* ơ֥륳ƥʺ */
-			table = gtk_table_new(16, 16, TRUE);
-			gtk_box_pack_start( GTK_BOX(main_vbox), table, TRUE, TRUE, 0);
+		
+			/* テーブルコンテナ作成 */
+			//g_print("layerset_dlg->use_layer = %d\n", layerset_dlg->use_layer);
+			table = gtk_table_new(10, (layerset_dlg->use_layer / 10), FALSE);
+			gtk_box_pack_start( GTK_BOX(main_vbox), table, FALSE, FALSE, 0);
 			gtk_widget_show(table);
 			
-			for (x = 0 ; x < 16 ; x++) {
-				for (y = 0 ; y < 16 ; y++) {
-					l = y * 16 + x;
-					sprintf(str, "%x", l);
-
-					layer_area = gtk_drawing_area_new();
-					layerset_dlg->Layer_widget[l] = layer_area;
-					layerset_dlg->layerNo = l;
-					/* ɥ󥰥ꥢΥ */
-					gtk_drawing_area_size( GTK_DRAWING_AREA(layer_area), 20, 20);
-					gtk_table_attach_defaults(GTK_TABLE(table), layer_area, x, x+1, y, y+1);
-					gtk_object_set_data(GTK_OBJECT(layer_area), "value", (gpointer)l);
-
-					/* "expose_event" ٥ȥϥɥ */
-					gtk_signal_connect(GTK_OBJECT(layer_area), "expose_event",
-							   (GtkSignalFunc) layer_area_expose_event, (gpointer)layerset_dlg);
-					/* "button_press_event" ٥ȥϥɥ */
-					gtk_signal_connect(GTK_OBJECT(layer_area), "button_press_event",
-							   (GtkSignalFunc) layer_area_button_press_event, (gpointer)layerset_dlg);
-					/* ٥ȥޥ */
-					gtk_widget_set_events(layer_area,  GDK_EXPOSURE_MASK
-													 | GDK_LEAVE_NOTIFY_MASK
-													 | GDK_BUTTON_PRESS_MASK
-													 | GDK_POINTER_MOTION_MASK
-													 | GDK_POINTER_MOTION_HINT_MASK);
-					gtk_widget_show(layer_area);
+			/* y の計算 */
+			j = ((layerset_dlg->use_layer + 1) / 10) * 10;
+			k = layerset_dlg->use_layer - j;
+			if (k > 0) j++;
+			
+			for (x = 0 ; x < 10 ; x++) {
+				for (y = 0 ; y < j; y++) {
+					l = y * 10 + x;
+					sprintf(str, "%d", l);
+					
+					if (l < layerset_dlg->use_layer && l < 256 ) {
+						layer_area = gtk_drawing_area_new();
+						//g_print("Layer_widget[%d] : %d\n", l, (long)layer_area);
+						
+						layerset_dlg->Layer_widget[l] = layer_area;
+						layerset_dlg->layerNo = l;
+						/* ドローイングエリアのサイズ設定 */
+						if (layerset_dlg->use_layer < 101) {
+							gtk_widget_set_size_request( GTK_WIDGET(layer_area), 
+										LAYER_AREA_HEIGHT, LAYER_AREA_HEIGHT);
+						}
+						else {
+							gtk_widget_set_size_request( GTK_WIDGET(layer_area), 
+										LAYER_AREA_WIDTH, LAYER_AREA_HEIGHT);
+						}
+						gtk_table_attach_defaults(GTK_TABLE(table), layer_area, x, x+1, y, y+1);
+						g_object_set_data(G_OBJECT(layer_area), "value", (gpointer)l);
+						
+						/* "expose_event" イベントハンドラ設定 */
+						g_signal_connect(G_OBJECT(layer_area), "expose_event",
+								   G_CALLBACK(layer_area_expose_event), (gpointer)layerset_dlg);
+						/* "button_press_event" イベントハンドラ設定 */
+						g_signal_connect(G_OBJECT(layer_area), "button_press_event",
+								   G_CALLBACK(layer_area_button_press_event), (gpointer)layerset_dlg);
+						/* イベントマスク設定 */
+						gtk_widget_set_events(layer_area,  GDK_EXPOSURE_MASK
+														 | GDK_LEAVE_NOTIFY_MASK
+														 | GDK_BUTTON_PRESS_MASK
+														 | GDK_POINTER_MOTION_MASK
+														 | GDK_POINTER_MOTION_HINT_MASK);
+						gtk_widget_show(layer_area);
+					}
 				}
 			}
-
-
-			/* ѥ졼(separator) */
+			
+			/* セパレーター(separator) */
 			separator = gtk_hseparator_new();
-			gtk_box_pack_start( GTK_BOX(main_vbox), separator, TRUE, TRUE, 0);
+			gtk_box_pack_start( GTK_BOX(main_vbox), separator, FALSE, FALSE, 0);
 			gtk_widget_show(separator);
-
-
-
-			/* ѥå󥰥ܥå(action_vbox) */
+			
+			/* パッキングボックス(action_vbox) */
 			action_vbox = gtk_vbox_new(FALSE, 2);
-			gtk_box_pack_start( GTK_BOX(main_vbox), action_vbox, TRUE, TRUE, 0);
+			gtk_box_pack_start( GTK_BOX(main_vbox), action_vbox, FALSE, FALSE, 0);
 			gtk_widget_show(action_vbox);
-
-
-				/* ѥå󥰥ܥå(name_hbox) */
+			
+				/* パッキングボックス(name_hbox) */
 				name_hbox = gtk_hbox_new(FALSE, 2);
 				gtk_box_pack_start( GTK_BOX(action_vbox), name_hbox, TRUE, TRUE, 0);
 				gtk_widget_show(name_hbox);
-
-					/* ٥ (name_label) */
+				
+					/* ラベル生成 (name_label) */
 					name_label = gtk_label_new( _("Active Layer Name") );
-					//gtk_widget_set_usize (name_label, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(name_hbox), name_label, TRUE, TRUE, 0);
 					gtk_label_set_justify(GTK_LABEL(name_label), GTK_JUSTIFY_LEFT);
 					gtk_widget_show(name_label);
-
-
-					/* ƥȥȥ꡼ (name_entry) */
+					
+					/* テキストエントリー生成 (name_entry) */
 					layerset_dlg->entry = gtk_entry_new();
-					//gtk_widget_set_usize (layerset_dlg->entry, 150, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(name_hbox), layerset_dlg->entry, TRUE, TRUE, 1);
-					/*  */
+					/* 初期値設定 */
 					gtk_entry_set_text(GTK_ENTRY(layerset_dlg->entry), Layer[NowLayer].name);
-					//gtk_signal_connect (GTK_OBJECT(layerset_dlg->entry), "activate", 
-					//					  GTK_SIGNAL_FUNC(entry_callback), NULL);
 					gtk_widget_show(layerset_dlg->entry);
-
-
-
-
-
-				/* ѥ졼(separator) */
+					
+				/* セパレーター(separator) */
 				separator = gtk_hseparator_new();
-				gtk_box_pack_start( GTK_BOX(action_vbox), separator, TRUE, TRUE, 0);
+				gtk_box_pack_start( GTK_BOX(action_vbox), separator, FALSE, FALSE, 0);
 				gtk_widget_show(separator);
-
-
-				/* ơ֥ѥå󥰥ܥå(sample_table) */
-				sample_table = gtk_table_new(3, 16, TRUE);
-				gtk_box_pack_start( GTK_BOX(action_vbox), sample_table, TRUE, TRUE, 0);
-				gtk_widget_set_usize (sample_table, 320, 60);
+				
+				/* テーブルパッキングボックス(sample_table) */
+				sample_table = gtk_table_new(4, 3, FALSE);
+				gtk_box_pack_start( GTK_BOX(action_vbox), sample_table, FALSE, FALSE, 0);
 				gtk_widget_show(sample_table);
-
-					/* ȥ쥤䡼Υץ */
+				
+					/* カレントレイヤーのサンプル */
 					current_draw = gtk_drawing_area_new();
-					gtk_drawing_area_size( GTK_DRAWING_AREA(current_draw), 20, 20);
-					gtk_table_attach_defaults(GTK_TABLE(sample_table), current_draw, 0, 1, 0, 1);
-					gtk_object_set_data(GTK_OBJECT(current_draw), "value", (gpointer)0);
-					/* "expose_event" ٥ȥϥɥ */
-					gtk_signal_connect(GTK_OBJECT(current_draw), "expose_event",
-									   (GtkSignalFunc) sample_table_expose_event, (gpointer)layerset_dlg);
-					/* ٥ȥޥ */
+					gtk_widget_set_size_request( GTK_WIDGET(current_draw), SAMPLE_LAYER_AREA_WIDTH, SAMPLE_LAYER_AREA_HEIGHT);
+					gtk_table_attach(GTK_TABLE(sample_table), current_draw, 
+								0, 1, 0, 1, 0, 0, 0, 0);
+					g_object_set_data(G_OBJECT(current_draw), "value", (gpointer)0);
+					/* "expose_event" イベントハンドラ設定 */
+					g_signal_connect(G_OBJECT(current_draw), "expose_event",
+									   G_CALLBACK(sample_table_expose_event), (gpointer)layerset_dlg);
+					/* イベントマスク設定 */
 					gtk_widget_set_events(layer_area, GDK_EXPOSURE_MASK);
 					gtk_widget_show(current_draw);
 
-					/* ٥ (label) */
+					/* ラベル生成 (label) */
 					label = gtk_label_new( _("Active") );
-					gtk_widget_set_usize (label, 140, 20);
-					gtk_table_attach_defaults(GTK_TABLE(sample_table), label, 1, 8, 0, 1);
+					gtk_table_attach(GTK_TABLE(sample_table), label, 1, 2, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 					gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
 					gtk_widget_show(label);
 
 
-					/* on_o Υץ */
+					/* on_o のサンプル */
 					on_o_draw = gtk_drawing_area_new();
-					gtk_drawing_area_size( GTK_DRAWING_AREA(on_o_draw), 20, 20);
-					gtk_table_attach_defaults(GTK_TABLE(sample_table), on_o_draw, 0, 1, 1, 2);
-					gtk_object_set_data(GTK_OBJECT(on_o_draw), "value", (gpointer)1);
-					/* "expose_event" ٥ȥϥɥ */
-					gtk_signal_connect(GTK_OBJECT(on_o_draw), "expose_event",
-									   (GtkSignalFunc) sample_table_expose_event, (gpointer)layerset_dlg);
-					/* ٥ȥޥ */
+					gtk_widget_set_size_request( GTK_WIDGET(on_o_draw), SAMPLE_LAYER_AREA_WIDTH, SAMPLE_LAYER_AREA_HEIGHT);
+					gtk_table_attach(GTK_TABLE(sample_table), on_o_draw, 0, 1, 1, 2, 0,0,0,0);
+					g_object_set_data(G_OBJECT(on_o_draw), "value", (gpointer)1);
+					/* "expose_event" イベントハンドラ設定 */
+					g_signal_connect(G_OBJECT(on_o_draw), "expose_event",
+									   G_CALLBACK(sample_table_expose_event), (gpointer)layerset_dlg);
+					/* イベントマスク設定 */
 					gtk_widget_set_events(on_o_draw, GDK_EXPOSURE_MASK);
 					gtk_widget_show(on_o_draw);
 
-					/* ٥ (label) */
+					/* ラベル生成 (label) */
 					label = gtk_label_new( _("display-on Data-O") );
-					gtk_widget_set_usize (label, 140, 20);
-					gtk_table_attach_defaults(GTK_TABLE(sample_table), label, 1, 8, 1, 2);
+					gtk_table_attach(GTK_TABLE(sample_table), label, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 					gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
 					gtk_widget_show(label);
 
 
-					/* on_x Υץ */
+					/* on_x のサンプル */
 					on_x_draw = gtk_drawing_area_new();
-					gtk_drawing_area_size( GTK_DRAWING_AREA(on_x_draw), 20, 20);
-					gtk_table_attach_defaults(GTK_TABLE(sample_table), on_x_draw, 8, 9, 1, 2);
-					gtk_object_set_data(GTK_OBJECT(on_x_draw), "value", (gpointer)2);
-					/* "expose_event" ٥ȥϥɥ */
-					gtk_signal_connect(GTK_OBJECT(on_x_draw), "expose_event",
-									   (GtkSignalFunc) sample_table_expose_event, (gpointer)layerset_dlg);
-					/* ٥ȥޥ */
+					gtk_widget_set_size_request( GTK_WIDGET(on_x_draw), SAMPLE_LAYER_AREA_WIDTH, SAMPLE_LAYER_AREA_HEIGHT);
+					gtk_table_attach(GTK_TABLE(sample_table), on_x_draw, 2, 3, 1, 2, 0,0,0,0);
+					g_object_set_data(G_OBJECT(on_x_draw), "value", (gpointer)2);
+					/* "expose_event" イベントハンドラ設定 */
+					g_signal_connect(G_OBJECT(on_x_draw), "expose_event",
+									   G_CALLBACK(sample_table_expose_event), (gpointer)layerset_dlg);
+					/* イベントマスク設定 */
 					gtk_widget_set_events(on_x_draw, GDK_EXPOSURE_MASK);
 					gtk_widget_show(on_x_draw);
 
-					/* ٥ (label) */
+					/* ラベル生成 (label) */
 					label = gtk_label_new( _("display-on Data-X") );
-					gtk_widget_set_usize (label, 140, 20);
-					gtk_table_attach_defaults(GTK_TABLE(sample_table), label, 9, 16, 1, 2);
+					gtk_table_attach(GTK_TABLE(sample_table), label, 3, 4, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 					gtk_widget_show(label);
 
 
-					/* off_o Υץ */
+					/* off_o のサンプル */
 					off_o_draw = gtk_drawing_area_new();
-					gtk_drawing_area_size( GTK_DRAWING_AREA(off_o_draw), 20, 20);
-					gtk_table_attach_defaults(GTK_TABLE(sample_table), off_o_draw, 0, 1, 2, 3);
-					gtk_object_set_data(GTK_OBJECT(off_o_draw), "value", (gpointer)3);
-					/* "expose_event" ٥ȥϥɥ */
-					gtk_signal_connect(GTK_OBJECT(off_o_draw), "expose_event",
-									   (GtkSignalFunc) sample_table_expose_event, (gpointer)layerset_dlg);
-					/* ٥ȥޥ */
+					gtk_widget_set_size_request( GTK_WIDGET(off_o_draw), SAMPLE_LAYER_AREA_WIDTH, SAMPLE_LAYER_AREA_HEIGHT);
+					gtk_table_attach(GTK_TABLE(sample_table), off_o_draw, 0, 1, 2, 3, 0,0,0,0);
+					g_object_set_data(G_OBJECT(off_o_draw), "value", (gpointer)3);
+					/* "expose_event" イベントハンドラ設定 */
+					g_signal_connect(G_OBJECT(off_o_draw), "expose_event",
+									   G_CALLBACK(sample_table_expose_event), (gpointer)layerset_dlg);
+					/* イベントマスク設定 */
 					gtk_widget_set_events(off_o_draw, GDK_EXPOSURE_MASK);
 					gtk_widget_show(off_o_draw);
 
-					/* ٥ (label) */
+					/* ラベル生成 (label) */
 					label = gtk_label_new( _("display-off Data-O") );
-					gtk_widget_set_usize (label, 140, 20);
-					gtk_table_attach_defaults(GTK_TABLE(sample_table), label, 1, 8, 2, 3);
+					gtk_table_attach(GTK_TABLE(sample_table), label, 1, 2, 2, 3, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 					gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
 					gtk_widget_show(label);
 
 
-					/* off_x Υץ */
+					/* off_x のサンプル */
 					off_x_draw = gtk_drawing_area_new();
-					gtk_drawing_area_size( GTK_DRAWING_AREA(off_x_draw), 20, 20);
-					gtk_table_attach_defaults(GTK_TABLE(sample_table), off_x_draw, 8, 9, 2, 3);
-					gtk_object_set_data(GTK_OBJECT(off_x_draw), "value", (gpointer)4);
-					/* "expose_event" ٥ȥϥɥ */
-					gtk_signal_connect(GTK_OBJECT(off_x_draw), "expose_event",
-									   (GtkSignalFunc) sample_table_expose_event, (gpointer)layerset_dlg);
-					/* ٥ȥޥ */
+					gtk_widget_set_size_request( GTK_WIDGET(off_x_draw), SAMPLE_LAYER_AREA_WIDTH, SAMPLE_LAYER_AREA_HEIGHT);
+					gtk_table_attach(GTK_TABLE(sample_table), off_x_draw, 2, 3, 2, 3, 0,0,0,0);
+					g_object_set_data(G_OBJECT(off_x_draw), "value", (gpointer)4);
+					/* "expose_event" イベントハンドラ設定 */
+					g_signal_connect(G_OBJECT(off_x_draw), "expose_event",
+									   G_CALLBACK(sample_table_expose_event), (gpointer)layerset_dlg);
+					/* イベントマスク設定 */
 					gtk_widget_set_events(off_x_draw, GDK_EXPOSURE_MASK);
 					gtk_widget_show(off_x_draw);
 
-					/* ٥ (label) */
+					/* ラベル生成 (label) */
 					label = gtk_label_new( _("display-off Data-X") );
-					gtk_widget_set_usize (label, 140, 20);
-					gtk_table_attach_defaults(GTK_TABLE(sample_table), label, 9, 16, 2, 3);
+					gtk_table_attach(GTK_TABLE(sample_table), label, 3, 4, 2, 3, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 					gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
 					gtk_widget_show(label);
 
 
 
-				/* ѥ졼(separator) */
+				/* セパレーター(separator) */
 				separator = gtk_hseparator_new();
-				gtk_box_pack_start( GTK_BOX(action_vbox), separator, TRUE, TRUE, 0);
+				gtk_box_pack_start( GTK_BOX(action_vbox), separator, FALSE, FALSE, 0);
 				gtk_widget_show(separator);
 
 
-				/* ѥå󥰥ܥå(button_hbox) */
+				/* パッキングボックス(button_hbox) */
 				button_hbox = gtk_hbox_new(FALSE, 2);
-				gtk_box_pack_start( GTK_BOX(action_vbox), button_hbox, TRUE, TRUE, 0);
+				gtk_box_pack_start( GTK_BOX(action_vbox), button_hbox, FALSE, FALSE, 0);
 				gtk_widget_show(button_hbox);
 
-					/* ON ܥ */
+					/* ON ボタンの生成 */
 					on_buttun = gtk_button_new_with_label("All on");
-					//gtk_widget_set_usize (on_buttun, 80, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(button_hbox), on_buttun, TRUE, TRUE, 2);
-					gtk_signal_connect(GTK_OBJECT(on_buttun), "clicked", 
-									   GTK_SIGNAL_FUNC(layerset_dlg_on_pushed), /*(gpointer)*/layerset_dlg);
+					g_signal_connect(G_OBJECT(on_buttun), "clicked", 
+									   G_CALLBACK(layerset_dlg_on_pushed), /*(gpointer)*/layerset_dlg);
 					gtk_widget_show(on_buttun);
 
 
-					/* OFF ܥ */
+					/* OFF ボタンの生成 */
 					off_buttun = gtk_button_new_with_label("All off");
-					//gtk_widget_set_usize (off_buttun, 80, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(button_hbox), off_buttun, TRUE, TRUE, 2);
-					gtk_signal_connect(GTK_OBJECT(off_buttun), "clicked", 
-									   GTK_SIGNAL_FUNC(layerset_dlg_off_pushed), /*(gpointer)*/layerset_dlg);
+					g_signal_connect(G_OBJECT(off_buttun), "clicked", 
+									   G_CALLBACK(layerset_dlg_off_pushed), /*(gpointer)*/layerset_dlg);
 					gtk_widget_show(off_buttun);
 
 
-					/* OKܥ */
+					/* OKボタンの生成 */
 					ok_buttun = gtk_button_new_with_label("OK");
-					//gtk_widget_set_usize (ok_buttun, 80, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(button_hbox), ok_buttun, TRUE, TRUE, 2);
-					gtk_signal_connect(GTK_OBJECT(ok_buttun), "clicked", GTK_SIGNAL_FUNC(layerset_dlg_ok_pushed), layerset_dlg);
-					gtk_signal_connect(GTK_OBJECT(ok_buttun), "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+					g_signal_connect(G_OBJECT(ok_buttun), "clicked", G_CALLBACK(layerset_dlg_ok_pushed), layerset_dlg);
+					g_signal_connect(G_OBJECT(ok_buttun), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 					gtk_widget_show(ok_buttun);
 
 
-
-	/* ̤ɽ */
-	gtk_window_set_modal(GTK_WINDOW(layerset_dlg->dialog), TRUE);
-	/* ᥤ󥦥ɥǤʤ褦 */
-	gtk_window_set_transient_for(GTK_WINDOW(layerset_dlg->dialog), GTK_WINDOW(layerset_dlg->parent));
-
-
-	/* Ļ֤ */
+	/* ダイアログを可視状態へ */
 	gtk_widget_show(layerset_dlg->dialog);
-	/* ᥤ󥤥٥ȥ롼 */
+	/* メインイベントループ */
 	gtk_main();
 	gtk_widget_destroy(layerset_dlg->dialog);
 	return 0; 
@@ -635,7 +689,7 @@ gint LayerSetDialog(LAYERSET_DLG *layerset_dlg)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : LayerSet.c
