@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/01/15
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/08
  * ====================================================================
  */
 
@@ -69,25 +69,25 @@ int init_block(BLOCK *block)
 
 
 /* -------------------------------------------------------------------
- * BLOCK Data ꥹȤκǽɲ
+ * BLOCK Data をリストの最初に追加
  *	
- * ǡ (CAD DIMENSION TEXT POLYLINE) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (CAD DIMENSION TEXT POLYLINE) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 BLOCK_LIST *r_block_list_add_first(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list_info)
 {
 	BLOCK_LIST *p;
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_block_list = (BLOCK_LIST *)xmalloc(sizeof(BLOCK_LIST));
 
-	/* ݤΰ˥ǡ (block) 񤭹 */
+	/* 確保した領域にデータ (block) を書き込む */
 	p_block_list->block = add_block;
 	p_block_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_block_list_info->head == NULL && p_block_list_info->tail == NULL) {
 		p_block_list_info->head = p_block_list;
@@ -95,7 +95,7 @@ BLOCK_LIST *r_block_list_add_first(BLOCK *add_block, BLOCK_LIST_INFO *p_block_li
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_block_list_info->head;
@@ -111,30 +111,30 @@ BLOCK_LIST *r_block_list_add_first(BLOCK *add_block, BLOCK_LIST_INFO *p_block_li
 
 
 /* -------------------------------------------------------------------
- * BLOCK Data ꥹȤκǽɲ
+ * BLOCK Data をリストの最初に追加
  *	
  */
 BLOCK_LIST *block_list_add_first(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list_info)
 {
 	BLOCK_LIST *p;
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_block_list = (BLOCK_LIST *)xmalloc(sizeof(BLOCK_LIST));
 
-	/* ǡ (block) 񤭹िΰݤ */
+	/* データ (block) を書き込むための領域を確保する */
 	p_block_list->block = (BLOCK *)xmalloc(sizeof(BLOCK));
 
-	/* vertex ΰϡ */
-	/* ǡ (vertex) 񤭹िΰݤ */
+	/* vertex の領域は、作成時に */
+	/* データ (vertex) を書き込むための領域を確保する */
 //	p_block_list->block->vertex = (VERTEX *)xmalloc(add_block->block->index * sizeof(VERTEX));
 
-	/* ݤΰ˥ǡ (block) 񤭹 */
+	/* 確保した領域にデータ (block) を書き込む */
 	*p_block_list->block = *add_block;
 	p_block_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ
+	 * head & tail の両方が NULL のときは、１個もデータがない
 	 */
 	if (p_block_list_info->head == NULL && p_block_list_info->tail == NULL) {
 		p_block_list_info->head = p_block_list;
@@ -142,7 +142,7 @@ BLOCK_LIST *block_list_add_first(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_block_list_info->head;
@@ -156,10 +156,10 @@ BLOCK_LIST *block_list_add_first(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list
 
 
 /* ---------------------------------------------------------
- * BLOCK Data ꥹȤκǽɲäơ Undo Baffer ˽
+ * BLOCK Data をリストの最初に追加して、 Undo Baffer に書込む
  *	
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 BLOCK_LIST *block_list_add_first_with_undo(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list_info)
 {
@@ -170,22 +170,22 @@ BLOCK_LIST *block_list_add_first_with_undo(BLOCK *add_block, BLOCK_LIST_INFO *p_
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_block_list = (BLOCK_LIST *)xmalloc(sizeof(BLOCK_LIST));
 
-	/* ǡ (block) 񤭹िΰݤ */
+	/* データ (block) を書き込むための領域を確保する */
 	p_block_list->block = (BLOCK *)xmalloc(sizeof(BLOCK));
 
-	/* ǡ (AssistLine) 񤭹िΰݤ */
+	/* データ (AssistLine) を書き込むための領域を確保する */
 //	p_block_list->block->AssistLine = (ASSISTANCE *)xmalloc(add_block->index * sizeof(ASSISTANCE));
 
-	/* ݤΰ˥ǡ (block) 񤭹 */
+	/* 確保した領域にデータ (block) を書き込む */
 	*p_block_list->block = *add_block;
 	p_block_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_block_list_info->head == NULL && p_block_list_info->tail == NULL) {
 		p_block_list_info->head = p_block_list;
@@ -193,7 +193,7 @@ BLOCK_LIST *block_list_add_first_with_undo(BLOCK *add_block, BLOCK_LIST_INFO *p_
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_block_list_info->head;
@@ -215,30 +215,30 @@ BLOCK_LIST *block_list_add_first_with_undo(BLOCK *add_block, BLOCK_LIST_INFO *p_
 
 
 /* -------------------------------------------------------------------
- * BLOCK Data ꥹȤκǸɲ
+ * BLOCK Data をリストの最後に追加
  *	
  */
 BLOCK_LIST *block_list_add_last(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list_info)
 {
 	BLOCK_LIST *p;
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_block_list = (BLOCK_LIST *)xmalloc(sizeof(BLOCK_LIST));
 
-	/* ǡ (block) 񤭹िΰݤ */
+	/* データ (block) を書き込むための領域を確保する */
 	p_block_list->block = (BLOCK *)xmalloc(sizeof(BLOCK));
 
-	/* vertex ΰϡ */
-	/* ǡ (vertex) 񤭹िΰݤ */
+	/* vertex の領域は、作成時に */
+	/* データ (vertex) を書き込むための領域を確保する */
 //	p_block_list->block->vertex = (VERTEX *)xmalloc(add_block->block->index * sizeof(VERTEX));
 
-	/* ݤΰ˥ǡ (block) 񤭹 */
+	/* 確保した領域にデータ (block) を書き込む */
 	*p_block_list->block = *add_block;
 	p_block_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_block_list_info->head == NULL && p_block_list_info->tail == NULL) {
 		p_block_list_info->head = p_block_list;
@@ -246,7 +246,7 @@ BLOCK_LIST *block_list_add_last(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list_
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_block_list_info->head != NULL 
 				&& p_block_list_info->tail != NULL 
@@ -256,7 +256,7 @@ BLOCK_LIST *block_list_add_last(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list_
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_block_list_info->tail;
@@ -264,7 +264,7 @@ BLOCK_LIST *block_list_add_last(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list_
 		p->next = p_block_list_info->tail;
 	}
 
-	/* ɥХåե˽ */
+	/* アンドゥバッファに書込む */
 //	undo_list_add_first(11, p_block_list_info->tail, NULL);
 	return p_block_list_info->tail;
 }
@@ -274,10 +274,10 @@ BLOCK_LIST *block_list_add_last(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list_
 
 
 /* ---------------------------------------------------------
- * BLOCK Data ꥹȤκǸɲá Undo Baffer ˽
+ * BLOCK Data をリストの最後に追加、 Undo Baffer に書込む
  *	
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 BLOCK_LIST *block_list_add_last_with_undo(BLOCK *add_block, BLOCK_LIST_INFO *p_block_list_info)
 {
@@ -288,22 +288,22 @@ BLOCK_LIST *block_list_add_last_with_undo(BLOCK *add_block, BLOCK_LIST_INFO *p_b
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_block_list = (BLOCK_LIST *)xmalloc(sizeof(BLOCK_LIST));
 
-	/* ǡ (block) 񤭹िΰݤ */
+	/* データ (block) を書き込むための領域を確保する */
 	p_block_list->block = (BLOCK *)xmalloc(sizeof(BLOCK));
 
-	/* ǡ (AssistLine) 񤭹िΰݤ */
+	/* データ (AssistLine) を書き込むための領域を確保する */
 //	p_block_list->block->AssistLine = (ASSISTANCE *)xmalloc(add_block->index * sizeof(ASSISTANCE));
 
-	/* ݤΰ˥ǡ (block) 񤭹 */
+	/* 確保した領域にデータ (block) を書き込む */
 	*p_block_list->block = *add_block;
 	p_block_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_block_list_info->head == NULL && p_block_list_info->tail == NULL) {
 		p_block_list_info->head = p_block_list;
@@ -311,7 +311,7 @@ BLOCK_LIST *block_list_add_last_with_undo(BLOCK *add_block, BLOCK_LIST_INFO *p_b
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_block_list_info->head != NULL 
 				&& p_block_list_info->tail != NULL 
@@ -321,7 +321,7 @@ BLOCK_LIST *block_list_add_last_with_undo(BLOCK *add_block, BLOCK_LIST_INFO *p_b
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_block_list_info->tail;
@@ -343,7 +343,7 @@ BLOCK_LIST *block_list_add_last_with_undo(BLOCK *add_block, BLOCK_LIST_INFO *p_b
 
 
 /* -------------------------------------------------------------------
- * BLOCK Data κǽ (κǤϤʤ)
+ * BLOCK Data の削除機能 (メモリの削除ではない)
  * 
  */
 int block_list_delete(BLOCK_LIST *del_List, BLOCK_LIST_INFO *p_block_list_info)
@@ -353,41 +353,41 @@ int block_list_delete(BLOCK_LIST *del_List, BLOCK_LIST_INFO *p_block_list_info)
 	long i;
 
 	/* -------------------------------------------
-	 * ݥ󥿤ΥǡΤꤿΤǡ
-	 * head (ꥹȤƬ) ݥ󥿤
-	 * ĤޤǷ֤Υǡõ
+	 * 削除するポインタの前のデータを知りたいので、
+	 * head (リストの先頭) から削除するポインタが
+	 * 見つかるまで繰り返し、前のデータを探す。
 	 */
 	p = p_block_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL && p != del_List) {
 		if (i == 0) i++;
-		pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pb = p;			/* 前のデータのポインタとして保存しておく */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 
-	/* Ĥä (p  NULL ǤϤʤȤ) */
+	/* 見つかった場合 (p が NULL ではないとき) */
 	if(p != NULL){
-		/* ƬΥǡ (i = 0 ΤȤ) */
+		/* 先頭のデータ (i = 0 のとき) */
 		if (i == 0) {
-			/* ƬΥǡĤʤ(ΥǡΥݥ󥿤 NULL) */
+			/* 先頭のデータ１個しかない場合(次のデータのポインタが NULL) */
 			if (p->next == NULL) {
 				p_block_list_info->head = NULL;
 				p_block_list_info->tail = NULL;
 			}
-			/* İʾǡȤ */
+			/* ２個以上データがあるとき */
 			else 
 				p_block_list_info->head = p->next;
 		}
 
-		/* ǸΥǡΤȤ (p->next = NULL) */
+		/* 最後のデータのとき (p->next = NULL) */
 		else if (p->next == NULL) pb->next = NULL;
 
-		/* ֤Υǡ (ξʳ) */
+		/* 中間のデータ (上の条件以外) */
 		else pb->next = p->next;
 		block_list_free(del_List, p_block_list_info);
 		return 1;
@@ -400,7 +400,7 @@ int block_list_delete(BLOCK_LIST *del_List, BLOCK_LIST_INFO *p_block_list_info)
 
 
 /* -------------------------------------------------------------------
- * BLOCK Data κǽ (κǤϤʤUndo Buffer ذܤ)
+ * BLOCK Data の削除機能 (メモリの削除ではなく、Undo Buffer へ移す)
  * 
  */
 int block_list_delete_Undo(BLOCK_LIST *del_List, BLOCK_LIST_INFO *p_block_list_info)
@@ -414,41 +414,41 @@ int block_list_delete_Undo(BLOCK_LIST *del_List, BLOCK_LIST_INFO *p_block_list_i
 
 
 	/* -------------------------------------------
-	 * ݥ󥿤ΥǡΤꤿΤǡ
-	 * head (ꥹȤƬ) ݥ󥿤
-	 * ĤޤǷ֤Υǡõ
+	 * 削除するポインタの前のデータを知りたいので、
+	 * head (リストの先頭) から削除するポインタが
+	 * 見つかるまで繰り返し、前のデータを探す。
 	 */
 	p = p_block_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL && p != del_List) {
 		i++;
-		pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pb = p;			/* 前のデータのポインタとして保存しておく */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 
-	/* Ĥä (p  NULL ǤϤʤȤ) */
+	/* 見つかった場合 (p が NULL ではないとき) */
 	if(p != NULL){
-		/* ƬΥǡ (i = 0 ΤȤ) */
+		/* 先頭のデータ (i = 0 のとき) */
 		if (i == 0) {
-			/* ƬΥǡĤʤ(ΥǡΥݥ󥿤 NULL) */
+			/* 先頭のデータ１個しかない場合(次のデータのポインタが NULL) */
 			if (p->next == NULL) {
 				p_block_list_info->head = NULL;
 				p_block_list_info->tail = NULL;
 			}
-			/* İʾǡȤ */
+			/* ２個以上データがあるとき */
 			else 
 				p_block_list_info->head = p->next;
 		}
 
-		/* ǸΥǡΤȤ (p->next = NULL) */
+		/* 最後のデータのとき (p->next = NULL) */
 		else if (p->next == NULL) pb->next = NULL;
 
-		/* ֤Υǡ (ξʳ) */
+		/* 中間のデータ (上の条件以外) */
 		else pb->next = p->next;
 
 		lpdiagram.block_point = del_List->block;
@@ -466,30 +466,30 @@ int block_list_delete_Undo(BLOCK_LIST *del_List, BLOCK_LIST_INFO *p_block_list_i
 
 
 /* ---------------------------------------------------------
- * BLOCK Υݥ󥿤Υǡ Undo ХåեԽˤơ
- * ξ˿ǡ롣
+ * BLOCK のポインタのデータを Undo バッファ（編集）に入れて、
+ * その場所に新しいデータを入れる。
  * 
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  * 
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 BLOCK_LIST *block_list_edit(BLOCK_LIST *point, BLOCK *change_block, BLOCK_LIST_INFO *p_block_list_info)
 {
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_block_list = (BLOCK_LIST *)xmalloc(sizeof(BLOCK_LIST));
 
-	/* ǡ (block) 񤭹िΰݤ */
+	/* データ (block) を書き込むための領域を確保する */
 	p_block_list->block = (BLOCK *)xmalloc(sizeof(BLOCK));
 
-	/* ǡ (AssistLine) 񤭹िΰݤ */
+	/* データ (AssistLine) を書き込むための領域を確保する */
 //	p_block_list->block->AssistLine = (ASSISTANCE *)xmalloc(change_block->index * sizeof(ASSISTANCE));
 
-	/* ݤΰѹΥǡ (block) 񤭹 */
+	/* 確保した領域に変更前のデータ (block) を書き込む */
 	*p_block_list->block = *point->block;
 //	p_block_list->next = point;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->block = *change_block;
 
 //	undo_list_add_first(13, p_block_list, NULL);
@@ -501,13 +501,13 @@ BLOCK_LIST *block_list_edit(BLOCK_LIST *point, BLOCK *change_block, BLOCK_LIST_I
 
 
 /* ---------------------------------------------------------
- * BLOCK ѹΥǡ(point) Undo ХåեԽˤơ
- * ξ˿ǡ(change_block)졢Undo Baffer ˽
+ * BLOCK の変更前のデータ(point)を Undo バッファ（編集）に入れて、
+ * その場所に新しいデータ(change_block)を入れ、Undo Baffer に書込む
  *	
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  *	
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 BLOCK_LIST *block_list_edit_with_undo(BLOCK_LIST *point, BLOCK *change_block, BLOCK_LIST_INFO *p_block_list_info)
 {
@@ -517,10 +517,10 @@ BLOCK_LIST *block_list_edit_with_undo(BLOCK_LIST *point, BLOCK *change_block, BL
 	LPDIAGRAM lpdiagram;
 
 
-	/* ݤΰѹΥǡ (BLOCK) 񤭹 */
+	/* 確保した領域に変更前のデータ (BLOCK) を書き込む */
 	block = *point->block;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->block = *change_block;
 
 
@@ -536,7 +536,7 @@ BLOCK_LIST *block_list_edit_with_undo(BLOCK_LIST *point, BLOCK *change_block, BL
 
 
 /* -------------------------------------------------------------------
- * ꥹȤĴ٤
+ * リストの総数を調べる
  */
 long block_list_num(BLOCK_LIST_INFO *p_block_list_info)
 {
@@ -546,12 +546,12 @@ long block_list_num(BLOCK_LIST_INFO *p_block_list_info)
 	p = p_block_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL) {
 		i++;
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 	return i;
 }
@@ -561,7 +561,7 @@ long block_list_num(BLOCK_LIST_INFO *p_block_list_info)
 
 
 /* -------------------------------------------------------------------
- * n ܤΥǡθ
+ * n 番目のデータの検索
  *	
  */
 BLOCK_LIST *block_search_num(long search_number, BLOCK_LIST_INFO *p_block_list_info)
@@ -577,11 +577,11 @@ BLOCK_LIST *block_search_num(long search_number, BLOCK_LIST_INFO *p_block_list_i
 		p = p->next;
 	}
 
-	/* n ܤΥǡΥɥ쥹֤ */
+	/* n 番目のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -592,9 +592,9 @@ BLOCK_LIST *block_search_num(long search_number, BLOCK_LIST_INFO *p_block_list_i
 
 
 /* -------------------------------------------------------------------
- * BLOCK Υǡθ
+ * BLOCK のデータの検索
  *	
- *   BLOCK_LIST
+ * 戻値  BLOCK_LIST
  */
 BLOCK_LIST *block_search_block(BLOCK *p_block, BLOCK_LIST_INFO *p_block_list_info)
 {
@@ -606,11 +606,11 @@ BLOCK_LIST *block_search_block(BLOCK *p_block, BLOCK_LIST_INFO *p_block_list_inf
 		p = p->next;
 	}
 
-	/* p_block ΥǡΥɥ쥹֤ */
+	/* p_block のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -621,9 +621,9 @@ BLOCK_LIST *block_search_block(BLOCK *p_block, BLOCK_LIST_INFO *p_block_list_inf
 
 
 /* -------------------------------------------------------------------
- * BLOCK Υǡθ (name)
+ * BLOCK のデータの検索 (name)
  *	
- *   BLOCK_LIST
+ * 戻値  BLOCK_LIST
  */
 BLOCK_LIST *block_search_block_name(char *name, BLOCK_LIST_INFO *p_block_list_info)
 {
@@ -638,11 +638,11 @@ BLOCK_LIST *block_search_block_name(char *name, BLOCK_LIST_INFO *p_block_list_in
 		p = p->next;
 	}
 
-	/* p_block ΥǡΥɥ쥹֤ */
+	/* p_block のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -653,9 +653,9 @@ BLOCK_LIST *block_search_block_name(char *name, BLOCK_LIST_INFO *p_block_list_in
 
 
 /* -------------------------------------------------------------------
- * BLOCK Υǡθ
+ * BLOCK のデータの検索
  *	
- *   long
+ * 戻値  long
  */
 long block_search_block_to_num(BLOCK *p_block, BLOCK_LIST_INFO *p_block_list_info)
 {
@@ -670,11 +670,11 @@ long block_search_block_to_num(BLOCK *p_block, BLOCK_LIST_INFO *p_block_list_inf
 		i++;
 	}
 
-	/* p_block ΥǡΥɥ쥹֤ */
+	/* p_block のデータのアドレスを返す */
 	if (p != NULL) {
 		return i;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return 0;
 	}
@@ -685,7 +685,7 @@ long block_search_block_to_num(BLOCK *p_block, BLOCK_LIST_INFO *p_block_list_inf
 
 
 /* -------------------------------------------------------------------
- * BLOCK Data ꥹȤ
+ * BLOCK Data をリストから削除
  */
 int block_list_free(BLOCK_LIST *del_List, BLOCK_LIST_INFO *p_block_list_info)
 {
@@ -693,47 +693,47 @@ int block_list_free(BLOCK_LIST *del_List, BLOCK_LIST_INFO *p_block_list_info)
 	BLOCK_LIST *pb = NULL;
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_block_list_info->head && del_List->next == NULL) {
 		p_block_list_info->head = NULL;
 		p_block_list_info->tail = NULL;
-		//g_print("ǡƬǣĤ\n");
+		//g_print("データが先頭で１個だけ\n");
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_block_list_info->head && del_List->next != NULL) {
 		p_block_list_info->head = p_block_list_info->head->next;
-		//g_print("ǡƬǣİʾ\n");
+		//g_print("データが先頭で２個以上\n");
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_block_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_block_list_info->tail) {
 				pb->next = NULL;
 				p_block_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_block_list_info->head && del_List != p_block_list_info->tail) {
 				pb->next = p->next;
 			}
 		}
 		else {
-			//g_print("ꥹȤ BLOCK ǡǤϤʤ\n");
+			//g_print("リストの BLOCK データではない\n");
 			return 0;
 		}
 	}
@@ -754,7 +754,7 @@ int block_list_free(BLOCK_LIST *del_List, BLOCK_LIST_INFO *p_block_list_info)
 
 
 /* -------------------------------------------------------------------
- * ꥹȤ
+ * 全リストを削除
  */
 void block_list_all_free(BLOCK_LIST_INFO *p_block_list_info)
 {
@@ -768,7 +768,7 @@ void block_list_all_free(BLOCK_LIST_INFO *p_block_list_info)
 
 
 /* ---------------------------------------------------------
- * BLOCK_LIST Υǡ log
+ * BLOCK_LIST のデータ log
  *	
  */
 void block_list_log(BLOCK_LIST_INFO *p_block_list_info)
@@ -777,7 +777,7 @@ void block_list_log(BLOCK_LIST_INFO *p_block_list_info)
 	long i = 0;
 
 
-	g_print("----- BLOCK ꥹȤɽ -----\n");
+	g_print("----- BLOCK リストを表示 -----\n");
 	p = p_block_list_info->head;
 	while( p != NULL) {
 		i++;
@@ -804,7 +804,7 @@ void block_list_log(BLOCK_LIST_INFO *p_block_list_info)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : List_Block.c
