@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/01/16
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/08
  * ====================================================================
  */
 
@@ -23,7 +23,7 @@
 
 #include <gtk/gtk.h>
 #include <unistd.h>
-#include <pwd.h>
+//#include <pwd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -48,7 +48,7 @@ int init_dimension(DIMENSION *dimension)
 {
 	double scale;
 
-	/* DIMENSION Data ν */
+	/* DIMENSION Data の初期化 */
 	dimension->Layer = 0;
 	dimension->text_color = sagcad_color.Dimension;
 	dimension->Assist_color = sagcad_color.Dimension;
@@ -85,25 +85,25 @@ int init_dimension(DIMENSION *dimension)
 
 
 /* -------------------------------------------------------------------
- * DIMENSION Data ꥹȤκǽɲ
+ * DIMENSION Data をリストの最初に追加
  *	
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 DIMENSION_LIST *r_dimension_list_add_first(DIMENSION *add_dimension, DIMENSION_LIST_INFO *p_dimension_list_info)
 {
 	DIMENSION_LIST *p;
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_dimension_list = (DIMENSION_LIST *)xmalloc(sizeof(DIMENSION_LIST));
 
-	/* ݤΰ˥ǡ (dimension) 񤭹 */
+	/* 確保した領域にデータ (dimension) を書き込む */
 	p_dimension_list->dimension = add_dimension;
 	p_dimension_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_dimension_list_info->head == NULL && p_dimension_list_info->tail == NULL) {
 		p_dimension_list_info->head = p_dimension_list;
@@ -111,7 +111,7 @@ DIMENSION_LIST *r_dimension_list_add_first(DIMENSION *add_dimension, DIMENSION_L
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_dimension_list_info->head;
@@ -127,31 +127,31 @@ DIMENSION_LIST *r_dimension_list_add_first(DIMENSION *add_dimension, DIMENSION_L
 
 
 /* -------------------------------------------------------------------
- * DIMENSION Data ꥹȤκǽɲ
+ * DIMENSION Data をリストの最初に追加
  *	
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 DIMENSION_LIST *dimension_list_add_first(DIMENSION *add_dimension, DIMENSION_LIST_INFO *p_dimension_list_info)
 {
 	DIMENSION_LIST *p;
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_dimension_list = (DIMENSION_LIST *)xmalloc(sizeof(DIMENSION_LIST));
 
-	/* ǡ (dimension) 񤭹िΰݤ */
+	/* データ (dimension) を書き込むための領域を確保する */
 	p_dimension_list->dimension = (DIMENSION *)xmalloc(sizeof(DIMENSION));
 
-	/* ǡ (AssistLine) 񤭹िΰݤ */
+	/* データ (AssistLine) を書き込むための領域を確保する */
 //	p_dimension_list->dimension->AssistLine = (ASSISTANCE *)xmalloc(add_dimension->index * sizeof(ASSISTANCE));
 
-	/* ݤΰ˥ǡ (dimension) 񤭹 */
+	/* 確保した領域にデータ (dimension) を書き込む */
 	*p_dimension_list->dimension = *add_dimension;
 	p_dimension_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_dimension_list_info->head == NULL && p_dimension_list_info->tail == NULL) {
 		p_dimension_list_info->head = p_dimension_list;
@@ -159,7 +159,7 @@ DIMENSION_LIST *dimension_list_add_first(DIMENSION *add_dimension, DIMENSION_LIS
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_dimension_list_info->head;
@@ -175,10 +175,10 @@ DIMENSION_LIST *dimension_list_add_first(DIMENSION *add_dimension, DIMENSION_LIS
 
 
 /* ---------------------------------------------------------
- * DIMENSION Data ꥹȤκǽɲäơ Undo Baffer ˽
+ * DIMENSION Data をリストの最初に追加して、 Undo Baffer に書込む
  *	
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 DIMENSION_LIST *dimension_list_add_first_with_undo(DIMENSION *add_dimension, DIMENSION_LIST_INFO *p_dimension_list_info)
 {
@@ -189,21 +189,21 @@ DIMENSION_LIST *dimension_list_add_first_with_undo(DIMENSION *add_dimension, DIM
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_dimension_list = (DIMENSION_LIST *)xmalloc(sizeof(DIMENSION_LIST));
-	/* ǡ (dimension) 񤭹िΰݤ */
+	/* データ (dimension) を書き込むための領域を確保する */
 	p_dimension_list->dimension = (DIMENSION *)xmalloc(sizeof(DIMENSION));
 
-	/* ǡ (AssistLine) 񤭹िΰݤ */
+	/* データ (AssistLine) を書き込むための領域を確保する */
 //	p_dimension_list->dimension->AssistLine = (ASSISTANCE *)xmalloc(add_dimension->index * sizeof(ASSISTANCE));
 
-	/* ݤΰ˥ǡ (dimension) 񤭹 */
+	/* 確保した領域にデータ (dimension) を書き込む */
 	*p_dimension_list->dimension = *add_dimension;
 	p_dimension_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_dimension_list_info->head == NULL && p_dimension_list_info->tail == NULL) {
 		p_dimension_list_info->head = p_dimension_list;
@@ -211,7 +211,7 @@ DIMENSION_LIST *dimension_list_add_first_with_undo(DIMENSION *add_dimension, DIM
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_dimension_list_info->head;
@@ -233,32 +233,32 @@ DIMENSION_LIST *dimension_list_add_first_with_undo(DIMENSION *add_dimension, DIM
 
 
 /* ---------------------------------------------------------
- * DIMENSION Data ꥹȤκǸɲ
+ * DIMENSION Data をリストの最後に追加
  *	
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 DIMENSION_LIST *dimension_list_add_last(DIMENSION *add_dimension, DIMENSION_LIST_INFO *p_dimension_list_info)
 {
 	DIMENSION_LIST *p;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_dimension_list = (DIMENSION_LIST *)xmalloc(sizeof(DIMENSION_LIST));
 
-	/* ǡ (dimension) 񤭹िΰݤ */
+	/* データ (dimension) を書き込むための領域を確保する */
 	p_dimension_list->dimension = (DIMENSION *)xmalloc(sizeof(DIMENSION));
 
-	/* ǡ (AssistLine) 񤭹िΰݤ */
+	/* データ (AssistLine) を書き込むための領域を確保する */
 //	p_dimension_list->dimension->AssistLine = (ASSISTANCE *)xmalloc(add_dimension->index * sizeof(ASSISTANCE));
 
-	/* ݤΰ˥ǡ (dimension) 񤭹 */
+	/* 確保した領域にデータ (dimension) を書き込む */
 	*p_dimension_list->dimension = *add_dimension;
 	p_dimension_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_dimension_list_info->head == NULL && p_dimension_list_info->tail == NULL) {
 		p_dimension_list_info->head = p_dimension_list;
@@ -266,7 +266,7 @@ DIMENSION_LIST *dimension_list_add_last(DIMENSION *add_dimension, DIMENSION_LIST
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_dimension_list_info->head != NULL 
 				&& p_dimension_list_info->tail != NULL 
@@ -276,7 +276,7 @@ DIMENSION_LIST *dimension_list_add_last(DIMENSION *add_dimension, DIMENSION_LIST
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_dimension_list_info->tail;
@@ -284,7 +284,7 @@ DIMENSION_LIST *dimension_list_add_last(DIMENSION *add_dimension, DIMENSION_LIST
 		p->next = p_dimension_list_info->tail;
 	}
 
-	/* ɥХåե˽ */
+	/* アンドゥバッファに書込む */
 //	undo_list_add_first(11, p_dimension_list_info->tail, NULL);
 	return p_dimension_list_info->tail;
 }
@@ -294,10 +294,10 @@ DIMENSION_LIST *dimension_list_add_last(DIMENSION *add_dimension, DIMENSION_LIST
 
 
 /* ---------------------------------------------------------
- * DIMENSION Data ꥹȤκǸɲá Undo Baffer ˽
+ * DIMENSION Data をリストの最後に追加、 Undo Baffer に書込む
  *	
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 DIMENSION_LIST *dimension_list_add_last_with_undo(DIMENSION *add_dimension, DIMENSION_LIST_INFO *p_dimension_list_info)
 {
@@ -308,22 +308,22 @@ DIMENSION_LIST *dimension_list_add_last_with_undo(DIMENSION *add_dimension, DIME
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_dimension_list = (DIMENSION_LIST *)xmalloc(sizeof(DIMENSION_LIST));
 
-	/* ǡ (dimension) 񤭹िΰݤ */
+	/* データ (dimension) を書き込むための領域を確保する */
 	p_dimension_list->dimension = (DIMENSION *)xmalloc(sizeof(DIMENSION));
 
-	/* ǡ (AssistLine) 񤭹िΰݤ */
+	/* データ (AssistLine) を書き込むための領域を確保する */
 //	p_dimension_list->dimension->AssistLine = (ASSISTANCE *)xmalloc(add_dimension->index * sizeof(ASSISTANCE));
 
-	/* ݤΰ˥ǡ (dimension) 񤭹 */
+	/* 確保した領域にデータ (dimension) を書き込む */
 	*p_dimension_list->dimension = *add_dimension;
 	p_dimension_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_dimension_list_info->head == NULL && p_dimension_list_info->tail == NULL) {
 		p_dimension_list_info->head = p_dimension_list;
@@ -331,7 +331,7 @@ DIMENSION_LIST *dimension_list_add_last_with_undo(DIMENSION *add_dimension, DIME
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_dimension_list_info->head != NULL 
 				&& p_dimension_list_info->tail != NULL 
@@ -341,7 +341,7 @@ DIMENSION_LIST *dimension_list_add_last_with_undo(DIMENSION *add_dimension, DIME
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_dimension_list_info->tail;
@@ -363,7 +363,7 @@ DIMENSION_LIST *dimension_list_add_last_with_undo(DIMENSION *add_dimension, DIME
 
 
 /* -------------------------------------------------------------------
- * DIMENSION Data κǽ (κǤϤʤ)
+ * DIMENSION Data の削除機能 (メモリの削除ではない)
  * 
  */
 int dimension_list_delete(DIMENSION_LIST *del_List, DIMENSION_LIST_INFO *p_dimension_list_info)
@@ -373,43 +373,43 @@ int dimension_list_delete(DIMENSION_LIST *del_List, DIMENSION_LIST_INFO *p_dimen
 	long i;
 
 	/* -------------------------------------------
-	 * ݥ󥿤ΥǡΤꤿΤǡ
-	 * head (ꥹȤƬ) ݥ󥿤
-	 * ĤޤǷ֤Υǡõ
+	 * 削除するポインタの前のデータを知りたいので、
+	 * head (リストの先頭) から削除するポインタが
+	 * 見つかるまで繰り返し、前のデータを探す。
 	 */
 	p = p_dimension_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while (p != NULL && p != del_List) {
 		if (i == 0) i++;
-		pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pb = p;			/* 前のデータのポインタとして保存しておく */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 
-	/* Ĥä (p  NULL ǤϤʤȤ) */
+	/* 見つかった場合 (p が NULL ではないとき) */
 	if (p != NULL){
-		/* ƬΥǡ (i = 0 ΤȤ) */
+		/* 先頭のデータ (i = 0 のとき) */
 		if (i == 0) {
-			/* ƬΥǡĤʤ(ΥǡΥݥ󥿤 NULL) */
+			/* 先頭のデータ１個しかない場合(次のデータのポインタが NULL) */
 			if (p->next == NULL) {
 				p_dimension_list_info->head = NULL;
 				p_dimension_list_info->tail = NULL;
 			}
-			/* İʾǡȤ */
+			/* ２個以上データがあるとき */
 			else 
 				p_dimension_list_info->head = p->next;
 		}
 
-		/* ǸΥǡΤȤ (p->next = NULL) */
+		/* 最後のデータのとき (p->next = NULL) */
 		else if (p->next == NULL) {
 			pb->next = NULL;
 		}
 
-		/* ֤Υǡ (ξʳ) */
+		/* 中間のデータ (上の条件以外) */
 		else {
 			pb->next = p->next;
 		}
@@ -426,7 +426,7 @@ int dimension_list_delete(DIMENSION_LIST *del_List, DIMENSION_LIST_INFO *p_dimen
 
 
 /* -------------------------------------------------------------------
- * DIMENSION Data κǽ (κǤϤʤUndo Buffer ذܤ)
+ * DIMENSION Data の削除機能 (メモリの削除ではなく、Undo Buffer へ移す)
  * 
  */
 int dimension_list_delete_Undo(DIMENSION_LIST *del_List, DIMENSION_LIST_INFO *p_dimension_list_info)
@@ -440,41 +440,41 @@ int dimension_list_delete_Undo(DIMENSION_LIST *del_List, DIMENSION_LIST_INFO *p_
 
 
 	/* -------------------------------------------
-	 * ݥ󥿤ΥǡΤꤿΤǡ
-	 * head (ꥹȤƬ) ݥ󥿤
-	 * ĤޤǷ֤Υǡõ
+	 * 削除するポインタの前のデータを知りたいので、
+	 * head (リストの先頭) から削除するポインタが
+	 * 見つかるまで繰り返し、前のデータを探す。
 	 */
 	p = p_dimension_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL && p != del_List) {
 		i++;
-		pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pb = p;			/* 前のデータのポインタとして保存しておく */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 
-	/* Ĥä (p  NULL ǤϤʤȤ) */
+	/* 見つかった場合 (p が NULL ではないとき) */
 	if(p != NULL){
-		/* ƬΥǡ (i = 0 ΤȤ) */
+		/* 先頭のデータ (i = 0 のとき) */
 		if (i == 0) {
-			/* ƬΥǡĤʤ(ΥǡΥݥ󥿤 NULL) */
+			/* 先頭のデータ１個しかない場合(次のデータのポインタが NULL) */
 			if (p->next == NULL) {
 				p_dimension_list_info->head = NULL;
 				p_dimension_list_info->tail = NULL;
 			}
-			/* İʾǡȤ */
+			/* ２個以上データがあるとき */
 			else 
 				p_dimension_list_info->head = p->next;
 		}
 
-		/* ǸΥǡΤȤ (p->next = NULL) */
+		/* 最後のデータのとき (p->next = NULL) */
 		else if (p->next == NULL) pb->next = NULL;
 
-		/* ֤Υǡ (ξʳ) */
+		/* 中間のデータ (上の条件以外) */
 		else pb->next = p->next;
 
 		lpdiagram.dimension_point = del_List->dimension;
@@ -492,30 +492,30 @@ int dimension_list_delete_Undo(DIMENSION_LIST *del_List, DIMENSION_LIST_INFO *p_
 
 
 /* ---------------------------------------------------------
- * DIMENSION Υݥ󥿤Υǡ Undo ХåեԽˤơ
- * ξ˿ǡ롣
+ * DIMENSION のポインタのデータを Undo バッファ（編集）に入れて、
+ * その場所に新しいデータを入れる。
  * 
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  * 
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 DIMENSION_LIST *dimension_list_edit(DIMENSION_LIST *point, DIMENSION *change_dimension, DIMENSION_LIST_INFO *p_dimension_list_info)
 {
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_dimension_list = (DIMENSION_LIST *)xmalloc(sizeof(DIMENSION_LIST));
 
-	/* ǡ (dimension) 񤭹िΰݤ */
+	/* データ (dimension) を書き込むための領域を確保する */
 	p_dimension_list->dimension = (DIMENSION *)xmalloc(sizeof(DIMENSION));
 
-	/* ǡ (AssistLine) 񤭹िΰݤ */
+	/* データ (AssistLine) を書き込むための領域を確保する */
 //	p_dimension_list->dimension->AssistLine = (ASSISTANCE *)xmalloc(change_dimension->index * sizeof(ASSISTANCE));
 
-	/* ݤΰѹΥǡ (dimension) 񤭹 */
+	/* 確保した領域に変更前のデータ (dimension) を書き込む */
 	*p_dimension_list->dimension = *point->dimension;
 //	p_dimension_list->next = point;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->dimension = *change_dimension;
 
 //	undo_list_add_first(13, p_dimension_list, NULL);
@@ -527,13 +527,13 @@ DIMENSION_LIST *dimension_list_edit(DIMENSION_LIST *point, DIMENSION *change_dim
 
 
 /* ---------------------------------------------------------
- * DIMENSION ѹΥǡ(point) Undo ХåեԽˤơ
- * ξ˿ǡ(change_dimension)졢Undo Baffer ˽
+ * DIMENSION の変更前のデータ(point)を Undo バッファ（編集）に入れて、
+ * その場所に新しいデータ(change_dimension)を入れ、Undo Baffer に書込む
  *	
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  *	
- * ǡ (AssistLine) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (AssistLine) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 DIMENSION_LIST *dimension_list_edit_with_undo(DIMENSION_LIST *point, DIMENSION *change_dimension, DIMENSION_LIST_INFO *p_dimension_list_info)
 {
@@ -543,10 +543,10 @@ DIMENSION_LIST *dimension_list_edit_with_undo(DIMENSION_LIST *point, DIMENSION *
 	LPDIAGRAM lpdiagram;
 
 
-	/* ݤΰѹΥǡ (DIMENSION) 񤭹 */
+	/* 確保した領域に変更前のデータ (DIMENSION) を書き込む */
 	dimension = *point->dimension;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->dimension = *change_dimension;
 
 
@@ -562,7 +562,7 @@ DIMENSION_LIST *dimension_list_edit_with_undo(DIMENSION_LIST *point, DIMENSION *
 
 
 /* ---------------------------------------------------------
- * ꥹȤĴ٤
+ * リストの総数を調べる
  */
 long dimension_list_num(DIMENSION_LIST_INFO *p_dimension_list_info)
 {
@@ -572,12 +572,12 @@ long dimension_list_num(DIMENSION_LIST_INFO *p_dimension_list_info)
 	p = p_dimension_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL) {
 		i++;
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 	return i;
 }
@@ -585,7 +585,7 @@ long dimension_list_num(DIMENSION_LIST_INFO *p_dimension_list_info)
 
 
 /* ---------------------------------------------------------
- * n ܤΥǡθ
+ * n 番目のデータの検索
  *	
  */
 DIMENSION_LIST *dimension_search_num(long search_number, DIMENSION_LIST_INFO *p_dimension_list_info)
@@ -601,11 +601,11 @@ DIMENSION_LIST *dimension_search_num(long search_number, DIMENSION_LIST_INFO *p_
 		p = p->next;
 	}
 
-	/* n ܤΥǡΥɥ쥹֤ */
+	/* n 番目のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -614,9 +614,9 @@ DIMENSION_LIST *dimension_search_num(long search_number, DIMENSION_LIST_INFO *p_
 
 
 /* ---------------------------------------------------------
- * DIMENSION Υǡθ
+ * DIMENSION のデータの検索
  *	
- *   DIMENSION_LIST
+ * 戻値  DIMENSION_LIST
  */
 DIMENSION_LIST *dimension_search_dimension(DIMENSION *p_dimension, DIMENSION_LIST_INFO *p_dimension_list_info)
 {
@@ -628,11 +628,11 @@ DIMENSION_LIST *dimension_search_dimension(DIMENSION *p_dimension, DIMENSION_LIS
 		p = p->next;
 	}
 
-	/* p_dimension ΥǡΥɥ쥹֤ */
+	/* p_dimension のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -641,9 +641,9 @@ DIMENSION_LIST *dimension_search_dimension(DIMENSION *p_dimension, DIMENSION_LIS
 
 
 /* ---------------------------------------------------------
- * DIMENSION Υǡθ
+ * DIMENSION のデータの検索
  *	
- *   long
+ * 戻値  long
  */
 long dimension_search_dimension_to_num(DIMENSION *p_dimension, DIMENSION_LIST_INFO *p_dimension_list_info)
 {
@@ -658,11 +658,11 @@ long dimension_search_dimension_to_num(DIMENSION *p_dimension, DIMENSION_LIST_IN
 		i++;
 	}
 
-	/* p_dimension ΥǡΥɥ쥹֤ */
+	/* p_dimension のデータのアドレスを返す */
 	if (p != NULL) {
 		return i;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return 0;
 	}
@@ -673,7 +673,7 @@ long dimension_search_dimension_to_num(DIMENSION *p_dimension, DIMENSION_LIST_IN
 
 
 /* ---------------------------------------------------------
- * DIMENSION Data ꥹȤ
+ * DIMENSION Data をリストから削除
  */
 int dimension_list_free(DIMENSION_LIST *del_List, DIMENSION_LIST_INFO *p_dimension_list_info)
 {
@@ -683,49 +683,49 @@ int dimension_list_free(DIMENSION_LIST *del_List, DIMENSION_LIST_INFO *p_dimensi
 //	char str[256];
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_dimension_list_info->head && del_List->next == NULL) {
 		p_dimension_list_info->head = NULL;
 		p_dimension_list_info->tail = NULL;
-		//g_print("ǡƬǣĤ\n");
+		//g_print("データが先頭で１個だけ\n");
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_dimension_list_info->head && del_List->next != NULL) {
 		p_dimension_list_info->head = p_dimension_list_info->head->next;
-		//g_print("ǡƬǣİʾ\n");
+		//g_print("データが先頭で２個以上\n");
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_dimension_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_dimension_list_info->tail) {
-				//g_print("ǸΥǡ\n");
+				//g_print("最後のデータ\n");
 				pb->next = NULL;
 				p_dimension_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_dimension_list_info->head && del_List != p_dimension_list_info->tail) {
-				//g_print("֤Υǡ\n");
+				//g_print("中間のデータ\n");
 				pb->next = p->next;
 			}
 		}
 		else {
-			//g_print("ꥹȤ DIMENSION ǡǤϤʤ\n");
+			//g_print("リストの DIMENSION データではない\n");
 			return 0;
 		}
 	}
@@ -761,7 +761,7 @@ int dimension_list_free(DIMENSION_LIST *del_List, DIMENSION_LIST_INFO *p_dimensi
 
 
 /* ---------------------------------------------------------
- * ꥹȤ
+ * 全リストを削除
  */
 void dimension_list_all_free(DIMENSION_LIST_INFO *p_dimension_list_info)
 {
@@ -776,7 +776,7 @@ void dimension_list_print(DIMENSION_LIST_INFO *p_dimension_list_info)
 	DIMENSION_LIST *p;
 	int i = 0, j;
 
-	g_print("----- DIMENSION ꥹȤɽ -----\n");
+	g_print("----- DIMENSION リストを表示 -----\n");
 	p = p_dimension_list_info->head;
 	while (p != NULL) {
 		i++;
@@ -806,7 +806,7 @@ void dimension_list_print(DIMENSION_LIST_INFO *p_dimension_list_info)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : List_dimension.c
