@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/03/25
- *    Last                 : 2003/03/25
+ *    Last                 : 2007/10/08
  * ====================================================================
  */
 
@@ -28,7 +28,7 @@
 #include "MemoryLeak.h"
 #include "types.h"
 #include "List_Undo.h"
-#include "Trace.h"
+#include "culcfunc.h"
 
 #define _LIST_ELLIPSE_
 #include "List_Ellipse.h"
@@ -37,7 +37,7 @@
 
 
 
-/* ELLIPSE Data ν */
+/* ELLIPSE Data の初期化 */
 int init_ellipse(ELLIPSE *ellipse)
 {
 	ellipse->layer = 0;
@@ -58,7 +58,7 @@ int init_ellipse(ELLIPSE *ellipse)
 
 
 /* -------------------------------------------------------------------
- * ΰݺѤߤ ELLIPSE Data ꥹȤκǽɲ
+ * 領域確保済みの ELLIPSE Data をリストの最初に追加
  * 
  */
 ELLIPSE_LIST *r_ellipse_list_add_first(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_ellipse_list_info)
@@ -66,15 +66,15 @@ ELLIPSE_LIST *r_ellipse_list_add_first(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *
 	ELLIPSE_LIST *p;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_ellipse_list = (ELLIPSE_LIST *)xmalloc(sizeof(ELLIPSE_LIST));
 
-	/* ݤΰ˥ǡ (ellipse) 񤭹 */
+	/* 確保した領域にデータ (ellipse) を書き込む */
 	p_ellipse_list->ellipse = add_ellipse;
 	p_ellipse_list->next = NULL;
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_ellipse_list_info->head == NULL && p_ellipse_list_info->tail == NULL) {
 		p_ellipse_list_info->head = p_ellipse_list;
@@ -82,7 +82,7 @@ ELLIPSE_LIST *r_ellipse_list_add_first(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_ellipse_list_info->head;
@@ -98,7 +98,7 @@ ELLIPSE_LIST *r_ellipse_list_add_first(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *
 
 
 /* -------------------------------------------------------------------
- * ELLIPSE Data ꥹȤκǽɲ
+ * ELLIPSE Data をリストの最初に追加
  * 
  */
 ELLIPSE_LIST *ellipse_list_add_first(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_ellipse_list_info)
@@ -106,17 +106,17 @@ ELLIPSE_LIST *ellipse_list_add_first(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_
 	ELLIPSE_LIST *p;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_ellipse_list = (ELLIPSE_LIST *)xmalloc(sizeof(ELLIPSE_LIST));
-	/* ǡ (ellipse) 񤭹िΰݤ */
+	/* データ (ellipse) を書き込むための領域を確保する */
 	p_ellipse_list->ellipse = (ELLIPSE *)xmalloc(sizeof(ELLIPSE));
 
-	/* ݤΰ˥ǡ (ellipse) 񤭹 */
+	/* 確保した領域にデータ (ellipse) を書き込む */
 	*p_ellipse_list->ellipse = *add_ellipse;
 	p_ellipse_list->next = NULL;
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_ellipse_list_info->head == NULL && p_ellipse_list_info->tail == NULL) {
 		p_ellipse_list_info->head = p_ellipse_list;
@@ -124,7 +124,7 @@ ELLIPSE_LIST *ellipse_list_add_first(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_ellipse_list_info->head;
@@ -140,7 +140,7 @@ ELLIPSE_LIST *ellipse_list_add_first(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_
 
 
 /* -------------------------------------------------------------------
- * ELLIPSE Data ꥹȤκǽɲäơ Undo Baffer ˽
+ * ELLIPSE Data をリストの最初に追加して、 Undo Baffer に書込む
  *	
  */
 ELLIPSE_LIST *ellipse_list_add_first_with_undo(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_ellipse_list_info)
@@ -152,17 +152,17 @@ ELLIPSE_LIST *ellipse_list_add_first_with_undo(ELLIPSE *add_ellipse, ELLIPSE_LIS
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_ellipse_list = (ELLIPSE_LIST *)xmalloc(sizeof(ELLIPSE_LIST));
-	/* ǡ (ellipse) 񤭹िΰݤ */
+	/* データ (ellipse) を書き込むための領域を確保する */
 	p_ellipse_list->ellipse = (ELLIPSE *)xmalloc(sizeof(ELLIPSE));
 
-	/* ݤΰ˥ǡ (ellipse) 񤭹 */
+	/* 確保した領域にデータ (ellipse) を書き込む */
 	*p_ellipse_list->ellipse = *add_ellipse;
 	p_ellipse_list->next = NULL;
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_ellipse_list_info->head == NULL && p_ellipse_list_info->tail == NULL) {
 		p_ellipse_list_info->head = p_ellipse_list;
@@ -170,7 +170,7 @@ ELLIPSE_LIST *ellipse_list_add_first_with_undo(ELLIPSE *add_ellipse, ELLIPSE_LIS
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_ellipse_list_info->head;
@@ -191,7 +191,7 @@ ELLIPSE_LIST *ellipse_list_add_first_with_undo(ELLIPSE *add_ellipse, ELLIPSE_LIS
 
 
 /* -------------------------------------------------------------------
- * ELLIPSE Data ꥹȤκǸɲ
+ * ELLIPSE Data をリストの最後に追加
  * 
  */
 ELLIPSE_LIST *ellipse_list_add_last(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_ellipse_list_info)
@@ -199,17 +199,17 @@ ELLIPSE_LIST *ellipse_list_add_last(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_e
 	ELLIPSE_LIST *p;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_ellipse_list = (ELLIPSE_LIST *)xmalloc(sizeof(ELLIPSE_LIST));
-	/* ǡ (ellipse) 񤭹िΰݤ */
+	/* データ (ellipse) を書き込むための領域を確保する */
 	p_ellipse_list->ellipse = (ELLIPSE *)xmalloc(sizeof(ELLIPSE));
 
-	/* ݤΰ˥ǡ (ellipse) 񤭹 */
+	/* 確保した領域にデータ (ellipse) を書き込む */
 	*p_ellipse_list->ellipse = *add_ellipse;
 	p_ellipse_list->next = NULL;
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_ellipse_list_info->head == NULL && p_ellipse_list_info->tail == NULL) {
 		p_ellipse_list_info->head = p_ellipse_list;
@@ -217,7 +217,7 @@ ELLIPSE_LIST *ellipse_list_add_last(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_e
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_ellipse_list_info->head != NULL 
 				&& p_ellipse_list_info->tail != NULL 
@@ -227,7 +227,7 @@ ELLIPSE_LIST *ellipse_list_add_last(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_e
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_ellipse_list_info->tail;
@@ -235,7 +235,7 @@ ELLIPSE_LIST *ellipse_list_add_last(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_e
 		p->next = p_ellipse_list_info->tail;
 	}
 
-	/* ɥХåե˽ */
+	/* アンドゥバッファに書込む */
 //	undo_list_add_first(11, p_ellipse_list_info->tail, NULL);
 	return p_ellipse_list_info->tail;
 }
@@ -245,7 +245,7 @@ ELLIPSE_LIST *ellipse_list_add_last(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_e
 
 
 /* -------------------------------------------------------------------
- * ELLIPSE Data ꥹȤκǸɲá Undo Baffer ˽
+ * ELLIPSE Data をリストの最後に追加、 Undo Baffer に書込む
  *	
  */
 ELLIPSE_LIST *ellipse_list_add_last_with_undo(ELLIPSE *add_ellipse, ELLIPSE_LIST_INFO *p_ellipse_list_info)
@@ -257,17 +257,17 @@ ELLIPSE_LIST *ellipse_list_add_last_with_undo(ELLIPSE *add_ellipse, ELLIPSE_LIST
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_ellipse_list = (ELLIPSE_LIST *)xmalloc(sizeof(ELLIPSE_LIST));
-	/* ǡ (ellipse) 񤭹िΰݤ */
+	/* データ (ellipse) を書き込むための領域を確保する */
 	p_ellipse_list->ellipse = (ELLIPSE *)xmalloc(sizeof(ELLIPSE));
 
-	/* ݤΰ˥ǡ (ellipse) 񤭹 */
+	/* 確保した領域にデータ (ellipse) を書き込む */
 	*p_ellipse_list->ellipse = *add_ellipse;
 	p_ellipse_list->next = NULL;
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_ellipse_list_info->head == NULL && p_ellipse_list_info->tail == NULL) {
 		p_ellipse_list_info->head = p_ellipse_list;
@@ -275,7 +275,7 @@ ELLIPSE_LIST *ellipse_list_add_last_with_undo(ELLIPSE *add_ellipse, ELLIPSE_LIST
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_ellipse_list_info->head != NULL 
 				&& p_ellipse_list_info->tail != NULL 
@@ -285,7 +285,7 @@ ELLIPSE_LIST *ellipse_list_add_last_with_undo(ELLIPSE *add_ellipse, ELLIPSE_LIST
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_ellipse_list_info->tail;
@@ -306,7 +306,7 @@ ELLIPSE_LIST *ellipse_list_add_last_with_undo(ELLIPSE *add_ellipse, ELLIPSE_LIST
 
 
 /* -------------------------------------------------------------------
- * ELLIPSE Data κǽ (κǤϤʤ)
+ * ELLIPSE Data の削除機能 (メモリの削除ではない)
  * 
  */
 int ellipse_list_delete(ELLIPSE_LIST *del_List, ELLIPSE_LIST_INFO *p_ellipse_list_info)
@@ -315,38 +315,38 @@ int ellipse_list_delete(ELLIPSE_LIST *del_List, ELLIPSE_LIST_INFO *p_ellipse_lis
 	ELLIPSE_LIST *pb = NULL;
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_ellipse_list_info->head && del_List->next == NULL) {
 		p_ellipse_list_info->head = NULL;
 		p_ellipse_list_info->tail = NULL;
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_ellipse_list_info->head && del_List->next != NULL) {
 		p_ellipse_list_info->head = p_ellipse_list_info->head->next;
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_ellipse_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_ellipse_list_info->tail) {
 				pb->next = NULL;
 				p_ellipse_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_ellipse_list_info->head && del_List != p_ellipse_list_info->tail) {
 				pb->next = p->next;
 			}
@@ -366,7 +366,7 @@ int ellipse_list_delete(ELLIPSE_LIST *del_List, ELLIPSE_LIST_INFO *p_ellipse_lis
 
 
 /* -------------------------------------------------------------------
- * ELLIPSE Data κǽ (κǤϤʤUndo Buffer ذܤ)
+ * ELLIPSE Data の削除機能 (メモリの削除ではなく、Undo Buffer へ移す)
  * 
  */
 int ellipse_list_delete_Undo(ELLIPSE_LIST *del_List, ELLIPSE_LIST_INFO *p_ellipse_list_info)
@@ -378,38 +378,38 @@ int ellipse_list_delete_Undo(ELLIPSE_LIST *del_List, ELLIPSE_LIST_INFO *p_ellips
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_ellipse_list_info->head && del_List->next == NULL) {
 		p_ellipse_list_info->head = NULL;
 		p_ellipse_list_info->tail = NULL;
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_ellipse_list_info->head && del_List->next != NULL) {
 		p_ellipse_list_info->head = p_ellipse_list_info->head->next;
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_ellipse_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_ellipse_list_info->tail) {
 				pb->next = NULL;
 				p_ellipse_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_ellipse_list_info->head && del_List != p_ellipse_list_info->tail) {
 				pb->next = p->next;
 			}
@@ -434,24 +434,24 @@ int ellipse_list_delete_Undo(ELLIPSE_LIST *del_List, ELLIPSE_LIST_INFO *p_ellips
 
 
 /* -------------------------------------------------------------------
- * ELLIPSE Υݥ󥿤Υǡ Undo ХåեԽˤơ
- * ξ˿ǡ롣
+ * ELLIPSE のポインタのデータを Undo バッファ（編集）に入れて、
+ * その場所に新しいデータを入れる。
  *	
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  */
 ELLIPSE_LIST *ellipse_list_edit(ELLIPSE_LIST *point, ELLIPSE *change_ellipse, ELLIPSE_LIST_INFO *p_ellipse_list_info)
 {
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_ellipse_list = (ELLIPSE_LIST *)xmalloc(sizeof(ELLIPSE_LIST));
 
-	/* ǡ (ellipse) 񤭹िΰݤ */
+	/* データ (ellipse) を書き込むための領域を確保する */
 	p_ellipse_list->ellipse = (ELLIPSE *)xmalloc(sizeof(ELLIPSE));
 
-	/* ݤΰѹΥǡ (ellipse) 񤭹 */
+	/* 確保した領域に変更前のデータ (ellipse) を書き込む */
 	*p_ellipse_list->ellipse = *point->ellipse;
 	p_ellipse_list->next = point;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->ellipse = *change_ellipse;
 
 //	undo_list_add_first(13, p_ellipse_list, NULL);
@@ -463,10 +463,10 @@ ELLIPSE_LIST *ellipse_list_edit(ELLIPSE_LIST *point, ELLIPSE *change_ellipse, EL
 
 
 /* -------------------------------------------------------------------
- * ELLIPSE Υݥ󥿤Υǡ Undo ХåեԽˤơ
- * ξ˿ǡ졢Undo Baffer ˽
+ * ELLIPSE のポインタのデータを Undo バッファ（編集）に入れて、
+ * その場所に新しいデータを入れ、Undo Baffer に書込む
  *	
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  */
 ELLIPSE_LIST *ellipse_list_edit_with_undo(ELLIPSE_LIST *point, ELLIPSE *change_ellipse, ELLIPSE_LIST_INFO *p_ellipse_list_info)
 {
@@ -476,10 +476,10 @@ ELLIPSE_LIST *ellipse_list_edit_with_undo(ELLIPSE_LIST *point, ELLIPSE *change_e
 	LPDIAGRAM lpdiagram;
 
 
-	/* ݤΰѹΥǡ (ELLIPSE) 񤭹 */
+	/* 確保した領域に変更前のデータ (ELLIPSE) を書き込む */
 	ellipse = *point->ellipse;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->ellipse = *change_ellipse;
 
 	lpdiagram.ellipse_point = point->ellipse;
@@ -494,7 +494,7 @@ ELLIPSE_LIST *ellipse_list_edit_with_undo(ELLIPSE_LIST *point, ELLIPSE *change_e
 
 
 /* -------------------------------------------------------------------
- *	ꥹȤĴ٤
+ *	リストの総数を調べる
  */
 long ellipse_list_num(ELLIPSE_LIST_INFO *p_ellipse_list_info)
 {
@@ -504,12 +504,12 @@ long ellipse_list_num(ELLIPSE_LIST_INFO *p_ellipse_list_info)
 	p = p_ellipse_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL) {
 		i++;
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 	return i;
 }
@@ -519,7 +519,7 @@ long ellipse_list_num(ELLIPSE_LIST_INFO *p_ellipse_list_info)
 
 
 /* -------------------------------------------------------------------
- * n ܤΥǡθ
+ * n 番目のデータの検索
  * 
  */
 ELLIPSE_LIST *ellipse_search_num(long search_number, ELLIPSE_LIST_INFO *p_ellipse_list_info)
@@ -536,11 +536,11 @@ ELLIPSE_LIST *ellipse_search_num(long search_number, ELLIPSE_LIST_INFO *p_ellips
 		p = p->next;
 	}
 
-	/* n ܤΥǡΥɥ쥹֤ */
+	/* n 番目のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -551,9 +551,9 @@ ELLIPSE_LIST *ellipse_search_num(long search_number, ELLIPSE_LIST_INFO *p_ellips
 
 
 /* -------------------------------------------------------------------
- * ELLIPSE Υǡθ
+ * ELLIPSE のデータの検索
  * 
- *   ELLIPSE_LIST
+ * 戻値  ELLIPSE_LIST
  */
 ELLIPSE_LIST *ellipse_search_ellipse(ELLIPSE *p_ellipse, ELLIPSE_LIST_INFO *p_ellipse_list_info)
 {
@@ -566,11 +566,11 @@ ELLIPSE_LIST *ellipse_search_ellipse(ELLIPSE *p_ellipse, ELLIPSE_LIST_INFO *p_el
 		p = p->next;
 	}
 
-	/* p_ellipse ΥǡΥɥ쥹֤ */
+	/* p_ellipse のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -581,9 +581,9 @@ ELLIPSE_LIST *ellipse_search_ellipse(ELLIPSE *p_ellipse, ELLIPSE_LIST_INFO *p_el
 
 
 /* -------------------------------------------------------------------
- * ELLIPSE Υǡθ
+ * ELLIPSE のデータの検索
  * 
- *   long
+ * 戻値  long
  */
 long ellipse_search_ellipse_to_num(ELLIPSE *p_ellipse, ELLIPSE_LIST_INFO *p_ellipse_list_info)
 {
@@ -598,11 +598,11 @@ long ellipse_search_ellipse_to_num(ELLIPSE *p_ellipse, ELLIPSE_LIST_INFO *p_elli
 		i++;
 	}
 
-	/* p_ellipse ΥǡΥɥ쥹֤ */
+	/* p_ellipse のデータのアドレスを返す */
 	if (p != NULL) {
 		return i;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return 0;
 	}
@@ -613,7 +613,7 @@ long ellipse_search_ellipse_to_num(ELLIPSE *p_ellipse, ELLIPSE_LIST_INFO *p_elli
 
 
 /* -------------------------------------------------------------------
- *	ELLIPSE Data ꥹȤ
+ *	ELLIPSE Data をリストから削除
  */
 int ellipse_list_free(ELLIPSE_LIST *del_List, ELLIPSE_LIST_INFO *p_ellipse_list_info)
 {
@@ -627,39 +627,39 @@ int ellipse_list_free(ELLIPSE_LIST *del_List, ELLIPSE_LIST_INFO *p_ellipse_list_
 	}
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_ellipse_list_info->head && del_List->next == NULL) {
 		p_ellipse_list_info->head = NULL;
 		p_ellipse_list_info->tail = NULL;
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_ellipse_list_info->head && del_List->next != NULL) {
 		p_ellipse_list_info->head = p_ellipse_list_info->head->next;
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_ellipse_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_ellipse_list_info->tail) {
 				pb->next = NULL;
 				p_ellipse_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_ellipse_list_info->head && del_List != p_ellipse_list_info->tail) {
 				pb->next = p->next;
 			}
@@ -679,13 +679,13 @@ int ellipse_list_free(ELLIPSE_LIST *del_List, ELLIPSE_LIST_INFO *p_ellipse_list_
 
 
 /* -------------------------------------------------------------------
- *	ꥹȤ
+ *	全リストを削除
  */
 void ellipse_list_all_free(ELLIPSE_LIST_INFO *p_ellipse_list_info)
 {
 	while(p_ellipse_list_info->head != NULL) {
 		if (ellipse_list_free(p_ellipse_list_info->head, p_ellipse_list_info) == 0) {
-			g_print("List_ellipse.c : ellipse_list_all_free() : ellipse_list_free() ǥ顼\n");
+			g_print("List_ellipse.c : ellipse_list_all_free() : ellipse_list_free() でエラー\n");
 			g_print("%s : %d : ellipse_list_all_free() : ERROR\n", __FILE__, __LINE__);
 		}
 	}
@@ -700,13 +700,13 @@ void ellipse_list_print(ELLIPSE_LIST_INFO *p_ellipse_list_info)
 	ELLIPSE_LIST *p;
 	int i = 0;
 
-	g_print("----- ELLIPSE ꥹȤɽ -----\n");
+	g_print("----- ELLIPSE リストを表示 -----\n");
 	p = p_ellipse_list_info->head;
 	while (p != NULL) {
 		i++;
 		g_print("%d(0x%x) : layer[%d] : color[%d] : style[0x%x]\n", 
 					i, (int)p->ellipse, p->ellipse->layer, (int)p->ellipse->color, p->ellipse->style);
-		g_print("    濴(%f,%f) Ĺΰ(%f,%f) [ûΡ %f] [ϳ %f] [λ %f]\n", 
+		g_print("    中心(%f,%f) 長軸の位置(%f,%f) [短軸の％ %f] [開始角 %f] [終了角 %f]\n", 
 					p->ellipse->cx, p->ellipse->cy, p->ellipse->dx, p->ellipse->dy, 
 					p->ellipse->k, p->ellipse->sa, p->ellipse->ea);
 		p = p->next;
@@ -719,7 +719,7 @@ void ellipse_list_print(ELLIPSE_LIST_INFO *p_ellipse_list_info)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : List_Ellipse.c
