@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/01/05
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/08
  * ====================================================================
  */
 
@@ -39,25 +39,25 @@ int init_polyline(POLYLINE *polyline)
 {
 	polyline->layer = 0;
 	/* -------------------------------------------
-	 *	8  : ݥ饤
-	 * 16  : ץ饤
-	 * 32  : ¥ץ饤
-	 *(64) : ٥
+	 *	8  : ポリライン
+	 * 16  : スプライン補間
+	 * 32  : ３次Ｂスプライン曲線
+	 *(64) : ベジェ曲線
 	 */
 	polyline->code = 1;
-	/*  */
+	/* 線種 */
 	polyline->style = 1;
-	/*  */
+	/* 色 */
 	polyline->color = 0xffffff;
-	/* ʬ */
+	/* 分割数 */
 	polyline->split = 7;
-	/* ԥå */
+	/* ピッチ */
 	polyline->pitch = 0.05;
-	/* ե饰 */
+	/* フラグ */
 	polyline->frag = 0;
-	/* ĺο */
+	/* 頂点の数 */
 	polyline->index = 0;
-	/* ĺΥǡ */
+	/* 頂点のデータ */
 	polyline->vertex_list_info.head = NULL;
 	polyline->vertex_list_info.tail = NULL;
 	return 1;
@@ -68,25 +68,25 @@ int init_polyline(POLYLINE *polyline)
 
 
 /* -------------------------------------------------------------------
- * POLYLINE Data ꥹȤκǽɲ
+ * POLYLINE Data をリストの最初に追加
  *	
- * ǡ (vertex) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (vertex) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 POLYLINE_LIST *r_polyline_list_add_first(POLYLINE *add_polyline, POLYLINE_LIST_INFO *p_polyline_list_info)
 {
 	POLYLINE_LIST *p;
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_polyline_list = (POLYLINE_LIST *)xmalloc(sizeof(POLYLINE_LIST));
 
-	/* ݤΰ˥ǡ (polyline) 񤭹 */
+	/* 確保した領域にデータ (polyline) を書き込む */
 	p_polyline_list->polyline = add_polyline;
 	p_polyline_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_polyline_list_info->head == NULL && p_polyline_list_info->tail == NULL) {
 		p_polyline_list_info->head = p_polyline_list;
@@ -94,7 +94,7 @@ POLYLINE_LIST *r_polyline_list_add_first(POLYLINE *add_polyline, POLYLINE_LIST_I
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_polyline_list_info->head;
@@ -110,28 +110,28 @@ POLYLINE_LIST *r_polyline_list_add_first(POLYLINE *add_polyline, POLYLINE_LIST_I
 
 
 /* -------------------------------------------------------------------
- * POLYLINE Data ꥹȤκǽɲ
+ * POLYLINE Data をリストの最初に追加
  * 
- * ǡ (vertex) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (vertex) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 POLYLINE_LIST *polyline_list_add_first(POLYLINE *add_polyline, POLYLINE_LIST_INFO *p_polyline_list_info)
 {
 	POLYLINE_LIST *p;
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_polyline_list = (POLYLINE_LIST *)xmalloc(sizeof(POLYLINE_LIST));
 
-	/* ǡ (polyline) 񤭹िΰݤ */
+	/* データ (polyline) を書き込むための領域を確保する */
 	p_polyline_list->polyline = (POLYLINE *)xmalloc(sizeof(POLYLINE));
 
-	/* ݤΰ˥ǡ (polyline) 񤭹 */
+	/* 確保した領域にデータ (polyline) を書き込む */
 	*p_polyline_list->polyline = *add_polyline;
 	p_polyline_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ
+	 * head & tail の両方が NULL のときは、１個もデータがない
 	 */
 	if (p_polyline_list_info->head == NULL && p_polyline_list_info->tail == NULL) {
 		p_polyline_list_info->head = p_polyline_list;
@@ -139,7 +139,7 @@ POLYLINE_LIST *polyline_list_add_first(POLYLINE *add_polyline, POLYLINE_LIST_INF
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_polyline_list_info->head;
@@ -155,10 +155,10 @@ POLYLINE_LIST *polyline_list_add_first(POLYLINE *add_polyline, POLYLINE_LIST_INF
 
 
 /* ---------------------------------------------------------
- * POLYLINE Data ꥹȤκǽɲäơ Undo Baffer ˽
+ * POLYLINE Data をリストの最初に追加して、 Undo Baffer に書込む
  *	
- * ǡ (vertex) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (vertex) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 POLYLINE_LIST *polyline_list_add_first_with_undo(POLYLINE *add_polyline, POLYLINE_LIST_INFO *p_polyline_list_info)
 {
@@ -169,19 +169,19 @@ POLYLINE_LIST *polyline_list_add_first_with_undo(POLYLINE *add_polyline, POLYLIN
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_polyline_list = (POLYLINE_LIST *)xmalloc(sizeof(POLYLINE_LIST));
 
-	/* ǡ (polyline) 񤭹िΰݤ */
+	/* データ (polyline) を書き込むための領域を確保する */
 	p_polyline_list->polyline = (POLYLINE *)xmalloc(sizeof(POLYLINE));
 
-	/* ݤΰ˥ǡ (polyline) 񤭹 */
+	/* 確保した領域にデータ (polyline) を書き込む */
 	*p_polyline_list->polyline = *add_polyline;
 	p_polyline_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_polyline_list_info->head == NULL && p_polyline_list_info->tail == NULL) {
 		p_polyline_list_info->head = p_polyline_list;
@@ -189,7 +189,7 @@ POLYLINE_LIST *polyline_list_add_first_with_undo(POLYLINE *add_polyline, POLYLIN
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_polyline_list_info->head;
@@ -211,29 +211,29 @@ POLYLINE_LIST *polyline_list_add_first_with_undo(POLYLINE *add_polyline, POLYLIN
 
 
 /* -------------------------------------------------------------------
- * POLYLINE Data ꥹȤκǸɲ
+ * POLYLINE Data をリストの最後に追加
  * 
- * ǡ (vertex) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (vertex) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 POLYLINE_LIST *polyline_list_add_last(POLYLINE *add_polyline, POLYLINE_LIST_INFO *p_polyline_list_info)
 {
 	POLYLINE_LIST *p;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_polyline_list = (POLYLINE_LIST *)xmalloc(sizeof(POLYLINE_LIST));
 
-	/* ǡ (polyline) 񤭹िΰݤ */
+	/* データ (polyline) を書き込むための領域を確保する */
 	p_polyline_list->polyline = (POLYLINE *)xmalloc(sizeof(POLYLINE));
 
-	/* ݤΰ˥ǡ (polyline) 񤭹 */
+	/* 確保した領域にデータ (polyline) を書き込む */
 	*p_polyline_list->polyline = *add_polyline;
 	p_polyline_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_polyline_list_info->head == NULL && p_polyline_list_info->tail == NULL) {
 		p_polyline_list_info->head = p_polyline_list;
@@ -241,7 +241,7 @@ POLYLINE_LIST *polyline_list_add_last(POLYLINE *add_polyline, POLYLINE_LIST_INFO
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_polyline_list_info->head != NULL 
 				&& p_polyline_list_info->tail != NULL 
@@ -251,7 +251,7 @@ POLYLINE_LIST *polyline_list_add_last(POLYLINE *add_polyline, POLYLINE_LIST_INFO
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_polyline_list_info->tail;
@@ -259,7 +259,7 @@ POLYLINE_LIST *polyline_list_add_last(POLYLINE *add_polyline, POLYLINE_LIST_INFO
 		p->next = p_polyline_list_info->tail;
 	}
 
-	/* ɥХåե˽ */
+	/* アンドゥバッファに書込む */
 //	undo_list_add_first(11, p_polyline_list_info->tail, NULL);
 	return p_polyline_list_info->tail;
 }
@@ -269,10 +269,10 @@ POLYLINE_LIST *polyline_list_add_last(POLYLINE *add_polyline, POLYLINE_LIST_INFO
 
 
 /* ---------------------------------------------------------
- * POLYLINE Data ꥹȤκǸɲá Undo Baffer ˽
+ * POLYLINE Data をリストの最後に追加、 Undo Baffer に書込む
  *	
- * ǡ (vertex) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (vertex) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 POLYLINE_LIST *polyline_list_add_last_with_undo(POLYLINE *add_polyline, POLYLINE_LIST_INFO *p_polyline_list_info)
 {
@@ -283,19 +283,19 @@ POLYLINE_LIST *polyline_list_add_last_with_undo(POLYLINE *add_polyline, POLYLINE
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_polyline_list = (POLYLINE_LIST *)xmalloc(sizeof(POLYLINE_LIST));
 
-	/* ǡ (polyline) 񤭹िΰݤ */
+	/* データ (polyline) を書き込むための領域を確保する */
 	p_polyline_list->polyline = (POLYLINE *)xmalloc(sizeof(POLYLINE));
 
-	/* ݤΰ˥ǡ (polyline) 񤭹 */
+	/* 確保した領域にデータ (polyline) を書き込む */
 	*p_polyline_list->polyline = *add_polyline;
 	p_polyline_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_polyline_list_info->head == NULL && p_polyline_list_info->tail == NULL) {
 		p_polyline_list_info->head = p_polyline_list;
@@ -303,7 +303,7 @@ POLYLINE_LIST *polyline_list_add_last_with_undo(POLYLINE *add_polyline, POLYLINE
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_polyline_list_info->head != NULL 
 				&& p_polyline_list_info->tail != NULL 
@@ -313,7 +313,7 @@ POLYLINE_LIST *polyline_list_add_last_with_undo(POLYLINE *add_polyline, POLYLINE
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_polyline_list_info->tail;
@@ -335,7 +335,7 @@ POLYLINE_LIST *polyline_list_add_last_with_undo(POLYLINE *add_polyline, POLYLINE
 
 
 /* -------------------------------------------------------------------
- * POLYLINE Data κǽ (κǤϤʤ)
+ * POLYLINE Data の削除機能 (メモリの削除ではない)
  * 
  */
 int polyline_list_delete(POLYLINE_LIST *del_List, POLYLINE_LIST_INFO *p_polyline_list_info)
@@ -345,41 +345,41 @@ int polyline_list_delete(POLYLINE_LIST *del_List, POLYLINE_LIST_INFO *p_polyline
 	long i;
 
 	/* -------------------------------------------
-	 * ݥ󥿤ΥǡΤꤿΤǡ
-	 * head (ꥹȤƬ) ݥ󥿤
-	 * ĤޤǷ֤Υǡõ
+	 * 削除するポインタの前のデータを知りたいので、
+	 * head (リストの先頭) から削除するポインタが
+	 * 見つかるまで繰り返し、前のデータを探す。
 	 */
 	p = p_polyline_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL && p != del_List) {
 		if (i == 0) i++;
-		pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pb = p;			/* 前のデータのポインタとして保存しておく */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 
-	/* Ĥä (p  NULL ǤϤʤȤ) */
+	/* 見つかった場合 (p が NULL ではないとき) */
 	if(p != NULL){
-		/* ƬΥǡ (i = 0 ΤȤ) */
+		/* 先頭のデータ (i = 0 のとき) */
 		if (i == 0) {
-			/* ƬΥǡĤʤ(ΥǡΥݥ󥿤 NULL) */
+			/* 先頭のデータ１個しかない場合(次のデータのポインタが NULL) */
 			if (p->next == NULL) {
 				p_polyline_list_info->head = NULL;
 				p_polyline_list_info->tail = NULL;
 			}
-			/* İʾǡȤ */
+			/* ２個以上データがあるとき */
 			else 
 				p_polyline_list_info->head = p->next;
 		}
 
-		/* ǸΥǡΤȤ (p->next = NULL) */
+		/* 最後のデータのとき (p->next = NULL) */
 		else if (p->next == NULL) pb->next = NULL;
 
-		/* ֤Υǡ (ξʳ) */
+		/* 中間のデータ (上の条件以外) */
 		else pb->next = p->next;
 		polyline_list_free(del_List, p_polyline_list_info);
 		return 1;
@@ -392,7 +392,7 @@ int polyline_list_delete(POLYLINE_LIST *del_List, POLYLINE_LIST_INFO *p_polyline
 
 
 /* -------------------------------------------------------------------
- * POLYLINE Data κǽ (κǤϤʤUndo Buffer ذܤ)
+ * POLYLINE Data の削除機能 (メモリの削除ではなく、Undo Buffer へ移す)
  * 
  */
 int polyline_list_delete_Undo(POLYLINE_LIST *del_List, POLYLINE_LIST_INFO *p_polyline_list_info)
@@ -406,41 +406,41 @@ int polyline_list_delete_Undo(POLYLINE_LIST *del_List, POLYLINE_LIST_INFO *p_pol
 
 
 	/* -------------------------------------------
-	 * ݥ󥿤ΥǡΤꤿΤǡ
-	 * head (ꥹȤƬ) ݥ󥿤
-	 * ĤޤǷ֤Υǡõ
+	 * 削除するポインタの前のデータを知りたいので、
+	 * head (リストの先頭) から削除するポインタが
+	 * 見つかるまで繰り返し、前のデータを探す。
 	 */
 	p = p_polyline_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL && p != del_List) {
 		i++;
-		pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pb = p;			/* 前のデータのポインタとして保存しておく */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 
-	/* Ĥä (p  NULL ǤϤʤȤ) */
+	/* 見つかった場合 (p が NULL ではないとき) */
 	if(p != NULL){
-		/* ƬΥǡ (i = 0 ΤȤ) */
+		/* 先頭のデータ (i = 0 のとき) */
 		if (i == 0) {
-			/* ƬΥǡĤʤ(ΥǡΥݥ󥿤 NULL) */
+			/* 先頭のデータ１個しかない場合(次のデータのポインタが NULL) */
 			if (p->next == NULL) {
 				p_polyline_list_info->head = NULL;
 				p_polyline_list_info->tail = NULL;
 			}
-			/* İʾǡȤ */
+			/* ２個以上データがあるとき */
 			else 
 				p_polyline_list_info->head = p->next;
 		}
 
-		/* ǸΥǡΤȤ (p->next = NULL) */
+		/* 最後のデータのとき (p->next = NULL) */
 		else if (p->next == NULL) pb->next = NULL;
 
-		/* ֤Υǡ (ξʳ) */
+		/* 中間のデータ (上の条件以外) */
 		else pb->next = p->next;
 
 		lpdiagram.polyline_point = del_List->polyline;
@@ -459,27 +459,27 @@ int polyline_list_delete_Undo(POLYLINE_LIST *del_List, POLYLINE_LIST_INFO *p_pol
 
 
 /* ---------------------------------------------------------
- * POLYLINE Υݥ󥿤Υǡ Undo ХåեԽˤơ
- * ξ˿ǡ롣
+ * POLYLINE のポインタのデータを Undo バッファ（編集）に入れて、
+ * その場所に新しいデータを入れる。
  * 
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  * 
- * ǡ (vertex) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (vertex) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 POLYLINE_LIST *polyline_list_edit(POLYLINE_LIST *point, POLYLINE *change_polyline, POLYLINE_LIST_INFO *p_polyline_list_info)
 {
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_polyline_list = (POLYLINE_LIST *)xmalloc(sizeof(POLYLINE_LIST));
 
-	/* ǡ (polyline) 񤭹िΰݤ */
+	/* データ (polyline) を書き込むための領域を確保する */
 	p_polyline_list->polyline = (POLYLINE *)xmalloc(sizeof(POLYLINE));
 
-	/* ݤΰѹΥǡ (polyline) 񤭹 */
+	/* 確保した領域に変更前のデータ (polyline) を書き込む */
 	*p_polyline_list->polyline = *point->polyline;
 //	p_polyline_list->next = point;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->polyline = *change_polyline;
 
 //	undo_list_add_first(13, p_polyline_list, NULL);
@@ -491,13 +491,13 @@ POLYLINE_LIST *polyline_list_edit(POLYLINE_LIST *point, POLYLINE *change_polylin
 
 
 /* ---------------------------------------------------------
- * POLYLINE ѹΥǡ(point) Undo ХåեԽˤơ
- * ξ˿ǡ(change_polyline)졢Undo Baffer ˽
+ * POLYLINE の変更前のデータ(point)を Undo バッファ（編集）に入れて、
+ * その場所に新しいデータ(change_polyline)を入れ、Undo Baffer に書込む
  *	
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  *	
- * ǡ (vertex) 񤭹िΰϡ
- * ݤƤΤǲƳݤɬפʤ
+ * データ (vertex) を書き込むための領域は、ここに来る前に
+ * 確保されているので改めて確保する必要ない。
  */
 POLYLINE_LIST *polyline_list_edit_with_undo(POLYLINE_LIST *point, POLYLINE *change_polyline, POLYLINE_LIST_INFO *p_polyline_list_info)
 {
@@ -507,10 +507,10 @@ POLYLINE_LIST *polyline_list_edit_with_undo(POLYLINE_LIST *point, POLYLINE *chan
 	LPDIAGRAM lpdiagram;
 
 
-	/* ݤΰѹΥǡ (POLYLINE) 񤭹 */
+	/* 確保した領域に変更前のデータ (POLYLINE) を書き込む */
 	polyline = *point->polyline;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->polyline = *change_polyline;
 
 
@@ -526,7 +526,7 @@ POLYLINE_LIST *polyline_list_edit_with_undo(POLYLINE_LIST *point, POLYLINE *chan
 
 
 /* -------------------------------------------------------------------
- * ꥹȤĴ٤
+ * リストの総数を調べる
  */
 long polyline_list_num(POLYLINE_LIST_INFO *p_polyline_list_info)
 {
@@ -536,12 +536,12 @@ long polyline_list_num(POLYLINE_LIST_INFO *p_polyline_list_info)
 	p = p_polyline_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL) {
 		i++;
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 	return i;
 }
@@ -551,7 +551,7 @@ long polyline_list_num(POLYLINE_LIST_INFO *p_polyline_list_info)
 
 
 /* -------------------------------------------------------------------
- * n ܤΥǡθ
+ * n 番目のデータの検索
  *	
  */
 POLYLINE_LIST *polyline_search_num(long search_number, POLYLINE_LIST_INFO *p_polyline_list_info)
@@ -567,11 +567,11 @@ POLYLINE_LIST *polyline_search_num(long search_number, POLYLINE_LIST_INFO *p_pol
 		p = p->next;
 	}
 
-	/* n ܤΥǡΥɥ쥹֤ */
+	/* n 番目のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -582,9 +582,9 @@ POLYLINE_LIST *polyline_search_num(long search_number, POLYLINE_LIST_INFO *p_pol
 
 
 /* -------------------------------------------------------------------
- * POLYLINE Υǡθ
+ * POLYLINE のデータの検索
  *	
- *   POLYLINE_LIST
+ * 戻値  POLYLINE_LIST
  */
 POLYLINE_LIST *polyline_search_polyline(POLYLINE *p_polyline, POLYLINE_LIST_INFO *p_polyline_list_info)
 {
@@ -596,11 +596,11 @@ POLYLINE_LIST *polyline_search_polyline(POLYLINE *p_polyline, POLYLINE_LIST_INFO
 		p = p->next;
 	}
 
-	/* p_polyline ΥǡΥɥ쥹֤ */
+	/* p_polyline のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -611,9 +611,9 @@ POLYLINE_LIST *polyline_search_polyline(POLYLINE *p_polyline, POLYLINE_LIST_INFO
 
 
 /* -------------------------------------------------------------------
- * POLYLINE Υǡθ
+ * POLYLINE のデータの検索
  *	
- *   long
+ * 戻値  long
  */
 long polyline_search_polyline_to_num(POLYLINE *p_polyline, POLYLINE_LIST_INFO *p_polyline_list_info)
 {
@@ -628,11 +628,11 @@ long polyline_search_polyline_to_num(POLYLINE *p_polyline, POLYLINE_LIST_INFO *p
 		i++;
 	}
 
-	/* p_polyline ΥǡΥɥ쥹֤ */
+	/* p_polyline のデータのアドレスを返す */
 	if (p != NULL) {
 		return i;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return 0;
 	}
@@ -643,7 +643,7 @@ long polyline_search_polyline_to_num(POLYLINE *p_polyline, POLYLINE_LIST_INFO *p
 
 
 /* -------------------------------------------------------------------
- * POLYLINE Data ꥹȤ
+ * POLYLINE Data をリストから削除
  */
 int polyline_list_free(POLYLINE_LIST *del_List, POLYLINE_LIST_INFO *p_polyline_list_info)
 {
@@ -656,47 +656,47 @@ int polyline_list_free(POLYLINE_LIST *del_List, POLYLINE_LIST_INFO *p_polyline_l
 		//g_print ("List_PolyLine.c : polyline_list_free() : del_List = PolyLineStartData\n");
 	}
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_polyline_list_info->head && del_List->next == NULL) {
 		p_polyline_list_info->head = NULL;
 		p_polyline_list_info->tail = NULL;
-		//g_print("ǡƬǣĤ\n");
+		//g_print("データが先頭で１個だけ\n");
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_polyline_list_info->head && del_List->next != NULL) {
 		p_polyline_list_info->head = p_polyline_list_info->head->next;
-		//g_print("ǡƬǣİʾ\n");
+		//g_print("データが先頭で２個以上\n");
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_polyline_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_polyline_list_info->tail) {
 				pb->next = NULL;
 				p_polyline_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_polyline_list_info->head && del_List != p_polyline_list_info->tail) {
 				pb->next = p->next;
 			}
 		}
 		else {
-			//g_print("ꥹȤ POLYLINE ǡǤϤʤ\n");
+			//g_print("リストの POLYLINE データではない\n");
 			return 0;
 		}
 	}
@@ -712,7 +712,7 @@ int polyline_list_free(POLYLINE_LIST *del_List, POLYLINE_LIST_INFO *p_polyline_l
 
 
 /* -------------------------------------------------------------------
- * ꥹȤ
+ * 全リストを削除
  */
 void polyline_list_all_free(POLYLINE_LIST_INFO *p_polyline_list_info)
 {
@@ -726,7 +726,7 @@ void polyline_list_all_free(POLYLINE_LIST_INFO *p_polyline_list_info)
 
 
 /* ---------------------------------------------------------
- * POLYLINE_LIST Υǡ log
+ * POLYLINE_LIST のデータ log
  *	
  */
 void polyline_list_log(POLYLINE_LIST_INFO *p_polyline_list_info)
@@ -738,7 +738,7 @@ void polyline_list_log(POLYLINE_LIST_INFO *p_polyline_list_info)
 	POLYLINE_LIST *p;
 	long i = 0;
 
-	g_print("----- POLYLINE ꥹȤɽ -----\n");
+	g_print("----- POLYLINE リストを表示 -----\n");
 	p = p_polyline_list_info->head;
 	while( p != NULL) {
 		i++;
@@ -759,7 +759,7 @@ void polyline_list_log(POLYLINE_LIST_INFO *p_polyline_list_info)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : List_polyline.c
