@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/01/16
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/08
  * ====================================================================
  */
 
@@ -43,18 +43,18 @@
 
 
 /* -------------------------------------------------------------------
- * Undo_index 򥤥󥯥Ȥ
+ * Undo_index をインクリメントする
  * -------------------------------------------------------------------
- * Undo/Redo ΤȤϡ޷񤯤Τ
- * ʹߤ Redo Ϻ
+ * Undo/Redo の途中のときは、新しい図形を書くので
+ * それ以降の Redo 情報は削除される
  *	
  * -------------------------------------------------------------------
  */
 void undo_index_plus(void)
 {
-	/* Undo/Redo ǿ޷򤷤Ȥ */
+	/* Undo/Redo の途中で新しい図形の操作をしたとき */
 	if (Undo_index + 1 != Undo_Now) {
-		/* Undo_Now ʹߤ index  Undo Buffer  */
+		/* Undo_Now 以降の index を持つ Undo Buffer を削除する */
 		Redo_Delete();
 		Undo_index = Undo_Now - 1;
 	}
@@ -69,16 +69,16 @@ void undo_index_plus(void)
 
 
 /* -------------------------------------------------------------------
- * Undo  CAD or Dimension  Data ꥹȤκǽɲ
+ * Undo  CAD or Dimension  Data をリストの最初に追加
  * -------------------------------------------------------------------
- * ѿ Undo_index ϤδؿγǤ餫ꤷƤ
+ * 外部変数 Undo_index はこの関数の外であらかじめ設定しておくこと
  *	
- * type : 11 : CAD_NEW  : CAD Data οεϿ
- *		: 12 : CAD_DEL  : CAD Data κεϿ
- *		: 13 : CAD_EDIT : CAD Data ԽεϿ
- *  : 21 : DIMENSION_NEW  : Dimension Data οεϿ
- *		: 22 : DIMENSION_DEL  : Dimension Data κεϿ
- *		: 23 : DIMENSION_EDIT : Dimension Data ԽεϿ
+ * type : 11 : CAD_NEW  : CAD Data の新規作成の記録
+ *		: 12 : CAD_DEL  : CAD Data の削除の記録
+ *		: 13 : CAD_EDIT : CAD Data の編集の記録
+ * 　　 : 21 : DIMENSION_NEW  : Dimension Data の新規作成の記録
+ *		: 22 : DIMENSION_DEL  : Dimension Data の削除の記録
+ *		: 23 : DIMENSION_EDIT : Dimension Data の編集の記録
  * -------------------------------------------------------------------
  */
 int undo_list_add_first(int type, LPDIAGRAM diagram_point, DIAGRAM diagram)
@@ -87,28 +87,28 @@ int undo_list_add_first(int type, LPDIAGRAM diagram_point, DIAGRAM diagram)
 //	int i;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_undo_list = (UNDO_LIST *)xmalloc(sizeof(UNDO_LIST));
 
 	/* -----------------------------------------------------
-	 * ΤȤϺǡؤɥ쥹
+	 * 新規のときは作成したデータを指すアドレス
 	 * 
-	 * ΤȤϺǡؤɥ쥹
-	 * (ºݤ˺˥ǡ Undo Buffer ˰ܤ)
+	 * 削除のときは削除したデータを指すアドレス
+	 * (実際に削除せずにデータを Undo Buffer に移す)
 	 * 
-	 * ԽΤȤϡΥǡѹ˿ǡ
-	 * ãĥǡꥹȤ夨롣
-	 * ơΥǡ򥢥ɥꥹȤ롣
-	 * κݡnext ˤϿǡΥɥ쥹Ƥ
+	 * 編集のときは、前のデータを変更せずに新しいデータを作成して
+	 * ＣＡＤデータリストを入れ代える。
+	 * そして、前のデータをアンドゥリストに入れる。
+	 * その際、next には新しいデータのアドレスを入れておく。
 	 */
 
-	/* ݤΰ˥ǡ (undo) 񤭹 */
+	/* 確保した領域にデータ (undo) を書き込む */
 	p_undo_list->type = type;
 	p_undo_list->index = Undo_index;
 	p_undo_list->next = NULL;
 
 
-	/*  */
+	/* 新規 */
 	if (type == CAD_NEW) {
 		p_undo_list->diagram_point.cad_point = diagram_point.cad_point;
 		p_undo_list->diagram.cad = diagram.cad;
@@ -135,7 +135,7 @@ int undo_list_add_first(int type, LPDIAGRAM diagram_point, DIAGRAM diagram)
 	}
 
 
-	/*  */
+	/* 削除 */
 	else if (type == CAD_DEL) {
 		p_undo_list->diagram_point.cad_point = diagram_point.cad_point;
 		p_undo_list->diagram.cad = diagram.cad;
@@ -162,7 +162,7 @@ int undo_list_add_first(int type, LPDIAGRAM diagram_point, DIAGRAM diagram)
 	}
 
 
-	/* Խ */
+	/* 編集 */
 	else if (type == CAD_EDIT) {
 		p_undo_list->diagram_point.cad_point = diagram_point.cad_point;
 		p_undo_list->diagram.cad = diagram.cad;
@@ -196,14 +196,14 @@ int undo_list_add_first(int type, LPDIAGRAM diagram_point, DIAGRAM diagram)
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (undo_list_info.head == NULL && undo_list_info.tail == NULL) {
 		undo_list_info.head = p_undo_list;
 		undo_list_info.tail = p_undo_list;
 	}
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = undo_list_info.head;
@@ -218,10 +218,10 @@ int undo_list_add_first(int type, LPDIAGRAM diagram_point, DIAGRAM diagram)
 
 
 /* -------------------------------------------------------------------
- * Redo 
+ * Redo を削除する
  * -------------------------------------------------------------------
- * Undo/Redo ΤȤϡ޷񤯤Τ
- * (Undo_Now)ʹߤ Redo Ϻ
+ * Undo/Redo の途中のときは、新しい図形を書くので
+ * それ(Undo_Now)以降の Redo 情報は削除する
  *	
  * -------------------------------------------------------------------
  */
@@ -247,7 +247,7 @@ void Redo_Delete(void)
 
 
 /* -------------------------------------------------------------------
- *  index Ʊǽ Undo_index õ, Undo Buffer Υݥ󥿤֤	
+ * 引数 index と同じ最初の Undo_index を探し,その Undo Buffer のポインタを返す	
  * 
  */
 UNDO_LIST *search_list_undo_start(long index)
@@ -256,11 +256,11 @@ UNDO_LIST *search_list_undo_start(long index)
 
 	p = undo_list_info.head;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while( p != NULL && p->index > index ) {
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 	if (p != NULL && p->next != NULL) {
@@ -276,7 +276,7 @@ UNDO_LIST *search_list_undo_start(long index)
 
 
 /* -------------------------------------------------------------------
- *  index ƱǸ Undo_index õ, Undo Buffer Υݥ󥿤֤	
+ * 引数 index と同じ最後の Undo_index を探し,その Undo Buffer のポインタを返す	
  * 
  */
 UNDO_LIST *search_list_undo_end(long index)
@@ -287,12 +287,12 @@ UNDO_LIST *search_list_undo_end(long index)
 
 	p = undo_list_info.head;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while( p != NULL && p->index >= index ) {
 		pb = p;
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 	if (pb != NULL) {
@@ -310,13 +310,13 @@ UNDO_LIST *search_list_undo_end(long index)
 /* -------------------------------------------------------------------
  * Undo
  * -------------------------------------------------------------------
- * ɥ¹
+ * アンドゥ実行
  *	
- *	 ɥϡޤ Undo_Now  -1 ˤơʣޤϣĤ Undo_Now 
- * Ʊֹ index Фƽ¹Ԥ롣
- *	 ĤΥǡФơºݤν򤹤ΤϡUndoRedo() ؿǤϡ
- * ɥǽؿƱ
- *	 ɥϡindex Ǥ⡢夫äǡ򤹤롣(ɥϡ)
+ *	 アンドゥは、まず先に Undo_Now を -1 にして、複数または１個ある Undo_Now と
+ * 同じ番号の index に対して処理を実行する。
+ *	 １個のデータに対して、実際の処理をするのは、UndoRedo() 関数でこれは、
+ * リドゥで処理する関数と同じ。
+ *	 アンドゥは、index の中でも、後から入ったデータから処理をする。(リドゥは、逆)
  * -------------------------------------------------------------------
  */
 int Undo(void)
@@ -326,18 +326,18 @@ int Undo(void)
 	UNDO_LIST *p_end;
 
 
-	/* Undo ϡ1 礭ʤм¹ԤǤʤ */
+	/* Undo は、1 よりも大きくなければ実行できない */
 	if (1 < Undo_Now) Undo_Now--;
 	else return 0;
 
 
-	/* index κǽΥɥ쥹õ */
+	/* index の最初のアドレスを探す */
 	p_start = search_list_undo_start(Undo_Now);
-	/* index κǸΥɥ쥹õ */
+	/* index の最後のアドレスを探す */
 	p_end = search_list_undo_end(Undo_Now);
 
 
-	/* index ĤΤȤ */
+	/* index が１個だけのとき */
 	if (p_start == p_end) {
 		UndoRedo(p_start);
 	}
@@ -348,12 +348,12 @@ int Undo(void)
 
 
 
-	/* index ʣȤ */
+	/* index が複数あるとき */
 	else {
 		p = p_start;
 		while( p != NULL && p != p_end->next ) {
 			UndoRedo(p);
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 	}
 	return 1;
@@ -364,13 +364,13 @@ int Undo(void)
 /* -------------------------------------------------------------------
  * Redo
  * -------------------------------------------------------------------
- * ɥ¹
+ * リドゥ実行
  *	
- *	 ɥϡUndo_Now  +1 ˤΤϡɥȤϵդ θ塣
- *	 ʣޤϣĤ Undo_Now Ʊֹ index Фƽ¹Ԥ뤬
- * index Ǥ⡢äŤǡ򤹤롣(ɥȤϵ)
- *	 ĤΥǡФơºݤν򤹤ΤϡUndoRedo() ؿǤϡ
- * ɥǽؿƱ
+ *	 リドゥは、Undo_Now を +1 にするのは、アンドゥとは逆で 処理の後。
+ *	 複数または１個ある Undo_Now と同じ番号の index に対して処理を実行するが、
+ * index の中でも、先に入った古いデータから処理をする。(アンドゥとは逆)。
+ *	 １個のデータに対して、実際の処理をするのは、UndoRedo() 関数でこれは、
+ * アンドゥで処理する関数と同じ。
  * -------------------------------------------------------------------
  */
 int Redo(void)
@@ -381,11 +381,11 @@ int Redo(void)
 	UNDO_LIST *p_end = NULL;
 
 
-	/* Rndo ϡ(Undo_index + 1) ⾮ʤм¹ԤǤʤ */
+	/* Rndo は、(Undo_index + 1) よりも小さくなければ実行できない */
 	if (Undo_index + 1 > Undo_Now) {
-		/* index κǽΥɥ쥹õ */
+		/* index の最初のアドレスを探す */
 		p_start = search_list_undo_start(Undo_Now);
-		/* index κǸΥɥ쥹õ */
+		/* index の最後のアドレスを探す */
 		p_end = search_list_undo_end(Undo_Now);
 
 
@@ -396,9 +396,9 @@ int Redo(void)
 
 		else {
 			/* -------------------------------------------------
-			 * p_end  p_start  UndoRedo() ¹Ԥ 
-			 * index ΥǡĤΤȤϡwhile ȴ
-			 * UndoRedo(p_start); ¹Ԥ롣
+			 * p_end から p_start の方向で UndoRedo() を実行する 
+			 * index のデータが１個だけのときは、while を抜けて
+			 * UndoRedo(p_start); だけを実行する。
 			 */
 			while (p_start != p_end) {
 				p = p_start;
@@ -420,16 +420,16 @@ int Redo(void)
 
 
 /* -------------------------------------------------------------------
- * Undo/Redo μºݤν򤹤
+ * Undo/Redo の実際の処理をする
  * -------------------------------------------------------------------
- *	 (type = 11 or 21) ǡäȤ󤬤СΥǡ
- * CAD ǡ List 鳰(꤫鳫ʤ)(type = 12 or 22) ѹ롣
+ *	 (type = 11 or 21) 新規データを作ったという情報があれば、そのデータを
+ * CAD データの List から外して(メモリから開放しない)、(type = 12 or 22) に変更する。
  *	
- *	 (type = 12 or 22) ǡȤ󤬤СΥǡ
- * CAD ǡ List ɲäơ(type = 11 or 21) ѹ롣
+ *	 (type = 12 or 22) データを削除したという情報があれば、そのデータを
+ * CAD データの List に追加して、(type = 11 or 21) に変更する。
  *	
- *	 (type = 13 or 23) ǡѹȤ󤬤СUndo List ˤǡ
- * Undo List  next ФؤƤ CAD Υǡ줫롣
+ *	 (type = 13 or 23) データを変更したという情報があれば、Undo List にあるデータと
+ * Undo List の next メンバが指している CAD のデータを入れかえる。
  * -------------------------------------------------------------------
  */
 void UndoRedo(UNDO_LIST *undo)
@@ -449,26 +449,26 @@ void UndoRedo(UNDO_LIST *undo)
 	 */
 	/* New */
 	if (undo->type == CAD_NEW) {
-		/* CAD Υǡơtype = 12 ˤ */
+		/* CAD のデータを削除して、type = 12 にする */
 		cad_list_delete(cad_search_cad(undo->diagram_point.cad_point, &cad_list_info), &cad_list_info);
 		undo->type = CAD_DEL;
 	}
 
 	/* Delete */
 	else if (undo->type == CAD_DEL) {
-		/* CAD Υǡɲäơtype = 11 ˤ */
-		/* CAD Data ꥹȤκǽɲ */
+		/* CAD のデータに追加して、type = 11 にする */
+		/* CAD Data をリストの最初に追加 */
 		r_cad_list_add_first(undo->diagram_point.cad_point, &cad_list_info);
 		undo->type = CAD_NEW;
 	}
 
 	/* Edit */
 	else if (undo->type == CAD_EDIT) {
-		/* CAD_LIST ΰΥǡ keep */
+		/* CAD_LIST の領域のデータを keep */
 		dummy_cad = *undo->diagram_point.cad_point;
-		/* CAD_LIST ΰ Undo ˤäƤǡ */
+		/* CAD_LIST の領域に Undo にに入っていたデータを入れる */
 		*undo->diagram_point.cad_point = undo->diagram.cad;
-		/* Undo ΰ keep Ƥäѹ CAD Υǡ򤤤 */
+		/* Undo の領域に keep してあった変更前の CAD のデータをいれる */
 		undo->diagram.cad = dummy_cad;
 	}
 
@@ -480,25 +480,25 @@ void UndoRedo(UNDO_LIST *undo)
 	 */
 	/* New */
 	else if (undo->type == DIMENSION_NEW) {
-		/* DIMENSION Υǡơtype = 22 ˤ */
+		/* DIMENSION のデータを削除して、type = 22 にする */
 		dimension_list_delete(dimension_search_dimension(undo->diagram_point.dimension_point, &dimension_list_info), &dimension_list_info);
 		undo->type = DIMENSION_DEL;
 	}
 
 	/* Delete */
 	else if (undo->type == DIMENSION_DEL) {
-		/* DIMENSION Υǡɲäơtype = 21 ˤ */
-		/* CAD Data ꥹȤκǽɲ */
+		/* DIMENSION のデータに追加して、type = 21 にする */
+		/* CAD Data をリストの最初に追加 */
 		r_dimension_list_add_first(undo->diagram_point.dimension_point, &dimension_list_info);
 		undo->type = DIMENSION_NEW;
 	}
 	/* Edit */
 	else if (undo->type == DIMENSION_EDIT) {
-		/* DIMENSION_LIST ΰΥǡ keep */
+		/* DIMENSION_LIST の領域のデータを keep */
 		dummy_dimension = *undo->diagram_point.dimension_point;
-		/* DIMENSION_LIST ΰ Undo ˤäƤǡ */
+		/* DIMENSION_LIST の領域に Undo にに入っていたデータを入れる */
 		*undo->diagram_point.dimension_point = undo->diagram.dimension;
-		/* Undo ΰ keep Ƥäѹ DIMENSION Υǡ򤤤 */
+		/* Undo の領域に keep してあった変更前の DIMENSION のデータをいれる */
 		undo->diagram.dimension = dummy_dimension;
 	}
 
@@ -510,26 +510,26 @@ void UndoRedo(UNDO_LIST *undo)
 	 */
 	/* New */
 	else if (undo->type == ELLIPSE_NEW) {
-		/* ELLIPSE Υǡơtype = ELLIPSE_DEL ˤ */
+		/* ELLIPSE のデータを削除して、type = ELLIPSE_DEL にする */
 		ellipse_list_delete(ellipse_search_ellipse(undo->diagram_point.ellipse_point, &ellipse_list_info), &ellipse_list_info);
 		undo->type = ELLIPSE_DEL;
 	}
 
 	/* Delete */
 	else if (undo->type == ELLIPSE_DEL) {
-		/* ELLIPSE Υǡɲäơtype = ELLIPSE_NEW ˤ */
-		/* ELLIPSE Data ꥹȤκǽɲ */
+		/* ELLIPSE のデータに追加して、type = ELLIPSE_NEW にする */
+		/* ELLIPSE Data をリストの最初に追加 */
 		r_ellipse_list_add_first(undo->diagram_point.ellipse_point, &ellipse_list_info);
 		undo->type = ELLIPSE_NEW;
 	}
 
 	/* Edit */
 	else if (undo->type == ELLIPSE_EDIT) {
-		/* ELLIPSE_LIST ΰΥǡ keep */
+		/* ELLIPSE_LIST の領域のデータを keep */
 		dummy_ellipse = *undo->diagram_point.ellipse_point;
-		/* ELLIPSE_LIST ΰ Undo ˤäƤǡ */
+		/* ELLIPSE_LIST の領域に Undo にに入っていたデータを入れる */
 		*undo->diagram_point.ellipse_point = undo->diagram.ellipse;
-		/* Undo ΰ keep Ƥäѹ ELLIPSE Υǡ򤤤 */
+		/* Undo の領域に keep してあった変更前の ELLIPSE のデータをいれる */
 		undo->diagram.ellipse = dummy_ellipse;
 	}
 
@@ -541,26 +541,26 @@ void UndoRedo(UNDO_LIST *undo)
 	 */
 	/* New */
 	else if (undo->type == POLYLINE_NEW) {
-		/* POLYLINE Υǡơtype = POLYLINE_DEL ˤ */
+		/* POLYLINE のデータを削除して、type = POLYLINE_DEL にする */
 		polyline_list_delete(polyline_search_polyline(undo->diagram_point.polyline_point, &polyline_list_info), &polyline_list_info);
 		undo->type = POLYLINE_DEL;
 	}
 
 	/* Delete */
 	else if (undo->type == POLYLINE_DEL) {
-		/* POLYLINE Υǡɲäơtype = POLYLINE_NEW ˤ */
-		/* POLYLINE Data ꥹȤκǽɲ */
+		/* POLYLINE のデータに追加して、type = POLYLINE_NEW にする */
+		/* POLYLINE Data をリストの最初に追加 */
 		r_polyline_list_add_first(undo->diagram_point.polyline_point, &polyline_list_info);
 		undo->type = POLYLINE_NEW;
 	}
 
 	/* Edit */
 	else if (undo->type == POLYLINE_EDIT) {
-		/* ELLIPSE_LIST ΰΥǡ keep */
+		/* ELLIPSE_LIST の領域のデータを keep */
 		dummy_polyline = *undo->diagram_point.polyline_point;
-		/* ELLIPSE_LIST ΰ Undo ˤäƤǡ */
+		/* ELLIPSE_LIST の領域に Undo にに入っていたデータを入れる */
 		*undo->diagram_point.polyline_point = undo->diagram.polyline;
-		/* Undo ΰ keep Ƥäѹ ELLIPSE Υǡ򤤤 */
+		/* Undo の領域に keep してあった変更前の ELLIPSE のデータをいれる */
 		undo->diagram.polyline = dummy_polyline;
 	}
 
@@ -572,26 +572,26 @@ void UndoRedo(UNDO_LIST *undo)
 	 */
 	/* New */
 	else if (undo->type == INSERT_NEW) {
-		/* INSERT Υǡơtype = INSERT_DEL ˤ */
+		/* INSERT のデータを削除して、type = INSERT_DEL にする */
 		insert_list_delete(insert_search_insert(undo->diagram_point.insert_point, &insert_list_info), &insert_list_info);
 		undo->type = INSERT_DEL;
 	}
 
 	/* Delete */
 	else if (undo->type == INSERT_DEL) {
-		/* INSERT Υǡɲäơtype = INSERT_NEW ˤ */
-		/* INSERT Data ꥹȤκǽɲ */
+		/* INSERT のデータに追加して、type = INSERT_NEW にする */
+		/* INSERT Data をリストの最初に追加 */
 		r_insert_list_add_first(undo->diagram_point.insert_point, &insert_list_info);
 		undo->type = INSERT_NEW;
 	}
 
 	/* Edit */
 	else if (undo->type == INSERT_EDIT) {
-		/* ELLIPSE_LIST ΰΥǡ keep */
+		/* ELLIPSE_LIST の領域のデータを keep */
 		dummy_insert = *undo->diagram_point.insert_point;
-		/* ELLIPSE_LIST ΰ Undo ˤäƤǡ */
+		/* ELLIPSE_LIST の領域に Undo にに入っていたデータを入れる */
 		*undo->diagram_point.insert_point = undo->diagram.insert;
-		/* Undo ΰ keep Ƥäѹ ELLIPSE Υǡ򤤤 */
+		/* Undo の領域に keep してあった変更前の ELLIPSE のデータをいれる */
 		undo->diagram.insert = dummy_insert;
 	}
 
@@ -602,7 +602,7 @@ void UndoRedo(UNDO_LIST *undo)
 
 
 /* ---------------------------------------------------------
- * ݥ󥿤ؤ Undo Data ꥹȤ
+ * ポインタが指す Undo Data をリストから削除
  */
 int undo_list_free(UNDO_LIST *del_List)
 {
@@ -612,41 +612,41 @@ char str[256];
 	long i;
 
 	/* -------------------------------------------
-	 * ݥ󥿤ΥǡΤꤿΤǡ
-	 * head (ꥹȤƬ) ݥ󥿤
-	 * ĤޤǷ֤Υǡõ
+	 * 削除するポインタの前のデータを知りたいので、
+	 * head (リストの先頭) から削除するポインタが
+	 * 見つかるまで繰り返し、前のデータを探す。
 	 */
 	p = undo_list_info.head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL && p != del_List) {
 		i++;
-		pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		pb = p;			/* 前のデータのポインタとして保存しておく */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 
 
-	/* Ĥä (p  NULL ǤϤʤȤ) */
+	/* 見つかった場合 (p が NULL ではないとき) */
 	if (p != NULL){
-		/* ƬΥǡ (i = 0 ΤȤ) */
+		/* 先頭のデータ (i = 0 のとき) */
 		if (i == 0) {
-			/* ƬΥǡĤʤ(ΥǡΥݥ󥿤 NULL) */
+			/* 先頭のデータ１個しかない場合(次のデータのポインタが NULL) */
 			if (p->next == NULL) {
 				undo_list_info.head = NULL;
 				undo_list_info.tail = NULL;
 			}
-			/* İʾǡȤ */
+			/* ２個以上データがあるとき */
 			else 
 				undo_list_info.head = p->next;
 		}
 
-		/* ǸΥǡΤȤ (p->next = NULL) */
+		/* 最後のデータのとき (p->next = NULL) */
 		else if (p->next == NULL) pb->next = NULL;
 
-		/* ֤Υǡ (ξʳ) */
+		/* 中間のデータ (上の条件以外) */
 		else pb->next = p->next;
 
 
@@ -663,7 +663,7 @@ char str[256];
 		/* -------------------------------------------------
 		 * DIMENSION DATA 
 		 */
-		/*  */
+		/* 削除 */
 		else if (del_List->type == DIMENSION_DEL) {
 			/* AssistLine */
 			if (
@@ -693,7 +693,7 @@ char str[256];
 				printf("This place is funny for NULL.");
 			}
 		}
-		/* Խ */
+		/* 編集 */
 		else if (del_List->type == DIMENSION_EDIT) {
 			/* AssistLine */
 			if (
@@ -702,7 +702,7 @@ char str[256];
 				del_List->diagram.dimension.AssistLine != NULL
 				) 
 			{
-				// ϡˡϡԽϤʤΤǡ¥ǡФ
+				// ここは、寸法線は、編集操作はしないので、実データだけ開放すればいい。
 				//xfree(del_List->diagram.dimension.AssistLine);
 			}
 
@@ -759,7 +759,7 @@ char str[256];
 
 
 /* ---------------------------------------------------------
- *	ꥹȤ
+ *	全リストを削除
  */
 void undo_list_all_free(void)
 {
@@ -775,7 +775,7 @@ void undo_list_all_free(void)
 
 
 /* ---------------------------------------------------------
- * UNDO_LIST Υǡ log
+ * UNDO_LIST のデータ log
  *	
  */
 void undo_list_log(void)
@@ -795,13 +795,13 @@ void undo_list_log(void)
 
 
 		if (p->type == 11) {
-			sprintf(msg, "ǡ  POINT ϡCAD_LIST ");
+			sprintf(msg, "データ作成  POINT は、CAD_LIST 上");
 		}
 		if (p->type == 12) {
-			sprintf(msg, "ǡ  POINT ϡCAD_LIST ˤϤʤ");
+			sprintf(msg, "データ削除  POINT は、CAD_LIST 上にはない。");
 		}
 		if (p->type == 13) {
-			sprintf(msg, "ǡԽ  POINT ϡCAD_LIST 塣CAD ϡԽΥǡ");
+			sprintf(msg, "データ編集  POINT は、CAD_LIST 上。CAD は、編集前のデータ。");
 		}
 
 
@@ -840,7 +840,7 @@ void undo_list_log(void)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : List_Undo.c
