@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/01/16
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/08
  * ====================================================================
  */
 
@@ -36,7 +36,7 @@
 
 int init_cad(CAD *cad)
 {
-	/* CAD Data ν */
+	/* CAD Data の初期化 */
 	cad->layer = 0;
 	cad->style = 1;
 	cad->color = 0xffffff;
@@ -57,14 +57,14 @@ int init_cad(CAD *cad)
 
 
 /* -------------------------------------------------------------------
- * ΰݺѤߤ CAD Data ꥹȤκǽɲ
+ * 領域確保済みの CAD Data をリストの最初に追加
  * 
  */
 CAD_LIST *r_cad_list_add_first(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 {
 	CAD_LIST *p;
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_cad_list = (CAD_LIST *)xmalloc(sizeof(CAD_LIST));
 
 
@@ -82,13 +82,13 @@ CAD_LIST *r_cad_list_add_first(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 #endif
 
 
-	/* ݤΰ˥ǡ (cad) 񤭹 */
+	/* 確保した領域にデータ (cad) を書き込む */
 	p_cad_list->cad = add_cad;
 	p_cad_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_cad_list_info->head == NULL && p_cad_list_info->tail == NULL) {
 		p_cad_list_info->head = p_cad_list;
@@ -96,7 +96,7 @@ CAD_LIST *r_cad_list_add_first(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_cad_list_info->head;
@@ -112,14 +112,14 @@ CAD_LIST *r_cad_list_add_first(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 
 
 /* -------------------------------------------------------------------
- * CAD Data ꥹȤκǽɲ
+ * CAD Data をリストの最初に追加
  * 
  */
 CAD_LIST *cad_list_add_first(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 {
 	CAD_LIST *p;
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_cad_list = (CAD_LIST *)xmalloc(sizeof(CAD_LIST));
 
 
@@ -132,10 +132,10 @@ CAD_LIST *cad_list_add_first(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 #endif
 
 
-	/* ǡ (cad) 񤭹िΰݤ */
+	/* データ (cad) を書き込むための領域を確保する */
 	p_cad_list->cad = (CAD *)xmalloc(sizeof(CAD));
 
-	/* ݤΰ˥ǡ (cad) 񤭹 */
+	/* 確保した領域にデータ (cad) を書き込む */
 	*p_cad_list->cad = *add_cad;
 	p_cad_list->next = NULL;
 
@@ -144,7 +144,7 @@ CAD_LIST *cad_list_add_first(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 //				p_cad_list->cad->cx, p_cad_list->cad->cy, p_cad_list->cad->r);
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_cad_list_info->head == NULL && p_cad_list_info->tail == NULL) {
 //		g_print("List Non Data\n");
@@ -153,7 +153,7 @@ CAD_LIST *cad_list_add_first(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 //		g_print("List over 1 Data\n");
@@ -170,7 +170,7 @@ CAD_LIST *cad_list_add_first(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 
 
 /* -------------------------------------------------------------------
- * CAD Data ꥹȤκǽɲäơ Undo Baffer ˽
+ * CAD Data をリストの最初に追加して、 Undo Baffer に書込む
  *	
  */
 CAD_LIST *cad_list_add_first_with_undo(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
@@ -182,19 +182,19 @@ CAD_LIST *cad_list_add_first_with_undo(CAD *add_cad, CAD_LIST_INFO *p_cad_list_i
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_cad_list = (CAD_LIST *)xmalloc(sizeof(CAD_LIST));
 
-	/* ǡ (cad) 񤭹िΰݤ */
+	/* データ (cad) を書き込むための領域を確保する */
 	p_cad_list->cad = (CAD *)xmalloc(sizeof(CAD));
 
-	/* ݤΰ˥ǡ (cad) 񤭹 */
+	/* 確保した領域にデータ (cad) を書き込む */
 	*p_cad_list->cad = *add_cad;
 	p_cad_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_cad_list_info->head == NULL && p_cad_list_info->tail == NULL) {
 		p_cad_list_info->head = p_cad_list;
@@ -202,7 +202,7 @@ CAD_LIST *cad_list_add_first_with_undo(CAD *add_cad, CAD_LIST_INFO *p_cad_list_i
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_cad_list_info->head;
@@ -224,7 +224,7 @@ CAD_LIST *cad_list_add_first_with_undo(CAD *add_cad, CAD_LIST_INFO *p_cad_list_i
 
 
 /* -------------------------------------------------------------------
- * CAD Data ꥹȤκǸɲ
+ * CAD Data をリストの最後に追加
  * 
  */
 CAD_LIST *cad_list_add_last(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
@@ -232,19 +232,19 @@ CAD_LIST *cad_list_add_last(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 	CAD_LIST *p;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_cad_list = (CAD_LIST *)xmalloc(sizeof(CAD_LIST));
 
-	/* ǡ (cad) 񤭹िΰݤ */
+	/* データ (cad) を書き込むための領域を確保する */
 	p_cad_list->cad = (CAD *)xmalloc(sizeof(CAD));
 
-	/* ݤΰ˥ǡ (cad) 񤭹 */
+	/* 確保した領域にデータ (cad) を書き込む */
 	*p_cad_list->cad = *add_cad;
 	p_cad_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_cad_list_info->head == NULL && p_cad_list_info->tail == NULL) {
 		p_cad_list_info->head = p_cad_list;
@@ -252,7 +252,7 @@ CAD_LIST *cad_list_add_last(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_cad_list_info->head != NULL 
 				&& p_cad_list_info->tail != NULL 
@@ -262,7 +262,7 @@ CAD_LIST *cad_list_add_last(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_cad_list_info->tail;
@@ -270,7 +270,7 @@ CAD_LIST *cad_list_add_last(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 		p->next = p_cad_list_info->tail;
 	}
 
-	/* ɥХåե˽ */
+	/* アンドゥバッファに書込む */
 //	undo_list_add_first(11, p_cad_list_info->tail, NULL);
 	return p_cad_list_info->tail;
 }
@@ -280,7 +280,7 @@ CAD_LIST *cad_list_add_last(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
 
 
 /* -------------------------------------------------------------------
- * CAD Data ꥹȤκǸɲá Undo Baffer ˽
+ * CAD Data をリストの最後に追加、 Undo Baffer に書込む
  *	
  */
 CAD_LIST *cad_list_add_last_with_undo(CAD *add_cad, CAD_LIST_INFO *p_cad_list_info)
@@ -292,19 +292,19 @@ CAD_LIST *cad_list_add_last_with_undo(CAD *add_cad, CAD_LIST_INFO *p_cad_list_in
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_cad_list = (CAD_LIST *)xmalloc(sizeof(CAD_LIST));
 
-	/* ǡ (cad) 񤭹िΰݤ */
+	/* データ (cad) を書き込むための領域を確保する */
 	p_cad_list->cad = (CAD *)xmalloc(sizeof(CAD));
 
-	/* ݤΰ˥ǡ (cad) 񤭹 */
+	/* 確保した領域にデータ (cad) を書き込む */
 	*p_cad_list->cad = *add_cad;
 	p_cad_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_cad_list_info->head == NULL && p_cad_list_info->tail == NULL) {
 		p_cad_list_info->head = p_cad_list;
@@ -312,7 +312,7 @@ CAD_LIST *cad_list_add_last_with_undo(CAD *add_cad, CAD_LIST_INFO *p_cad_list_in
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_cad_list_info->head != NULL 
 				&& p_cad_list_info->tail != NULL 
@@ -322,7 +322,7 @@ CAD_LIST *cad_list_add_last_with_undo(CAD *add_cad, CAD_LIST_INFO *p_cad_list_in
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_cad_list_info->tail;
@@ -343,7 +343,7 @@ CAD_LIST *cad_list_add_last_with_undo(CAD *add_cad, CAD_LIST_INFO *p_cad_list_in
 
 
 /* -------------------------------------------------------------------
- * CAD Data κǽ (κǤϤʤ)
+ * CAD Data の削除機能 (メモリの削除ではない)
  * 
  */
 int cad_list_delete(CAD_LIST *del_List, CAD_LIST_INFO *p_cad_list_info)
@@ -352,39 +352,39 @@ int cad_list_delete(CAD_LIST *del_List, CAD_LIST_INFO *p_cad_list_info)
 	CAD_LIST *pb = NULL;
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_cad_list_info->head && del_List->next == NULL) {
 		p_cad_list_info->head = NULL;
 		p_cad_list_info->tail = NULL;
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_cad_list_info->head && del_List->next != NULL) {
 		p_cad_list_info->head = p_cad_list_info->head->next;
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_cad_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_cad_list_info->tail) {
 				pb->next = NULL;
 				p_cad_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_cad_list_info->head && del_List != p_cad_list_info->tail) {
 				pb->next = p->next;
 			}
@@ -404,7 +404,7 @@ int cad_list_delete(CAD_LIST *del_List, CAD_LIST_INFO *p_cad_list_info)
 
 
 /* -------------------------------------------------------------------
- * CAD Data κǽ (κǤϤʤUndo Buffer ذܤ)
+ * CAD Data の削除機能 (メモリの削除ではなく、Undo Buffer へ移す)
  * 
  */
 int cad_list_delete_Undo(CAD_LIST *del_List, CAD_LIST_INFO *p_cad_list_info)
@@ -416,39 +416,39 @@ int cad_list_delete_Undo(CAD_LIST *del_List, CAD_LIST_INFO *p_cad_list_info)
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_cad_list_info->head && del_List->next == NULL) {
 		p_cad_list_info->head = NULL;
 		p_cad_list_info->tail = NULL;
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_cad_list_info->head && del_List->next != NULL) {
 		p_cad_list_info->head = p_cad_list_info->head->next;
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_cad_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_cad_list_info->tail) {
 				pb->next = NULL;
 				p_cad_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_cad_list_info->head && del_List != p_cad_list_info->tail) {
 				pb->next = p->next;
 			}
@@ -473,24 +473,24 @@ int cad_list_delete_Undo(CAD_LIST *del_List, CAD_LIST_INFO *p_cad_list_info)
 
 
 /* -------------------------------------------------------------------
- * CAD Υݥ󥿤Υǡ Undo ХåեԽˤơ
- * ξ˿ǡ롣
+ * CAD のポインタのデータを Undo バッファ（編集）に入れて、
+ * その場所に新しいデータを入れる。
  *	
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  */
 CAD_LIST *cad_list_edit(CAD_LIST *point, CAD *change_cad, CAD_LIST_INFO *p_cad_list_info)
 {
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_cad_list = (CAD_LIST *)xmalloc(sizeof(CAD_LIST));
 
-	/* ǡ (cad) 񤭹िΰݤ */
+	/* データ (cad) を書き込むための領域を確保する */
 	p_cad_list->cad = (CAD *)xmalloc(sizeof(CAD));
 
-	/* ݤΰѹΥǡ (cad) 񤭹 */
+	/* 確保した領域に変更前のデータ (cad) を書き込む */
 	*p_cad_list->cad = *point->cad;
 	p_cad_list->next = point;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->cad = *change_cad;
 
 //	undo_list_add_first(13, p_cad_list, NULL);
@@ -502,10 +502,10 @@ CAD_LIST *cad_list_edit(CAD_LIST *point, CAD *change_cad, CAD_LIST_INFO *p_cad_l
 
 
 /* -------------------------------------------------------------------
- * CAD Υݥ󥿤Υǡ Undo ХåեԽˤơ
- * ξ˿ǡ졢Undo Baffer ˽
+ * CAD のポインタのデータを Undo バッファ（編集）に入れて、
+ * その場所に新しいデータを入れ、Undo Baffer に書込む
  *	
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  */
 CAD_LIST *cad_list_edit_with_undo(CAD_LIST *point, CAD *change_cad, CAD_LIST_INFO *p_cad_list_info)
 {
@@ -515,10 +515,10 @@ CAD_LIST *cad_list_edit_with_undo(CAD_LIST *point, CAD *change_cad, CAD_LIST_INF
 	LPDIAGRAM lpdiagram;
 
 
-	/* ݤΰѹΥǡ (CAD) 񤭹 */
+	/* 確保した領域に変更前のデータ (CAD) を書き込む */
 	cad = *point->cad;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->cad = *change_cad;
 
 
@@ -534,7 +534,7 @@ CAD_LIST *cad_list_edit_with_undo(CAD_LIST *point, CAD *change_cad, CAD_LIST_INF
 
 
 /* -------------------------------------------------------------------
- *	ꥹȤĴ٤
+ *	リストの総数を調べる
  */
 long cad_list_num(CAD_LIST_INFO *p_cad_list_info)
 {
@@ -544,12 +544,12 @@ long cad_list_num(CAD_LIST_INFO *p_cad_list_info)
 	p = p_cad_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL) {
 		i++;
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 	return i;
 }
@@ -559,7 +559,7 @@ long cad_list_num(CAD_LIST_INFO *p_cad_list_info)
 
 
 /* -------------------------------------------------------------------
- * n ܤΥǡθ
+ * n 番目のデータの検索
  * 
  */
 CAD_LIST *cad_search_num(long search_number, CAD_LIST_INFO *p_cad_list_info)
@@ -575,11 +575,11 @@ CAD_LIST *cad_search_num(long search_number, CAD_LIST_INFO *p_cad_list_info)
 		p = p->next;
 	}
 
-	/* n ܤΥǡΥɥ쥹֤ */
+	/* n 番目のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -590,9 +590,9 @@ CAD_LIST *cad_search_num(long search_number, CAD_LIST_INFO *p_cad_list_info)
 
 
 /* -------------------------------------------------------------------
- * CAD Υǡθ
+ * CAD のデータの検索
  * 
- *   CAD_LIST
+ * 戻値  CAD_LIST
  */
 CAD_LIST *cad_search_cad(CAD *p_cad, CAD_LIST_INFO *p_cad_list_info)
 {
@@ -604,11 +604,11 @@ CAD_LIST *cad_search_cad(CAD *p_cad, CAD_LIST_INFO *p_cad_list_info)
 		p = p->next;
 	}
 
-	/* p_cad ΥǡΥɥ쥹֤ */
+	/* p_cad のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -619,9 +619,9 @@ CAD_LIST *cad_search_cad(CAD *p_cad, CAD_LIST_INFO *p_cad_list_info)
 
 
 /* -------------------------------------------------------------------
- * CAD Υǡθ
+ * CAD のデータの検索
  * 
- *   long
+ * 戻値  long
  */
 long cad_search_cad_to_num(CAD *p_cad, CAD_LIST_INFO *p_cad_list_info)
 {
@@ -636,11 +636,11 @@ long cad_search_cad_to_num(CAD *p_cad, CAD_LIST_INFO *p_cad_list_info)
 		i++;
 	}
 
-	/* p_cad ΥǡΥɥ쥹֤ */
+	/* p_cad のデータのアドレスを返す */
 	if (p != NULL) {
 		return i;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return 0;
 	}
@@ -651,7 +651,7 @@ long cad_search_cad_to_num(CAD *p_cad, CAD_LIST_INFO *p_cad_list_info)
 
 
 /* -------------------------------------------------------------------
- *	CAD Data ꥹȤ
+ *	CAD Data をリストから削除
  */
 int cad_list_free(CAD_LIST *del_List, CAD_LIST_INFO *p_cad_list_info)
 {
@@ -664,39 +664,39 @@ int cad_list_free(CAD_LIST *del_List, CAD_LIST_INFO *p_cad_list_info)
 		//g_print ("List_cad.c : cad_list_free() : del_List = StartData\n");
 	}
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_cad_list_info->head && del_List->next == NULL) {
 		p_cad_list_info->head = NULL;
 		p_cad_list_info->tail = NULL;
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_cad_list_info->head && del_List->next != NULL) {
 		p_cad_list_info->head = p_cad_list_info->head->next;
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_cad_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_cad_list_info->tail) {
 				pb->next = NULL;
 				p_cad_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_cad_list_info->head && del_List != p_cad_list_info->tail) {
 				pb->next = p->next;
 			}
@@ -716,7 +716,7 @@ int cad_list_free(CAD_LIST *del_List, CAD_LIST_INFO *p_cad_list_info)
 
 
 /* -------------------------------------------------------------------
- *	ꥹȤ
+ *	全リストを削除
  */
 void cad_list_all_free(CAD_LIST_INFO *p_cad_list_info)
 {
@@ -736,7 +736,7 @@ void cad_list_print(CAD_LIST_INFO *p_cad_list_info)
 	CAD_LIST *p;
 	int i = 0;
 
-	g_print("----- CAD ꥹȤɽ -----\n");
+	g_print("----- CAD リストを表示 -----\n");
 	p = p_cad_list_info->head;
 	while (p != NULL) {
 		i++;
@@ -754,7 +754,7 @@ void cad_list_print(CAD_LIST_INFO *p_cad_list_info)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : List_cad.c
