@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/01/16
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/14
  * ====================================================================
  */
 
@@ -23,10 +23,10 @@
 
 #include <gtk/gtk.h>
 #include <unistd.h>
-#include <pwd.h>
+//#include <pwd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <langinfo.h>
+//#include <langinfo.h>
 
 #include <math.h>
 #include <string.h>
@@ -41,7 +41,7 @@
 #include "List_Block.h"
 #include "List_Undo.h"
 #include "List_Select.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "etc.h"
 #define _LIST_FONT_
 #include "List_font.h"
@@ -51,7 +51,7 @@
 
 
 /* ---------------------------------------------------------
- * SAG_FONT Data ꥹȤκǸɲ
+ * SAG_FONT Data をリストの最後に追加
  * 
  * 
  */
@@ -59,23 +59,23 @@ SAG_FONT_LIST *font_list_add_last(SAG_FONT *add_font)
 {
 	SAG_FONT_LIST *p;
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_font_list = (SAG_FONT_LIST *)xmalloc(sizeof(SAG_FONT_LIST));
 
-	/* ǡ (font) 񤭹िΰݤ */
+	/* データ (font) を書き込むための領域を確保する */
 	p_font_list->font = (SAG_FONT *)xmalloc(sizeof(SAG_FONT));
 
-	/* ǤΰݤɬפϤʤեȤɤ߹Ȥ˳ݤ顣 */
-	/* ǡ (font_data) 񤭹िΰݤ */
+	/* ここでは領域を確保する必要はない。フォントを読み込んだときに確保したから。 */
+	/* データ (font_data) を書き込むための領域を確保する */
 //	p_font_list->font->font_data = (SAG_FONT_DATA *)xmalloc(add_font->index * sizeof(SAG_FONT_DATA));
 
-	/* ݤΰ˥ǡ (font) 񤭹 */
+	/* 確保した領域にデータ (font) を書き込む */
 	*p_font_list->font = *add_font;
 	p_font_list->next = NULL;
 
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (font_list_info.head == NULL && font_list_info.tail == NULL) {
 		font_list_info.head = p_font_list;
@@ -83,7 +83,7 @@ SAG_FONT_LIST *font_list_add_last(SAG_FONT *add_font)
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (font_list_info.head != NULL 
 				&& font_list_info.tail != NULL 
@@ -93,7 +93,7 @@ SAG_FONT_LIST *font_list_add_last(SAG_FONT *add_font)
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = font_list_info.tail;
@@ -101,7 +101,7 @@ SAG_FONT_LIST *font_list_add_last(SAG_FONT *add_font)
 		p->next = font_list_info.tail;
 	}
 
-	/* ɥХåե˽ */
+	/* アンドゥバッファに書込む */
 	return font_list_info.tail;
 }
 
@@ -110,7 +110,7 @@ SAG_FONT_LIST *font_list_add_last(SAG_FONT *add_font)
 
 
 /* ---------------------------------------------------------
- * SAG_FONT Data ꥹȤ
+ * SAG_FONT Data をリストから削除
  * 
  */
 int font_list_free(SAG_FONT_LIST *del_List)
@@ -119,47 +119,47 @@ int font_list_free(SAG_FONT_LIST *del_List)
 	SAG_FONT_LIST *pb = NULL;
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == font_list_info.head && del_List->next == NULL) {
 		font_list_info.head = NULL;
 		font_list_info.tail = NULL;
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == font_list_info.head && del_List->next != NULL) {
 		font_list_info.head = font_list_info.head->next;
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = font_list_info.head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == font_list_info.tail) {
-				//g_print("ǸΥǡ\n");
+				//g_print("最後のデータ\n");
 				pb->next = NULL;
 				font_list_info.tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != font_list_info.head && del_List != font_list_info.tail) {
-				//g_print("֤Υǡ\n");
+				//g_print("中間のデータ\n");
 				pb->next = p->next;
 			}
 		}
 		else {
-			//g_print("ꥹȤ SAG_FONT ǡǤϤʤ\n");
+			//g_print("リストの SAG_FONT データではない\n");
 			return 0;
 		}
 	}
@@ -176,7 +176,7 @@ int font_list_free(SAG_FONT_LIST *del_List)
 
 
 /* ---------------------------------------------------------
- * ꥹȤ
+ * 全リストを削除
  * 
  */
 void font_list_all_free(void)
@@ -191,7 +191,7 @@ void font_list_all_free(void)
 
 
 /* -------------------------------------------------------------------
- * SagCAD Font Type (sft File) Υǡɤ߹
+ * SagCAD Font Type (sft File) のデータを読み込む
  */
 int sft_file_read(FILE *stream)
 {
@@ -201,9 +201,9 @@ int sft_file_read(FILE *stream)
 	while(1) {
 		if (LineRead(stream, str) == 0) return 0;
 
-		/* "eof" ʸǽλ */
+		/* "eof" の文字で終了 */
 		if (strstr(str, "eof") != NULL ) break;
-		/* "EOF" ʸǽλ */
+		/* "EOF" の文字で終了 */
 		else if (strstr(str, "EOF") != NULL ) break;
 
 		else if(strstr(str, "s_") != NULL ) {
@@ -217,19 +217,19 @@ int sft_file_read(FILE *stream)
 
 int ScalingFont(SAG_FONT_DATA *font_data, double x, double y, double k)
 {
-	/* ΤȤ */
+	/* 点のとき */
 	if (font_data->code == 0) {
 		font_data->sx = sg((k * font_data->sx) + x * (1 - k), calcu_digits);
 		font_data->sy = sg((k * font_data->sy) + y * (1 - k), calcu_digits);
 	}
-	/* ΤȤ */
+	/* 線のとき */
 	else if (font_data->code == 1) {
 		font_data->sx = sg((k * font_data->sx) + x * (1 - k), calcu_digits);
 		font_data->sy = sg((k * font_data->sy) + y * (1 - k), calcu_digits);
 		font_data->ex = sg((k * font_data->ex) + x * (1 - k), calcu_digits);
 		font_data->ey = sg((k * font_data->ey) + y * (1 - k), calcu_digits);
 	}
-	/* ߸̤ΤȤ */
+	/* 円弧のとき */
 	else if (font_data->code == 2) {
 		font_data->cx = sg((k * font_data->cx) + x * (1 - k), calcu_digits);
 		font_data->cy = sg((k * font_data->cy) + y * (1 - k), calcu_digits);
@@ -239,7 +239,7 @@ int ScalingFont(SAG_FONT_DATA *font_data, double x, double y, double k)
 		font_data->ey = sg((k * font_data->ey) + y * (1 - k), calcu_digits);
 		font_data->r = sg(k * font_data->r, calcu_digits);
 	}
-	/* ߤΤȤ */
+	/* 円のとき */
 	else if (font_data->code == 4) {
 		font_data->cx = sg((k * font_data->cx) + x * (1 - k), calcu_digits);
 		font_data->cy = sg((k * font_data->cy) + y * (1 - k), calcu_digits);
@@ -251,7 +251,7 @@ int ScalingFont(SAG_FONT_DATA *font_data, double x, double y, double k)
 
 
 /* -------------------------------------------------------------------
- * SagCAD Font Type (sft File) Υǡɤ߹
+ * SagCAD Font Type (sft File) のデータを読み込む
  */
 SAG_FONT *sft_char_read(FILE *stream, char *str)
 {
@@ -263,7 +263,7 @@ SAG_FONT *sft_char_read(FILE *stream, char *str)
 	double scale;
 
 
-	/* ʸ */
+	/* 定義文字 */
 	strcpy (font.moji, &str[2]);
 	/* width */
 	if (LineRead(stream, str) == 0) return NULL;
@@ -280,14 +280,14 @@ SAG_FONT *sft_char_read(FILE *stream, char *str)
 	if (LineRead(stream, str) == 0) return NULL;
 	font.index = atoi(str);
 	if (font.index > 0) {
-		/* ǡ (font_data) 񤭹िΰݤ */
+		/* データ (font_data) を書き込むための領域を確保する */
 		font_data = (SAG_FONT_DATA *)xmalloc(font.index * sizeof(SAG_FONT_DATA));
 		font.font_data = font_data;
 	}
 	else {
 		font.font_data = NULL;
 	}
-	/* SAG_FONT Data ꥹȤκǸɲ */
+	/* SAG_FONT Data をリストの最後に追加 */
 	font_list = font_list_add_last(&font);
 
 
@@ -295,7 +295,7 @@ SAG_FONT *sft_char_read(FILE *stream, char *str)
 
 	if (font.index > 0) {
 		for (i = 0 ; i < font.index ; i++) {
-			/* ɤߤ */
+			/* １行読みこみ */
 			if (LineRead(stream, str) == 0) return NULL;
 			/* code */
 			LineDataSplit(str, ',', 1, ret);
@@ -334,7 +334,7 @@ SAG_FONT *sft_char_read(FILE *stream, char *str)
 
 
 /* -------------------------------------------------------------------
- * QCad Font Type (cxf File) Υǡɤ߹
+ * QCad Font Type (cxf File) のデータを読み込む
  */
 int cxf_file_read(FILE *stream)
 {
@@ -347,11 +347,11 @@ int cxf_file_read(FILE *stream)
 			return 0;
 		}
 
-		/* "eof" ʸǽλ */
+		/* "eof" の文字で終了 */
 		if (strstr(str, "eof") != NULL ) {
 			break;
 		}
-		/* "EOF" ʸǽλ */
+		/* "EOF" の文字で終了 */
 		else if (strstr(str, "#EOF") != NULL ) {
 			break;
 		}
@@ -366,7 +366,7 @@ int cxf_file_read(FILE *stream)
 
 
 /* -------------------------------------------------------------------
- * QCad Font Type (cxf File) Υǡɤ߹
+ * QCad Font Type (cxf File) のデータを読み込む
  */
 SAG_FONT *cxf_char_read(FILE *stream, char *str)
 {
@@ -430,7 +430,7 @@ SAG_FONT *cxf_char_read(FILE *stream, char *str)
 	index_start = strstr(str, "]") + 1;
 	font.index = atoi(index_start);
 	if (font.index > 0) {
-		/* ǡ (font_data) 񤭹िΰݤ */
+		/* データ (font_data) を書き込むための領域を確保する */
 		font_data = (SAG_FONT_DATA *)xmalloc(font.index * sizeof(SAG_FONT_DATA));
 		font.font_data = font_data;
 	}
@@ -441,9 +441,9 @@ SAG_FONT *cxf_char_read(FILE *stream, char *str)
 
 
 	if (font.index > 0) {
-		/* ʸǤ */
+		/* 文字の要素を取り込む */
 		for (i = 0 ; i < font.index ; i++) {
-			/* ɤߤ */
+			/* １行読みこみ */
 			if (LineRead(stream, str) == 0) return NULL;
 
 
@@ -515,7 +515,7 @@ SAG_FONT *cxf_char_read(FILE *stream, char *str)
 		font.width = max;
 
 	}
-	/* SAG_FONT Data ꥹȤκǸɲ */
+	/* SAG_FONT Data をリストの最後に追加 */
 	font_list = font_list_add_last(&font);
 
 	return font_list->font;
@@ -526,10 +526,10 @@ SAG_FONT *cxf_char_read(FILE *stream, char *str)
 
 
 /* -------------------------------------------------------------------
- * ʸΥեȥǡɤߤ (Ū)
+ * 文字のフォントデータを読みこむ (静的)
  * 
- * ãĤεư˥ɤߤե
- * եȥե [ font_file ]
+ * ＣＡＤの起動時にメモリに読みこむフォント
+ * フォントファイル [ font_file ]
  * 
  */
 int font_open(char *font_file)
@@ -538,34 +538,34 @@ int font_open(char *font_file)
 	char str[256], *file_name;
 
 
-	/* եȥեõƳ */
+	/* フォントファイルを探して開く */
 
-	/* ѥ */
+	/* 設定パス */
 	sprintf(str, "%s", font_file);
 	if( (stream  = fopen( str, "r" )) == NULL ) {
-		//g_print("եȥե [ %s ] ʤ\n", str);
+		//g_print("フォントファイル [ %s ] がない。\n", str);
 
 
-		/* ե̾Ф */
+		/* ファイル名を取り出す */
 		file_name = getFileName(font_file);
 
 
-		/* /usr/local/sagcad/font/ (̤˥󥹥ȡ뤷Ȥ) */
+		/* /usr/local/sagcad/font/ (普通にインストールしたとき) */
 		strcpy(str, FONTDIR);
 		strcat(str, "/");
 		strcat(str, file_name);
 		if( (stream  = fopen( str, "r" )) == NULL ) {
-			//g_print("      [ %s ] ˤʤ\n", str);
+			//g_print("      [ %s ] にもない。\n", str);
 
-			/* ./font/ (󥹥ȡ뤷ʤȤ) */
+			/* ./font/ (インストールしないとき用) */
 			sprintf(str, "./font/%s", file_name);
 			if( (stream  = fopen( str, "r" )) == NULL ) {
-				//g_print("  [ %s ] ˤʤ\n", str);
+				//g_print("  [ %s ] にもない。\n", str);
 
-				/*  */
+				/* カレント */
 				sprintf(str, "%s", file_name);
 				if( (stream  = fopen( str, "r" )) == NULL ){
-					//g_print("եȥե [ %s ] ʤ\n", str);
+					//g_print("フォントファイル [ %s ] がない。\n", str);
 
 					g_print( _("File Not Found. [%s]\n") , file_name);
 					not_find_font("?");
@@ -597,10 +597,10 @@ int font_open(char *font_file)
 
 
 /* -------------------------------------------------------------------
- * ʸΥեȥǡɤߤ (ưŪ)
+ * 文字のフォントデータを読みこむ (動的)
  * 
- * ãļ¹ɬפʥեȤɤ
- * եȥե [ font_file2 ]
+ * ＣＡＤ実行中に必要なフォントだけをロードする
+ * フォントファイル [ font_file2 ]
  * 
  */
 SAG_FONT *font_search_open(char *moji, char *font_file2)
@@ -613,35 +613,35 @@ SAG_FONT *font_search_open(char *moji, char *font_file2)
 	int bite = 0;
 
 
-	/* եȥեõƳ */
-	/* ѥ */
+	/* フォントファイルを探して開く */
+	/* 設定パス */
 	sprintf(str, "%s", font_file2);
 	if( (stream  = fopen( str, "r" )) == NULL ) {
-		//g_print("եȥե [ %s ] ʤ\n", str);
+		g_print("font not search 1 [ %s ]\n", str);
 
 
-		/* ե̾Ф */
+		/* ファイル名を取り出す */
 		file_name = getFileName(font_file2);
 
 
-		/* /usr/local/sagcad/font/ (̤˥󥹥ȡ뤷Ȥ) */
+		/* /usr/local/sagcad/font/ (普通にインストールしたとき) */
 		//sprintf(str, "/usr/local/sagcad/font/%s", file_name);
 		strcpy(str, FONTDIR);
 		strcat(str, "/");
 		strcat(str, file_name);
 		if( (stream  = fopen( str, "r" )) == NULL ) {
-			//g_print("      [ %s ] ˤʤ\n", str);
-
-			/* ./font/ (󥹥ȡ뤷ʤȤ) */
-			sprintf(str, "./font/%s", file_name);
+			g_print("font not search 2 [ %s ]\n", str);
+			
+			/* ./font/ (インストールしないとき用) */
+			sprintf(str, "../../font/%s", file_name);
 			if( (stream  = fopen( str, "r" )) == NULL ) {
-				//g_print("  [ %s ] ˤʤ\n", str);
-
-				/*  */
+				g_print("font not search 3 [ %s ]\n", str);
+				
+				/* カレント */
 				sprintf(str, "%s", file_name);
 				if( (stream  = fopen( str, "r" )) == NULL ){
-					//g_print("եȥե [ %s ] ʤ\n", str);
-
+					g_print("font not search 4 [ %s ] がない。\n", str);
+					
 					g_print( _("File Not Found. [%s]\n") , file_name);
 					not_find_font("?");
 					return 0;
@@ -661,13 +661,13 @@ SAG_FONT *font_search_open(char *moji, char *font_file2)
 			return NULL;
 		}
 
-		/* "eof" ʸǽλ */
+		/* "eof" の文字で終了 */
 		if(strstr(str, "eof") != NULL ) {
 			break;
 		}
 
 		else if (strstr(str, "[") != NULL && strstr(str, "]") != NULL) {
-			/* Хʸ */
+			/* １バイト文字 */
 			if (bite == 1) {
 				if (moji[0] == str[1]) {
 					font = cxf_char_read(stream, str);
@@ -675,7 +675,7 @@ SAG_FONT *font_search_open(char *moji, char *font_file2)
 					return font;
 				}
 			}
-			/* Хʸ */
+			/* ２バイト文字 */
 			else if (bite == 2) {
 				if (moji[0] == str[1] && moji[1] == str[2]) {
 					font = cxf_char_read(stream, str);
@@ -683,7 +683,7 @@ SAG_FONT *font_search_open(char *moji, char *font_file2)
 					return font;
 				}
 			}
-			/* Хʸ */
+			/* ３バイト文字 */
 			else if (bite == 3) {
 				if (moji[0] == str[1] && moji[1] == str[2] && moji[2] == str[3]) {
 					font = cxf_char_read(stream, str);
@@ -691,7 +691,7 @@ SAG_FONT *font_search_open(char *moji, char *font_file2)
 					return font;
 				}
 			}
-			/* Хʸ */
+			/* ４バイト文字 */
 			else if (bite == 4) {
 				if (moji[0] == str[1] && moji[1] == str[2] && moji[2] == str[3] && moji[3] == str[4]) {
 					font = cxf_char_read(stream, str);
@@ -708,10 +708,10 @@ SAG_FONT *font_search_open(char *moji, char *font_file2)
 
 
 /* -------------------------------------------------------------------
- * ʸΥǡõ
+ * 文字のデータを探す
  *	
- * char *moji				 : õʸ
- * struct sag_font *FontData : Ĥǡ빽¤
+ * char *moji				 : 探す文字
+ * struct sag_font *FontData : 見つけたデータを入れる構造体
  *	
  *	
  */
@@ -735,14 +735,14 @@ SAG_FONT *font_search(char *moji, char *font_file2)
 	while (p_list != NULL) {
 		if (bite == 1) {
 			if ((p_list->font->moji[0] & 0xff) == (moji[0] & 0xff)) {
-				//g_print ("[%s] ϥˤä[%s]\n", moji, p_list->font->moji);
+				//g_print ("[%s] はメモリにあった[%s]\n", moji, p_list->font->moji);
 				return p_list->font;
 			}
 		}
 		else if (bite == 2) {
 			if ((p_list->font->moji[0] & 0xff) == (moji[0] & 0xff) && 
 					(p_list->font->moji[1] & 0xff) == (moji[1] & 0xff)) {
-				//g_print ("charset = [%d]   [%s : %x%x] ϥˤä[%s : %x%x]\n", 
+				//g_print ("charset = [%d]   [%s : %x%x] はメモリにあった[%s : %x%x]\n", 
 				return p_list->font;
 			}
 		}
@@ -750,7 +750,7 @@ SAG_FONT *font_search(char *moji, char *font_file2)
 			if ((p_list->font->moji[0] & 0xff) == (moji[0] & 0xff) && 
 					(p_list->font->moji[1] & 0xff) == (moji[1] & 0xff) && 
 					(p_list->font->moji[2] & 0xff) == (moji[2] & 0xff)) {
-				//g_print ("charset = [%d]   [%s : %x%x] ϥˤä[%s : %x%x]\n", 
+				//g_print ("charset = [%d]   [%s : %x%x] はメモリにあった[%s : %x%x]\n", 
 				return p_list->font;
 			}
 		}
@@ -759,43 +759,43 @@ SAG_FONT *font_search(char *moji, char *font_file2)
 					(p_list->font->moji[1] & 0xff) == (moji[1] & 0xff) && 
 					(p_list->font->moji[2] & 0xff) == (moji[2] & 0xff) && 
 					(p_list->font->moji[3] & 0xff) == (moji[3] & 0xff)) {
-				//g_print ("charset = [%d]   [%s : %x%x] ϥˤä[%s : %x%x]\n", 
+				//g_print ("charset = [%d]   [%s : %x%x] はメモリにあった[%s : %x%x]\n", 
 				return p_list->font;
 			}
 		}
 
 		else {
-//			g_print ("charset = [%d]   [%s : %x%x] ϥˤʤ[%s : %x%x]\n", 
+//			g_print ("charset = [%d]   [%s : %x%x] はメモリにない[%s : %x%x]\n", 
 //						charset, moji, moji[0], moji[1], p_list->font->moji, p_list->font->moji[0], p_list->font->moji[1]);
 		}
 		p_list = p_list->next;
 	}
 
-//	g_print ("charset = [%d]   [%s : %x%x] ϥˤʤ\n", 
+//	g_print ("charset = [%d]   [%s : %x%x] はメモリにない\n", 
 //				charset, moji, (moji[0] & 0xff), (moji[1] & 0xff));
 
 
 
 	/* -----------------------------------------------------
-	 * ˡեȥե룲ɬפʥ٥ȥեȤҤȤõ
-	 * ɤߤߡݥ󥿤ι¤Τ֤
+	 * 次に、フォントファイル２から必要なベクトルフォントをひとつ探し
+	 * メモリに読みこみ、ポインタの構造体に入れて返す。
 	 */
 	p_font = font_search_open(moji, font_file2);
 	if (p_font != NULL) {
-		//g_print ("[%s] ϥˤʤä font_file2 ˤä\n", moji);
+		//g_print ("[%s] はメモリになかったが font_file2 にあった\n", moji);
 		return p_font;
 	}
 
 
 	/* -----------------------------------------------------
-	 * Ǥ⸫Ĥʤä "?" 
+	 * それでも見つからなかったら "?" 
 	 */
 	p_font = not_find_font(moji);
 	if (p_font != NULL) {
-		//g_print ("[%s] Ϥʤä֡\n", moji);
+		//g_print ("[%s] はなかったから「？」\n", moji);
 		return p_font;
 	}
-	//g_print ("[%s] ϤʤäNULL\n", moji);
+	//g_print ("[%s] はなかったから「NULL」\n", moji);
 	return NULL;
 }
 
@@ -804,10 +804,10 @@ SAG_FONT *font_search(char *moji, char *font_file2)
 
 
 /* -------------------------------------------------------------------
- * moji 򡩤Ȥɽ褦Ͽ
+ * moji を？として表示するように登録
  * 
- * ե뤫õƤɽ٤Τǡ
- * Ͽ롣ɽϡ
+ * 毎回ファイルから探していたら表示が遅いので、
+ * メモリに登録する。表示は？
  * 
  */
 SAG_FONT *not_find_font(char *moji)
@@ -836,7 +836,7 @@ SAG_FONT *not_find_font(char *moji)
 	int bite = 0;
 
 
-	/* SJIS  euc  UTF-8 ⥹ڡ 0x20 */
+	/* SJIS も euc も UTF-8 もスペースは 0x20 */
 	if (moji[0] == ' ') {
 		font.moji[0] = ' ';
 		font.moji[1] = '\0';
@@ -844,7 +844,7 @@ SAG_FONT *not_find_font(char *moji)
 		font.height = 9;
 		font.index = 0;
 		font_data = NULL;
-		/* SAG_FONT Data ꥹȤκǸɲ */
+		/* SAG_FONT Data をリストの最後に追加 */
 		font_list = font_list_add_last(&font);
 		return font_list->font;
 	}
@@ -888,7 +888,7 @@ SAG_FONT *not_find_font(char *moji)
 		font_data[i].cy   = data[i].cy;
 		font_data[i].r	  = data[i].r;
 	}
-	/* SAG_FONT Data ꥹȤκǸɲ */
+	/* SAG_FONT Data をリストの最後に追加 */
 	font_list = font_list_add_last(&font);
 	//font_list_print();
 
@@ -900,53 +900,53 @@ SAG_FONT *not_find_font(char *moji)
 
 
 /* -------------------------------------------------------------------
- * ʸɤμ̤Ƚꤹ
+ * 文字コードの種別を判定する
  *	
- * ؿ 
- * μ̤ɽ
- * strƬʸȾѥʤξ硢ؿͤ1
- * strƬ2ʸեJISɤξ硢ؿͤ2
- * strƬ2ʸEUCȾѥʥɤξ硢ؿͤ4
- * strƬ2ʸEUCѥɤξ硢ؿͤ8
- * strƬ3ʸJIS(X0208-1983)եȥɤξ硢
- * ؿͤ16
- * strƬ3ʸJIS(X0208-1978)եȥɤξ硢
- * ؿͤ32
- * strƬ3ʸJIS޻(X0201)եȥɤξ硢
- * ؿͤ64
- * strƬ3ʸASCII եȥɤξ硢ؿͤ128
- * ΥʣƱ˵ϡؿͤϤ
- * ΤǤʤϡؿͤ0
+ * 関数値 
+ * 漢字の種別を表す値
+ * ・引数strの先頭文字が半角カナの場合、関数値は1
+ * ・引数strの先頭2文字がシフトJISコードの場合、関数値は2
+ * ・引数strの先頭2文字がEUC半角カナコードの場合、関数値は4
+ * ・引数strの先頭2文字がEUC全角コードの場合、関数値は8
+ * ・引数strの先頭3文字が新JIS(X0208-1983)シフトコードの場合、
+ * 　関数値は16
+ * ・引数strの先頭3文字が旧JIS(X0208-1978)シフトコードの場合、
+ * 　関数値は32
+ * ・引数strの先頭3文字がJISローマ字(X0201)シフトコードの場合、
+ * 　関数値は64
+ * ・引数strの先頭3文字がASCII シフトコードの場合、関数値は128
+ * ・上のケースが複数個同時に起きる場合は、関数値はそれらの論理和
+ * ・上のいずれでもない場合は、関数値は0
  *	
  *	
- * ջ 
+ * 注意事項 
  *	
- * whatKanji-test.c
- * whatKanji("");
+ * 用例（whatKanji-test.c）
+ * whatKanji("漢字");
  *	
  *	
- *  
- *	 Ⱦѥʥɤ 0xa0 - 0xdf δ֤Ȥ
- *	 եJISɤ1ХȤȤ 0x81 - 0x9f ޤǤ 0xe0 - 0xfc ޤǡ2ХȤ
- *  0x40 - 0xfc ޤǡ0x7fˤȤΤᡢեJISϾ嵭Ⱦѥ
- * ȺߤǤ롣ʸȤƻȤ ʥХååޤϱߵˤ
- * ɤ2ХȤΰäƤ뤿꤬뤳Ȥ롣
- *	 EUCɤ12ХȤȤ 0xa1 - 0xfe ޤǤǤ뤬ȾѤΥʸˤĤƤϡ
- * 0x8e ȾѥʸˤĤ2ХȤɽ롣
- *	 JISɤ7ӥåȷϴɤǤ뤿ᡢĤΤ褦ʥեȥɤȤäơ
- * ʸåȤڤؤԤʴɽ롣
+ * 説明 
+ *	 半角カナコードは 0xa0 - 0xdf の間を使う。
+ *	 シフトJISコードは第1バイトとして 0x81 - 0x9f までと 0xe0 - 0xfc まで、第2バイトと
+ * して 0x40 - 0xfc まで（0x7fを除く）を使う。このため、シフトJISは上記の半角コード
+ * と混在できる。しかし、制御文字として使われる ＼（バックスラッシュまたは円記号）な
+ * どが第2バイトの領域に入っているために問題が生じることがある。
+ *	 EUCコードは第1、第2バイトとも 0xa1 - 0xfe までであるが、半角のカナ文字については、
+ * 0x8e を半角カナ文字の前につけ、2バイトで表現する。
+ *	 一方、JISコードは7ビット系漢字コードであるため、つぎのようなシフトコードを使って、
+ * 文字セットの切り替えを行い、かな漢字を表現する。
  *	
- * եȥɰ
- * ʸå  եȥ  
- * JIS X0208-1983  ESC $ B  
- * JIS X0208-1978  ESC $ @  
- * JIS޻ X0201  ESC ( J	
+ * 　　　シフトコード一覧
+ * 文字セット  シフトコード  
+ * 新JIS X0208-1983  ESC $ B  
+ * 旧JIS X0208-1978  ESC $ @  
+ * JISローマ字 X0201  ESC ( J	
  * ASCII  ESC ( B	
  *	
  */
 int whatKanji_sjis(/* unsigned */ char *str)
 {
-//0x810x9F   0xE00xEF 
+//0x81～0x9F   0xE0～0xEF 
 	int val = 0;
 	unsigned char b1, b2, b3;
 
@@ -980,18 +980,18 @@ int whatKanji_euc(/*unsigned */ char *str)
 
 
 #ifdef TEST
-EUC  
+EUC 漢字コード 
 
-UNIX Ǵɽ뤿Ѥ줿 IN/OUT  Ȥ鷺ʸ
-ASCII ʸȺߤǤ뤬SHIFT-JIS  Ʊ 8ӥåǤʤɽǤ
-ʤʸδʤɤ 롣ɽ르ꥺ SHIFT-JIS Ȼ
-ƤꡢΤ褦 ʤäƤ롣 
+UNIX で漢字を表現するために用いられた方式。漢字 IN/OUT を 使わずに制御文字、
+ASCII コード文字と混在できるが、SHIFT-JIS 方式と 同じく 8ビット幅でないと表現でき
+ない、文字化けの危険性があるなどの 欠点がある。表示アルゴリズムは SHIFT-JIS と似
+ており、次のように なっている。 
 
-1Хܤ 0x00  0x7F ä顢 single-byte ʸȤ Τޤɽ롣 
-1Хܤ 0x8E ä顢ΤȤ³ʸȾѥʤȤ ɽ (ΤȤ
- 2Хܤ SHIFT-JIS ˤȾѥʸ ɽɤƱΤȤ)
- 1Хܤ 0xA1  0xFE ä顢ϴ 1ХܤȤߤʤ  1Х
-ȹ碌ƴɽ롣 
+1バイト目が 0x00 ～ 0x7F だったら、それを single-byte 文字として そのまま表示する。 
+1バイト目が 0x8E だったら、そのあとに続く文字を半角カナとして 表示する (このとき
+の 2バイト目は SHIFT-JIS における半角カナ文字を 表すコードと同じものが使われる)。
+ 1バイト目が 0xA1 ～ 0xFE だったら、それは漢字の 1バイト目とみなし、 次の 1バイト
+と合わせて漢字を表示する。 
 
 	int val = 0;
 	unsigned char b1, b2, b3;
@@ -1034,7 +1034,7 @@ void font_list_print(void)
 
 	p = font_list_info.head;
 	if (p == NULL) {
-		OneShotLog("font Data ϡޤ\n");
+		OneShotLog("font Data は、ありません。\n");
 		return;
 	}
 
@@ -1075,7 +1075,7 @@ void font_list_print(void)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : List_font.c
