@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/03/23
- *    Last                 : 2003/03/23
+ *    Last                 : 2007/10/08
  * ====================================================================
  */
 
@@ -39,7 +39,7 @@
 
 int init_insert(INSERT *insert)
 {
-	/* INSERT Data ν */
+	/* INSERT Data の初期化 */
 	strcpy(insert->name, "None");
 	insert->layer = 0;
 	insert->color = 0xffffff;
@@ -63,7 +63,7 @@ int init_insert(INSERT *insert)
 
 
 /* -------------------------------------------------------------------
- * ΰݺѤߤ INSERT Data ꥹȤκǽɲ
+ * 領域確保済みの INSERT Data をリストの最初に追加
  * 
  */
 INSERT_LIST *r_insert_list_add_first(INSERT *add_insert, INSERT_LIST_INFO *p_insert_list_info)
@@ -71,15 +71,15 @@ INSERT_LIST *r_insert_list_add_first(INSERT *add_insert, INSERT_LIST_INFO *p_ins
 	INSERT_LIST *p;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_insert_list = (INSERT_LIST *)xmalloc(sizeof(INSERT_LIST));
 
-	/* ݤΰ˥ǡ (insert) 񤭹 */
+	/* 確保した領域にデータ (insert) を書き込む */
 	p_insert_list->insert = add_insert;
 	p_insert_list->next = NULL;
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_insert_list_info->head == NULL && p_insert_list_info->tail == NULL) {
 		p_insert_list_info->head = p_insert_list;
@@ -87,7 +87,7 @@ INSERT_LIST *r_insert_list_add_first(INSERT *add_insert, INSERT_LIST_INFO *p_ins
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_insert_list_info->head;
@@ -103,7 +103,7 @@ INSERT_LIST *r_insert_list_add_first(INSERT *add_insert, INSERT_LIST_INFO *p_ins
 
 
 /* -------------------------------------------------------------------
- * INSERT Data ꥹȤκǽɲ
+ * INSERT Data をリストの最初に追加
  * 
  */
 INSERT_LIST *insert_list_add_first(INSERT *add_insert, INSERT_LIST_INFO *p_insert_list_info)
@@ -111,17 +111,17 @@ INSERT_LIST *insert_list_add_first(INSERT *add_insert, INSERT_LIST_INFO *p_inser
 	INSERT_LIST *p;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_insert_list = (INSERT_LIST *)xmalloc(sizeof(INSERT_LIST));
-	/* ǡ (insert) 񤭹िΰݤ */
+	/* データ (insert) を書き込むための領域を確保する */
 	p_insert_list->insert = (INSERT *)xmalloc(sizeof(INSERT));
 
-	/* ݤΰ˥ǡ (insert) 񤭹 */
+	/* 確保した領域にデータ (insert) を書き込む */
 	*p_insert_list->insert = *add_insert;
 	p_insert_list->next = NULL;
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_insert_list_info->head == NULL && p_insert_list_info->tail == NULL) {
 		p_insert_list_info->head = p_insert_list;
@@ -129,7 +129,7 @@ INSERT_LIST *insert_list_add_first(INSERT *add_insert, INSERT_LIST_INFO *p_inser
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_insert_list_info->head;
@@ -145,7 +145,7 @@ INSERT_LIST *insert_list_add_first(INSERT *add_insert, INSERT_LIST_INFO *p_inser
 
 
 /* -------------------------------------------------------------------
- * INSERT Data ꥹȤκǽɲäơ Undo Baffer ˽
+ * INSERT Data をリストの最初に追加して、 Undo Baffer に書込む
  *	
  */
 INSERT_LIST *insert_list_add_first_with_undo(INSERT *add_insert, INSERT_LIST_INFO *p_insert_list_info)
@@ -157,17 +157,17 @@ INSERT_LIST *insert_list_add_first_with_undo(INSERT *add_insert, INSERT_LIST_INF
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_insert_list = (INSERT_LIST *)xmalloc(sizeof(INSERT_LIST));
-	/* ǡ (insert) 񤭹िΰݤ */
+	/* データ (insert) を書き込むための領域を確保する */
 	p_insert_list->insert = (INSERT *)xmalloc(sizeof(INSERT));
 
-	/* ݤΰ˥ǡ (insert) 񤭹 */
+	/* 確保した領域にデータ (insert) を書き込む */
 	*p_insert_list->insert = *add_insert;
 	p_insert_list->next = NULL;
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_insert_list_info->head == NULL && p_insert_list_info->tail == NULL) {
 		p_insert_list_info->head = p_insert_list;
@@ -175,7 +175,7 @@ INSERT_LIST *insert_list_add_first_with_undo(INSERT *add_insert, INSERT_LIST_INF
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが１個以上ある
 	 */
 	else {
 		p = p_insert_list_info->head;
@@ -196,7 +196,7 @@ INSERT_LIST *insert_list_add_first_with_undo(INSERT *add_insert, INSERT_LIST_INF
 
 
 /* -------------------------------------------------------------------
- * INSERT Data ꥹȤκǸɲ
+ * INSERT Data をリストの最後に追加
  * 
  */
 INSERT_LIST *insert_list_add_last(INSERT *add_insert, INSERT_LIST_INFO *p_insert_list_info)
@@ -204,17 +204,17 @@ INSERT_LIST *insert_list_add_last(INSERT *add_insert, INSERT_LIST_INFO *p_insert
 	INSERT_LIST *p;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_insert_list = (INSERT_LIST *)xmalloc(sizeof(INSERT_LIST));
-	/* ǡ (insert) 񤭹िΰݤ */
+	/* データ (insert) を書き込むための領域を確保する */
 	p_insert_list->insert = (INSERT *)xmalloc(sizeof(INSERT));
 
-	/* ݤΰ˥ǡ (insert) 񤭹 */
+	/* 確保した領域にデータ (insert) を書き込む */
 	*p_insert_list->insert = *add_insert;
 	p_insert_list->next = NULL;
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_insert_list_info->head == NULL && p_insert_list_info->tail == NULL) {
 		p_insert_list_info->head = p_insert_list;
@@ -222,7 +222,7 @@ INSERT_LIST *insert_list_add_last(INSERT *add_insert, INSERT_LIST_INFO *p_insert
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_insert_list_info->head != NULL 
 				&& p_insert_list_info->tail != NULL 
@@ -232,7 +232,7 @@ INSERT_LIST *insert_list_add_last(INSERT *add_insert, INSERT_LIST_INFO *p_insert
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_insert_list_info->tail;
@@ -240,7 +240,7 @@ INSERT_LIST *insert_list_add_last(INSERT *add_insert, INSERT_LIST_INFO *p_insert
 		p->next = p_insert_list_info->tail;
 	}
 
-	/* ɥХåե˽ */
+	/* アンドゥバッファに書込む */
 //	undo_list_add_first(11, p_insert_list_info->tail, NULL);
 	return p_insert_list_info->tail;
 }
@@ -250,7 +250,7 @@ INSERT_LIST *insert_list_add_last(INSERT *add_insert, INSERT_LIST_INFO *p_insert
 
 
 /* -------------------------------------------------------------------
- * INSERT Data ꥹȤκǸɲá Undo Baffer ˽
+ * INSERT Data をリストの最後に追加、 Undo Baffer に書込む
  *	
  */
 INSERT_LIST *insert_list_add_last_with_undo(INSERT *add_insert, INSERT_LIST_INFO *p_insert_list_info)
@@ -262,17 +262,17 @@ INSERT_LIST *insert_list_add_last_with_undo(INSERT *add_insert, INSERT_LIST_INFO
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_insert_list = (INSERT_LIST *)xmalloc(sizeof(INSERT_LIST));
-	/* ǡ (insert) 񤭹िΰݤ */
+	/* データ (insert) を書き込むための領域を確保する */
 	p_insert_list->insert = (INSERT *)xmalloc(sizeof(INSERT));
 
-	/* ݤΰ˥ǡ (insert) 񤭹 */
+	/* 確保した領域にデータ (insert) を書き込む */
 	*p_insert_list->insert = *add_insert;
 	p_insert_list->next = NULL;
 
 	/* -----------------------------------------------------
-	 * head & tail ξ NULL ΤȤϡĤǡʤ 
+	 * head & tail の両方が NULL のときは、１個もデータがない 
 	 */
 	if (p_insert_list_info->head == NULL && p_insert_list_info->tail == NULL) {
 		p_insert_list_info->head = p_insert_list;
@@ -280,7 +280,7 @@ INSERT_LIST *insert_list_add_last_with_undo(INSERT *add_insert, INSERT_LIST_INFO
 	}
 
 	/* -----------------------------------------------------
-	 * head = tail  NULL ǤϤʤȤϡĤǡ
+	 * head = tail で NULL ではないときは、１個だけデータがある
 	 */
 	else if (p_insert_list_info->head != NULL 
 				&& p_insert_list_info->tail != NULL 
@@ -290,7 +290,7 @@ INSERT_LIST *insert_list_add_last_with_undo(INSERT *add_insert, INSERT_LIST_INFO
 	}
 
 	/* -----------------------------------------------------
-	 * ǡİʾ夢
+	 * データが２個以上ある
 	 */
 	else {
 		p = p_insert_list_info->tail;
@@ -311,7 +311,7 @@ INSERT_LIST *insert_list_add_last_with_undo(INSERT *add_insert, INSERT_LIST_INFO
 
 
 /* -------------------------------------------------------------------
- * INSERT Data κǽ (κǤϤʤ)
+ * INSERT Data の削除機能 (メモリの削除ではない)
  * 
  */
 int insert_list_delete(INSERT_LIST *del_List, INSERT_LIST_INFO *p_insert_list_info)
@@ -320,38 +320,38 @@ int insert_list_delete(INSERT_LIST *del_List, INSERT_LIST_INFO *p_insert_list_in
 	INSERT_LIST *pb = NULL;
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_insert_list_info->head && del_List->next == NULL) {
 		p_insert_list_info->head = NULL;
 		p_insert_list_info->tail = NULL;
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_insert_list_info->head && del_List->next != NULL) {
 		p_insert_list_info->head = p_insert_list_info->head->next;
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_insert_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_insert_list_info->tail) {
 				pb->next = NULL;
 				p_insert_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_insert_list_info->head && del_List != p_insert_list_info->tail) {
 				pb->next = p->next;
 			}
@@ -371,7 +371,7 @@ int insert_list_delete(INSERT_LIST *del_List, INSERT_LIST_INFO *p_insert_list_in
 
 
 /* -------------------------------------------------------------------
- * INSERT Data κǽ (κǤϤʤUndo Buffer ذܤ)
+ * INSERT Data の削除機能 (メモリの削除ではなく、Undo Buffer へ移す)
  * 
  */
 int insert_list_delete_Undo(INSERT_LIST *del_List, INSERT_LIST_INFO *p_insert_list_info)
@@ -383,38 +383,38 @@ int insert_list_delete_Undo(INSERT_LIST *del_List, INSERT_LIST_INFO *p_insert_li
 	LPDIAGRAM lpdiagram;
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_insert_list_info->head && del_List->next == NULL) {
 		p_insert_list_info->head = NULL;
 		p_insert_list_info->tail = NULL;
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_insert_list_info->head && del_List->next != NULL) {
 		p_insert_list_info->head = p_insert_list_info->head->next;
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_insert_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_insert_list_info->tail) {
 				pb->next = NULL;
 				p_insert_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_insert_list_info->head && del_List != p_insert_list_info->tail) {
 				pb->next = p->next;
 			}
@@ -439,24 +439,24 @@ int insert_list_delete_Undo(INSERT_LIST *del_List, INSERT_LIST_INFO *p_insert_li
 
 
 /* -------------------------------------------------------------------
- * INSERT Υݥ󥿤Υǡ Undo ХåեԽˤơ
- * ξ˿ǡ롣
+ * INSERT のポインタのデータを Undo バッファ（編集）に入れて、
+ * その場所に新しいデータを入れる。
  *	
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  */
 INSERT_LIST *insert_list_edit(INSERT_LIST *point, INSERT *change_insert, INSERT_LIST_INFO *p_insert_list_info)
 {
-	/* ǡ (LIST) 񤭹िΰݤ */
+	/* データ (LIST) を書き込むための領域を確保する */
 	p_insert_list = (INSERT_LIST *)xmalloc(sizeof(INSERT_LIST));
 
-	/* ǡ (insert) 񤭹िΰݤ */
+	/* データ (insert) を書き込むための領域を確保する */
 	p_insert_list->insert = (INSERT *)xmalloc(sizeof(INSERT));
 
-	/* ݤΰѹΥǡ (insert) 񤭹 */
+	/* 確保した領域に変更前のデータ (insert) を書き込む */
 	*p_insert_list->insert = *point->insert;
 	p_insert_list->next = point;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->insert = *change_insert;
 
 //	undo_list_add_first(13, p_insert_list, NULL);
@@ -468,10 +468,10 @@ INSERT_LIST *insert_list_edit(INSERT_LIST *point, INSERT *change_insert, INSERT_
 
 
 /* -------------------------------------------------------------------
- * INSERT Υݥ󥿤Υǡ Undo ХåեԽˤơ
- * ξ˿ǡ졢Undo Baffer ˽
+ * INSERT のポインタのデータを Undo バッファ（編集）に入れて、
+ * その場所に新しいデータを入れ、Undo Baffer に書込む
  *	
- * ͡ΥǡΥɥ쥹
+ * 戻り値　元のデータのアドレス
  */
 INSERT_LIST *insert_list_edit_with_undo(INSERT_LIST *point, INSERT *change_insert, INSERT_LIST_INFO *p_insert_list_info)
 {
@@ -481,10 +481,10 @@ INSERT_LIST *insert_list_edit_with_undo(INSERT_LIST *point, INSERT *change_inser
 	LPDIAGRAM lpdiagram;
 
 
-	/* ݤΰѹΥǡ (INSERT) 񤭹 */
+	/* 確保した領域に変更前のデータ (INSERT) を書き込む */
 	insert = *point->insert;
 
-	/* ѹǡ񤭹 */
+	/* 変更データを書き込む */
 	*point->insert = *change_insert;
 
 	lpdiagram.insert_point = point->insert;
@@ -499,7 +499,7 @@ INSERT_LIST *insert_list_edit_with_undo(INSERT_LIST *point, INSERT *change_inser
 
 
 /* -------------------------------------------------------------------
- *	ꥹȤĴ٤
+ *	リストの総数を調べる
  */
 long insert_list_num(INSERT_LIST_INFO *p_insert_list_info)
 {
@@ -509,12 +509,12 @@ long insert_list_num(INSERT_LIST_INFO *p_insert_list_info)
 	p = p_insert_list_info->head;
 	i = 0;
 	/* -------------------------------------------
-	 * ǸޤǸĤʤ硢 p  NULL  
-	 * äƥ롼פȴ롣
+	 * 最後まで見つからない場合、 p に NULL が 
+	 * 入ってループを抜ける。
 	 */
 	while(p != NULL) {
 		i++;
-		p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+		p = p->next;	/* ポインタを次のデータに移す */
 	}
 	return i;
 }
@@ -524,7 +524,7 @@ long insert_list_num(INSERT_LIST_INFO *p_insert_list_info)
 
 
 /* -------------------------------------------------------------------
- * n ܤΥǡθ
+ * n 番目のデータの検索
  * 
  */
 INSERT_LIST *insert_search_num(long search_number, INSERT_LIST_INFO *p_insert_list_info)
@@ -541,11 +541,11 @@ INSERT_LIST *insert_search_num(long search_number, INSERT_LIST_INFO *p_insert_li
 		p = p->next;
 	}
 
-	/* n ܤΥǡΥɥ쥹֤ */
+	/* n 番目のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -556,9 +556,9 @@ INSERT_LIST *insert_search_num(long search_number, INSERT_LIST_INFO *p_insert_li
 
 
 /* -------------------------------------------------------------------
- * INSERT Υǡθ
+ * INSERT のデータの検索
  * 
- *   INSERT_LIST
+ * 戻値  INSERT_LIST
  */
 INSERT_LIST *insert_search_insert(INSERT *p_insert, INSERT_LIST_INFO *p_insert_list_info)
 {
@@ -571,11 +571,11 @@ INSERT_LIST *insert_search_insert(INSERT *p_insert, INSERT_LIST_INFO *p_insert_l
 		p = p->next;
 	}
 
-	/* p_insert ΥǡΥɥ쥹֤ */
+	/* p_insert のデータのアドレスを返す */
 	if (p != NULL) {
 		return p;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return NULL;
 	}
@@ -586,9 +586,9 @@ INSERT_LIST *insert_search_insert(INSERT *p_insert, INSERT_LIST_INFO *p_insert_l
 
 
 /* -------------------------------------------------------------------
- * INSERT Υǡθ
+ * INSERT のデータの検索
  * 
- *   long
+ * 戻値  long
  */
 long insert_search_insert_to_num(INSERT *p_insert, INSERT_LIST_INFO *p_insert_list_info)
 {
@@ -603,11 +603,11 @@ long insert_search_insert_to_num(INSERT *p_insert, INSERT_LIST_INFO *p_insert_li
 		i++;
 	}
 
-	/* p_insert ΥǡΥɥ쥹֤ */
+	/* p_insert のデータのアドレスを返す */
 	if (p != NULL) {
 		return i;
 	}
-	/* ޤǥǡʤ */
+	/* そこまでデータがない */
 	else {
 		return 0;
 	}
@@ -618,7 +618,7 @@ long insert_search_insert_to_num(INSERT *p_insert, INSERT_LIST_INFO *p_insert_li
 
 
 /* -------------------------------------------------------------------
- *	INSERT Data ꥹȤ
+ *	INSERT Data をリストから削除
  */
 int insert_list_free(INSERT_LIST *del_List, INSERT_LIST_INFO *p_insert_list_info)
 {
@@ -626,39 +626,39 @@ int insert_list_free(INSERT_LIST *del_List, INSERT_LIST_INFO *p_insert_list_info
 	INSERT_LIST *pb = NULL;
 
 
-	/* ǡƬǣĤ  */
+	/* データが先頭で１個だけ  */
 	if (del_List == p_insert_list_info->head && del_List->next == NULL) {
 		p_insert_list_info->head = NULL;
 		p_insert_list_info->tail = NULL;
 	}
-	/* ǡƬǣİʾ  */
+	/* データが先頭で２個以上  */
 	else if (del_List == p_insert_list_info->head && del_List->next != NULL) {
 		p_insert_list_info->head = p_insert_list_info->head->next;
 	}
 	else {
 		/* -------------------------------------------
-		 * ݥ󥿤ΥǡΤꤿΤǡ
-		 * head (ꥹȤƬ) ݥ󥿤
-		 * ĤޤǷ֤Υǡõ
+		 * 削除するポインタの前のデータを知りたいので、
+		 * head (リストの先頭) から削除するポインタが
+		 * 見つかるまで繰り返し、前のデータを探す。
 		 */
 		p = p_insert_list_info->head;
 		/* -------------------------------------------
-		 * ǸޤǸĤʤ硢 p  NULL  
-		 * äƥ롼פȴ롣
+		 * 最後まで見つからない場合、 p に NULL が 
+		 * 入ってループを抜ける。
 		 */
 		while(p != NULL && p != del_List) {
-			pb = p;			/* ΥǡΥݥ󥿤Ȥ¸Ƥ */
-			p = p->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			pb = p;			/* 前のデータのポインタとして保存しておく */
+			p = p->next;	/* ポインタを次のデータに移す */
 		}
 
 
 		if(p != NULL){
-			/* ǸΥǡ */
+			/* 最後のデータ */
 			if (del_List == p_insert_list_info->tail) {
 				pb->next = NULL;
 				p_insert_list_info->tail = pb;
 			}
-			/* ֤Υǡ */
+			/* 中間のデータ */
 			else if (del_List != p_insert_list_info->head && del_List != p_insert_list_info->tail) {
 				pb->next = p->next;
 			}
@@ -678,13 +678,13 @@ int insert_list_free(INSERT_LIST *del_List, INSERT_LIST_INFO *p_insert_list_info
 
 
 /* -------------------------------------------------------------------
- *	ꥹȤ
+ *	全リストを削除
  */
 void insert_list_all_free(INSERT_LIST_INFO *p_insert_list_info)
 {
 	while(p_insert_list_info->head != NULL) {
 		if (insert_list_free(p_insert_list_info->head, p_insert_list_info) == 0) {
-			g_print("List_insert.c : insert_list_all_free() : insert_list_free() ǥ顼\n");
+			g_print("List_insert.c : insert_list_all_free() : insert_list_free() でエラー\n");
 			g_print("%s : %d : insert_list_all_free() : ERROR\n", __FILE__, __LINE__);
 		}
 	}
@@ -699,11 +699,11 @@ void insert_list_print(INSERT_LIST_INFO *p_insert_list_info)
 	INSERT_LIST *p;
 	int i = 0;
 
-	g_print("----- INSERT ꥹȤɽ -----\n");
+	g_print("----- INSERT リストを表示 -----\n");
 	p = p_insert_list_info->head;
 	while (p != NULL) {
 		i++;
-		g_print("%d(0x%x) : name[%s] : layer[%d] : color[%d] : style[0x%x]\n(%f,%f) %f scale(%f,%f) Ŀ(%d,%d) pitch(%f,%f)\n", 
+		g_print("%d(0x%x) : name[%s] : layer[%d] : color[%d] : style[0x%x]\n位置(%f,%f) %f度 scale(%f,%f) 個数(%d,%d) pitch(%f,%f)\n", 
 					i, (int)p->insert, p->insert->name, 
 					p->insert->layer, (int)p->insert->color, p->insert->style, 
 					p->insert->x, p->insert->y, p->insert->angle, 
@@ -720,7 +720,7 @@ void insert_list_print(INSERT_LIST_INFO *p_insert_list_info)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : List_insert.c
