@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/05/25
- *    Last                 : 2003/05/25
+ *    Last                 : 2007/10/15
  * ====================================================================
  */
 
@@ -39,7 +39,7 @@
 #include "List_Block.h"
 #include "List_Undo.h"
 #include "List_Select.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "MsgBox.h"
 #include "sagcad.h"
 #include "global.h"
@@ -60,7 +60,7 @@
 /* -------------------------------------------------------------------
  * outside_process
  * 
- * outside_process_on ξ֤ SELECT & RECT 򤦤ޤȤ
+ * outside_process_on の状態で SELECT & RECT をうまく使う
  */
 int os_process(void)
 {
@@ -68,7 +68,7 @@ int os_process(void)
 	char str[256],path[256], tempfile[256];
 	int Ret;
 
-	/* outside_process ޤ¹ԤƤʤȤ */
+	/* outside_process がまだ実行されていないとき */
 	if (outside_process_on == 0) {
 
 		strcpy(str, TOOLDIR);
@@ -76,8 +76,8 @@ int os_process(void)
 //		strcat(str, "/NoName.ops");
 		g_print("Tool path ---> [%s]\n", str);
 		Ret = read_file_name_get(str);
-		/* ե򥭥󥻥 */
-		if (Ret == 0) {
+		/* ファイルの選択をキャンセル */
+		if (Ret == -1) {
 			return 0;
 		}
 
@@ -96,15 +96,15 @@ int os_process(void)
 		}
 
 
-		/* osp_temp.txt к */
+		/* osp_temp.txt があれば削除 */
 		strcpy(tempfile, sagcad_user.ConfigPath);
 		strcat(tempfile, "osp_temp.txt");
 		if ((stream = fopen(tempfile, "r")) == NULL) {
-			//g_print("osp_temp.txt ʤä\n");
+			//g_print("osp_temp.txt がなかった\n");
 		}
 		else {
 			fclose(stream);
-			//g_print("osp_temp.txt ä\n");
+			//g_print("osp_temp.txt があったから削除\n");
 			sprintf(str, "rm %s", tempfile);
 			system(str);
 		}
@@ -117,9 +117,9 @@ int os_process(void)
 
 
 
-	/* outside_process ¹ */
+	/* outside_process 実行中 */
 	/* 
-	 * SELECT,MANY ι
+	 * SELECT,MANY の選択確定の合図
 	 * 
 	 * 
 	 */
@@ -155,7 +155,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 	/* ---------------------------------
-	 * ե򥪡ץ
+	 * ファイルをオープン
 	 */ 
 	if ( (stream = fopen( outside_process->opsFile, "r" )) == NULL ){
 		g_print ("ops File [%s] Not Open\n", outside_process->opsFile);
@@ -171,7 +171,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * COMMENT 
+		 * COMMENT セクション
 		 */
 		if (str[0] == '#') {
 			
@@ -179,7 +179,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * OPS_VERSION 
+		 * OPS_VERSION セクション
 		 */
 		else if (strstr(str, "OPS_VERSION") != NULL ) {
 			/* Data check */
@@ -194,7 +194,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * MSGBAR 
+		 * MSGBAR セクション
 		 */
 		else if (strstr(str, "MSGBAR") != NULL ) {
 			/* Data check */
@@ -227,7 +227,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * MSGBOX 
+		 * MSGBOX セクション
 		 */
 		else if (strstr(str, "MSGBOX") != NULL ) {
 			/* Data check */
@@ -260,7 +260,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * INPUT 
+		 * INPUT セクション
 		 */
 		else if (strstr(str, "INPUT") != NULL ) {
 
@@ -297,7 +297,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * SELECT_ONE 
+		 * SELECT_ONE セクション
 		 */
 		else if (strstr(str, "SELECT") != NULL && strstr(str, "ONE") != NULL) {
 			/* Data check */
@@ -343,7 +343,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * SELECT_MANY 
+		 * SELECT_MANY セクション
 		 */
 		else if (strstr(str, "SELECT") != NULL && strstr(str, "MANY") != NULL) {
 			/* Data check */
@@ -389,7 +389,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * OUT_FILE 
+		 * OUT_FILE セクション
 		 */
 		else if (strstr(str, "OUT_FILE") != NULL ) {
 			/* Data check */
@@ -422,7 +422,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * INP_FILE 
+		 * INP_FILE セクション
 		 */
 		else if (strstr(str, "INP_FILE") != NULL ) {
 			/* Data check */
@@ -455,7 +455,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * EXEC 
+		 * EXEC セクション
 		 */
 		else if (strstr(str, "EXEC") != NULL ) {
 			/* Data check */
@@ -490,7 +490,7 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * END 
+		 * END セクション
 		 */
 		else if (strstr(str, "END") != NULL ) {
 			outside_process->index = outside_process->index + 1;
@@ -519,13 +519,13 @@ int ops_read(OUTSIDE_PROCESS *outside_process)
 
 
 		/* -------------------------------------------------
-		 * LOOP 
+		 * LOOP セクション
 		 */
 		else if (strstr(str, "LOOP") != NULL ) {
 			outside_process->index = outside_process->index + 1;
 			outside_process->Work[outside_process->index].work = OPS_LOOP;
 
-			/* sel_obj ֤ */
+			/* sel_obj に戻る位置を指定 */
 			LineDataSplit(str, ',', 2, ret);
 			outside_process->Work[outside_process->index].sel_obj = atoi(ret);
 
@@ -571,7 +571,7 @@ int ops_next_go(OUTSIDE_PROCESS *op)
 	
 	switch (op->Work[op->now].work) {
 
-		/* å򥹥ơС */
+		/* メッセージをステータスバーで伝える */
 		case OPS_MSGBAR:
 			if (StatusMsg(op->Work[op->now].msg) == 0) {
 				g_print ("MSGBAR error\n");
@@ -582,16 +582,16 @@ int ops_next_go(OUTSIDE_PROCESS *op)
 			return 1;
 			break;
 
-		/* åܥå */
+		/* メッセージをダイアログボックスで伝える */
 		case OPS_MSGBOX :
 			MsgBox("Outside Process", op->Work[op->now].msg, "", NULL, NULL, "OK");
 			ops_next_go(op);
 			return 1;
 			break;
 
-		/* ϥܥåˤǡ */
+		/* 数値入力ダイアログボックスによるデータ入力 */
 		case OPS_INPUT :
-			/* ϥܥåɽ */
+			/* 数値入力ダイアログボックス表示 */
 			strcpy(ret, "");
 			Ret = InputBox("SagCAD Outside Process", op->Work[op->now].msg, op->Work[op->now].keyword, ret);
 			if (Ret == -1) {
@@ -600,7 +600,7 @@ int ops_next_go(OUTSIDE_PROCESS *op)
 				return 0;
 			}
 
-			/* ե򥪡ץ */ 
+			/* ファイルをオープン */ 
 			strcpy(tempfile, sagcad_user.ConfigPath);
 			strcat(tempfile, "osp_temp.txt");
 			if ((stream = fopen(tempfile, "a")) == NULL) {
@@ -611,7 +611,7 @@ int ops_next_go(OUTSIDE_PROCESS *op)
 
 			sprintf(str, "INPUT,\"%s\",\"%s\"\n", op->Work[op->now].keyword, ret);
 			fputs(str, stream);
-			/* ե򥯥 */ 
+			/* ファイルをクローズ */ 
 			fclose(stream);
 			ops_next_go(op);
 			return 1;
@@ -637,7 +637,7 @@ int ops_next_go(OUTSIDE_PROCESS *op)
 			SelectColorFrag = 0;
 			break;
 
-		/* ǡ (osp_temp.txt ˤƤեե̾) */
+		/* データを出力 (osp_temp.txt にためておいたファイルを指定ファイルに名変) */
 		case OPS_OUT_FILE :
 			ops_select_output_info(op);
 
@@ -650,9 +650,9 @@ int ops_next_go(OUTSIDE_PROCESS *op)
 			return 1;
 			break;
 
-		/* ǡ */
+		/* データを取り込む */
 		case OPS_INP_FILE :
-			/* ե򥪡ץ */
+			/* ファイルをオープン */
 			sprintf(tempfile, "%s", op->Work[op->now].keyword);
 //			strcpy(tempfile, op->Work[op->now].keyword);
 			if ((stream = fopen(tempfile, "r")) == NULL) {
@@ -663,13 +663,13 @@ int ops_next_go(OUTSIDE_PROCESS *op)
 
 			Ret = ops_select_input(stream);
 
-			/* ե򥯥 */ 
+			/* ファイルをクローズ */ 
 			fclose(stream);
 			ops_next_go(op);
 			return 1;
 			break;
 
-		/* ץư */
+		/* 外部プログラムを起動する */
 		case OPS_EXEC :
 			/* shell */
 			sprintf(str, "%s %s", op->Work[op->now].keyword, op->Work[op->now].msg);
@@ -681,16 +681,16 @@ int ops_next_go(OUTSIDE_PROCESS *op)
 			return 1;
 			break;
 
-		/* Outside Process λ */
+		/* Outside Process を終了する */
 		case OPS_END :
 			Redraw();
-			//MsgBox("SagCAD", "Outside Process", "λޤ", NULL, NULL, "OK");
+			//MsgBox("SagCAD", "Outside Process", "処理が終了しました。", NULL, NULL, "OK");
 			SelectCancel(MainWindow);
 			StatusMsg( _(" [Outside Process] The processing ended.") );
 			return 1;
 			break;
 
-		/* ǽ餫 */
+		/* 最初から */
 		case OPS_LOOP :
 			Redraw();
 			op->now = op->Work[op->now].sel_obj - 1;
@@ -713,8 +713,8 @@ int ops_select_output_info(OUTSIDE_PROCESS *op)
 	int i;
 
 
-	/*  */
-	/* ե򥪡ץ */ 
+	/* 出力 */
+	/* ファイルをオープン */ 
 	strcpy(tempfile, sagcad_user.ConfigPath);
 	strcat(tempfile, "osp_temp.txt");
 
@@ -790,7 +790,7 @@ int ops_select_output_info(OUTSIDE_PROCESS *op)
 	str[65] = '\0';
 	fputs(str, stream );
 
-	/* ե򥯥 */ 
+	/* ファイルをクローズ */ 
 	fclose(stream);
 
 	return 1;
@@ -801,7 +801,7 @@ int ops_select_output_info(OUTSIDE_PROCESS *op)
 
 
 /* -------------------------------------------------------
- * ޷Ϥ롣
+ * 選択図形を出力する。
  * 
  * osp_temp.txt
  */
@@ -812,8 +812,8 @@ int ops_select_output(OUTSIDE_PROCESS *op)
 	SELECT_LIST *ps;
 
 
-	/*  */
-	/* ե򥪡ץ */ 
+	/* 出力 */
+	/* ファイルをオープン */ 
 	strcpy(tempfile, sagcad_user.ConfigPath);
 	strcat(tempfile, "osp_temp.txt");
 
@@ -828,13 +828,13 @@ int ops_select_output(OUTSIDE_PROCESS *op)
 	fputs(str, stream);
 
 	/* -----------------------------------------------------------------
-	 * ޷
+	 * 選択図形
 	 */
 	if (select_list_info.head != NULL) {
 		ps = select_list_info.head;
 		while (ps != NULL) {
 			ops_select_output_select(stream, ps->select);
-			ps = ps->next;	/* ݥ󥿤򼡤Υǡ˰ܤ */
+			ps = ps->next;	/* ポインタを次のデータに移す */
 		}
 	}
 
@@ -847,18 +847,18 @@ int ops_select_output(OUTSIDE_PROCESS *op)
 	}
 	fputs(str, stream);
 
-	/* ե򥯥 */ 
+	/* ファイルをクローズ */ 
 	fclose(stream);
 
 
-	/* Cut ʤ */
-	/* SELECT_LIST 򥯥ꥢ */
+	/* Cut なら削除 */
+	/* SELECT_LIST をクリア */
 	if (op->Work[op->now].Cut == 1) {
 		SelectDelete(MainWindow);
 	}
 
 
-	/* ꥹȤ */
+	/* 全リストを削除 */
 	select_list_all_free();
 	UpDate();
 
@@ -876,7 +876,7 @@ int ops_select_output(OUTSIDE_PROCESS *op)
 
 
 /* -------------------------------------------------------
- * ޷Ϥ롣
+ * 選択図形を出力する。
  * 
  * diagram_type
  *     CAD       : 2 or 4
@@ -893,9 +893,9 @@ int ops_select_output_select(FILE *stream, SELECT *select)
 	int i;
 
 
-	/* Ǥ */
+	/* 任意点 */
 	if (select->index == 1) {
-		/* ANY POINT () */
+		/* ANY POINT (点) */
 		sprintf(str, "POINT,%d,%d,%d,%f,%f\n", 
 				NowLayer, 
 				(int)NowColor, 
@@ -914,7 +914,7 @@ int ops_select_output_select(FILE *stream, SELECT *select)
 		}
 
 		switch (select->diagram_point.cad_point->code) {
-			/* POINT () */
+			/* POINT (点) */
 			case 0:
 				sprintf(str, "POINT,%d,%d,%d,%f,%f\n", 
 						select->diagram_point.cad_point->layer, 
@@ -925,7 +925,7 @@ int ops_select_output_select(FILE *stream, SELECT *select)
 				fputs(str, stream);
 				break;
 
-			/* LINE () */
+			/* LINE (線) */
 			case 1:
 				sprintf(str, "LINE,%d,%d,%d,%f,%f,%f,%f\n", 
 						select->diagram_point.cad_point->layer, 
@@ -938,7 +938,7 @@ int ops_select_output_select(FILE *stream, SELECT *select)
 				fputs(str, stream);
 				break;
 
-			/* ARC (߸) */
+			/* ARC (円弧) */
 			case 2:
 				sprintf(str, "ARC,%d,%d,%d,%f,%f,%f,%f,%f,%f,%f\n", 
 						select->diagram_point.cad_point->layer, 
@@ -954,7 +954,7 @@ int ops_select_output_select(FILE *stream, SELECT *select)
 				fputs(str, stream);
 				break;
 
-			/* CIRCLE () */
+			/* CIRCLE (円) */
 			case 4:
 				sprintf(str, "CIRCLE,%d,%d,%d,%f,%f,%f\n", 
 						select->diagram_point.cad_point->layer, 
@@ -1067,7 +1067,7 @@ int ops_select_output_select(FILE *stream, SELECT *select)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : OutsideProcess.c
@@ -1085,7 +1085,7 @@ int ops_select_input(FILE *stream)
 
 //	g_print("ops_select_input() : in\n");
 
-	/*  */
+	/* 入力 */
 	while(1){
 		if (LineRead(stream, str) == 0) {
 			fclose(stream);
@@ -1094,7 +1094,7 @@ int ops_select_input(FILE *stream)
 		}
 
 		/* -------------------------------------------------
-		 * START 
+		 * START セクション
 		 */
 		if (strstr(str, "START") != NULL && str[0] == 'S') {
 			if ( opsStartSectionRead(stream) == 0 ) {
@@ -1105,10 +1105,10 @@ int ops_select_input(FILE *stream)
 		}
 
 		/* -------------------------------------------------
-		 * ERROR 
+		 * ERROR セクション
 		 */
 		if (strstr(str, "ERROR") != NULL && str[0] == 'E') {
-			/* ǡå */
+			/* データ数をチェック */
 			if (split_word_num(str, ',') != 1) {
 				g_print ("[Input File] ERROR Format Error !\n");
 				return 0;
@@ -1121,7 +1121,7 @@ int ops_select_input(FILE *stream)
 		}
 
 		/* -------------------------------------------------
-		 * EOF 
+		 * EOF セクション
 		 */
 		if (strstr(str, "EOF") != NULL && str[0] == 'E') {
 			return 1;
@@ -1228,7 +1228,7 @@ int ops_Point_read(char *str)
 
 //	g_print("ops_select_input() : in\n");
 
-	/* ǡå */
+	/* データ数をチェック */
 	if (split_word_num(str, ',') != 5) {
 		g_print ("OPS POINT Format Error !\n");
 		return 0;
@@ -1256,7 +1256,7 @@ int ops_Point_read(char *str)
 	cad.cy = 0;
 	cad.r = 0;
 
-	/* CAD Data ꥹȤκǽɲ */
+	/* CAD Data をリストの最初に追加 */
 	cad_list_add_first_with_undo(&cad, &cad_list_info);
 
 	return 1;
@@ -1270,7 +1270,7 @@ int ops_Line_read(char *str)
 	CAD cad;
 
 
-	/* ǡå */
+	/* データ数をチェック */
 	if (split_word_num(str, ',') != 7) {
 		g_print ("OPS LINE Format Error !\n");
 		return 0;
@@ -1300,7 +1300,7 @@ int ops_Line_read(char *str)
 	cad.cy = 0;
 	cad.r = 0;
 
-	/* CAD Data ꥹȤκǽɲ */
+	/* CAD Data をリストの最初に追加 */
 	cad_list_add_first_with_undo(&cad, &cad_list_info);
 
 	return 1;
@@ -1314,7 +1314,7 @@ int ops_Arc_read(char *str)
 	CAD cad;
 
 
-	/* ǡå */
+	/* データ数をチェック */
 	if (split_word_num(str, ',') != 10) {
 		g_print ("OPS ARC Format Error !\n");
 		return 0;
@@ -1347,7 +1347,7 @@ int ops_Arc_read(char *str)
 	LineDataSplit(str, ',', 11, ret);
 	cad.ey = atof(ret);
 
-	/* CAD Data ꥹȤκǽɲ */
+	/* CAD Data をリストの最初に追加 */
 	cad_list_add_first_with_undo(&cad, &cad_list_info);
 
 	return 1;
@@ -1361,7 +1361,7 @@ int ops_Circle_read(char *str)
 	CAD cad;
 
 
-	/* ǡå */
+	/* データ数をチェック */
 	if (split_word_num(str, ',') != 6) {
 		g_print ("OPS CIRCLE Format Error !\n");
 		return 0;
@@ -1390,7 +1390,7 @@ int ops_Circle_read(char *str)
 	cad.ex = 0;
 	cad.ey = 0;
 
-	/* CAD Data ꥹȤκǽɲ */
+	/* CAD Data をリストの最初に追加 */
 	cad_list_add_first_with_undo(&cad, &cad_list_info);
 
 	return 1;
@@ -1404,7 +1404,7 @@ int ops_Ellipse_read(char *str)
 	ELLIPSE ellipse;
 
 
-	/* ǡå */
+	/* データ数をチェック */
 	if (split_word_num(str, ',') != 10) {
 		g_print ("OPS ELLIPSE Format Error !\n");
 		return 0;
@@ -1446,7 +1446,7 @@ int ops_Ellipse_read(char *str)
 //			  ellipse.sa, ellipse.ea);
 
 
-	/* ELLIPSE Data ꥹȤκǽɲ */
+	/* ELLIPSE Data をリストの最初に追加 */
 	ellipse_list_add_first_with_undo(&ellipse, &ellipse_list_info);
 
 	return 1;
@@ -1461,7 +1461,7 @@ int ops_Dimension_read(char *str, FILE *stream)
 	int i;
 
 
-	/* ǡå */
+	/* データ数をチェック */
 	if (split_word_num(str, ',') != 13) {
 		g_print ("OPS DIMENSION Format Error !\n");
 		return 0;
@@ -1498,13 +1498,13 @@ int ops_Dimension_read(char *str, FILE *stream)
 
 	if (dimension.index != 0) {
 
-		/* ǡ (AssistLine) 񤭹िΰݤ */
+		/* データ (AssistLine) を書き込むための領域を確保する */
 		dimension.AssistLine = (ASSISTANCE *)xmalloc(dimension.index * sizeof(ASSISTANCE));
 
 		for (i = 0 ; i < dimension.index ; i++) {
 			if (LineRead(stream, str) == 0) return 0;
 
-			/* ǡå */
+			/* データ数をチェック */
 			if (split_word_num(str, ',') != 8) {
 				g_print ("OPS ASSISTLINE Format Error !\n");
 				return 0;
@@ -1540,7 +1540,7 @@ int ops_Dimension_read(char *str, FILE *stream)
 		}
 	}
 
-	/* DIMENSION Data ꥹȤκǽɲ */
+	/* DIMENSION Data をリストの最初に追加 */
 	dimension_list_add_first_with_undo(&dimension, &dimension_list_info);
 
 	return 1;
@@ -1556,7 +1556,7 @@ int ops_PolyLine_read(char *str, FILE *stream)
 	int i;
 
 
-	/* ǡå */
+	/* データ数をチェック */
 	if (split_word_num(str, ',') != 8) {
 		g_print ("OPS DIMENSION Format Error !\n");
 		return 0;
@@ -1594,7 +1594,7 @@ int ops_PolyLine_read(char *str, FILE *stream)
 		for (i = 0 ; i < polyline.index ; i++) {
 			if (LineRead(stream, str) == 0) return 0;
 
-			/* ǡå */
+			/* データ数をチェック */
 			if (split_word_num(str, ',') != 8) {
 				g_print ("OPS ASSISTLINE Format Error !\n");
 				return 0;
@@ -1613,7 +1613,7 @@ int ops_PolyLine_read(char *str, FILE *stream)
 		}
 	}
 
-	/* POLYLINE Data ꥹȤκǽɲ */
+	/* POLYLINE Data をリストの最初に追加 */
 	polyline_list_add_first_with_undo(&polyline, &polyline_list_info);
 
 	return 1;
