@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/04/12
- *    Last                 : 2003/04/12
+ *    Last                 : 2007/10/11
  * ====================================================================
  */
 
@@ -37,7 +37,7 @@
 #include "List_Block.h"
 #include "List_Undo.h"
 #include "List_Select.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "MsgBox.h"
 #include "sagcad.h"
 #include "etc.h"
@@ -50,7 +50,7 @@
 
 
 /* -------------------------------------------------------------------
- * ϰ ܥ ٥
+ * 印刷範囲 ボタン イベント
  */
 void view_button_toggled(GtkWidget *widget, PRINTSET_DLG *printset_dlg)
 {
@@ -78,7 +78,7 @@ void view_button_toggled(GtkWidget *widget, PRINTSET_DLG *printset_dlg)
 
 
 /* -------------------------------------------------------------------
- * ϰ ܥ ٥
+ * 印刷範囲 ボタン イベント
  */
 void orientation_button_toggled(GtkWidget *widget, PRINTSET_DLG *printset_dlg)
 {
@@ -106,7 +106,7 @@ void orientation_button_toggled(GtkWidget *widget, PRINTSET_DLG *printset_dlg)
 
 
 /* -------------------------------------------------------------------
- * ѻ極 ܥ ٥
+ * 用紙サイズ ボタン イベント
  */
 void paper_button_toggled(GtkWidget *widget, PRINTSET_DLG *printset_dlg)
 {
@@ -155,7 +155,7 @@ void paper_button_toggled(GtkWidget *widget, PRINTSET_DLG *printset_dlg)
 
 
 /* -------------------------------------------------------------------
- * Default ꤷƽλ
+ * Default に設定して終了
  */
 void printset_dlg_default_set_pushed(GtkWidget *widget, PRINTSET_DLG *printset_dlg)
 {
@@ -182,7 +182,7 @@ void printset_dlg_ok_pushed(GtkWidget *widget, PRINTSET_DLG *printset_dlg)
 	char str[256];
 
 
-	/* ƥȥȥ꡼ʸ */
+	/* テキストエントリーから文字列を取得 */
 	strcpy(str, gtk_entry_get_text(GTK_ENTRY(printset_dlg->up_scale_entry)));
 	printset_dlg->up_scale = atof(str);
 
@@ -225,7 +225,7 @@ void printset_dlg_ok_pushed(GtkWidget *widget, PRINTSET_DLG *printset_dlg)
 
 
 /* -------------------------------------------------------------------
- * 줿٥
+ * キーが押されたイベント
  * key_press_event
  */
 static gint printset_dlg_key_press_event(GtkWidget *widget, GdkEventKey *event, PRINTSET_DLG *printset_dlg)
@@ -244,14 +244,14 @@ static gint printset_dlg_key_press_event(GtkWidget *widget, GdkEventKey *event,
 
 
 /* -------------------------------------------------------------------
- * ԡڰư/ʣ̡
+ * コピー【移動/複写】設定
  * 
  * 
- * printset_dlg->x_pitch && printset_dlg->x_pitch  0 ʤ focus 
- * printset_dlg->x_pitch_entry ˤ
+ * printset_dlg->x_pitch && printset_dlg->x_pitch が 0 なら focus を
+ * printset_dlg->x_pitch_entry にする
  * 
- * printset_dlg->x_pitch || printset_dlg->x_pitch  0 ʳʤ focus 
- * printset_dlg->repeats_entry ˤ
+ * printset_dlg->x_pitch || printset_dlg->x_pitch が 0 以外なら focus を
+ * printset_dlg->repeats_entry にする
  * 
  */
 gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
@@ -288,22 +288,22 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 	printset_dlg->toggle_frag = 0;
 
 
-	/* (printset_dlg->dialog) */
-	printset_dlg->dialog = gtk_window_new(GTK_WINDOW_DIALOG);
+	/* ダイアログ(printset_dlg->dialog)生成 */
+	printset_dlg->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_position(GTK_WINDOW(printset_dlg->dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_title(GTK_WINDOW(printset_dlg->dialog), _("Print Setting") );
-	gtk_signal_connect( GTK_OBJECT(printset_dlg->dialog), "key_press_event",
-						GTK_SIGNAL_FUNC(printset_dlg_key_press_event), printset_dlg);
+	g_signal_connect( G_OBJECT(printset_dlg->dialog), "key_press_event",
+						G_CALLBACK(printset_dlg_key_press_event), printset_dlg);
 
 
 
-		/* ѥå󥰥ܥå(main_vbox) */
+		/* パッキングボックス(main_vbox)を作成 */
 		main_vbox = gtk_vbox_new(0, 5);
 		gtk_container_add(GTK_CONTAINER(printset_dlg->dialog), main_vbox);
-		gtk_container_border_width(GTK_CONTAINER(printset_dlg->dialog), 5);
+		gtk_container_set_border_width(GTK_CONTAINER(printset_dlg->dialog), 5);
 		gtk_widget_show(main_vbox);
 
-			/* ѥå󥰥ܥå(view_vbox)  */
+			/* パッキングボックス(view_vbox) を作成 */
 			view_vbox = gtk_vbox_new(FALSE, 2);
 			gtk_box_pack_start( (GtkBox *)GTK_BOX(main_vbox), view_vbox, TRUE, TRUE, 0);
 			gtk_widget_show(view_vbox);
@@ -311,7 +311,7 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				/* -----------------------------------------
 				 * view_group 
 				 */
-				/*  1 */
+				/* 画面 1 */
 				printset_dlg->display_check = gtk_check_button_new_with_label( _("The range which is displayed in the screen") );
 				gtk_box_pack_start( (GtkBox *)GTK_BOX(view_vbox), printset_dlg->display_check, TRUE, TRUE, 0);
 				if (printset_dlg->view == 1) {
@@ -320,13 +320,13 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(printset_dlg->display_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(printset_dlg->display_check), 
+				g_signal_connect (G_OBJECT(printset_dlg->display_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(view_button_toggled), 
+									G_CALLBACK(view_button_toggled), 
 									printset_dlg);
 				gtk_widget_show(printset_dlg->display_check);
 
-				/*  0 */
+				/* 図面 0 */
 				printset_dlg->drawing_check = gtk_check_button_new_with_label( _("Drawing Setting") );
 				gtk_box_pack_start( (GtkBox *)GTK_BOX(view_vbox), printset_dlg->drawing_check, TRUE, TRUE, 0);
 				if (printset_dlg->view == 0) {
@@ -335,52 +335,52 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(printset_dlg->drawing_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(printset_dlg->drawing_check), 
+				g_signal_connect (G_OBJECT(printset_dlg->drawing_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(view_button_toggled), 
+									G_CALLBACK(view_button_toggled), 
 									printset_dlg);
 				gtk_widget_show(printset_dlg->drawing_check);
 
 
 
-			/* ѥå󥰥ܥå(scale_hbox)  */
+			/* パッキングボックス(scale_hbox) を作成 */
 			scale_hbox = gtk_hbox_new(FALSE, 2);
 			gtk_box_pack_start( (GtkBox *)GTK_BOX(main_vbox), scale_hbox, TRUE, TRUE, 0);
 			gtk_widget_show(scale_hbox);
 
 				label = gtk_label_new( _("Scale") );
-//				gtk_widget_set_usize (label, 100, 20);
+//				gtk_widget_set_size_request(label, 100, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(scale_hbox), label, TRUE, TRUE, 0);
 				gtk_widget_show(label);
 
-				/* ƥȥȥ꡼ */
+				/* テキストエントリー生成 */
 				printset_dlg->up_scale_entry = gtk_entry_new();
-//				gtk_widget_set_usize (printset_dlg->up_scale_entry, 80, 20);
+//				gtk_widget_set_size_request(printset_dlg->up_scale_entry, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(scale_hbox), printset_dlg->up_scale_entry, TRUE, TRUE, 1);
-				/*  */
+				/* 初期値設定 */
 				FloatOut_n(str, printset_dlg->up_scale, 6, 0);
 				gtk_entry_set_text(GTK_ENTRY(printset_dlg->up_scale_entry), str);
-				//gtk_signal_connect (GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(entry_callback), NULL);
+				//g_signal_connect (G_OBJECT(entry), "activate", G_CALLBACK(entry_callback), NULL);
 				gtk_widget_show(printset_dlg->up_scale_entry);
 
 				label = gtk_label_new(" / ");
-//				gtk_widget_set_usize (label, 20, 20);
+//				gtk_widget_set_size_request(label, 20, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(scale_hbox), label, TRUE, TRUE, 0);
 				gtk_widget_show(label);
 
-				/* ƥȥȥ꡼ */
+				/* テキストエントリー生成 */
 				printset_dlg->low_scale_entry = gtk_entry_new();
-//				gtk_widget_set_usize (printset_dlg->low_scale_entry, 80, 20);
+//				gtk_widget_set_size_request(printset_dlg->low_scale_entry, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(scale_hbox), printset_dlg->low_scale_entry, TRUE, TRUE, 1);
-				/*  */
+				/* 初期値設定 */
 				FloatOut_n(str, printset_dlg->low_scale, 6, 0);
 				gtk_entry_set_text(GTK_ENTRY(printset_dlg->low_scale_entry), str);
-				//gtk_signal_connect (GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(entry_callback), NULL);
+				//g_signal_connect (G_OBJECT(entry), "activate", G_CALLBACK(entry_callback), NULL);
 				gtk_widget_show(printset_dlg->low_scale_entry);
 
 
 
-			/* ơ֥륳ƥʺ */
+			/* テーブルコンテナ作成 */
 			paper_table = gtk_table_new(3, 3, TRUE);
 			gtk_box_pack_start( GTK_BOX(main_vbox), paper_table, TRUE, TRUE, 0);
 			gtk_widget_show(paper_table);
@@ -389,7 +389,7 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				 * paper_group 
 				 */
 				button = gtk_button_new_with_label( _("Paper Size") );
-				//gtk_widget_set_usize (label, 20, 20);
+				//gtk_widget_set_size_request(label, 20, 20);
 				gtk_table_attach_defaults(GTK_TABLE(paper_table), button, 0, 2, 0, 1);
 				gtk_widget_show(button);
 
@@ -403,9 +403,9 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(printset_dlg->A4_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(printset_dlg->A4_check), 
+				g_signal_connect (G_OBJECT(printset_dlg->A4_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(paper_button_toggled), 
+									G_CALLBACK(paper_button_toggled), 
 									printset_dlg);
 				gtk_widget_show(printset_dlg->A4_check);
 
@@ -418,9 +418,9 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(printset_dlg->A3_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(printset_dlg->A3_check), 
+				g_signal_connect (G_OBJECT(printset_dlg->A3_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(paper_button_toggled), 
+									G_CALLBACK(paper_button_toggled), 
 									printset_dlg);
 				gtk_widget_show(printset_dlg->A3_check);
 
@@ -433,9 +433,9 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(printset_dlg->B5_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(printset_dlg->B5_check), 
+				g_signal_connect (G_OBJECT(printset_dlg->B5_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(paper_button_toggled), 
+									G_CALLBACK(paper_button_toggled), 
 									printset_dlg);
 				gtk_widget_show(printset_dlg->B5_check);
 
@@ -448,9 +448,9 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(printset_dlg->B4_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(printset_dlg->B4_check), 
+				g_signal_connect (G_OBJECT(printset_dlg->B4_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(paper_button_toggled), 
+									G_CALLBACK(paper_button_toggled), 
 									printset_dlg);
 				gtk_widget_show(printset_dlg->B4_check);
 
@@ -460,7 +460,7 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				 * orientation_group 
 				 */
 				button = gtk_button_new_with_label( _("Direction") );
-				//gtk_widget_set_usize (label, 20, 20);
+				//gtk_widget_set_size_request(label, 20, 20);
 				gtk_table_attach_defaults(GTK_TABLE(paper_table), button, 2, 3, 0, 1);
 				gtk_widget_show(button);
 
@@ -473,9 +473,9 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(printset_dlg->portrait_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(printset_dlg->portrait_check), 
+				g_signal_connect (G_OBJECT(printset_dlg->portrait_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(orientation_button_toggled), 
+									G_CALLBACK(orientation_button_toggled), 
 									printset_dlg);
 				gtk_widget_show(printset_dlg->portrait_check);
 
@@ -488,61 +488,61 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				else {
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(printset_dlg->landscape_check), FALSE);
 				}
-				gtk_signal_connect (GTK_OBJECT(printset_dlg->landscape_check), 
+				g_signal_connect (G_OBJECT(printset_dlg->landscape_check), 
 									"toggled", 
-									GTK_SIGNAL_FUNC(orientation_button_toggled), 
+									G_CALLBACK(orientation_button_toggled), 
 									printset_dlg);
 				gtk_widget_show(printset_dlg->landscape_check);
 
 
 
-		/* ѥ졼(separator) */
+		/* セパレーター(separator) */
 		separator = gtk_hseparator_new();
 		gtk_box_pack_start( GTK_BOX(main_vbox), separator, TRUE, TRUE, 0);
 		gtk_widget_show(separator);
 
 
 
-		/* ѥå󥰥ܥå(action_hbox) */
+		/* パッキングボックス(action_hbox) */
 		action_hbox = gtk_hbox_new(FALSE, 2);
 		gtk_box_pack_start( GTK_BOX(main_vbox), action_hbox, TRUE, TRUE, 0);
 		gtk_widget_show(action_hbox);
 
 			/* -----------------------------------------------------
-			 * ѥå󥰥ܥå(action_hbox) 
-			 * ܥ(cancel_buttun & ok_buttun) 
-			 * Ǽ
+			 * パッキングボックス(action_hbox) に入れる
+			 * ボタン(cancel_buttun & ok_buttun) を作成し
+			 * 格納する
 			 */
 
 
 
 
-			/* Default Set ܥ */
+			/* Default Set ボタンの生成 */
 			default_set_buttun = gtk_button_new_with_label( _("EnvSet Save & End") );
-			gtk_widget_set_usize (default_set_buttun, 150, 20);
+			gtk_widget_set_size_request(default_set_buttun, 150, 20);
 			gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), default_set_buttun, TRUE, TRUE, 2);
-			gtk_signal_connect(GTK_OBJECT(default_set_buttun), 
-							   "clicked", GTK_SIGNAL_FUNC(printset_dlg_ok_pushed), printset_dlg);
-			gtk_signal_connect( GTK_OBJECT(default_set_buttun), 
-							   "clicked", GTK_SIGNAL_FUNC(printset_dlg_default_set_pushed), printset_dlg);
-			gtk_signal_connect( GTK_OBJECT(default_set_buttun), 
-							   "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+			g_signal_connect(G_OBJECT(default_set_buttun), 
+							   "clicked", G_CALLBACK(printset_dlg_ok_pushed), printset_dlg);
+			g_signal_connect( G_OBJECT(default_set_buttun), 
+							   "clicked", G_CALLBACK(printset_dlg_default_set_pushed), printset_dlg);
+			g_signal_connect( G_OBJECT(default_set_buttun), 
+							   "clicked", G_CALLBACK(gtk_main_quit), NULL);
 			gtk_widget_show(default_set_buttun);
 
-			/* CANCELܥ */
+			/* CANCELボタンの生成 */
 			cancel_buttun = gtk_button_new_with_label("CANCEL");
-			gtk_widget_set_usize (cancel_buttun, 80, 20);
+			gtk_widget_set_size_request(cancel_buttun, 80, 20);
 			gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), cancel_buttun, TRUE, TRUE, 2);
-			gtk_signal_connect( GTK_OBJECT(cancel_buttun), "clicked", GTK_SIGNAL_FUNC(printset_dlg_cancel_pushed), printset_dlg);
-			gtk_signal_connect( GTK_OBJECT(cancel_buttun), "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+			g_signal_connect( G_OBJECT(cancel_buttun), "clicked", G_CALLBACK(printset_dlg_cancel_pushed), printset_dlg);
+			g_signal_connect( G_OBJECT(cancel_buttun), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 			gtk_widget_show(cancel_buttun);
 
-			/* OKܥ */
+			/* OKボタンの生成 */
 			ok_buttun = gtk_button_new_with_label("OK");
-			gtk_widget_set_usize (ok_buttun, 80, 20);
+			gtk_widget_set_size_request(ok_buttun, 80, 20);
 			gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), ok_buttun, TRUE, TRUE, 2);
-			gtk_signal_connect(GTK_OBJECT(ok_buttun), "clicked", GTK_SIGNAL_FUNC(printset_dlg_ok_pushed), printset_dlg);
-			gtk_signal_connect(GTK_OBJECT(ok_buttun), "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+			g_signal_connect(G_OBJECT(ok_buttun), "clicked", G_CALLBACK(printset_dlg_ok_pushed), printset_dlg);
+			g_signal_connect(G_OBJECT(ok_buttun), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 		//	  GTK_WIDGET_SET_FLAGS(ok_buttun, GTK_CAN_DEFAULT);
 		//	  gtk_widget_grab_default(ok_buttun);
 			gtk_widget_show(ok_buttun);
@@ -551,19 +551,19 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 
 
 
-	/*  ե x_pitch_entry  */
+	/*  フォーカスを x_pitch_entry に設定 */
 //	gtk_window_set_focus(GTK_WINDOW(printset_dlg->dialog), printset_dlg->x_pitch_entry);
 
 
-	/* ̤ɽ */
+	/* ダイアログを最前面に表示する */
 	gtk_window_set_modal(GTK_WINDOW(printset_dlg->dialog), TRUE);
-	/* ᥤ󥦥ɥǤʤ褦 */
+	/* メインウィンドウを操作できないように設定 */
 	gtk_window_set_transient_for(GTK_WINDOW(printset_dlg->dialog), GTK_WINDOW(printset_dlg->parent));
 
 
-	/* Ļ֤ */
+	/* ダイアログを可視状態へ */
 	gtk_widget_show(printset_dlg->dialog);
-	/* ᥤ󥤥٥ȥ롼 */
+	/* メインイベントループ */
 	gtk_main();
 	gtk_widget_destroy(printset_dlg->dialog);
 	return 0; 
@@ -574,7 +574,7 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : PrintSetDlg.c
