@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/02/20
- *    Last                 : 2003/02/20
+ *    Last                 : 2007/10/13
  * ====================================================================
  */
 
@@ -28,7 +28,7 @@
 //#include <math.h>
 #include "intl.h"
 
-//#include "Trace.h"
+//#include "culcfunc.h"
 #define _SNAPDLG_
 #include "SnapDlg.h"
 
@@ -47,20 +47,20 @@ void snap_dlg_cancel_pushed(GtkWidget *widget, SNAP_DLG *snap_dlg)
 
 
 /* 
- *	  ޷	 1 : 
- *				 2 : 
- *				 4 : ߸
- *				 8 : 
- *				15 : ޷
+ *	  図形要素	 1 : 点
+ *				 2 : 線
+ *				 4 : 円弧
+ *				 8 : 円
+ *				15 : 全図形
  *	
- *	  ˡ޷	16 : 
- *				32 : Ⱦ
- *				64 : 濴
- *			   128 : Ǥ
- *			   256 : ˡ޷
- *			   512 : ݥ饤
- *			  1024 : ֥å
- *			  2048 : ʱ
+ *	  寸法図形	16 : 始点・終点
+ *				32 : 四半点
+ *				64 : 中心点
+ *			   128 : 任意点
+ *			   256 : 寸法図形
+ *			   512 : ポリライン
+ *			  1024 : ブロック
+ *			  2048 : 楕円
  *			  
  */
 
@@ -162,15 +162,18 @@ void snap_dlg_ok_pushed(GtkWidget *widget, SNAP_DLG *snap_dlg)
 
 
 /* -------------------------------------------------------------------
- * 줿٥
+ * キーが押されたイベント
  * key_press_event
  */
 static gint snap_dlg_key_press_event(GtkWidget *widget, GdkEventKey *event, SNAP_DLG *snap_dlg)
 {
 //	g_print("sagcad.c : snap_dlg_key_press_event  state:%d  keyval:0x%x  length:%d  string:%s\n", 
 //			event->state, event->keyval, event->length, event->string);
-
-	return TRUE; 
+	if (event->keyval == 0xff0d || event->keyval == 0xff8d) {		/* Enter */
+		snap_dlg_ok_pushed(widget, snap_dlg);
+		gtk_main_quit();
+	}
+	return FALSE; 
 }
 
 
@@ -178,7 +181,7 @@ static gint snap_dlg_key_press_event(GtkWidget *widget, GdkEventKey *event, SNAP
 
 
 /* -------------------------------------------------------------------
- * ʥå
+ * スナップ設定
  * 
  */
 gint SnapDialog(SNAP_DLG *snap_dlg)
@@ -210,361 +213,361 @@ gint SnapDialog(SNAP_DLG *snap_dlg)
 				GtkWidget *ok_buttun;
 
 
-	/* (snap_dlg->dialog) */
-	snap_dlg->dialog = gtk_window_new(GTK_WINDOW_DIALOG);
+	/* ダイアログ(snap_dlg->dialog)生成 */
+	snap_dlg->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_position(GTK_WINDOW(snap_dlg->dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_title(GTK_WINDOW(snap_dlg->dialog), _("Snap Setting") );
-	gtk_signal_connect( GTK_OBJECT(snap_dlg->dialog), "key_press_event",
-						GTK_SIGNAL_FUNC(snap_dlg_key_press_event), snap_dlg);
+	g_signal_connect( G_OBJECT(snap_dlg->dialog), "key_press_event",
+						G_CALLBACK(snap_dlg_key_press_event), snap_dlg);
 
 
 
-		/* ˤޤѥå󥰥ܥå(main_vbox) */
+		/* ダイアログの中にまず、パッキングボックス(main_vbox)を作成 */
 		main_vbox = gtk_vbox_new(0, 5);
 		gtk_container_add(GTK_CONTAINER(snap_dlg->dialog), main_vbox);
-		gtk_container_border_width(GTK_CONTAINER(snap_dlg->dialog), 5);
+		gtk_container_set_border_width(GTK_CONTAINER(snap_dlg->dialog), 5);
 		gtk_widget_show(main_vbox);
 
 			/* -----------------------------------------------------
-			 * ѥå󥰥ܥå(main_vbox) 
-			 * ѥå󥰥ܥå(hbox & action_hbox) 
-			 * Ǽ
+			 * パッキングボックス(main_vbox) に入れる
+			 * パッキングボックス(hbox & action_hbox) を作成し
+			 * 格納する
 			 */
-			/* ѥå󥰥ܥå(hbox) */
+			/* パッキングボックス(hbox) */
 			hbox = gtk_hbox_new(FALSE, 2);
 			gtk_box_pack_start( (GtkBox *)GTK_BOX(main_vbox), 
 								hbox, TRUE, TRUE, 0);
 			gtk_widget_show(hbox);
 
 				/* -----------------------------------------------------
-				 * ѥå󥰥ܥå(hbox) 
-				 * ѥå󥰥ܥå(label_vbox & entry_vbox) 
-				 * Ǽ
+				 * パッキングボックス(hbox) に入れる
+				 * パッキングボックス(label_vbox & entry_vbox) を作成し
+				 * 格納する
 				 */
-				/* ѥå󥰥ܥå(base_vbox) */
+				/* パッキングボックス(base_vbox) */
 				base_vbox = gtk_vbox_new(FALSE, 2);
 				gtk_box_pack_start( (GtkBox *)GTK_BOX(hbox), base_vbox, TRUE, TRUE, 0);
 				gtk_widget_show(base_vbox);
 
 					/* -----------------------------------------------------
-					 * ѥå󥰥ܥå(base_vbox) 
-					 * åܥ
+					 * パッキングボックス(base_vbox) に入れる
+					 * チェックボタン
 					 * snap_dlg->point_check_button
 					 * snap_dlg->line_check_button
 					 * snap_dlg->arc_check_button
 					 * snap_dlg->circle_check_button
-					 * Ǽ
+					 * を作成し、格納する
 					 */
-					/*  */
+					/* 点 */
 					snap_dlg->point_check_button = gtk_check_button_new_with_label( _("Point") );
-					gtk_widget_set_usize (snap_dlg->point_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->point_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(base_vbox), snap_dlg->point_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->point_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 1) != 1) {
 						gtk_widget_set_sensitive(snap_dlg->point_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 1) == 1) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->point_check_button), TRUE);
 					}
 
 
-					/*  */
+					/* 線 */
 					snap_dlg->line_check_button = gtk_check_button_new_with_label( _("Line") );
-					gtk_widget_set_usize (snap_dlg->line_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->line_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(base_vbox), snap_dlg->line_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->line_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 2) != 2) {
 						gtk_widget_set_sensitive(snap_dlg->line_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 2) == 2) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->line_check_button), TRUE);
 					}
 
 
-					/* ߸ */
+					/* 円弧 */
 					snap_dlg->arc_check_button = gtk_check_button_new_with_label( _("Arc") );
-					gtk_widget_set_usize (snap_dlg->arc_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->arc_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(base_vbox), snap_dlg->arc_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->arc_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 4) != 4) {
 						gtk_widget_set_sensitive(snap_dlg->arc_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 4) == 4) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->arc_check_button), TRUE);
 					}
 
 
-					/*  */
+					/* 円 */
 					snap_dlg->circle_check_button = gtk_check_button_new_with_label( _("Circle") );
-					gtk_widget_set_usize (snap_dlg->circle_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->circle_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(base_vbox), snap_dlg->circle_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->circle_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 8) != 8) {
 						gtk_widget_set_sensitive(snap_dlg->circle_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 8) == 8) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->circle_check_button), TRUE);
 					}
 
 /*
-åȤ̵ʤ뤤ͭˤˤˤϡ
- gtk_widget_set_sensitive()ؿȤäƲ
-δؿκǽΥѥ᡼ϡΥåȤؤΥݥ󥿤Ǥ
-ܤΥѥ᡼ͤǡTRUE ʤ餽ΥåȤͭˤʤޤ
+ウィジェットを無効（あるいは有効）にするには、
+ gtk_widget_set_sensitive()関数を使って下さい。
+この関数の最初のパラメータは、そのウィジェットへのポインタです。
+二番目のパラメータは論理値で、TRUE ならそのウィジェットは有効になります。
 */
 
 
 
 
-				/* ѥå󥰥ܥå(etc_vbox) */
+				/* パッキングボックス(etc_vbox) */
 				etc_vbox = gtk_vbox_new(FALSE, 2);
 				gtk_box_pack_start( (GtkBox *)GTK_BOX(hbox), etc_vbox, TRUE, TRUE, 0);
 				gtk_widget_show(etc_vbox);
 
 					/* -----------------------------------------------------
-					 * ѥå󥰥ܥå(etc_vbox) 
-					 * åܥ
+					 * パッキングボックス(etc_vbox) に入れる
+					 * チェックボタン
 					 * snap_dlg->start_end_check_button
 					 * snap_dlg->half_4_point_check_button
 					 * snap_dlg->center_check_button
 					 * snap_dlg->any_check_button
-					 * Ǽ
+					 * を作成し、格納する
 					 */
-					/* ü */
+					/* 端点 */
 					snap_dlg->start_end_check_button = gtk_check_button_new_with_label( _("End Point") );
-					gtk_widget_set_usize (snap_dlg->start_end_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->start_end_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(etc_vbox), snap_dlg->start_end_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->start_end_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 16) != 16) {
 						gtk_widget_set_sensitive(snap_dlg->start_end_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 16) == 16) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->start_end_check_button), TRUE);
 					}
 
 
-					/* Ⱦ */
+					/* 四半点 */
 					snap_dlg->half_4_point_check_button = gtk_check_button_new_with_label( _("4 half points") );
-					gtk_widget_set_usize (snap_dlg->half_4_point_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->half_4_point_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(etc_vbox), snap_dlg->half_4_point_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->half_4_point_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 32) != 32) {
 						gtk_widget_set_sensitive(snap_dlg->half_4_point_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 32) == 32) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->half_4_point_check_button), TRUE);
 					}
 
 
-					/* 濴 */
+					/* 中心点 */
 					snap_dlg->center_check_button = gtk_check_button_new_with_label( _("Central Point") );
-					gtk_widget_set_usize (snap_dlg->center_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->center_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(etc_vbox), snap_dlg->center_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->center_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 64) != 64) {
 						gtk_widget_set_sensitive(snap_dlg->center_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 64) == 64) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->center_check_button), TRUE);
 					}
 
 
-					/* Ǥ */
+					/* 任意点 */
 					snap_dlg->any_check_button = gtk_check_button_new_with_label( _("Optional Point") );
-					gtk_widget_set_usize (snap_dlg->any_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->any_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(etc_vbox), snap_dlg->any_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->any_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 128) != 128) {
 						gtk_widget_set_sensitive(snap_dlg->any_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 128) == 128) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->any_check_button), TRUE);
 					}
 
 
 
-				/* ѥå󥰥ܥå(option_vbox) */
+				/* パッキングボックス(option_vbox) */
 				option_vbox = gtk_vbox_new(FALSE, 2);
 				gtk_box_pack_start( (GtkBox *)GTK_BOX(hbox), option_vbox, TRUE, TRUE, 0);
 				gtk_widget_show(option_vbox);
 
 					/* -----------------------------------------------------
-					 * ѥå󥰥ܥå(option_vbox) 
-					 * åܥ
+					 * パッキングボックス(option_vbox) に入れる
+					 * チェックボタン
 					 * snap_dlg->polyline_check_button
 					 * snap_dlg->dimension_check_button
 					 * snap_dlg->block_check_button
 					 * snap_dlg->ellipse_check_button
-					 * Ǽ
+					 * を作成し、格納する
 					 */
 					/* -----------------------------------------------
-					 * 
+					 * 曲線
 					 */
 					snap_dlg->polyline_check_button = gtk_check_button_new_with_label( _("Curve") );
-					gtk_widget_set_usize (snap_dlg->polyline_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->polyline_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(option_vbox), snap_dlg->polyline_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->polyline_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 512) != 512) {
 						gtk_widget_set_sensitive(snap_dlg->polyline_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 512) == 512) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->polyline_check_button), TRUE);
 					}
 
 
 					/* -----------------------------------------------
-					 * ˡ 
+					 * 寸法 
 					 */
 					snap_dlg->dimension_check_button = gtk_check_button_new_with_label( _("Dimension") );
-					gtk_widget_set_usize (snap_dlg->dimension_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->dimension_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(option_vbox), snap_dlg->dimension_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->dimension_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 256) != 256) {
 						gtk_widget_set_sensitive(snap_dlg->dimension_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 256) == 256) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->dimension_check_button), TRUE);
 					}
 
 
 					/* -----------------------------------------------
-					 * ֥å 
+					 * ブロック 
 					 */
 					snap_dlg->block_check_button = gtk_check_button_new_with_label( _("Block") );
-					gtk_widget_set_usize (snap_dlg->block_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->block_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(option_vbox), snap_dlg->block_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->block_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 1024) != 1024) {
 						gtk_widget_set_sensitive(snap_dlg->block_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 1024) == 1024) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->block_check_button), TRUE);
 					}
 
 
 					/* -----------------------------------------------
-					 * ʱ 
+					 * 楕円 
 					 */
 					snap_dlg->ellipse_check_button = gtk_check_button_new_with_label( _("Ellipse") );
-					gtk_widget_set_usize (snap_dlg->ellipse_check_button, 100, 20);
+					gtk_widget_set_size_request(snap_dlg->ellipse_check_button, 100, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(option_vbox), snap_dlg->ellipse_check_button, TRUE, TRUE, 0);
 					gtk_widget_show(snap_dlg->ellipse_check_button);
-					/* ̵ͭ */
+					/* 有効か無効の設定 */
 					if ((snap_dlg->mask & 2048) != 2048) {
 						gtk_widget_set_sensitive(snap_dlg->ellipse_check_button, FALSE);
 					}
-					/*  */
+					/* 初期設定 */
 					else if ((snap_dlg->snap & 2048) == 2048) {
 						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snap_dlg->ellipse_check_button), TRUE);
 					}
 
 
 
-			/* ѥ졼(separator) */
+			/* セパレーター(separator) */
 			separator = gtk_hseparator_new();
 			gtk_box_pack_start( GTK_BOX(main_vbox), separator, TRUE, TRUE, 0);
 			gtk_widget_show(separator);
 
 
 
-			/* ѥå󥰥ܥå(action_hbox) */
+			/* パッキングボックス(action_hbox) */
 			action_hbox = gtk_hbox_new(FALSE, 2);
 			gtk_box_pack_start( GTK_BOX(main_vbox), 
 								action_hbox, TRUE, TRUE, 0);
 			gtk_widget_show(action_hbox);
 
 				/* -----------------------------------------------------
-				 * ѥå󥰥ܥå(action_hbox) 
-				 * ܥ(cancel_buttun & ok_buttun) 
-				 * Ǽ
+				 * パッキングボックス(action_hbox) に入れる
+				 * ボタン(cancel_buttun & ok_buttun) を作成し
+				 * 格納する
 				 */
 				if (snap_dlg->value == 16) {
-					/* chain ܥ */
+					/* chain ボタンの生成 */
 					chain_buttun = gtk_button_new_with_label("Chain");
-//					gtk_widget_set_usize (chain_buttun, 80, 20);
+//					gtk_widget_set_size_request(chain_buttun, 80, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), chain_buttun, TRUE, TRUE, 2);
-					gtk_signal_connect(GTK_OBJECT(chain_buttun), "clicked", 
-									   GTK_SIGNAL_FUNC(snap_dlg_ok_pushed), snap_dlg);
-					gtk_signal_connect(GTK_OBJECT(chain_buttun), "clicked", 
-									   GTK_SIGNAL_FUNC(snap_dlg_chain_pushed), snap_dlg);
-					gtk_signal_connect(GTK_OBJECT(chain_buttun), "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+					g_signal_connect(G_OBJECT(chain_buttun), "clicked", 
+									   G_CALLBACK(snap_dlg_ok_pushed), snap_dlg);
+					g_signal_connect(G_OBJECT(chain_buttun), "clicked", 
+									   G_CALLBACK(snap_dlg_chain_pushed), snap_dlg);
+					g_signal_connect(G_OBJECT(chain_buttun), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 					gtk_widget_show(chain_buttun);
 
-					/* chain2 ܥ */
+					/* chain2 ボタンの生成 */
 					chain2_buttun = gtk_button_new_with_label("Chain One Way");
-//					gtk_widget_set_usize (chain2_buttun, 80, 20);
+//					gtk_widget_set_size_request(chain2_buttun, 80, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), chain2_buttun, TRUE, TRUE, 2);
-					gtk_signal_connect(GTK_OBJECT(chain2_buttun), "clicked", 
-									   GTK_SIGNAL_FUNC(snap_dlg_ok_pushed), snap_dlg);
-					gtk_signal_connect(GTK_OBJECT(chain2_buttun), "clicked", 
-									   GTK_SIGNAL_FUNC(snap_dlg_chain2_pushed), snap_dlg);
-					gtk_signal_connect(GTK_OBJECT(chain2_buttun), "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+					g_signal_connect(G_OBJECT(chain2_buttun), "clicked", 
+									   G_CALLBACK(snap_dlg_ok_pushed), snap_dlg);
+					g_signal_connect(G_OBJECT(chain2_buttun), "clicked", 
+									   G_CALLBACK(snap_dlg_chain2_pushed), snap_dlg);
+					g_signal_connect(G_OBJECT(chain2_buttun), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 					gtk_widget_show(chain2_buttun);
 
-					/* color ܥ */
+					/* color ボタンの生成 */
 					color_buttun = gtk_button_new_with_label("Color");
-//					gtk_widget_set_usize (color_buttun, 80, 20);
+//					gtk_widget_set_size_request(color_buttun, 80, 20);
 					gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), color_buttun, TRUE, TRUE, 2);
-					gtk_signal_connect(GTK_OBJECT(color_buttun), "clicked", 
-									   GTK_SIGNAL_FUNC(snap_dlg_ok_pushed), snap_dlg);
-					gtk_signal_connect(GTK_OBJECT(color_buttun), "clicked", 
-									   GTK_SIGNAL_FUNC(snap_dlg_color_pushed), snap_dlg);
-					gtk_signal_connect(GTK_OBJECT(color_buttun), "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+					g_signal_connect(G_OBJECT(color_buttun), "clicked", 
+									   G_CALLBACK(snap_dlg_ok_pushed), snap_dlg);
+					g_signal_connect(G_OBJECT(color_buttun), "clicked", 
+									   G_CALLBACK(snap_dlg_color_pushed), snap_dlg);
+					g_signal_connect(G_OBJECT(color_buttun), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 					gtk_widget_show(color_buttun);
 				}
 
 
-				/* CANCELܥ */
+				/* CANCELボタンの生成 */
 				cancel_buttun = gtk_button_new_with_label("CANCEL");
-//				gtk_widget_set_usize (cancel_buttun, 80, 20);
+//				gtk_widget_set_size_request(cancel_buttun, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), cancel_buttun, TRUE, TRUE, 2);
-				gtk_signal_connect( GTK_OBJECT(cancel_buttun), "clicked", GTK_SIGNAL_FUNC(snap_dlg_cancel_pushed), snap_dlg);
-				gtk_signal_connect( GTK_OBJECT(cancel_buttun), "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+				g_signal_connect( G_OBJECT(cancel_buttun), "clicked", G_CALLBACK(snap_dlg_cancel_pushed), snap_dlg);
+				g_signal_connect( G_OBJECT(cancel_buttun), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 				gtk_widget_show(cancel_buttun);
 
-				/* OKܥ */
+				/* OKボタンの生成 */
 				ok_buttun = gtk_button_new_with_label("OK");
-//				gtk_widget_set_usize (ok_buttun, 80, 20);
+//				gtk_widget_set_size_request(ok_buttun, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), ok_buttun, TRUE, TRUE, 2);
-				gtk_signal_connect(GTK_OBJECT(ok_buttun), "clicked", GTK_SIGNAL_FUNC(snap_dlg_ok_pushed), snap_dlg);
-				gtk_signal_connect(GTK_OBJECT(ok_buttun), "clicked", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+				g_signal_connect(G_OBJECT(ok_buttun), "clicked", G_CALLBACK(snap_dlg_ok_pushed), snap_dlg);
+				g_signal_connect(G_OBJECT(ok_buttun), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 			//	  GTK_WIDGET_SET_FLAGS(ok_buttun, GTK_CAN_DEFAULT);
 			//	  gtk_widget_grab_default(ok_buttun);
 				gtk_widget_show(ok_buttun);
 
 
 
-	/* ̤ɽ */
+	/* ダイアログを最前面に表示する */
 	gtk_window_set_modal(GTK_WINDOW(snap_dlg->dialog), TRUE);
-	/* ᥤ󥦥ɥǤʤ褦 */
+	/* メインウィンドウを操作できないように設定 */
 	gtk_window_set_transient_for(GTK_WINDOW(snap_dlg->dialog), GTK_WINDOW(snap_dlg->parent));
 
 
-	/* Ļ֤ */
+	/* ダイアログを可視状態へ */
 	gtk_widget_show(snap_dlg->dialog);
-	/* ᥤ󥤥٥ȥ롼 */
+	/* メインイベントループ */
 	gtk_main();
 	gtk_widget_destroy(snap_dlg->dialog);
 	return 0; 
@@ -575,7 +578,7 @@ gint SnapDialog(SNAP_DLG *snap_dlg)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : SnapDlg.c
