@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/02/25
- *    Last                 : 2003/02/25
+ *    Last                 : 2007/10/13
  * ====================================================================
  */
 
@@ -36,7 +36,7 @@
 #include "List_Select.h"
 #include "global.h"
 #include "etc.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #define _TEXTEDITDLG_
 #include "TextEditDlg.h"
 
@@ -52,7 +52,7 @@ void text_edit_dlg_FileName_pushed(GtkWidget *widget, TEXT_EDIT_DLG *text_edit_d
 	char str[256], FileName[256], dummy[256];
 
 
-	/* text_edit_dlg->text_entry äƤʸ */
+	/* text_edit_dlg->text_entry に入っている文字列を得る */
 	strcpy(str, gtk_entry_get_text(GTK_ENTRY(text_edit_dlg->entry_Text)));
 
 	strcpy(dummy, NowFile);
@@ -61,7 +61,7 @@ void text_edit_dlg_FileName_pushed(GtkWidget *widget, TEXT_EDIT_DLG *text_edit_d
 
 	strcat(FileName, str);
 
-	/* text_edit_dlg->text_entry ʸꤹ */
+	/* text_edit_dlg->text_entry に文字列を設定する */
 	gtk_entry_set_text(GTK_ENTRY(text_edit_dlg->entry_Text), FileName);
 }
 
@@ -70,19 +70,19 @@ void text_edit_dlg_FileName_pushed(GtkWidget *widget, TEXT_EDIT_DLG *text_edit_d
 
 
 /* -------------------------------------------------------------------
- * 
+ * φ
  */
 void text_edit_dlg_Fai_pushed(GtkWidget *widget, TEXT_EDIT_DLG *text_edit_dlg)
 {
 	char str[256], fai_str[256];
 
-	/* text_edit_dlg->text_entry äƤʸ */
+	/* text_edit_dlg->text_entry に入っている文字列を得る */
 	strcpy(str, gtk_entry_get_text(GTK_ENTRY(text_edit_dlg->entry_Text)));
 
-	strcpy(fai_str, "");
+	strcpy(fai_str, "φ");
 	strcat(fai_str, str);
 
-	/* text_edit_dlg->text_entry ʸꤹ */
+	/* text_edit_dlg->text_entry に文字列を設定する */
 	gtk_entry_set_text(GTK_ENTRY(text_edit_dlg->entry_Text), fai_str);
 }
 
@@ -97,13 +97,13 @@ void text_edit_dlg_R_pushed(GtkWidget *widget, TEXT_EDIT_DLG *text_edit_dlg)
 {
 	char str[256], fai_str[256];
 
-	/* text_edit_dlg->text_entry äƤʸ */
+	/* text_edit_dlg->text_entry に入っている文字列を得る */
 	strcpy(str, gtk_entry_get_text(GTK_ENTRY(text_edit_dlg->entry_Text)));
 
 	strcpy(fai_str, "R");
 	strcat(fai_str, str);
 
-	/* text_edit_dlg->text_entry ʸꤹ */
+	/* text_edit_dlg->text_entry に文字列を設定する */
 	gtk_entry_set_text(GTK_ENTRY(text_edit_dlg->entry_Text), fai_str);
 }
 
@@ -139,7 +139,7 @@ void text_edit_dlg_cancel_pushed(GtkWidget *widget, TEXT_EDIT_DLG *a)
  */
 void text_edit_dlg_ok_pushed(GtkWidget *widget, TEXT_EDIT_DLG *a)
 {
-	/* ƥȥȥ꡼ʸ */
+	/* テキストエントリーから文字列を取得 */
 
 	/* Text */
 	strcpy(a->Text, gtk_entry_get_text(GTK_ENTRY(a->entry_Text)));
@@ -174,7 +174,7 @@ void text_edit_dlg_ok_pushed(GtkWidget *widget, TEXT_EDIT_DLG *a)
 
 
 /* -------------------------------------------------------------------
- * 줿٥
+ * キーが押されたイベント
  * key_press_event
  */
 static gint text_edit_dlg_key_press_event(GtkWidget *widget, GdkEventKey *event, TEXT_EDIT_DLG *text_edit_dlg)
@@ -184,26 +184,26 @@ static gint text_edit_dlg_key_press_event(GtkWidget *widget, GdkEventKey *event,
 
 #ifdef TEST
 	if (event->keyval == 0xff0d || event->keyval == 0xff8d) {		/* Enter */
-		/* ե x_pitch_entry  Enter ʤե y_pitch_entry ˰ܤ */
+		/* フォーカス x_pitch_entry で Enter ならフォーカスを y_pitch_entry に移す */
 		if (GTK_WIDGET( text_edit_dlg->x_pitch_entry) == GTK_WINDOW(text_edit_dlg->dialog)->focus_widget) {
 			gtk_window_set_focus(GTK_WINDOW(text_edit_dlg->dialog), text_edit_dlg->y_pitch_entry);
-			gtk_entry_select_region( GTK_ENTRY(text_edit_dlg->y_pitch_entry), 0, 
+			gtk_editable_select_region( GTK_ENTRY(text_edit_dlg->y_pitch_entry), 0, 
 									 GTK_ENTRY(text_edit_dlg->y_pitch_entry)->text_length);
 		}
-		/* ե y_pitch_entry  Enter ʤե repeats_entry ˰ܤ */
+		/* フォーカス y_pitch_entry で Enter ならフォーカスを repeats_entry に移す */
 		else if (GTK_WIDGET(text_edit_dlg->y_pitch_entry) == GTK_WINDOW(text_edit_dlg->dialog)->focus_widget) {
 			gtk_window_set_focus(GTK_WINDOW(text_edit_dlg->dialog), text_edit_dlg->repeats_entry);
-			gtk_entry_select_region( GTK_ENTRY(text_edit_dlg->repeats_entry), 0, 
+			gtk_editable_select_region( GTK_ENTRY(text_edit_dlg->repeats_entry), 0, 
 									 GTK_ENTRY(text_edit_dlg->repeats_entry)->text_length);
 		}
-		/* ե repeats_entry  Enter ʤ齪 */
+		/* フォーカス repeats_entry で Enter なら終わり */
 		else if (GTK_WIDGET(text_edit_dlg->repeats_entry) == GTK_WINDOW(text_edit_dlg->dialog)->focus_widget) {
 			text_edit_dlg_ok_pushed(widget, text_edit_dlg);
 			gtk_main_quit();
 		}
 	}
 #endif
-	return TRUE; 
+	return FALSE; 
 }
 
 
@@ -211,7 +211,7 @@ static gint text_edit_dlg_key_press_event(GtkWidget *widget, GdkEventKey *event,
 
 
 /* -------------------------------------------------------------------
- * ˡܥå
+ * 寸法値設定ボックス
  */
 gint make_box_text(GtkWidget *vbox_Text, TEXT_EDIT_DLG *a)
 {
@@ -225,7 +225,7 @@ gint make_box_text(GtkWidget *vbox_Text, TEXT_EDIT_DLG *a)
 //		GtkWidget *entry_LowerText;
 
 
-	/* ѥå󥰥ܥå(hbox_Text1)  */
+	/* パッキングボックス(hbox_Text1) 作成 */
 	hbox_Text1 = gtk_hbox_new(FALSE, 2);
 	gtk_box_pack_start( (GtkBox *)GTK_BOX(vbox_Text), hbox_Text1, TRUE, TRUE, 0);
 	gtk_widget_show(hbox_Text1);
@@ -233,19 +233,19 @@ gint make_box_text(GtkWidget *vbox_Text, TEXT_EDIT_DLG *a)
 			/* label_Text */
 			label_Text = gtk_label_new( _("Size Value") );
 			gtk_misc_set_alignment(GTK_MISC(label_Text), 0.0f, 1.0f);
-			gtk_widget_set_usize (label_Text, TED_LABEL_WIDTH, TED_HEIGHT);
+			gtk_widget_set_size_request(label_Text, TED_LABEL_WIDTH, TED_HEIGHT);
 			gtk_box_pack_start((GtkBox *)GTK_BOX(hbox_Text1), label_Text, FALSE, TRUE, 0);
 			gtk_widget_show(label_Text);
 
 			/* entry_Text */
 			a->entry_Text = gtk_entry_new();
-			gtk_widget_set_usize (a->entry_Text, TED_ENTRY_WIDTH, TED_HEIGHT);
+			gtk_widget_set_size_request(a->entry_Text, TED_ENTRY_WIDTH, TED_HEIGHT);
 			gtk_box_pack_start((GtkBox *)GTK_BOX(hbox_Text1), a->entry_Text, FALSE, TRUE, 0);
-			gtk_entry_set_text(GTK_ENTRY(a->entry_Text), a->Text);	/*  */
+			gtk_entry_set_text(GTK_ENTRY(a->entry_Text), a->Text);	/* 初期値設定 */
 			gtk_widget_show(a->entry_Text);
 
 
-	/* ѥå󥰥ܥå(hbox_Text2)  */
+	/* パッキングボックス(hbox_Text2) 作成 */
 	hbox_Text2 = gtk_hbox_new(FALSE, 4);
 	gtk_box_pack_start( (GtkBox *)GTK_BOX(vbox_Text), hbox_Text2, TRUE, TRUE, 0);
 	gtk_widget_show(hbox_Text2);
@@ -253,29 +253,29 @@ gint make_box_text(GtkWidget *vbox_Text, TEXT_EDIT_DLG *a)
 		/* label_UpperText */
 		label_UpperText = gtk_label_new( _("Maximum") );
 		gtk_misc_set_alignment(GTK_MISC(label_UpperText), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_UpperText, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_UpperText, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(hbox_Text2), label_UpperText, FALSE, TRUE, 0);
 		gtk_widget_show(label_UpperText);
 
 		/* entry_UpperText */
 		a->entry_UpperText = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_UpperText, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_UpperText, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(hbox_Text2), a->entry_UpperText, FALSE, TRUE, 0);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_UpperText), a->UpperText);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_UpperText), a->UpperText);	/* 初期値設定 */
 		gtk_widget_show(a->entry_UpperText);
 
 		/* label_LowerText */
 		label_LowerText = gtk_label_new( _("Minimum") );
 		gtk_misc_set_alignment(GTK_MISC(label_LowerText), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_LowerText, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_LowerText, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(hbox_Text2), label_LowerText, FALSE, TRUE, 0);
 		gtk_widget_show(label_LowerText);
 
 		/* entry_LowerText */
 		a->entry_LowerText = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_LowerText, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_LowerText, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(hbox_Text2), a->entry_LowerText, FALSE, TRUE, 0);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_LowerText), a->UpperText);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_LowerText), a->UpperText);	/* 初期値設定 */
 		gtk_widget_show(a->entry_LowerText);
 
 	return 1;
@@ -286,7 +286,7 @@ gint make_box_text(GtkWidget *vbox_Text, TEXT_EDIT_DLG *a)
 
 
 /* -------------------------------------------------------------------
- * ¾ܥå
+ * その他設定ボックス
  */
 gint make_box_etc(GtkWidget *hbox_etc, TEXT_EDIT_DLG *a)
 {
@@ -316,7 +316,7 @@ gint make_box_etc(GtkWidget *hbox_etc, TEXT_EDIT_DLG *a)
 //		GtkWidget *entry_FitPointY;
 
 
-	/* ѥå󥰥ܥå(vbox_label_etc1)  */
+	/* パッキングボックス(vbox_label_etc1) 作成 */
 	vbox_label_etc1 = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start( (GtkBox *)GTK_BOX(hbox_etc), vbox_label_etc1, TRUE, TRUE, 0);
 	gtk_widget_show(vbox_label_etc1);
@@ -324,71 +324,71 @@ gint make_box_etc(GtkWidget *hbox_etc, TEXT_EDIT_DLG *a)
 		/* label_FontHeight */
 		label_FontHeight = gtk_label_new( _("Height of the character") );
 		gtk_misc_set_alignment(GTK_MISC(label_FontHeight), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_FontHeight, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_FontHeight, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_label_etc1), label_FontHeight, FALSE, TRUE, 0);
 		gtk_widget_show(label_FontHeight);
 
 		/* label_FontSpace */
 		label_FontSpace = gtk_label_new( _("Interval of the character") );
 		gtk_misc_set_alignment(GTK_MISC(label_FontSpace), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_FontSpace, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_FontSpace, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_label_etc1), label_FontSpace, FALSE, TRUE, 0);
 		gtk_widget_show(label_FontSpace);
 
 		/* label_WordSpace */
 		label_WordSpace = gtk_label_new( _("Interval of the word") );
 		gtk_misc_set_alignment(GTK_MISC(label_WordSpace), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_WordSpace, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_WordSpace, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_label_etc1), label_WordSpace, FALSE, TRUE, 0);
 		gtk_widget_show(label_WordSpace);
 
 		/* label_FontOverLineSpace */
 		label_FontOverLineSpace = gtk_label_new( _("The offset from the size line") );
 		gtk_misc_set_alignment(GTK_MISC(label_FontOverLineSpace), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_FontOverLineSpace, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_FontOverLineSpace, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_label_etc1), label_FontOverLineSpace, FALSE, TRUE, 0);
 		gtk_widget_show(label_FontOverLineSpace);
 
 
-	/* ѥå󥰥ܥå(vbox_entry_etc1)  */
+	/* パッキングボックス(vbox_entry_etc1) 作成 */
 	vbox_entry_etc1 = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start( (GtkBox *)GTK_BOX(hbox_etc), vbox_entry_etc1, TRUE, TRUE, 0);
 	gtk_widget_show(vbox_entry_etc1);
 
 		/* entry_FontHeight */
 		a->entry_FontHeight = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_FontHeight, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_FontHeight, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_entry_etc1), a->entry_FontHeight, FALSE, TRUE, 0);
 		FloatOut_n(str, a->FontHeight, 6, 0);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_FontHeight), str);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_FontHeight), str);	/* 初期値設定 */
 		gtk_widget_show(a->entry_FontHeight);
 
 		/* entry_FontSpace */
 		a->entry_FontSpace = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_FontSpace, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_FontSpace, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_entry_etc1), a->entry_FontSpace, FALSE, TRUE, 0);
 		FloatOut_n(str, a->FontSpace, 6, 0);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_FontSpace), str);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_FontSpace), str);	/* 初期値設定 */
 		gtk_widget_show(a->entry_FontSpace);
 
 		/* entry_WordSpace */
 		a->entry_WordSpace = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_WordSpace, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_WordSpace, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_entry_etc1), a->entry_WordSpace, FALSE, TRUE, 0);
 		FloatOut_n(str, a->WordSpace, 6, 0);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_WordSpace), str);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_WordSpace), str);	/* 初期値設定 */
 		gtk_widget_show(a->entry_WordSpace);
 
 		/* entry_FontOverLineSpace */
 		a->entry_FontOverLineSpace = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_FontOverLineSpace, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_FontOverLineSpace, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_entry_etc1), a->entry_FontOverLineSpace, FALSE, TRUE, 0);
 		FloatOut_n(str, a->FontOverLineSpace, 6, 0);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_FontOverLineSpace), str);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_FontOverLineSpace), str);	/* 初期値設定 */
 		gtk_widget_show(a->entry_FontOverLineSpace);
 
 
-	/* ѥå󥰥ܥå(vbox_label_etc2)  */
+	/* パッキングボックス(vbox_label_etc2) 作成 */
 	vbox_label_etc2 = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start( (GtkBox *)GTK_BOX(hbox_etc), vbox_label_etc2, TRUE, TRUE, 0);
 	gtk_widget_show(vbox_label_etc2);
@@ -396,82 +396,82 @@ gint make_box_etc(GtkWidget *hbox_etc, TEXT_EDIT_DLG *a)
 		/* label_SearchPointX */
 		label_SearchPointX = gtk_label_new( _("Insertion point X") );
 		gtk_misc_set_alignment(GTK_MISC(label_SearchPointX), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_SearchPointX, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_SearchPointX, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_label_etc2), label_SearchPointX, FALSE, TRUE, 0);
 		gtk_widget_show(label_SearchPointX);
 
 		/* label_SearchPointY */
 		label_SearchPointY = gtk_label_new( _("Insertion point Y") );
 		gtk_misc_set_alignment(GTK_MISC(label_SearchPointY), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_SearchPointY, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_SearchPointY, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_label_etc2), label_SearchPointY, FALSE, TRUE, 0);
 		gtk_widget_show(label_SearchPointY);
 
 		/* label_Angle */
 		label_Angle = gtk_label_new( _("Angle") );
 		gtk_misc_set_alignment(GTK_MISC(label_Angle), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_Angle, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_Angle, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_label_etc2), label_Angle, FALSE, TRUE, 0);
 		gtk_widget_show(label_Angle);
 
 		/* label_FitPointX */
 		label_FitPointX = gtk_label_new( _("It adjusts in the horizontal."));
 		gtk_misc_set_alignment(GTK_MISC(label_FitPointX), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_FitPointX, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_FitPointX, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_label_etc2), label_FitPointX, FALSE, TRUE, 0);
 		gtk_widget_show(label_FitPointX);
 
 		/* label_FitPointY */
 		label_FitPointY = gtk_label_new( _("It adjusts in the vertical.") );
 		gtk_misc_set_alignment(GTK_MISC(label_FitPointY), 0.0f, 1.0f);
-		gtk_widget_set_usize (label_FitPointY, TED_LABEL_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(label_FitPointY, TED_LABEL_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_label_etc2), label_FitPointY, FALSE, TRUE, 0);
 		gtk_widget_show(label_FitPointY);
 
 
-	/* ѥå󥰥ܥå(vbox_entry_etc2)  */
+	/* パッキングボックス(vbox_entry_etc2) 作成 */
 	vbox_entry_etc2 = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start( (GtkBox *)GTK_BOX(hbox_etc), vbox_entry_etc2, TRUE, TRUE, 0);
 	gtk_widget_show(vbox_entry_etc2);
 
 		/* entry_SearchPointX */
 		a->entry_SearchPointX = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_SearchPointX, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_SearchPointX, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_entry_etc2), a->entry_SearchPointX, FALSE, TRUE, 0);
 		FloatOut_n(str, a->SearchPointX, 6, 0);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_SearchPointX), str);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_SearchPointX), str);	/* 初期値設定 */
 		gtk_widget_show(a->entry_SearchPointX);
 
 		/* entry_SearchPointY */
 		a->entry_SearchPointY = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_SearchPointY, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_SearchPointY, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_entry_etc2), a->entry_SearchPointY, FALSE, TRUE, 0);
 		FloatOut_n(str, a->SearchPointY, 6, 0);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_SearchPointY), str);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_SearchPointY), str);	/* 初期値設定 */
 		gtk_widget_show(a->entry_SearchPointY);
 
 		/* entry_Angle */
 		a->entry_Angle = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_Angle, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_Angle, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_entry_etc2), a->entry_Angle, FALSE, TRUE, 0);
 		FloatOut_n(str, a->Angle, 6, 0);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_Angle), str);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_Angle), str);	/* 初期値設定 */
 		gtk_widget_show(a->entry_Angle);
 
 		/* entry_FitPointX */
 		a->entry_FitPointX = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_FitPointX, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_FitPointX, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_entry_etc2), a->entry_FitPointX, FALSE, TRUE, 0);
 		sprintf(str, "%d", a->FitPointX);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_FitPointX), str);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_FitPointX), str);	/* 初期値設定 */
 		gtk_widget_show(a->entry_FitPointX);
 
 		/* entry_FitPointY */
 		a->entry_FitPointY = gtk_entry_new();
-		gtk_widget_set_usize (a->entry_FitPointY, TED_ETC_WIDTH, TED_HEIGHT);
+		gtk_widget_set_size_request(a->entry_FitPointY, TED_ETC_WIDTH, TED_HEIGHT);
 		gtk_box_pack_start((GtkBox *)GTK_BOX(vbox_entry_etc2), a->entry_FitPointY, FALSE, TRUE, 0);
 		sprintf(str, "%d", a->FitPointY);
-		gtk_entry_set_text(GTK_ENTRY(a->entry_FitPointY), str);	/*  */
+		gtk_entry_set_text(GTK_ENTRY(a->entry_FitPointY), str);	/* 初期値設定 */
 		gtk_widget_show(a->entry_FitPointY);
 
 	return 1;
@@ -482,7 +482,7 @@ gint make_box_etc(GtkWidget *hbox_etc, TEXT_EDIT_DLG *a)
 
 
 /* -------------------------------------------------------------------
- * ˡ
+ * 寸法値設定ダイアログ
  * 
  */
 gint TextEditDialog(TEXT_EDIT_DLG *text_edit_dlg)
@@ -500,27 +500,27 @@ gint TextEditDialog(TEXT_EDIT_DLG *text_edit_dlg)
 
 
 
-	/* (text_edit_dlg->dialog) */
-	text_edit_dlg->dialog = gtk_window_new(GTK_WINDOW_DIALOG);
+	/* ダイアログ(text_edit_dlg->dialog)生成 */
+	text_edit_dlg->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_position(GTK_WINDOW(text_edit_dlg->dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_title(GTK_WINDOW(text_edit_dlg->dialog),  _("Text Setting") );
-	gtk_signal_connect( GTK_OBJECT(text_edit_dlg->dialog), "key_press_event",
-						GTK_SIGNAL_FUNC(text_edit_dlg_key_press_event), text_edit_dlg);
+	g_signal_connect( G_OBJECT(text_edit_dlg->dialog), "key_press_event",
+						G_CALLBACK(text_edit_dlg_key_press_event), text_edit_dlg);
 
 
-		/* ˤޤѥå󥰥ܥå(main_vbox) */
+		/* ダイアログの中にまず、パッキングボックス(main_vbox)を作成 */
 		main_vbox = gtk_vbox_new(0, 5);
 		gtk_container_add(GTK_CONTAINER(text_edit_dlg->dialog), main_vbox);
-		gtk_container_border_width(GTK_CONTAINER(text_edit_dlg->dialog), 5);
+		gtk_container_set_border_width(GTK_CONTAINER(text_edit_dlg->dialog), 5);
 		gtk_widget_show(main_vbox);
 
 
 			/* -----------------------------------------------------
-			 * ѥå󥰥ܥå(main_vbox) 
-			 * ѥå󥰥ܥå(vbox_Text & separator & action_hbox) 
-			 * Ǽ
+			 * パッキングボックス(main_vbox) に入れる
+			 * パッキングボックス(vbox_Text & separator & action_hbox) を作成し
+			 * 格納する
 			 */
-			/* ѥå󥰥ܥå(vbox_Text) */
+			/* パッキングボックス(vbox_Text) */
 			vbox_Text = gtk_vbox_new(FALSE, 2);
 			gtk_box_pack_start( (GtkBox *)GTK_BOX(main_vbox), vbox_Text, TRUE, TRUE, 0);
 			gtk_widget_show(vbox_Text);
@@ -528,12 +528,12 @@ gint TextEditDialog(TEXT_EDIT_DLG *text_edit_dlg)
 				/*  */
 				make_box_text(vbox_Text, text_edit_dlg);
 
-			/* ѥ졼(separator) */
+			/* セパレーター(separator) */
 			separator = gtk_hseparator_new();
 			gtk_box_pack_start( GTK_BOX(main_vbox), separator, TRUE, TRUE, 0);
 			gtk_widget_show(separator);
 
-			/* ѥå󥰥ܥå(hbox_etc) */
+			/* パッキングボックス(hbox_etc) */
 			hbox_etc = gtk_hbox_new(FALSE, 2);
 			gtk_box_pack_start( (GtkBox *)GTK_BOX(main_vbox), 
 								hbox_etc, TRUE, TRUE, 0);
@@ -542,70 +542,70 @@ gint TextEditDialog(TEXT_EDIT_DLG *text_edit_dlg)
 				/*  */
 				make_box_etc(hbox_etc, text_edit_dlg);
 
-			/* ѥ졼(separator) */
+			/* セパレーター(separator) */
 			separator = gtk_hseparator_new();
 			gtk_box_pack_start( GTK_BOX(main_vbox), separator, TRUE, TRUE, 0);
 			gtk_widget_show(separator);
 
 
-			/* ѥå󥰥ܥå(action_hbox) */
+			/* パッキングボックス(action_hbox) */
 			action_hbox = gtk_hbox_new(FALSE, 2);
 			gtk_box_pack_start( GTK_BOX(main_vbox), action_hbox, TRUE, TRUE, 0);
 			gtk_widget_show(action_hbox);
 
 				/* -----------------------------------------------------
-				 * ѥå󥰥ܥå(action_hbox) 
-				 * ܥ
+				 * パッキングボックス(action_hbox) に入れる
+				 * ボタン
 				 * file_name_button 
 				 * fai_button 
 				 * R_button 
 				 * cancel_button 
 				 * ok_button
-				 * 
-				 * Ǽ
+				 * を作成し
+				 * 格納する
 				 */
-				/* FileName ܥ */
+				/* FileName ボタンの生成 */
 				file_name_button = gtk_button_new_with_label( _("File Name") );
-				gtk_widget_set_usize (file_name_button, 80, 20);
+				gtk_widget_set_size_request(file_name_button, 80, 22);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), file_name_button, TRUE, TRUE, 2);
-				gtk_signal_connect( GTK_OBJECT(file_name_button), "clicked", 
-									GTK_SIGNAL_FUNC(text_edit_dlg_FileName_pushed), text_edit_dlg);
+				g_signal_connect( G_OBJECT(file_name_button), "clicked", 
+									G_CALLBACK(text_edit_dlg_FileName_pushed), text_edit_dlg);
 				gtk_widget_show(file_name_button);
 
-				/*  ܥ */
-				fai_button = gtk_button_new_with_label("");
-				gtk_widget_set_usize (fai_button, 30, 20);
+				/* Φ ボタンの生成 */
+				fai_button = gtk_button_new_with_label("φ");
+				gtk_widget_set_size_request(fai_button, 30, 22);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), fai_button, TRUE, TRUE, 2);
-				gtk_signal_connect( GTK_OBJECT(fai_button), "clicked", 
-									GTK_SIGNAL_FUNC(text_edit_dlg_Fai_pushed), text_edit_dlg);
+				g_signal_connect( G_OBJECT(fai_button), "clicked", 
+									G_CALLBACK(text_edit_dlg_Fai_pushed), text_edit_dlg);
 				gtk_widget_show(fai_button);
 
-				/* R ܥ */
+				/* R ボタンの生成 */
 				R_button = gtk_button_new_with_label("R");
-				gtk_widget_set_usize (R_button, 30, 20);
+				gtk_widget_set_size_request(R_button, 30, 22);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), R_button, TRUE, TRUE, 2);
-				gtk_signal_connect( GTK_OBJECT(R_button), "clicked", 
-									GTK_SIGNAL_FUNC(text_edit_dlg_R_pushed), text_edit_dlg);
+				g_signal_connect( G_OBJECT(R_button), "clicked", 
+									G_CALLBACK(text_edit_dlg_R_pushed), text_edit_dlg);
 				gtk_widget_show(R_button);
 
-				/* CANCELܥ */
+				/* CANCELボタンの生成 */
 				cancel_button = gtk_button_new_with_label("CANCEL");
-				gtk_widget_set_usize (cancel_button, 80, 20);
+				gtk_widget_set_size_request(cancel_button, 80, 22);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), cancel_button, TRUE, TRUE, 2);
-				gtk_signal_connect( GTK_OBJECT(cancel_button), "clicked", 
-									GTK_SIGNAL_FUNC(text_edit_dlg_cancel_pushed), text_edit_dlg);
-				gtk_signal_connect( GTK_OBJECT(cancel_button), "clicked", 
-									GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+				g_signal_connect( G_OBJECT(cancel_button), "clicked", 
+									G_CALLBACK(text_edit_dlg_cancel_pushed), text_edit_dlg);
+				g_signal_connect( G_OBJECT(cancel_button), "clicked", 
+									G_CALLBACK(gtk_main_quit), NULL);
 				gtk_widget_show(cancel_button);
 
-				/* OKܥ */
+				/* OKボタンの生成 */
 				ok_button = gtk_button_new_with_label("OK");
-				gtk_widget_set_usize (ok_button, 30, 20);
+				gtk_widget_set_size_request(ok_button, 30, 22);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(action_hbox), ok_button, TRUE, TRUE, 2);
-				gtk_signal_connect( GTK_OBJECT(ok_button), "clicked", 
-									GTK_SIGNAL_FUNC(text_edit_dlg_ok_pushed), text_edit_dlg);
-				gtk_signal_connect( GTK_OBJECT(ok_button), "clicked", 
-									GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+				g_signal_connect( G_OBJECT(ok_button), "clicked", 
+									G_CALLBACK(text_edit_dlg_ok_pushed), text_edit_dlg);
+				g_signal_connect( G_OBJECT(ok_button), "clicked", 
+									G_CALLBACK(gtk_main_quit), NULL);
 			//	  GTK_WIDGET_SET_FLAGS(ok_button, GTK_CAN_DEFAULT);
 			//	  gtk_widget_grab_default(ok_button);
 				gtk_widget_show(ok_button);
@@ -614,18 +614,18 @@ gint TextEditDialog(TEXT_EDIT_DLG *text_edit_dlg)
 
 
 
-	/*  ե entry_Text  */
+	/*  フォーカスを entry_Text に設定 */
 	gtk_window_set_focus(GTK_WINDOW(text_edit_dlg->dialog), text_edit_dlg->entry_Text);
 
-	/* ̤ɽ */
+	/* ダイアログを最前面に表示する */
 	gtk_window_set_modal(GTK_WINDOW(text_edit_dlg->dialog), TRUE);
-	/* ᥤ󥦥ɥǤʤ褦 */
+	/* メインウィンドウを操作できないように設定 */
 	gtk_window_set_transient_for(GTK_WINDOW(text_edit_dlg->dialog), GTK_WINDOW(text_edit_dlg->parent));
 
 
-	/* Ļ֤ */
+	/* ダイアログを可視状態へ */
 	gtk_widget_show(text_edit_dlg->dialog);
-	/* ᥤ󥤥٥ȥ롼 */
+	/* メインイベントループ */
 	gtk_main();
 	gtk_widget_destroy(text_edit_dlg->dialog);
 	return 0; 
@@ -636,7 +636,7 @@ gint TextEditDialog(TEXT_EDIT_DLG *text_edit_dlg)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : TextEditDlg.c
