@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2002 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2002 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/01/16
- *    Last                 : 2003/07/18
+ *    Last                 : 2007/10/31
  * ====================================================================
  */
 
@@ -23,12 +23,18 @@
 
 #include <gtk/gtk.h>
 #include <unistd.h>
+
+#ifdef G_OS_WIN32
+
+#else 
 #include <pwd.h>
+#include <langinfo.h>
+#include <locale.h>
+#endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <langinfo.h>
 #include <iconv.h>
-#include <locale.h>
 #include <errno.h>
 #include <string.h>
 #include <stdio.h>
@@ -49,9 +55,9 @@
 
 
 /* -------------------------------------------------------------------
- * ʸ str  nܤˤ split_word ΰ֤֤
+ * 文字列 str の中の n番目にある split_word の位置を返す
  *	
- * "פ˰Ϥޤ줿,Ͽʤ
+ * 「"」に囲まれた,は数えない
  *	
  */
 int split_word_point(char *str, char split_word, int n)
@@ -80,9 +86,9 @@ int split_word_point(char *str, char split_word, int n)
 
 
 /* -------------------------------------------------------------------
- * ʸ str  split_word Ĥ뤫֤
+ * 文字列 str の中に split_word が何個あるかを返す
  *	
- * "פ˰Ϥޤ줿,Ͽʤ
+ * 「"」に囲まれた,は数えない
  *	
  */
 int split_word_num(char *str, char split_word)
@@ -106,9 +112,9 @@ int split_word_num(char *str, char split_word)
 
 
 /* -------------------------------------------------------------------
- * ʸ str κ num ʸФʸ ret ֤
+ * 文字列 str の左から num 文字を取り出して文字列 ret に入れて返す
  *	
- * "פ˰Ϥޤ줿,Ͽʤ
+ * 「"」に囲まれた,は数えない
  *	
  */
 int strLeft(char *str, int num, char *ret)
@@ -129,10 +135,10 @@ int strLeft(char *str, int num, char *ret)
 
 
 /* -------------------------------------------------------------------
- * ʸ str κ midܤ numʸФ
- * ʸ ret ֤
+ * 文字列 str の左から mid番目から num文字を取り出して
+ * 文字列 ret に入れて返す
  *	
- * "פ˰Ϥޤ줿,Ͽʤ
+ * 「"」に囲まれた,は数えない
  *	
  */
 int strMid(char *str, int mid, int num, char *ret)
@@ -159,9 +165,9 @@ int strMid(char *str, int mid, int num, char *ret)
 
 
 /* -------------------------------------------------------------------
- * ʸ str α num ʸФʸ ret ֤
+ * 文字列 str の右から num 文字を取り出して文字列 ret に入れて返す
  *	
- * "פ˰Ϥޤ줿,Ͽʤ
+ * 「"」に囲まれた,は数えない
  *	
  */
 int strRight(char *str, int num, char *ret)
@@ -180,15 +186,15 @@ int strRight(char *str, int num, char *ret)
 
 
 /* -------------------------------------------------------------------
- * ץåʸ (split_word) Ƕڤơǡ¤Ǥʸ (str) 
- * num ܤΥǡʸФʸ (ret) ֤
+ * スプリット文字 (split_word) で区切られて、データが並んでいる文字列 (str) の
+ * num 番目のデータ文字列を取り出して文字列 (ret) に入れて返す
  *	
  * 1,2,3,4,5,6,7
  *	1 2 3 4 5 6
  * 1234567890123
  *	
  *	
- * "פ˰Ϥޤ줿,Ͽʤ
+ * 「"」に囲まれた,は数えない
  *	
  */
 int LineDataSplit(char *str, char split_word, int num, char *ret)
@@ -196,26 +202,26 @@ int LineDataSplit(char *str, char split_word, int num, char *ret)
 	char DumyStr[256], StrStr[256];
 	int Len, Split, Split_P[2];
 
-	/* ʸ str  split_word Ĥ뤫֤ */
+	/* 文字列 str の中に split_word が何個あるかを返す */
 	Split = split_word_num(str, split_word);
 	if (num	 > Split + 1 )	return -1;
 
 	if (num == 1) {
-		/* ʸ str  nܤˤ split_word ΰ֤֤ */
+		/* 文字列 str の中の n番目にある split_word の位置を返す */
 		Split_P[0] = split_word_point(str, split_word, 1);
-		/* ʸ str κ num ʸФʸ ret ֤ */
+		/* 文字列 str の左から num 文字を取り出して文字列 ret に入れて返す */
 		strLeft(str, Split_P[0] - 1, DumyStr);
 	}
 	else if (num > 1 && num <= Split) {
-		/* ʸ str  nܤˤ split_word ΰ֤֤ */
+		/* 文字列 str の中の n番目にある split_word の位置を返す */
 		Split_P[0] = split_word_point(str, split_word, num - 1);
 		Split_P[1] = split_word_point(str, split_word, num);
 		strMid(str, Split_P[0] + 1, Split_P[1] - Split_P[0] - 1, DumyStr);
 	}
 	else if (num == Split + 1) {
-		/* ʸ str  nܤˤ split_word ΰ֤֤ */
+		/* 文字列 str の中の n番目にある split_word の位置を返す */
 		Split_P[0] = split_word_point(str, split_word, num - 1);
-		/* ʸ str α num ʸФʸ ret ֤ */
+		/* 文字列 str の右から num 文字を取り出して文字列 ret に入れて返す */
 		strRight(str, strlen(str) - Split_P[0], DumyStr);
 	}
 
@@ -240,7 +246,7 @@ int LineDataSplit(char *str, char split_word, int num, char *ret)
 
 
 /* -------------------------------------------------------------------
- * ֤ؿ
+ * 置き換え関数
  * 
  */
 void replace(char *text, char *key, char *rep)
@@ -248,7 +254,7 @@ void replace(char *text, char *key, char *rep)
 	char *p, work[2*256], a[2*256];
 
 	strcpy(work, text);
-	p = search(work, key);				/*	ΰ˥ԡ*/
+	p = search(work, key);				/*	作業領域にコピー*/
 	while (p != NULL) {
 		if (strlen(work) > (256*2)-1) {
 			work[2*256-2] = '\n';
@@ -256,9 +262,9 @@ void replace(char *text, char *key, char *rep)
 			break;
 		}
 		*p = '\0';
-		strcpy(a, p + strlen(key)); 	/* ʸƤȥХåե˥ԡ */
-		strcat(work, rep);				/* ֤ʸworkϢ뤹 */
-		strcat(work, a);				/* ΰ֤õ */
+		strcpy(a, p + strlen(key)); 	/* サーチ文字より後の内容を作業バッファにコピー */
+		strcat(work, rep);				/* 置きかえる文字列をworkに連結する */
+		strcat(work, a);				/* 次の位置を探す */
 		p = search(p+strlen(rep), key);
 	}
 	strcpy(text, work);
@@ -267,7 +273,7 @@ void replace(char *text, char *key, char *rep)
 
 
 /* -------------------------------------------------------------------
- * ؿ
+ * サーチ関数
  * 
  */
 char *search(char *text, char *key)
@@ -278,7 +284,7 @@ char *search(char *text, char *key)
 	m = strlen(text);
 	n = strlen(key);
 	for (p = text ; p <= text + m - n ; p++) {
-		if (strncmp(p, key, n) == 0)	/* 2ĤʸʸӤޤ */
+		if (strncmp(p, key, n) == 0)	/* 2つの文字列の文字を比較します */
 			return (p);
 	}
 	return (NULL);
@@ -309,48 +315,29 @@ int ltrim(char *str, char *ret)
 
 
 /* -------------------------------------------------------------------
- * եѥ̾ե̾
+ * フルパス名からファイル名を取得する
  *	
- * char *lpszPath	  ե̾ޤѥ̾ؤΥݥ
- * char * ե̾ؤΥݥ
- * ե̾ޤޤʤȤ""ؤΥݥ
- * [\],[/],[:]Ĥʤä硢ե̾ȤߤʤƤΤޤ֤
+ * char *lpszPath	  ファイル名を含むパス名へのポインタ
+ * char * ファイル名へのポインタ
+ * ファイル名を含まないときは""へのポインタ
+ * [\],[/],[:]が見つからなかった場合、引数をファイル名とみなしてそのまま返す
  *	
- * ѥ̾Ƭʸ򸡺ơ:,\,/פΤ줫Ǹ˸õ
- * ʸӤȤϡоݤʸ2Хʸ1ХʸĴ٤ɬפޤ
+ * パス名の先頭から文字列を検索して，「:,\,/」のいずれかが最後に現れる地点を探す。
+ * 文字を比較するときは，比較対象の文字が2バイト文字か1バイト文字かを調べる必要があります。
  *	
- * "פ˰Ϥޤ줿,Ͽʤ
+ * 「"」に囲まれた,は数えない
  */
 char *getFileName(char *lpszPath)
 {
 	char *lpszPtr = lpszPath;
-	int charset = 0, Ret;
-	int (*WHAT_KANJI)(/* unsigned */ char *str) = 0;
 
 
-	Ret = Get_charset();
-	if (Ret == 0) {
-		charset = 2;
-		WHAT_KANJI = whatKanji_sjis;
-	}
-	else if (Ret == 1) {
-		charset = 8;
-		WHAT_KANJI = whatKanji_euc;
-	}
-
-	while(*lpszPtr != '\0') {
-		/* ХʸƬϥå */
-		if((WHAT_KANJI((unsigned char *) lpszPtr) & charset) == charset ) {
-			/* ʸ */
-			lpszPtr++;
+	while (*lpszPtr != '\0') {
+		/* [\],[/],[:]を見つけたら現在地+1のポインタを保存 */
+		if((*lpszPtr == '\\') || (*lpszPtr == '/') || (*lpszPtr == ':')) {
+			lpszPath = lpszPtr + 1;
 		}
-		else {
-			/* [\],[/],[:]򸫤Ĥ鸽+1Υݥ󥿤¸ */
-			if((*lpszPtr == '\\') || (*lpszPtr == '/') || (*lpszPtr == ':')) {
-				lpszPath=lpszPtr+1;
-			}
-		}
-		/* ʸ */
+		/* 次の文字へ */
 		lpszPtr++;
 	}
 	return lpszPath;
@@ -359,127 +346,77 @@ char *getFileName(char *lpszPath)
 
 
 /* -------------------------------------------------------------------
- * ե̾ĥҤ
+ * ファイル名から拡張子を取り除く
  *	
- * char *lpszFileName	  ե̾ؤΥݥ
- * ʼ¹Ը塢ե̾ĥҤڤΥ
+ * char *lpszFileName	  ファイル名へのポインタ
+ * （実行後、ファイル名から拡張子が切り離される）
  */
 void cutExtName(char *lpszFileName)
 {
 	char *pEnd = lpszFileName;
 	char *pStart = lpszFileName;
 
-	int charset = 0, Ret;
-	int (*WHAT_KANJI)(/* unsigned */ char *str) = 0;
 
-
-	Ret = Get_charset();
-	if (Ret == 0) {
-		charset = 2;
-		WHAT_KANJI = whatKanji_sjis;
-	}
-	else if (Ret == 1) {
-		charset = 8;
-		WHAT_KANJI = whatKanji_euc;
-	}
-
-
-	/* ǥ쥯ȥʬκǸޤ */
-	while(*pEnd != '\0') {
-		/* ХʸƬϥå */
-		if((WHAT_KANJI((unsigned char *) pEnd) & charset) == charset ) {
-			/* ʸ */
-			pEnd++;
+	/* ディレクトリ部分の最後まで飛ぶ */
+	while (*pEnd != '\0') {
+		/* [\],[/],[:]を見つけたら現在地+1のポインタを保存 */
+		if((*pEnd == '\\') || (*pEnd == '/') || (*pEnd == ':')) {
+			pStart = pEnd + 1;
 		}
-		else {
-			/* [\],[/],[:]򸫤Ĥ鸽+1Υݥ󥿤¸ */
-			if((*pEnd == '\\') || (*pEnd == '/') || (*pEnd == ':')) {
-				pStart=pEnd+1;
-			}
-		}
-		/* ʸ */
+		/* 次の文字へ */
 		pEnd++;
 	}
 
 
-	pEnd=lpszFileName;
-	while(*pStart != '\0') {
-		/* ХʸƬϥå */
-		if((WHAT_KANJI((unsigned char *) pStart) & charset) == charset ) {
-			/* ʸ */
-			pStart++;
+	pEnd = lpszFileName;
+	while (*pStart != '\0') {
+		/* [.]を見つけたら現在地+1のポインタを保存 */
+		if(*pStart == '.') {
+			pEnd=pStart;
 		}
-		else {
-			/* [.]򸫤Ĥ鸽+1Υݥ󥿤¸ */
-			if(*pStart == '.') {
-				pEnd=pStart;
-			}
-		}
-		/* ʸ */
+		/* 次の文字へ */
 		pStart++;
 	}
 
 
-	/* ե̾˳ĥҤޤޤʤä粿⤷ʤ */
-	if(pEnd == lpszFileName) {
+	/* ファイル名に拡張子を含まなかった場合何もしない */
+	if (pEnd == lpszFileName) {
 		return;
 	}
-	/* ե̾ĥҤڤΥ */
-	*pEnd='\0';
+	/* ファイル名から拡張子を切り離す */
+	*pEnd = '\0';
 }
 
 
 
 /* -------------------------------------------------------------------
- * ѥ̾ե̾
+ * パス名からファイル名を取り除く
  *	
- * char *lpszPath	  ե̾ޤѥ̾ؤΥݥ
- * ʼ¹Ը塢ѥ̾ե̾ڤΥ
+ * char *lpszPath	  ファイル名を含むパス名へのポインタ
+ * （実行後、パス名からファイル名が切り離される）
  *
- * ѥ̾Ƭʸ򸡺ơ:,\,/פΤ줫Ǹ˸줿Υݥ󥿤
- * '\0' 뤳Ȥǥե̾ޤ
+ * パス名の先頭から文字列を検索して，「:,\,/」のいずれかが最後に現れた地点のポインタに
+ * '\0' を代入することでファイル名を取り除きます。
  */
 void cutFileName(char *lpszPath)
 {
 	char *lpszEnd = lpszPath;
 
-	int charset = 0, Ret;
-	int (*WHAT_KANJI)(/* unsigned */ char *str) = 0;
-
-
-	Ret = Get_charset();
-	if (Ret == 0) {
-		charset = 2;
-		WHAT_KANJI = whatKanji_sjis;
-	}
-	else if (Ret == 1) {
-		charset = 8;
-		WHAT_KANJI = whatKanji_euc;
-	}
-
 
 	while(*lpszPath != '\0') {
-		/* ХʸƬϥå */
-		if((WHAT_KANJI((unsigned char *) lpszPath) & charset) == charset ) {
-			/* ʸ */
-			lpszPath++;
+		/* [\],[/],[:]を見つけたら現在地+1のポインタを保存 */
+		if((*lpszPath == '\\') || (*lpszPath == '/') || (*lpszPath == ':')) {
+			lpszEnd = lpszPath + 1;
 		}
-		else {
-			/* [\],[/],[:]򸫤Ĥ鸽+1Υݥ󥿤¸ */
-			if((*lpszPath == '\\') || (*lpszPath == '/') || (*lpszPath == ':')) {
-				lpszEnd=lpszPath+1;
-			}
-		}
-		/* ʸ */
+		/* 次の文字へ */
 		lpszPath++;
 	}
 
-
-	/* ѥ̾˥եޤޤʤä粿⤷ʤ */
+	/* パス名にファイルを含まなかった場合何もしない */
 	if(lpszEnd == lpszPath) {
 		return;
 	}
-	/* ѥ̾ե̾ڤΥ */
+	/* パス名からファイル名を切り離す */
 	*lpszEnd='\0';
 	return;
 }
@@ -487,22 +424,22 @@ void cutFileName(char *lpszPath)
 
 
 /* -------------------------------------------------------------------
- * ¹ԥեΥեѥ
+ * 実行ファイルのフルパス取得
  *	
  */
 #ifdef AFTER
 int GetAppPath(char *App_Path)
 {
-	char  szModulePath[MAX_PATH];
+	char  szModulePath[MAXPATHLEN];
 
 
-	/* ¹ԥեΥեѥ */
-	GetModuleFileName(NULL, szModulePath, MAX_PATH);
+	/* 実行ファイルのフルパス取得 */
+	GetModuleFileName(NULL, szModulePath, MAXPATHLEN);
 
-	//ѥ̾ե̾
-	//  char *lpszPath	ե̾ޤѥ̾ؤΥݥ
-	//			  ʼ¹Ը塢ѥ̾ե̾ڤΥ
-	//͡ʤ
+	//パス名からファイル名を取り除く
+	//引数：  char *lpszPath	ファイル名を含むパス名へのポインタ
+	//			  （実行後、パス名からファイル名が切り離される）
+	//戻り値：なし
 	cutFileName(szModulePath);
 	strcpy(App_Path, szModulePath);
 	return 1;
@@ -512,25 +449,97 @@ int GetAppPath(char *App_Path)
 
 
 /* -------------------------------------------------------------------
- * ȥ꡼फ飱ɤߤ ret ֤
+ * ファイルに１行書き込み
+ * 
+ * 
+ * int code
+ *     CHARSET_UTF8    5
+ *     CHARSET_LOCALE  0
+ */
+int write_locale_from_utf8(char *str, FILE *stream, int code)
+{
+	char *locale_str;
+	GError *err;
+	
+	if (code != CHARSET_UTF8) {
+		/* Convert from UTF8 to system string */
+		if (!(locale_str = g_locale_from_utf8 ( str, -1, NULL, NULL, &err))) {
+			g_printerr ( "Failed UTF-8 to locale conversion: %s\n", err->message ) ;
+			g_clear_error ( &err ) ;
+			return -1;
+		}
+		fputs(locale_str, stream );
+		g_free(locale_str);
+	}
+	else {
+		fputs(str, stream );
+	}
+	return 0;
+}
+
+
+
+/* -------------------------------------------------------------------
+ * ファイルから１行読み込み
+ * 
+ * 
+ * int code
+ *     CHARSET_UTF8    5
+ *     CHARSET_LOCALE  0
+ */
+int read_utf8_from_locale(FILE *stream, char *str, int code)
+{
+	int ret;
+	char locale_str[1024];
+	char * utf8_str;
+	GError *err;
+	
+	ret = LineRead(stream, locale_str);
+	if (ret == -1) {
+		return -1;
+	}
+	
+	
+	if (code != CHARSET_UTF8) {
+		/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+		   sgy ファイルのロケールが合っていないと、エラーになる。
+		   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
+		if (!(utf8_str = g_locale_to_utf8(locale_str, -1, NULL, NULL, &err))) {
+			g_printerr ( "Failed locale to UTF-8 conversion: %s\n", err->message ) ;
+			g_clear_error ( &err ) ;
+			return -1;
+		}
+		strcpy(str, utf8_str);
+		g_free(utf8_str);
+	}
+	else {
+		strcpy(str, locale_str);
+	}
+	return ret;
+}
+
+
+
+/* -------------------------------------------------------------------
+ * ストリームから１行読みこんで ret に入れて返す。
  *	
  *	
- *	1 : Ԥ֤
- *	0 : ե뽪üˤ
+ *	1 : １行を正常に返す。
+ *	0 : ファイル終端にきた。
  */
 int LineRead(FILE *stream, char *ret)
 {
 	int i, j;
-	char c, str[256];
+	char c, str[1024];
 
 	i = 0;
 	j = 0;
 	while((c = getc( stream )) != EOF) {
-		/* CR ʳ */
+		/* CR 以外 */
 		if (c == 0x0d) {
-			// Ф
+			// 飛ばす
 		}
-		/* 1ɤ߹ߴλ */
+		/* 1行読み込み完了 */
 		else if(c == 0x0a) {
 			str[i] = '\0';
 			strcpy(ret, str);
@@ -541,15 +550,19 @@ int LineRead(FILE *stream, char *ret)
 			i++;
 		}
 		j++;
-		if (j == 255) return -1;
+		/* 1024 bite 以上 */
+		if (j == 1023) return -1;
 	}
+	/* EOF 終了 */
+	str[i] = '\0';
+	strcpy(ret, str);
 	return 0;
 }
 
 
 
 /* -------------------------------------------------------------------
- * RGB(0xrrggbb) Υ顼 (red, green, blue) Υǡʬ
+ * RGB(0xrrggbb) のカラーを (red, green, blue) のデータに分解
  * 
  */
 int color_split(struct ColorDat *a)
@@ -573,7 +586,7 @@ int color_split(struct ColorDat *a)
 
 
 /* ---------------------------------------------------------------------
- * (red, green, blue) Υǡ RGB(0xrrggbb) Υ顼˹
+ * (red, green, blue) のデータを RGB(0xrrggbb) のカラーに合成
  * 
  */
 long color_rgb(struct ColorDat *a)
@@ -595,8 +608,8 @@ long color_rgb(struct ColorDat *a)
 
 
 /* ---------------------------------------------------------------------
- * 0xrrggbb ηΥǡ "rr"  "bb" 򴹤
- * Windows(0xbbggrr) Υ顼  <-->  0xrrggbb  Ѵ
+ * 0xrrggbb の形式のデータの "rr" と "bb" を交換する
+ * Windows(0xbbggrr) のカラー  <-->  0xrrggbb  の変換
  * 
  */
 long color_rb_change(long rgbcol)
@@ -622,7 +635,7 @@ long color_rb_change(long rgbcol)
 
 
 /* -------------------------------------------------------------------
- * ʸ(б 0xղ)ͤѴ
+ * 文字列(１６進対応 0x付加)を数値に変換
  * 
  */
 int atoi16(char *str)
@@ -639,9 +652,9 @@ int atoi16(char *str)
 
 
 /* -------------------------------------------------------------------
- * ʸͤѴ
+ * １６進文字列を数値に変換
  * 
- *  hextoint("B6119");
+ * 用例 hextoint("B6119");
  */
 int hextoint(char *str)
 {
@@ -672,7 +685,7 @@ int hextoint(char *str)
 
 
 /* -------------------------------------------------------------------
- * ʸ
+ * １６進文字列を作成
  * 
  */
 int HexString(long data, char *hex)
@@ -719,14 +732,14 @@ int HexString(long data, char *hex)
 
 
 /* -------------------------------------------------------------------
- * log ե񤭤
+ * log ファイル書きこみ
  *	
  */
 int LogFileOpen(char *str)
 {
-	/* ե򥪡ץ */ 
+	/* ファイルをオープン */ 
 	if((stream_log = fopen( str, "w")) == NULL) {
-//		MsgBox("LogFileOpen", "ե %s ϳޤǤ");
+//		MsgBox("LogFileOpen", "設定ファイル %s は開けませんでした。");
 		return 0;
 	}
 	LogFileWrite("SagCAD run\n");
@@ -746,7 +759,7 @@ int LogFileWrite(char *str)
 int LogFileClose(void)
 {
 	LogFileWrite("SagCAD stop\n");
-	/* ե򥯥 */ 
+	/* ファイルをクローズ */ 
 	fclose(stream_log);
 	return 1;
 }
@@ -754,7 +767,7 @@ int LogFileClose(void)
 
 
 /* -------------------------------------------------------------------
- * log ե񤭤
+ * log ファイル書きこみ
  *	
  */
 int OneShotLog(char *str)
@@ -767,16 +780,16 @@ int OneShotLog(char *str)
 
 	sprintf(dummy, "%s//OneShotLog", path);
 
-	/* ե򥪡ץ */ 
+	/* ファイルをオープン */ 
 	if((stream = fopen(dummy, "a")) == NULL) {
-//		MsgBox("LogFileOpen", "ե %s ϳޤǤ");
+//		MsgBox("LogFileOpen", "設定ファイル %s は開けませんでした。");
 		return 0;
 	}
 
 //	if (strstr(str, "\n") == NULL) strcat(str, "\n");
 	fputs(str, stream);
 
-	/* ե򥯥 */ 
+	/* ファイルをクローズ */ 
 	fclose(stream);
 	return 1;
 }
@@ -797,68 +810,49 @@ int DeleteOneShotLog(void)
 
 
 
-
-
 /* -------------------------------------------------------------------
- * եΥѥ
+ * 設定ファイルのパス取得
  *	
- * Windows ξ硢¹ԥեƱեե֤
- * LINUX ξ硢/home/[user]/.sagcad/sagcadrc
+ * Windows の場合、実行ファイルと同じフォルダに設定ファイルを置く
+ * LINUX の場合、/home/[user]/.sagcad/sagcadrc
  */
 int GetConfigPath(char *path)
 {
+#ifdef G_OS_WIN32
+	char str[256];
+	FILE *fp;
+	
+	sprintf(path, "%s/.sagcad", g_get_home_dir());
+	
+	/* check & make */
+	sprintf(str, "%s/sagcadrc", path);
+	if((fp=fopen(str, "r")) != NULL) {
+		/* find file */
+		fclose(fp);
+		//g_print("GetConfigPath() : .sagcad OK !\n");
+	}
+	else {
+		if (mkdir(path) < 0) {
+			g_print("GetConfigPath() : %s nothing and not make !", path);
+			return -1;
+		}
+		else {
+			g_print("GetConfigPath() : %s nothing and make !", path);
+		}
+		//mkdir(g_get_home_dir());
+		//g_print("GetConfigPath() : .sagcad No and make !");
+	}
+	
+	return 0;
+#else
 	uid_t uid;
 	struct passwd *pwd;
 
 	uid = getuid();
 	pwd = getpwuid(uid);
 	sprintf(path, "%s/.sagcad", pwd->pw_dir);
-	return 1;
-
 	return 0;
-}
-
-
-
-
-
-/* -------------------------------------------------------------------
- * ɤμ 
- * 
- * եJISʤ0eucʤ1֤
- */
-int Get_charset(void)
-{
-	char *envvalue, str[256];
-
-	/* ja_JP.eucJP */
-	envvalue = getenv("LANG");
-	if (envvalue != NULL) {
-		strcpy(str, envvalue);
-		if (strstr(str, "euc") != NULL) {
-			return 1;
-		}
-		else if (strstr(str, "EUC") != NULL) {
-			return 1;
-		}
-		else if (strstr(str, "ujis") != NULL) {
-			return 1;
-		}
-		else if (strstr(str, "SJIS") != NULL) {
-			return 0;
-		}
-		else if (strstr(str, "sjis") != NULL) {
-			return 0;
-		}
-		else if (strstr(str, "shift_jis") != NULL) {
-			return 0;
-		}
-		else {
-			return 1;
-		}
-		return 1;
-	}
-	return -1;
+#endif
 }
 
 
@@ -867,12 +861,16 @@ int Get_charset(void)
 
 void home_of_user(char *home)
 {
+#ifdef G_OS_WIN32
+	sprintf(home, "%s", g_get_home_dir());
+#else
 	uid_t uid;
 	struct passwd *pwd;
 
 	uid = getuid();
 	pwd = getpwuid(uid);
 	strcpy (home, pwd->pw_dir);
+#endif
 }
 
 
@@ -881,12 +879,16 @@ void home_of_user(char *home)
 
 void name_of_user(char *user)
 {
+#ifdef G_OS_WIN32
+	sprintf(user, "%s", g_get_user_name());
+#else
 	uid_t uid;
 	struct passwd *pwd;
 
 	uid = getuid();
 	pwd = getpwuid(uid);
 	strcpy (user, pwd->pw_name);
+#endif
 }
 
 
@@ -894,36 +896,36 @@ void name_of_user(char *user)
 
 
 /* -------------------------------------------------------------------
- * ʸΥѴ
+ * 文字列のコード変換
  * 
- * from_str : Ѵʸ
- * from_code : ѴΥ
- * to_code : ѴΥ
+ * from_str : 変換元文字列
+ * from_code : 変換元のコード
+ * to_code : 変換後のコード
  * 
- * ѴʸΥݥ󥿤֤ƤӽФ¦ free 롣
+ * 変換後の文字列のポインタを返す。呼び出し側で free する。
  */
 char *p_sag_iconv(char *from_str, char *from_code, char *to_code)
 {
 //#ifdef P_SAG_ICONV
-	iconv_t cd;					/* Ѵѥǥץ */
-	char *inbuf;				/* ѥХåե */
-	char *outbuf;				/* ѥХåե */
-	char *outptr;				/* ƥݥݥ󥿡ʽѡ */
-	const char *inptr;			/* ƥݥݥ󥿡ѡ */
-	size_t inbyteleft;			/* ϥХåե */
-	size_t outbyteleft;			/* ϥХåե */
-	size_t ret;					/*  */
+	iconv_t cd;					/* 変換用ディスクリプタ */
+	char *inbuf;				/* 入力用バッファ */
+	char *outbuf;				/* 出力用バッファ */
+	char *outptr;				/* テンポラリポインタ（出力用） */
+	const char *inptr;			/* テンポラリポインタ（入力用） */
+	size_t inbyteleft;			/* 入力バッファサイズ */
+	size_t outbyteleft;			/* 出力バッファサイズ */
+	size_t ret;					/* 戻り値 */
 #ifdef P_SAG_ICONV
-	int i;						/* 롼ץѿ */
-	int n;						/* ХåեĹ */
+	int i;						/* ループカウンタ用変数 */
+	int n;						/* バッファ長 */
 #endif
 
-	/* Ϥ줿ʸ򥳥ԡơĹ */
+	/* 入力された文字列をコピーして、長さを求める */
 	inbuf = strdup(from_str);
 	inbyteleft = strlen(inbuf);
 
-	/* ѤΥХåեݤ */
-	/* malloc ϡvoid ݥ󥿤֤Τǡ˾η˥㥹ȤƻȤޤ礦 */
+	/* 出力用のバッファを確保する */
+	/* malloc は、void ポインタを返すので、所望の型にキャストして使いましょう */
 	outbuf = (char *)xmalloc(inbyteleft * 4 + 1);
 	outbyteleft = inbyteleft * 4;
 	inbyteleft = strlen(inbuf) + 1;
@@ -932,28 +934,28 @@ char *p_sag_iconv(char *from_str, char *from_code, char *to_code)
 		return NULL;
 	}
 
-	/* ѥХåեΥԡʥݥ󥿡 */
+	/* 入出力用バッファのコピー（ポインタ） */
 	outptr = outbuf;
 	inptr = inbuf;
 
 	/* iconv open */
-	/* ʸѴѤΥǥץ򥪡ץ󤹤 */
+	/* 文字コード変換用のディスクリプタをオープンする */
 	cd = iconv_open(to_code, from_code);
 	if (cd == (iconv_t)(-1)) {
 		printf("error in iconv_open\n");
 
 		switch(errno) {
 			case EMFILE:
-				printf("p_sag_iconv() : ƤӽФȤΥץǴOPEN_MAXĤεһҤץ󤵤Ƥ\n");
+				printf("p_sag_iconv() : 呼び出しもとのプロセスで既にOPEN_MAX個の記述子がオープンされている\n");
 				break;
 			case ENFILE:
-				printf("p_sag_iconv() : ץ󤵤Ƥե¤¿\n");
+				printf("p_sag_iconv() : オープンされているファイルの和が多すぎる\n");
 				break;
 			case ENOMEM:
-				printf("p_sag_iconv() : ΰ褬­Ƥ\n");
+				printf("p_sag_iconv() : 記憶領域が不足している\n");
 				break;
 			case EINVAL:
-				printf("p_sag_iconv() : fromcodetocodeǻꤷѴ򥵥ݡȤƤʤ\n");
+				printf("p_sag_iconv() : fromcodeおよびtocode引数で指定したコード変換をサポートしていない\n");
 				break;
 		}
 
@@ -963,25 +965,25 @@ char *p_sag_iconv(char *from_str, char *from_code, char *to_code)
 	}
 
 	/* iconv */
-	/* ʸѴ¹ */
-	/* iconv ΰץȥ̤˷㥹ȤȡٹϽФʤʤޤ*/
+	/* 文字コード変換を実行 */
+	/* iconv の引数をプロトタイプ宣言通りに型キャストすると、警告は出なくなります。*/
 	ret = iconv(cd, (char **)&inptr, &inbyteleft, (char **)&outptr, &outbyteleft);
 //	printf("ret1 = %d\n", ret);
 	if ((size_t)(-1) != ret) {
 		switch( errno ) {
 			case EBADF:
-				printf("p_sag_iconv() : ɥåȡСεһҤǤϤʤ\n");
+				printf("p_sag_iconv() : コードセット・コンバーターの記述子ではない。\n");
 				break;
 			case E2BIG:
-				printf("p_sag_iconv() : Ѵʸΰ­\n");
+				printf("p_sag_iconv() : 変換後の文字列取得領域不足\n");
 				break;
 #ifdef ELISEQ
 			case ELISEQ:
-				printf("p_sag_iconv() : ϥХåեѴΥɥåȤ°ʤǡ¸\n");
+				printf("p_sag_iconv() : 入力バッファに変換元のコードセットに属しないデータが存在\n");
 				break;
 #endif
 			case EINVAL:
-				printf("p_sag_iconv() : ϥХåեκǸԴʸ¸ߤ\n");
+				printf("p_sag_iconv() : 入力バッファの最後に不完全な文字が存在した。\n");
 				break;
 		}
 
@@ -992,7 +994,7 @@ char *p_sag_iconv(char *from_str, char *from_code, char *to_code)
 	}
 
 #ifdef P_SAG_ICONV
-	/* ̤ɸϤɽ */
+	/* 結果を標準出力に表示する */
 	n = strlen(outbuf);
 	printf("in sag_iconv() \n");
 	printf("----------------------------------------------------------\n");
@@ -1007,10 +1009,10 @@ char *p_sag_iconv(char *from_str, char *from_code, char *to_code)
 	printf("\n");
 #endif
 
-	/* ѤǥץĤ */
+	/* 使用したディスクリプタを閉じる */
 	iconv_close(cd);
 
-	/* Ѥΰ */
+	/* 使用した領域を開放する */
 	free(inbuf);
 
 	return outbuf;
@@ -1021,35 +1023,35 @@ char *p_sag_iconv(char *from_str, char *from_code, char *to_code)
 
 
 /* -------------------------------------------------------------------
- * ʸΥѴ
+ * 文字列のコード変換
  * 
- * from_str  : Ѵʸ
- * to_str    : Ѵʸ
- * from_code : ѴΥ
- * to_code   : ѴΥ
+ * from_str  : 変換元文字列
+ * to_str    : 変換後の文字列が入る
+ * from_code : 変換元のコード
+ * to_code   : 変換後のコード
  */
 int sag_iconv(char *from_str, char *to_str, char *from_code, char *to_code)
 {
 //#define SAG_ICONV
-	iconv_t cd;					/* Ѵѥǥץ */
-	char *inbuf;				/* ѥХåե */
-	char *outbuf;				/* ѥХåե */
-	char *outptr;				/* ƥݥݥ󥿡ʽѡ */
-	const char *inptr;			/* ƥݥݥ󥿡ѡ */
-	size_t inbyteleft;			/* ϥХåե */
-	size_t outbyteleft;			/* ϥХåե */
-	size_t ret;					/*  */
+	iconv_t cd;					/* 変換用ディスクリプタ */
+	char *inbuf;				/* 入力用バッファ */
+	char *outbuf;				/* 出力用バッファ */
+	char *outptr;				/* テンポラリポインタ（出力用） */
+	const char *inptr;			/* テンポラリポインタ（入力用） */
+	size_t inbyteleft;			/* 入力バッファサイズ */
+	size_t outbyteleft;			/* 出力バッファサイズ */
+	size_t ret;					/* 戻り値 */
 #ifdef SAG_ICONV
-	int i;						/* 롼ץѿ */
-	int n;						/* ХåեĹ */
+	int i;						/* ループカウンタ用変数 */
+	int n;						/* バッファ長 */
 #endif
 
-	/* Ϥ줿ʸ򥳥ԡơĹ */
+	/* 入力された文字列をコピーして、長さを求める */
 	inbuf = strdup(from_str);
 	inbyteleft = strlen(inbuf);
 
-	/* ѤΥХåեݤ */
-	/* malloc ϡvoid ݥ󥿤֤Τǡ˾η˥㥹ȤƻȤޤ礦 */
+	/* 出力用のバッファを確保する */
+	/* malloc は、void ポインタを返すので、所望の型にキャストして使いましょう */
 	outbuf = (char *)xmalloc(inbyteleft * 4 + 1);
 	outbyteleft = inbyteleft * 4;
 	inbyteleft = strlen(inbuf) + 1;
@@ -1058,27 +1060,27 @@ int sag_iconv(char *from_str, char *to_str, char *from_code, char *to_code)
 		return 0;
 	}
 
-	/* ѥХåեΥԡʥݥ󥿡 */
+	/* 入出力用バッファのコピー（ポインタ） */
 	outptr = outbuf;
 	inptr = inbuf;
 
 	/* iconv open */
-	/* ʸѴѤΥǥץ򥪡ץ󤹤 */
+	/* 文字コード変換用のディスクリプタをオープンする */
 	cd = iconv_open(to_code, from_code);
 	if (cd == (iconv_t)(-1)) {
 		printf("error in iconv_open\n");
 		switch(errno) {
 			case EMFILE:
-				printf("sag_iconv() : ƤӽФȤΥץǴOPEN_MAXĤεһҤץ󤵤Ƥ\n");
+				printf("sag_iconv() : 呼び出しもとのプロセスで既にOPEN_MAX個の記述子がオープンされている\n");
 				break;
 			case ENFILE:
-				printf("sag_iconv() : ץ󤵤Ƥե¤¿\n");
+				printf("sag_iconv() : オープンされているファイルの和が多すぎる\n");
 				break;
 			case ENOMEM:
-				printf("sag_iconv() : ΰ褬­Ƥ\n");
+				printf("sag_iconv() : 記憶領域が不足している\n");
 				break;
 			case EINVAL:
-				printf("sag_iconv() : fromcodetocodeǻꤷѴ򥵥ݡȤƤʤ\n");
+				printf("sag_iconv() : fromcodeおよびtocode引数で指定したコード変換をサポートしていない\n");
 				break;
 		}
 		free(inbuf);
@@ -1087,25 +1089,25 @@ int sag_iconv(char *from_str, char *to_str, char *from_code, char *to_code)
 	}
 
 	/* iconv */
-	/* ʸѴ¹ */
-	/* iconv ΰץȥ̤˷㥹ȤȡٹϽФʤʤޤ*/
+	/* 文字コード変換を実行 */
+	/* iconv の引数をプロトタイプ宣言通りに型キャストすると、警告は出なくなります。*/
 	ret = iconv(cd, (char **)&inptr, &inbyteleft, (char **)&outptr, &outbyteleft);
 //	printf("ret = %d\n", ret);
 	if ((size_t)(-1) != ret) {
 		switch( errno ) {
 			case EBADF:
-				printf("sag_iconv() : ɥåȡСεһҤǤϤʤ\n");
+				printf("sag_iconv() : コードセット・コンバーターの記述子ではない。\n");
 				break;
 			case E2BIG:
-				printf("sag_iconv() : Ѳʸΰ­\n");
+				printf("sag_iconv() : 変化後の文字列取得領域不足\n");
 				break;
 #ifdef ELISEQ
 			case ELISEQ:
-				printf("sag_iconv() : ϥХåեѴΥɥåȤ°ʤǡ¸\n");
+				printf("sag_iconv() : 入力バッファに変換元のコードセットに属しないデータが存在\n");
 				break;
 #endif
 			case EINVAL:
-				printf("sag_iconv() : ϥХåեκǸԴʸ¸ߤ\n");
+				printf("sag_iconv() : 入力バッファの最後に不完全な文字が存在した。\n");
 				break;
 		}
 
@@ -1114,7 +1116,7 @@ int sag_iconv(char *from_str, char *to_str, char *from_code, char *to_code)
 	}
 
 #ifdef SAG_ICONV
-	/* ̤ɸϤɽ */
+	/* 結果を標準出力に表示する */
 	n = strlen(outbuf);
 	printf("in sag_iconv() \n");
 	printf("----------------------------------------------------------\n");
@@ -1129,13 +1131,13 @@ int sag_iconv(char *from_str, char *to_str, char *from_code, char *to_code)
 	printf("\n");
 #endif
 
-	/* ̤᤹ */
+	/* 結果を戻す */
 	strcpy(to_str, outbuf);
 
-	/* ѤǥץĤ */
+	/* 使用したディスクリプタを閉じる */
 	iconv_close(cd);
 
-	/* Ѥΰ */
+	/* 使用した領域を開放する */
 	free(inbuf);
 	free(outbuf);
 
@@ -1149,58 +1151,58 @@ int sag_iconv(char *from_str, char *to_str, char *from_code, char *to_code)
 /*============================================================================
  * NAME:	conv_iconv
  * USAGE:	char *conv_iconv(const char *from_str, const char *from_code, const char *to_code)
- * PARAMS:	from_str		Ѵʸؤݥ(I)
- *			from_code		ѴΥɤǼʸ(I)
- *			to_code			ѴΥɤǼʸ(I)
+ * PARAMS:	from_str		変換前の文字列を指すポインタ(I)
+ *			from_code		変換前のコードを格納した文字配列(I)
+ *			to_code			変換後のコードを格納した文字配列(I)
  * RETURN VALUE:
- *			ｪλ		char *	Ѵʸؤݥ(O)
- * 			۾ｪλ		NULL	ѴǤʤä
+ *			正常終了		char *	変換後の文字列を指すポインタ(O)
+ * 			異常終了		NULL	変換できなかった。
  * DESCRIPTION:
- *			ʸΥѴ
- * 			from_str ʸ from_code  to_code ʸѴ
- * 			ѴʸΥݥ󥿤֤
- * 			ѴʸΥϡƤӽФ¦ǳ (free) 롣
+ *			文字列のコード変換
+ * 			from_str の文字列を from_code から to_code に文字コード変換し、
+ * 			変換後の文字列のポインタを返す。
+ * 			変換後の文字列のメモリは、呼び出し側で開放する (free) する。
  *=============================================================================
  */
 char *conv_iconv(const char *from_str, const char *from_code, const char *to_code)
 {
 //#define CONV_ICONV
-	iconv_t cd;				/* Ѵѥǥץ */
-	const char *inbuf_p;	/* ƥݥݥ󥿡ѡ */
-	char *outbuf;			/* ѥХåե */
-	char *outbuf_p;			/* ƥݥݥ󥿡ʽѡ */
-	int in_size;			/* ϥХåե */
-	int in_left;			/* ϥХåե */
-	int out_size;			/* ϥХåե */
-	int out_left;			/* ϥХåե */
+	iconv_t cd;				/* 変換用ディスクリプタ */
+	const char *inbuf_p;	/* テンポラリポインタ（入力用） */
+	char *outbuf;			/* 出力用バッファ */
+	char *outbuf_p;			/* テンポラリポインタ（出力用） */
+	int in_size;			/* 入力バッファサイズ */
+	int in_left;			/* 入力バッファサイズ */
+	int out_size;			/* 出力バッファサイズ */
+	int out_left;			/* 出力バッファサイズ */
 	int n_conv;
 	int len;
 #ifdef CONV_ICONV
-	int i;					/* 롼ץѿ */
-	int n;					/* ХåեĹ */
+	int i;					/* ループカウンタ用変数 */
+	int n;					/* バッファ長 */
 #endif
 
 
-	/* ʸѴѤΥǥץ򥪡ץ󤹤 */
+	/* 文字コード変換用のディスクリプタをオープンする */
 	cd = iconv_open(to_code, from_code);
 	if (cd == (iconv_t)-1) {
 		return NULL;
 	}
 
 
-	/* ѴʸΥԡȡ */
+	/* 変換前の文字列のコピーと、サイズを求める */
 	inbuf_p = from_str;
 	in_size = strlen(from_str);
 	in_left = in_size;
 	out_size = (in_size + 1) * 2;
-	/* ѤΥХåեݤ */
+	/* 出力用のバッファを確保する */
 	outbuf = (char *)g_malloc(out_size);
 	if ( !outbuf ) {
-		/* malloc Υå */
+		/* malloc のチェック */
 		g_print ("conv_iconv() : error in malloc\n");
 		return NULL;
 	}
-	/* ѴʸΥԡȡ */
+	/* 変換後の文字列のコピーと、サイズを求める */
 	outbuf_p = outbuf;
 	out_left = out_size;
 
@@ -1253,11 +1255,11 @@ char *conv_iconv(const char *from_str, const char *from_code, const char *to_cod
 	outbuf = g_realloc(outbuf, len + 1);
 	outbuf[len] = '\0';
 
-	/* ѤǥץĤ */
+	/* 使用したディスクリプタを閉じる */
 	iconv_close(cd);
 
 #ifdef CONV_ICONV
-	/* ̤ɸϤɽ */
+	/* 結果を標準出力に表示する */
 	n = strlen(outbuf);
 	printf("----------------------------------------------------------\n");
 	printf("from [%s] %s \n", from_code, from_str);
@@ -1279,7 +1281,7 @@ char *conv_iconv(const char *from_str, const char *from_code, const char *to_cod
 
 
 /* -------------------------------------------------------------------
- * UTF-8 ΣʸΣХܤ飱ʸΥХȿ֤
+ * UTF-8 の１文字の１バイト目から１文字のバイト数を返す
  */
 int utf8_bite_num(char c)
 {
@@ -1308,7 +1310,7 @@ int utf8_bite_num(char c)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : etc.c
