@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/02/27
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/14
  * ====================================================================
  */
 
@@ -26,7 +26,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
-#include <langinfo.h>
+//#include <langinfo.h>
 
 #include "MemoryLeak.h"
 #include "List_cad.h"
@@ -37,7 +37,7 @@
 #include "List_Undo.h"
 #include "List_Select.h"
 #include "global.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "Select.h"
 #include "Draw.h"
 #include "etc.h"
@@ -53,30 +53,30 @@
 
 
 /* -------------------------------------------------------------------
- * ʸɽ
+ * 文字列を表示する
  * -------------------------------------------------------------------
- *	1 : n ʸܤ ǡ ɤ߹ǥ󥰤ǡؿ(char_scale)Ǻ
- *	2 : 1 Υǡ now_char_X եåȤƼࡣ
- *	3 : now_char_X  ʸ + distance եåȤ롣
- *	4 : 1,2,3 ʸ֤
+ *	1 : n 文字目の データを 原点に読み込んでスケーリングしたデータを関数(char_scale)で作成
+ *	2 : 1 のデータを now_char_X オフセットして取り込む。
+ *	3 : now_char_X を取り込んだ 文字幅 + distance オフセットさせる。
+ *	4 : 1,2,3 を文字数繰り返す。
  *	
- *	5 : Ǥǡ angle ǲž(xy) եåȤɽ
+ *	5 : できたデータを angle で回転させ、(x､y) オフセットさせ表示。
  *	
- * text	 : ƥ
- * height: ⤵
- * space : ʸʸδֳ
- * angle : 
- * x	 : 
- * y	 : 
- * color : 
- * point : 0,1,2 񤭽Ф
- *		   0 :	TEXT
- *		   1 :	TEXT
+ * text	 : テキスト
+ * height: 高さ
+ * space : 文字と文字の間隔
+ * angle : 角度
+ * x	 : 基準Ｘ
+ * y	 : 基準Ｙ
+ * color : 色
+ * point : 0,1,2 書き出し位置
+ *		   0 :	．TEXT
+ *		   1 :	TE．XT
  *		   2 :	TEXT
- * frag  : 0:ʸĹ׻   1:ɽ
+ * frag  : 0:文字列長さ計算だけ   1:表示
  *	
  *	
- * hDC ϤơLineBasic ΤǤϡ
+ * hDC も渡して、LineBasic で描いた方がいいのでは？
  * -------------------------------------------------------------------
  */
 int DrawTextVector (GtkWidget *widget, DIMENSION *a, long color)
@@ -92,10 +92,10 @@ int DrawTextVector (GtkWidget *widget, DIMENSION *a, long color)
 
 
 	/* -------------------------------------------------------------------
-	 * ľȤκɸ֤
+	 * 直線を枠の中だけの座標を返す
 	 *	
 	 *	
-	 * ͡ int    0:ԲĻ    1:Ѵ OK	2:Ѵ̵Ļ
+	 * 戻値　： int    0:不可視    1:変換 OK	2:変換無し可視
 	 *	
 	 */
 	SX = a->start.x;
@@ -116,10 +116,10 @@ int DrawTextVector (GtkWidget *widget, DIMENSION *a, long color)
 
 #ifdef TEST
 	/* -----------------------------------------------------
-	 * ɽ
+	 * 表示
 	 */
 	for (i = 0 ; i < a->diagram_of_char_index ; i++) {
-		/* ʸɽ */
+		/* 文字を表示 */
 		char_draw(widget, &a->diagram_of_char[i], color);
 	}
 #endif
@@ -160,7 +160,7 @@ int DrawTextVector (GtkWidget *widget, DIMENSION *a, long color)
 
 
 /* -------------------------------------------------------------------
- * ʸ򥹥 
+ * 文字をスケーリング 
  */
 int char_scale(double scale, SAG_FONT *font)
 {
@@ -188,7 +188,7 @@ int char_scale(double scale, SAG_FONT *font)
 
 
 /* -------------------------------------------------------------------
- * ʸ򥪥եåȤ
+ * 文字をオフセットさせる
  */
 int char_offset(double x, double y, SAG_FONT *font)
 {
@@ -214,7 +214,7 @@ int char_offset(double x, double y, SAG_FONT *font)
 
 
 /* -------------------------------------------------------------------
- * ʸž
+ * 文字を回転させる
  */
 int char_rolling(double angle, SAG_FONT *font)
 {
@@ -253,7 +253,7 @@ int char_rolling(double angle, SAG_FONT *font)
 
 
 /* -------------------------------------------------------------------
- * ʸɽ
+ * 文字を表示
  */
 int char_draw(GtkWidget *widget, SAG_FONT *font, long color)
 {
@@ -290,7 +290,7 @@ int char_draw(GtkWidget *widget, SAG_FONT *font, long color)
 
 
 /* -------------------------------------------------------------------
- * ʸǡɽ
+ * 文字データを表示
  */
 int char_data_print(SAG_FONT *font)
 {
@@ -311,23 +311,19 @@ int char_data_print(SAG_FONT *font)
 
 
 /* -------------------------------------------------------------------
- * ʸǡ UTF-8 ǲʸ׻
+ * 文字列データを UTF-8 で何文字かを計算
  */
 int saglen(char *text)
 {
 	int i, k, TextLen, bite;
-	char *utf8_text;
+	char utf8_text[256];
 
-
-	utf8_text = conv_iconv(text, nl_langinfo(CODESET), "UTF-8");
-	if (utf8_text == NULL) {
-		return 0;
-	}
+	strcpy(utf8_text, text);
 
 	k=0;
 	TextLen = strlen(utf8_text);
 	for (i = 0 ; i < TextLen ; i++) {
-		/* ¿Хʸν */
+		/* 多バイト文字の処理 */
 		bite = utf8_bite_num(utf8_text[k]);
 		if (bite > 1) {
 			TextLen = TextLen - (bite - 1);
@@ -343,26 +339,26 @@ int saglen(char *text)
 
 
 /* -------------------------------------------------------------------
- * ٥ȥեȤη׻
+ * ベクトルフォントの計算
  * -------------------------------------------------------------------
- *	1 : n ʸܤ ǡ ɤ߹ǥ󥰤ǡؿ(char_scale)Ǻ
- *	2 : 1 Υǡ now_char_X եåȤƼࡣ
- *	3 : now_char_X  ʸ + distance եåȤ롣
- *	4 : 1,2,3 ʸ֤
+ *	1 : n 文字目の データを 原点に読み込んでスケーリングしたデータを関数(char_scale)で作成
+ *	2 : 1 のデータを now_char_X オフセットして取り込む。
+ *	3 : now_char_X を取り込んだ 文字幅 + distance オフセットさせる。
+ *	4 : 1,2,3 を文字数繰り返す。
  *	
- *	5 : Ǥǡ angle ǲž(xy) եåȤɽ
+ *	5 : できたデータを angle で回転させ、(x､y) オフセットさせ表示。
  *	
- * a->text : ƥ
- * a->UpperText : ƥ
- * a->LowerText : ƥ
- * a->FontHeight : ⤵
- * a->FontSpace : ʸʸδֳ				ˡ˷׻ƤΤȤ
- * a->FontOverLineSpace : ʸδֳ	ˡ˷׻ƤΤȤ
- * a->Angle : 
- * a->SearchPointX : 
- * a->SearchPointY : 
- * a->text_color : 
- * a->FitPointX : 0,1,2 񤭽Ф
+ * a->text : テキスト
+ * a->UpperText : テキスト
+ * a->LowerText : テキスト
+ * a->FontHeight : 高さ
+ * a->FontSpace : 文字と文字の間隔				寸法作成時に計算されているものとする
+ * a->FontOverLineSpace : 文字と補助線の間隔	寸法作成時に計算されているものとする
+ * a->Angle : 角度
+ * a->SearchPointX : 基準Ｘ
+ * a->SearchPointY : 基準Ｙ
+ * a->text_color : 色
+ * a->FitPointX : 0,1,2 書き出し位置
  *     0 :	.TEXT
  *     1 :	TE.XT
  *     2 :	TEXT.
@@ -373,7 +369,7 @@ int saglen(char *text)
  *     3 : UpperLine
  *     4 : UpperLine + FontOverLineSpace
  * 
- * frag  : 0:ʸĹ׻   1:ɽ
+ * frag  : 0:文字列長さ計算だけ   1:表示
  *	
  *	
  * -------------------------------------------------------------------
@@ -392,10 +388,10 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 	double scale = 0, font_space = 0, word_space = 0, Font_space_line = 0, y_pos = 0;
 	double UpLow_space = 0;
 	struct RtnDat PAPH;
-	char *utf8_text = NULL;		/* Ѵ UTF-8 ʸǼ */
-	char *utf8_upper = NULL;	/* Ѵ UTF-8 ʸǼ */
-	char *utf8_lower = NULL;	/* Ѵ UTF-8 ʸǼ */
-	int bite = 0;				/* UTF-8 ʸΥХȿ */
+	char utf8_text[256];
+	char utf8_upper[256];
+	char utf8_lower[256];
+	int bite = 0;				/* UTF-8 １文字のバイト数 */
 
 
 //g_print("font.c : CulcTextVector() : a->FontHeight = %f\n", a->FontHeight);
@@ -403,32 +399,20 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 
 
 	/* -----------------------------------------------------
-	 * UTF-8 Ѵ
+	 * UTF-8 に変換
 	 */
-	utf8_text = conv_iconv(a->Text, nl_langinfo(CODESET), "UTF-8");
-	if (utf8_text == NULL) {
-		return 0;
-	}
-	utf8_upper = conv_iconv(a->UpperText, nl_langinfo(CODESET), "UTF-8");
-	if (utf8_upper == NULL) {
-		return 0;
-	}
-	utf8_lower = conv_iconv(a->LowerText, nl_langinfo(CODESET), "UTF-8");
-	if (utf8_lower == NULL) {
-		return 0;
-	}
+	strcpy(utf8_text, a->Text);
+	strcpy(utf8_upper, a->UpperText);
+	strcpy(utf8_lower, a->LowerText);
 
 	/* -----------------------------------------------------
-	 * ʸʬΥեѥǡ
+	 * 文字列分のフォント用データを確保
 	 */
 	len = strlen(utf8_text) + strlen(utf8_upper) + strlen(utf8_lower);
 	if (len != 0) {
 		p_array_font = (SAG_FONT *)xmalloc(len * sizeof(SAG_FONT));
 	}
 	else {
-		free(utf8_text);
-		free(utf8_upper);
-		free(utf8_lower);
 		return 0;
 	}
 
@@ -445,39 +429,36 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 
 
 	/* -------------------------------------------
-	 * ˡʸ
+	 * 寸法文字
 	 */
-	/*  */
+	/* 初期設定 */
 	scale = (a->FontHeight / 9);
 	font_space = a->FontSpace;
 	word_space = a->WordSpace;
 	UpLow_space = word_space;
 	Font_space_line = a->FontOverLineSpace;
 
-	/* ׻ */
+	/* 計算 */
 	for (i = 0; i < TextLen; i++) {
-		/* ʸΥǡõ */
-		p_font = font_search(&utf8_text[k], sagcad_dimension.font_file2);// <----
+		/* １文字のデータを探す */
+		p_font = font_search(&utf8_text[k], sagcad_dimension.font_file2);// <----ここがおかしい
 		if (p_font == NULL) {
 			g_print("Error : font.c : DrawTextVector() : Text\n");
-			free(utf8_text);
-			free(utf8_upper);
-			free(utf8_lower);
 			return 0;
 		}
 		
-		/* p_array_font[i] õǡ򥳥ԡ */
+		/* p_array_font[i] に探したデータをコピー */
 		p_array_font[i] = *p_font;
 		if (p_array_font[i].moji[0] == ' ' && p_array_font[i].moji[1] == '\0') p_array_font[i].width = word_space;
 
-		/* եȤΥǡѤΥ index ݤ */
+		/* フォントのデータ用のメモリを index だけ確保する */
 		if (p_array_font[i].index > 0) {
 			p_font_data = (SAG_FONT_DATA *)xmalloc(p_array_font[i].index * sizeof(SAG_FONT_DATA));
-			/* ˥եȤΥǡ򥳥ԡ */
+			/* メモリにフォントのデータをコピーする */
 			for (data = 0 ; data < p_array_font[i].index ; data++) {
 				p_font_data[data] = p_font->font_data[data];
 			}
-			/* եȤΥǡ򥳥ԡݥ󥿤˽񤭴 */
+			/* フォントのデータをコピーしたポインタに書き換える */
 			p_array_font[i].font_data = p_font_data;
 		}
 		else {
@@ -485,14 +466,14 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 			p_array_font[i].font_data = NULL;
 		}
 
-		/* ʸ򥹥 */
+		/* 文字をスケーリング */
 		char_scale(scale, &p_array_font[i]);
-		/* ʸ i ܤΰ֤˥եåȤ롣 */
+		/* 文字列中の i 番目の位置にオフセットする。 */
 		char_offset(now_char_X, 0, &p_array_font[i]);
-		/* ʸν񤭽Ф */
+		/* 次の文字の書き出し位置 */
 		now_char_X = now_char_X + p_array_font[i].width + font_space;
 
-		/* ʸν */
+		/* 全角文字の処理 */
 		bite = utf8_bite_num(utf8_text[k]);
 		if (bite > 1) {
 			TextLen = TextLen - (bite - 1);
@@ -500,7 +481,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		}
 		k++;
 	}
-	/* ʸ׻ */
+	/* 文字列の幅を計算 */
 	text_string_width = now_char_X - font_space;
 
 
@@ -508,7 +489,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 
 
 	/* -----------------------------------------------------
-	 * ¸
+	 * 上限公差
 	 * 
 	 */
 	if (strlen(utf8_upper) == 0) {
@@ -519,37 +500,34 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		k=0;
 		UpperTextLen = strlen(a->UpperText);
 
-		/*  */
+		/* 初期設定 */
 		scale = ((a->FontHeight * MINI_TEXT_HEIGHT) / 9);
 		font_space = a->FontSpace * MINI_TEXT_HEIGHT;
 		word_space = a->WordSpace * MINI_TEXT_HEIGHT;
 		y_pos = (a->FontHeight / 2)+(MINI_TEXT_UP_POS * a->FontHeight);
 
-		/* ׻ */
+		/* 計算 */
 		for (i = TextLen ; i < TextLen + UpperTextLen ; i++) {
-			/* ʸΥǡõ */
+			/* １文字のデータを探す */
 			p_font = font_search(&utf8_upper[k], sagcad_dimension.font_file2);
 			if (p_font == NULL) {
 				g_print("Error : font.c : DrawTextVector() : UpperText\n");
-				free(utf8_text);
-				free(utf8_upper);
-				free(utf8_lower);
 				return 0;
 			}
 			
-			/* p_array_font[i] õǡ򥳥ԡ */
+			/* p_array_font[i] に探したデータをコピー */
 			p_array_font[i] = *p_font;
 			if (p_array_font[i].moji[0] == ' ' && p_array_font[i].moji[1] == '\0') p_array_font[i].width = word_space;
 
-			/* γ */
+			/* メモリの確保 */
 			if (p_array_font[i].index > 0) {
-				/* եȤΥǡѤΥ index ݤ */
+				/* フォントのデータ用のメモリを index だけ確保する */
 				p_font_data = (SAG_FONT_DATA *)xmalloc(p_array_font[i].index * sizeof(SAG_FONT_DATA));
-				/* ˥եȤΥǡ򥳥ԡ */
+				/* メモリにフォントのデータをコピーする */
 				for (data = 0 ; data < p_array_font[i].index ; data++) {
 					p_font_data[data] = p_font->font_data[data];
 				}
-				/* եȤΥǡ򥳥ԡݥ󥿤˽񤭴 */
+				/* フォントのデータをコピーしたポインタに書き換える */
 				p_array_font[i].font_data = p_font_data;
 			}
 			else {
@@ -557,14 +535,14 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 				p_array_font[i].font_data = NULL;
 			}
 
-			/* ʸ򥹥 */
+			/* 文字をスケーリング */
 			char_scale(scale, &p_array_font[i]);
-			/* ʸ i ܤΰ֤˥եåȤ롣 */
+			/* 文字列中の i 番目の位置にオフセットする。 */
 			char_offset(now_char_X, y_pos, &p_array_font[i]);
-			/* ʸν񤭽Ф */
+			/* 次の文字の書き出し位置 */
 			now_char_X = now_char_X + p_array_font[i].width + font_space;
 
-			/* ʸν */
+			/* 全角文字の処理 */
 			bite = utf8_bite_num(utf8_upper[k]);
 			if (bite > 1) {
 				UpperTextLen = UpperTextLen - (bite - 1);
@@ -572,7 +550,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 			}
 			k++;
 		}
-		/* ʸ׻ */
+		/* 文字列の幅を計算 */
 		upper_text_string_width = (now_char_X - font_space);
 	}
 
@@ -581,7 +559,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 
 
 	/* -----------------------------------------------------
-	 * ¸
+	 * 下限公差
 	 * 
 	 */
 	if (strlen(utf8_lower) == 0) {
@@ -593,38 +571,35 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		LowerTextLen = strlen(a->LowerText);
 
 
-		/*  */
+		/* 初期設定 */
 		scale = ((a->FontHeight * MINI_TEXT_HEIGHT) / 9/*p_array_font[i].height*/);
 		font_space = a->FontSpace * MINI_TEXT_HEIGHT/* * scale*/;
 		word_space = a->WordSpace * MINI_TEXT_HEIGHT;
 		y_pos = (a->FontHeight / 2)-(MINI_TEXT_LOW_POS * a->FontHeight);
 
-		/* ׻ */
+		/* 計算 */
 		for (i = TextLen + UpperTextLen ; i < TextLen + UpperTextLen + LowerTextLen ; i++) {
-			/* ʸΥǡõ */
+			/* １文字のデータを探す */
 			p_font = font_search(&utf8_lower[k], sagcad_dimension.font_file2);
 			if (p_font == NULL) {
 				g_print("Error : font.c : DrawTextVector() : LowerText\n");
-				free(utf8_text);
-				free(utf8_upper);
-				free(utf8_lower);
 				return 0;
 			}
 			
-			/* p_array_font[i] õǡ򥳥ԡ */
+			/* p_array_font[i] に探したデータをコピー */
 			p_array_font[i] = *p_font;
 			if (p_array_font[i].moji[0] == ' ' && p_array_font[i].moji[1] == '\0') p_array_font[i].width = word_space;
 
-			/* γ */
+			/* メモリの確保 */
 			if (p_array_font[i].index > 0) {
 
-				/* եȤΥǡѤΥ index ݤ */
+				/* フォントのデータ用のメモリを index だけ確保する */
 				p_font_data = (SAG_FONT_DATA *)xmalloc(p_array_font[i].index * sizeof(SAG_FONT_DATA));
-				/* ˥եȤΥǡ򥳥ԡ */
+				/* メモリにフォントのデータをコピーする */
 				for (data = 0 ; data < p_array_font[i].index ; data++) {
 					p_font_data[data] = p_font->font_data[data];
 				}
-				/* եȤΥǡ򥳥ԡݥ󥿤˽񤭴 */
+				/* フォントのデータをコピーしたポインタに書き換える */
 				p_array_font[i].font_data = p_font_data;
 			}
 			else {
@@ -632,14 +607,14 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 				p_array_font[i].font_data = NULL;
 			}
 
-			/* ʸ򥹥 */
+			/* 文字をスケーリング */
 			char_scale(scale, &p_array_font[i]);
-			/* ʸ i ܤΰ֤˥եåȤ롣 */
+			/* 文字列中の i 番目の位置にオフセットする。 */
 			char_offset(now_char_X, y_pos, &p_array_font[i]);
-			/* ʸν񤭽Ф */
+			/* 次の文字の書き出し位置 */
 			now_char_X = now_char_X + p_array_font[i].width + font_space;
 
-			/* ʸν */
+			/* 全角文字の処理 */
 			bite = utf8_bite_num(utf8_lower[k]);
 			if (bite > 1) {
 				LowerTextLen = LowerTextLen - (bite - 1);
@@ -647,21 +622,17 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 			}
 			k++;
 		}
-		/* ʸ׻ */
+		/* 文字列の幅を計算 */
 		lower_text_string_width = (now_char_X - font_space);
 	}
 
-	/* UTF-8 ǡϤ⤦ʤΤǳ */
-	free(utf8_text);
-	free(utf8_upper);
-	free(utf8_lower);
 
 
 
 
 
 	/* -----------------------------------------------------
-	 * ʸ׻
+	 * 文字列の幅を計算
 	 * 
 	 */
 	if(upper_text_string_width >= lower_text_string_width)
@@ -669,11 +640,11 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 	else 
 		string_width = lower_text_string_width;
 
-	/* ʸ׻ */
+	/* 全部の文字数を計算 */
 	TotalTextLen = TextLen + UpperTextLen + LowerTextLen;
 
 
-	/* ʸֹ碌 */
+	/* 文字位置合わせ前に設定 */
 	a->start.x = a->SearchPointX;
 	a->start.y = a->SearchPointY;
 
@@ -682,11 +653,11 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 
 
 	/* -----------------------------------------------------
-	 * ʸֹ碌 X
+	 * 文字位置合わせ X
 	 */
 	/* Left (default) */
 	if (a->FitPointX == 0) {
-		// ǥե
+		// デフォルト
 	}
 	/* Center */
 	else if (a->FitPointX == 1) {
@@ -696,7 +667,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		PAPH.l = string_width / 2;
 		pap(&PAPH);
 		for (i = 0 ; i < TotalTextLen ; i++) {
-			/* ʸ i ܤΰ֤˥եåȤ롣 */
+			/* 文字列中の i 番目の位置にオフセットする。 */
 			char_offset(PAPH.ex[1], PAPH.ey[1], &p_array_font[i]);
 		}
 
@@ -711,7 +682,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		PAPH.l = string_width;
 		pap(&PAPH);
 		for (i = 0 ; i < TotalTextLen ; i++) {
-			/* ʸ i ܤΰ֤˥եåȤ롣 */
+			/* 文字列中の i 番目の位置にオフセットする。 */
 			char_offset(PAPH.ex[1], PAPH.ey[1], &p_array_font[i]);
 		}
 		a->start.x = sg(a->start.x + PAPH.ex[1], 6);
@@ -721,11 +692,11 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 
 
 	/* -----------------------------------------------------
-	 * ʸֹ碌 Y
+	 * 文字位置合わせ Y
 	 */
 	/* Bottom (default) */
 	if (a->FitPointY == 0) {
-		// ǥե
+		// デフォルト
 	}
 	/* Bottom + FontOverLineSpace */
 	else if (a->FitPointY == 1) {
@@ -735,7 +706,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		PAPH.l = Font_space_line;
 		pap(&PAPH);
 		for (i = 0 ; i < TotalTextLen ; i++) {
-			/* եåȤ롣 */
+			/* オフセットする。 */
 			char_offset(PAPH.ex[1], PAPH.ey[1], &p_array_font[i]);
 		}
 		a->start.x = sg(a->start.x + PAPH.ex[1], 6);
@@ -749,7 +720,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		PAPH.l = a->FontHeight / 2;
 		pap(&PAPH);
 		for (i = 0 ; i < TotalTextLen ; i++) {
-			/* եåȤ롣 */
+			/* オフセットする。 */
 			char_offset(PAPH.ex[1], PAPH.ey[1], &p_array_font[i]);
 		}
 		a->start.x = sg(a->start.x + PAPH.ex[1], 6);
@@ -763,7 +734,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		PAPH.l = a->FontHeight;
 		pap(&PAPH);
 		for (i = 0 ; i < TotalTextLen ; i++) {
-			/* եåȤ롣 */
+			/* オフセットする。 */
 			char_offset(PAPH.ex[1], PAPH.ey[1], &p_array_font[i]);
 		}
 		a->start.x = sg(a->start.x + PAPH.ex[1], 6);
@@ -777,7 +748,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		PAPH.l = a->FontHeight + Font_space_line;
 		pap(&PAPH);
 		for (i = 0 ; i < TotalTextLen ; i++) {
-			/* եåȤ롣 */
+			/* オフセットする。 */
 			char_offset(PAPH.ex[1], PAPH.ey[1], &p_array_font[i]);
 		}
 		a->start.x = sg(a->start.x + PAPH.ex[1], 6);
@@ -789,15 +760,15 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 
 
 	/* -----------------------------------------------------
-	 * ºݤο̤ΰ֤˰ư
+	 * 実際の図面の位置に移動する
 	 * 
 	 */
 	for (i = 0 ; i < TotalTextLen ; i++) {
-		/* ž */
+		/* 回転させる */
 		Ret = char_rolling(a->Angle, &p_array_font[i]);
-		/* ʸ̾ΰ֤˥եåȤ */
+		/* 文字を図面上の位置にオフセットさせる */
 		char_offset(a->SearchPointX, a->SearchPointY, &p_array_font[i]);
-		/* ʸɽ */
+		/* 文字を表示 */
 //			char_draw(widget, &p_array_font[i], color);
 	}
 
@@ -806,7 +777,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 
 
 	/* -------------------------------------------------------------------
-	 * pap ȳ٤ȵΥľν
+	 * pap 始点と角度と距離で直線の終点を求める
 	 */
 	PAPH.sx[1] = a->start.x;
 	PAPH.sy[1] = a->start.y;
@@ -818,13 +789,13 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 
 
 
-	/* ޷Ǥο */
+	/* 図形要素の数を求める */
 	TotalDiagram = 0;
 	for (i = 0 ; i < TotalTextLen ; i++) {
 		TotalDiagram = TotalDiagram + p_array_font[i].index;
 	}
 
-	/* ޷Ǥο */
+	/* 図形要素の数だけメモリを確保 */
 	if (TotalDiagram > 0) {
 		p_assistance = (ASSISTANCE *)xmalloc( TotalDiagram * sizeof(ASSISTANCE) );
 		a->diagram_of_char_index = TotalDiagram;
@@ -835,7 +806,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		a->diagram_of_char = NULL;
 	}
 
-	/* ݤ˥եȤο޷Ǥ򥳥ԡ */
+	/* 確保したメモリにフォントの図形要素をコピー */
 	if (TotalDiagram > 0) {
 		k = 0;
 		for (i = 0 ; i < TotalTextLen ; i++) {
@@ -861,7 +832,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 		//g_print("font.c : CulcTextVector() : k != TotalDiagram  %d : %d \n", k, TotalDiagram);
 	}
 
-	/* ѤΥ곫 */
+	/* 作業用のメモリ開放 */
 	for (i = 0 ; i < TotalTextLen ; i++) {
 		if (p_array_font[i].index > 0 && p_array_font[i].font_data != NULL) {
 			xfree(p_array_font[i].font_data);
@@ -877,7 +848,7 @@ double CulcTextVector (GtkWidget *widget, DIMENSION *a)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : font.c
