@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2002/09/11
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/10
  * ====================================================================
  */
 
@@ -23,7 +23,7 @@
 
 #include <gtk/gtk.h>
 #include <unistd.h>
-#include <pwd.h>
+//#include <pwd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -41,7 +41,7 @@
 #include "List_Block.h"
 #include "List_Undo.h"
 #include "List_Select.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "MsgBox.h"
 #include "sagcad.h"
 #define _GLOBAL_
@@ -68,13 +68,7 @@ int sagcad_global_init(void)
 	strcpy(sagcad_user.CompanyName, "Your Company");
 
 
-	/* ɤμ */
-	Get_charset();
-#ifdef DEBUG
-	if (Get_charset() == 1) g_print("charset = euc\n");
-	else g_print("charset = sjis\n");
-#endif
-	/* եΥѥμ */
+	/* 設定ファイルのパスの取得 */
 	GetConfigPath(sagcad_user.ConfigPath);
 
 	strcpy(sagcad_user.BrowserPath, "netscape");
@@ -96,7 +90,7 @@ int sagcad_global_init(void)
 	sagcad_system.RealTimeLayerSet = 1;	/* 1 */
 	sagcad_system.GridMode = 0;			/* 0 */
 
-	/* ԥ㡼ܥåΥڥ (ASPECT = H / W) */
+	/* ピクチャーボックスのアスペクト比 (ASPECT = H / W) */
 	sagcad_system.ViewX = 300;
 	sagcad_system.DeviceX = 0;
 	sagcad_system.DeviceY = 0;
@@ -117,8 +111,8 @@ int sagcad_global_init(void)
 	sagcad_system.Grid = (float) 0.5;				/* 0.5 */
 
 	/* sagcad_dimension */
-	sagcad_dimension.Draw_Type = DRAW_REAL;			/* 0  0:̤ν̼	1:	2:ʸ */
-	sagcad_dimension.font_Type = 1;					/* 1  1:٥ȥ   0:TrueType */
+	sagcad_dimension.Draw_Type = DRAW_REAL;			/* 0  0:図面の縮尺	1:実寸	2:文字サイズ固定 */
+	sagcad_dimension.font_Type = 1;					/* 1  1:ベクトル   0:TrueType */
 	sagcad_dimension.Font_height = (float) 3.2;		/* 3.2 */
 	sagcad_dimension.Font_space = 2;				/* 0 */
 	sagcad_dimension.Word_space = 8;				/* 0 */
@@ -237,7 +231,7 @@ int sagcad_global_init(void)
 
 	/* Printer */
 	printer.Paper = A4_PAPER;
-	printer.Orientation = LANDSCAPE; /* PORTRAIT : 1 : ġ LANDSCAPE : 0 : */
+	printer.Orientation = LANDSCAPE; /* 【PORTRAIT : 1 : 縦】 【LANDSCAPE : 0 : 横】*/
 
 	printer.paper_top = 297;
 	printer.paper_bottom = 0;
@@ -253,7 +247,7 @@ int sagcad_global_init(void)
 	printer.up_scale = 1;
 	printer.low_scale = 1;
 
-	printer.Draw_View = DISPLAY_VIEW; /* DISPLAY_VIEW : 1 : ̡ DRAWING_VIEW : 0 : ̡*/
+	printer.Draw_View = DISPLAY_VIEW; /* 【DISPLAY_VIEW : 1 : 画面】 【DRAWING_VIEW : 0 : 図面】*/
 	printer.WakuLayer = 0xff;
 
 	keep_printer = printer;
@@ -267,11 +261,11 @@ int sagcad_global_init(void)
 
 	cad_list_info.head = NULL;
 	cad_list_info.tail = NULL;
-	/* CAD ǡ */
+	/* CAD データ作成 */
 	cad.layer = 0; cad.code = 0; cad.style = 3; cad.color = sagcad_color.FirstCenterLine;
 	cad.sx = 0; cad.sy = 0; cad.ex = 0; cad.ey = 0;
 	cad.cx = 0; cad.cy = 0; cad.r = 0;
-	/* CAD Data ꥹȤκǽɲ */
+	/* CAD Data をリストの最初に追加 */
 	cad_list_add_first(&cad, &cad_list_info);
 
 	cad.layer = 0; cad.code = 1; cad.style = 3; cad.color = sagcad_color.FirstCenterLine;
@@ -304,7 +298,7 @@ int sagcad_global_init(void)
 		sprintf(Layer[i].name, "%X", i);
 	}
 
-	/* Ͽѿ */
+	/* 登録画面設定変数 */
 	for (i = 0 ; i < 7 ; i++) {
 		GamenMag[i] = 1;
 		GamenMagX[i] = 0;
@@ -320,7 +314,7 @@ int sagcad_global_init(void)
 
 
 /* ---------------------------------------------------------------------
- * RGB(0xrrggbb) Υ顼 GTK(GdkColor)ѤѴ
+ * RGB(0xrrggbb) のカラーを GTK(GdkColor)用に変換
  */
 GdkColor color_gtk(long rgbcol)
 {
@@ -352,7 +346,7 @@ GdkColor color_gtk(long rgbcol)
 
 
 /* ---------------------------------------------------------------------
- * GTK(GdkColor) Υ顼  RGB(0xrrggbb)Ѵ
+ * GTK(GdkColor) のカラー を RGB(0xrrggbb)に変換
  */
 long gtk_color_rgb(GdkColor color)
 {
@@ -374,8 +368,8 @@ long gtk_color_rgb(GdkColor color)
 
 
 /* ---------------------------------------------------------------------
- * 0xrrggbb ηΥǡ "rr"  "bb" 򴹤
- * Windows(0xbbggrr) Υ顼  <-->  0xrrggbb  Ѵ
+ * 0xrrggbb の形式のデータの "rr" と "bb" を交換する
+ * Windows(0xbbggrr) のカラー  <-->  0xrrggbb  の変換
  * 
  */
 long Color_RB_Change(long rgbcol)
@@ -403,7 +397,7 @@ long Color_RB_Change(long rgbcol)
 
 
 /* -------------------------------------------------------------------
- * ȥ˥ץ
+ * コントロールにキャプションを設定
  * 
  */
 int set_window_text(GtkWidget *widget, char *str)
@@ -417,12 +411,12 @@ int set_window_text(GtkWidget *widget, char *str)
 
 
 /* -------------------------------------------------------------------
- * ٥˥ƥȤ
+ * ラベルにテキストを設定
  * 
  */
 int set_label_text(GtkWidget *widget, char *str)
 {
-	gtk_label_set(GTK_LABEL(widget), str);
+	gtk_label_set_text(GTK_LABEL(widget), str);
 	return 1;
 }
 
@@ -431,7 +425,7 @@ int set_label_text(GtkWidget *widget, char *str)
 
 
 /* -------------------------------------------------------------------
- * եɤ߹
+ * 初期設定ファイル読み込み
  * 
  */
 int ConfigRead(void)
@@ -439,25 +433,25 @@ int ConfigRead(void)
 //char test[256];
 
 	FILE *stream;
-	char Path[256], str[256], home[256];
+	char Path[256], str[256];//, home[256];
 
 
 	/* -----------------------------------------------------
 	 * Open File
 	 */
 	GetConfigPath(str);
-//	home_of_user(home);
+	//home_of_user(home);
 	sprintf(Path, "%s/sagcadrc", str);
 
 //g_print("%s\n", Path);
 	if ((stream = fopen( Path, "r")) == NULL) {
-//		g_print("ե %s ĤޤǤ\nư夹˴ĶԤäƤ\n", Path);
+		//g_print("初期設定ファイル %s が見つかりませんでした。\n起動後すぐに環境設定を行ってください。\n", Path);
 		MsgBox("SagCAD ERROR", _("An initial setting file wasn't found out.") , 
 			   _("Set environment immediately after start-up.") , NULL, NULL, "OK");
 
-		home_of_user(home);
-		sprintf(str, "%s/.sagcad", home);
-		mkdir(str, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP);
+		//home_of_user(home);
+		//sprintf(str, "%s/.sagcad", home);
+		//mkdir(str, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP);
 		if (ConfigWrite() == 0) {
 			g_print( _("The initial setting file [%s] It wasn't possible to create.\n") , Path);
 		}
@@ -476,7 +470,7 @@ int ConfigRead(void)
 		/* EOF */
 		if(strstr(str,"EOF") != NULL ) break;
 
-		/*  */
+		/* 注釈行 */
 		if (strstr(str,"#") - str == 0) {
 			;
 		}
@@ -552,6 +546,11 @@ int ConfigRead(void)
 
 		/* System */
 
+		/* Data Version */
+		else if(strstr(str, "Data Version") != NULL ) {
+			if (LineRead(stream, str) == 0) return 0;
+			data_version = atoi(str);
+		}
 		/* Wait */
 		else if(strstr(str, "Wait") != NULL ) {
 			if (LineRead(stream, str) == 0) return 0;
@@ -632,7 +631,7 @@ int ConfigRead(void)
 
 
 
-		/* ˡ */
+		/* 寸法設定 */
 
 		/* DimensionConfig */
 		else if(strstr(str, "DimensionConfig") != NULL || strstr(str, "Draw_Type") != NULL ) {
@@ -724,7 +723,7 @@ int ConfigRead(void)
 
 
 
-		/* ƥ५顼 */
+		/* システムカラー */
 
 		/* BackColor */
 		else if(strstr(str, "BackColor") != NULL ) {
@@ -753,7 +752,7 @@ int ConfigRead(void)
 
 
 
-		/* 顼 ˥塼 */
+		/* カラー メニュー */
 
 		/* ColorMenu00 */
 		else if(strstr(str, "ColorMenu01") != NULL ) {
@@ -858,7 +857,7 @@ int ConfigRead(void)
 
 
 
-		/*  */
+		/* 線種設定 */
 
 		/* LineStyle[0] */
 		else if(strstr(str, "LineStyle00_style") != NULL ) {
@@ -1183,7 +1182,7 @@ int ConfigRead(void)
 
 
 /* -------------------------------------------------------------------
- * ե񤭤
+ * 初期設定ファイル書きこみ
  * 
  */
 int ConfigWrite(void)
@@ -1202,15 +1201,15 @@ int ConfigWrite(void)
 //	home_of_user(home);
 //	sprintf(Path, "%s/.sagcadrc", home);
 	if ((stream = fopen( Path, "w")) == NULL) {
-//		g_print("ե %s ǤޤǤ", Path);
-		MsgBox("SagCAD ERROR", "ե", "ǤޤǤ", NULL, NULL, "OK");
+//		g_print("初期設定ファイル %s を作成できませんでした。", Path);
+		MsgBox("SagCAD ERROR", "初期設定ファイルを", "作成できませんでした。", NULL, NULL, "OK");
 		return 0;
 	}
 
 
 	sprintf(str, "# ====================================================================\n");
 	fputs(str, stream);
-	sprintf(str, "# ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===\n");
+	sprintf(str, "# ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===\n");
 	fputs(str, stream);
 	sprintf(str, "# ====================================================================\n");
 	fputs(str, stream);
@@ -1228,7 +1227,7 @@ int ConfigWrite(void)
 	fputs(str, stream);
 	sprintf(str, "# \n");
 	fputs(str, stream);
-	sprintf(str, "#    Copyright            : (C) 1998-2003 by Yutaka Sagiya\n");
+	sprintf(str, "#    Copyright            : (C) 1998-2007 by Yutaka Sagiya\n");
 	fputs(str, stream);
 	sprintf(str, "#    email                : kappa@a6s.highway.ne.jp\n");
 	fputs(str, stream);
@@ -1352,6 +1351,12 @@ int ConfigWrite(void)
 	sprintf(str, "# \n");
 	fputs(str, stream);
 
+	/* Data Version */
+	sprintf(str, "Data Version\n");
+	fputs(str, stream);
+	sprintf(str, "  %d\n", data_version);
+	fputs(str, stream);
+	
 	/* Wait */
 	sprintf(str, "Wait\n");
 	fputs(str, stream);
@@ -1450,7 +1455,7 @@ int ConfigWrite(void)
 
 
 	/* -----------------------------------------------------
-	 * ˡ 
+	 * 寸法設定 
 	 */
 	sprintf(str, "\n");
 	fputs(str, stream);
@@ -1458,7 +1463,7 @@ int ConfigWrite(void)
 	fputs(str, stream);
 	sprintf(str, "# --------------------------------------------------------------------\n");
 	fputs(str, stream);
-	sprintf(str, "# ˡ\n");
+	sprintf(str, "# 寸法設定\n");
 	fputs(str, stream);
 	sprintf(str, "# \n");
 	fputs(str, stream);
@@ -1554,7 +1559,7 @@ int ConfigWrite(void)
 
 
 
-	/* ƥ५顼 */
+	/* システムカラー */
 
 	sprintf(str, "\n");
 	fputs(str, stream);
@@ -1607,7 +1612,7 @@ int ConfigWrite(void)
 
 
 
-	/* 顼 ˥塼 */
+	/* カラー メニュー */
 
 	sprintf(str, "\n");
 	fputs(str, stream);
@@ -1750,7 +1755,7 @@ int ConfigWrite(void)
 
 
 
-	/*  */
+	/* 線種設定 */
 	sprintf(str, "\n");
 	fputs(str, stream);
 	sprintf(str, "\n");
@@ -1953,7 +1958,7 @@ int ConfigWrite(void)
 	/* EOF */
 	sprintf(str, "EOF\n");
 	fputs(str, stream );
-	/* ե򥯥 */ 
+	/* ファイルをクローズ */ 
 	fclose(stream);
 	return 1;
 }
@@ -1965,7 +1970,7 @@ int ConfigWrite(void)
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : global.c
