@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2002/09/11
- *    Last                 : 2003/04/16
+ *    Last                 : 2007/10/24
  * ====================================================================
  */
 
@@ -27,7 +27,7 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 1 :   (struct #define etc)
+ * 1 : 前処理  (struct #define etc)
  * -------------------------------------------------------
  */
 //#define PRINTER_TEST
@@ -36,7 +36,7 @@ extern "C" {
 #define DRAW_DISP      0
 #define DRAW_REAL      2
 #define DRAW_CONST     1
-#define MAX_PATH     256
+#define MAXPATH     256
 
 #define A0_PAPER     129
 #define A1_PAPER     257
@@ -52,9 +52,9 @@ extern "C" {
 #define B5_PAPER    4098
 #define USER_PAPER     4
 
-/*  */
+/* 横 */
 #define LANDSCAPE      0
-/*  */
+/* 縦 */
 #define PORTRAIT       1
 
 #define DRAWING_VIEW   0
@@ -71,15 +71,15 @@ extern "C" {
 struct _sagcad_user {
 	char UserName[64];		/*	*/
 	char CompanyName[64];	/*	*/
-	char ConfigPath[256];	/* եΥѥ */
-	char BrowserPath[256];	/* եΥѥ */
+	char ConfigPath[256];	/* 設定ファイルのパス */
+	char BrowserPath[256];	/* 設定ファイルのパス */
 	char CadPath[256];
 	char NcPath[256];
 	char KeepCadPath[256];
 
-	char print_command[256];	/* եΥѥ */
-	char editor_command[256];	/* եΥѥ */
-	char browser_command[256];	/* եΥѥ */
+	char print_command[256];	/* 設定ファイルのパス */
+	char editor_command[256];	/* 設定ファイルのパス */
+	char browser_command[256];	/* 設定ファイルのパス */
 
 };
 //struct _sagcad_user sagcad_user;
@@ -93,7 +93,7 @@ struct _sagcad_system {
 	int LostCurrent;		/* 1 */
 	int RealTimeLayerSet;	/* 1 */
 
-	int WinMode;			/* 0:WM ˤޤ   1:   2:λ */
+	int WinMode;			/* 0:WM にまかせる   1:設定値   2:前回終了時の設定 */
 	int win_x_pos;
 	int win_y_pos;
 	int win_width;
@@ -102,14 +102,14 @@ struct _sagcad_system {
 //	int MaxLayer;			/* 100 */
 
 	/* ---------------------------------
-	 * 0 : ɽʤ  ǽʤ
-	 * 1 : ɽ
-	 * 2 : ǽ
+	 * 0 : 表示しない ＆ 機能しない
+	 * 1 : 表示する
+	 * 2 : 機能する
 	*/
 	int GridMode;			/* 2 */
 	float Grid;				/* 0.5 */
 
-	/* ԥ㡼ܥåΥڥ (ASPECT = H / W) */
+	/* ピクチャーボックスのアスペクト比 (ASPECT = H / W) */
 	double ViewX;
 	int DeviceX;
 	int DeviceY;
@@ -128,7 +128,7 @@ struct _sagcad_system {
 
 /* dimension */
 struct _sagcad_dimension {
-	int Draw_Type;						/* 0  0:̤ν̼	1:	2:ʸ */
+	int Draw_Type;						/* 0  0:図面の縮尺	1:実寸	2:文字サイズ固定 */
 	int font_Type;						/* 1 */
 	float Font_height;					/* 2.5 */
 	float Font_space;					/* 0.5 */
@@ -223,10 +223,10 @@ struct _sagcad_cam sagcad_cam
 */
 
 
-/* */
+/* 印刷設定用*/
 struct _printer {
 	/* ---------------------------------
-	 * ѻ Paper
+	 * 用紙 Paper
 	 * 
 	 * A 1
 	 * B 2
@@ -256,15 +256,15 @@ struct _printer {
 	int Paper;
 
 	/* ---------------------------------
-	 * ѻ Orientation
+	 * 用紙の方向 Orientation
 	 * 
-	 * ֤    LANDSCAPE   0
-	 * ֤    PORTRAIT    1
+	 * 横置き    LANDSCAPE   0
+	 * 縦置き    PORTRAIT    1
 	 */
 	int Orientation;
 
 	/* ---------------------------------
-	 *  size
+	 * サイズ size
 	 * 
 	 * paper_top
 	 * paper_bottom
@@ -278,7 +278,7 @@ struct _printer {
 	double paper_right;
 
 	/* ---------------------------------
-	 * ; blank
+	 * 余白 blank
 	 * 
 	 * blank_top
 	 * blank_bottom
@@ -292,19 +292,19 @@ struct _printer {
 	double blank_right;
 
 	/* ---------------------------------
-	 * Ψ() Scale
+	 * 倍率(尺度) Scale
 	 */
 	float scale;
 	float up_scale;
 	float low_scale;
 	/* ---------------------------------
-	 * о
+	 * 印刷対象
 	 * 
-	 *     DRAWING_VIEW    0
-	 *     DISPLAY_VIEW    1
+	 * 図面    DRAWING_VIEW    0
+	 * 画面    DISPLAY_VIEW    1
 	 */
 	int Draw_View;
-	/* ȤΥ쥤䡼 */
+	/* 枠のレイヤー */
 	int WakuLayer;
 };
 //struct _printer printer;
@@ -314,16 +314,16 @@ struct _printer {
 
 
 /* -------------------------------------------------------
- * 2 : ѿ (global)
+ * 2 : 外部変数 (global)
  * -------------------------------------------------------
  */
 #ifdef _GLOBAL_
 #define   GLOBAL
-// 
+// 初期値設定
 #define   GLOBAL_VAL(v)  = (v)
 #else
 #define   GLOBAL	extern
-// ʬ̵
+// 初期値設定の代入部分を無くす
 #define   GLOBAL_VAL(v)  /* */
 #endif
 
@@ -339,7 +339,7 @@ struct _printer {
 	GLOBAL struct _printer printer;
 	GLOBAL struct _printer keep_printer;
 
-	/* ϥɥ */
+	/* ハンドル */
 	/* SagCAD RootWindow */
 	GLOBAL GtkWidget *MainWindow, *drawing_area, *statusbar, *work_hbox;
 	GLOBAL GtkWidget *line_status, *MouseX, *MouseY, *Tooltip;
@@ -348,53 +348,61 @@ struct _printer {
 	GLOBAL GdkGC *gc GLOBAL_VAL((void *)0);
 	GLOBAL GdkGC *ls_gc GLOBAL_VAL((void *)0);
 	
+	GLOBAL GdkCursor *cursor;
+	
 	GLOBAL GtkWidget *UndoButton GLOBAL_VAL((void *)0);
 	GLOBAL GtkWidget *RedoButton GLOBAL_VAL((void *)0);
 
 
-	/* ȥ */
+	/* タイトル */
 	GLOBAL char Title[40] GLOBAL_VAL("SagCAD");
-	/*  */
-	GLOBAL char Copyright[60] GLOBAL_VAL("Copyright (C) 1998-2003 Yutaka Sagiya");
+	/* 著作権 */
+	GLOBAL char Copyright[60] GLOBAL_VAL("Copyright (C) 1998-2007 Yutaka Sagiya");
 
 
-	/* CAD Ķ */
-	/* ɸѿ */
-	/*	  Ψ , 濴ɸ , 濴ɸ */
+	/* CAD 環境設定 */
+	/* 座標設定変数 */
+	/*	  倍率 , 中心座標Ｘ , 中心座標Ｙ */
 	GLOBAL float Mag GLOBAL_VAL(1);
 	GLOBAL float MagX GLOBAL_VAL(0);
 	GLOBAL float MagY GLOBAL_VAL(0);
 
-	GLOBAL char NowFile[256] GLOBAL_VAL("NoName.sgy");
-	GLOBAL char PartsFile[256] GLOBAL_VAL("NoName.sgy");
+	GLOBAL char NowFile[256] GLOBAL_VAL("Untitled.sgy");
+	GLOBAL char PartsFile[256] GLOBAL_VAL("Untitled.sgy");
 	GLOBAL int NowLayer GLOBAL_VAL(1);
 	GLOBAL int NowWidth GLOBAL_VAL(1);
 	GLOBAL int NowStyle GLOBAL_VAL(1);
 	GLOBAL long NowColor GLOBAL_VAL(0x00ff00);
 
-	/* 쥤䡼ɽ֡0;̤ɽ(1)1;ɽ(14)5;ȥ쥤䡼(12) */
+	/* レイヤー表示状態　　0;未表示(青1)　　1;表示(明黄14)　　5;カレントレイヤー(赤12) */
 	GLOBAL LAYER Layer[256];
+	GLOBAL int use_layer GLOBAL_VAL(100);
 
-	/* Ͽѿ */
+	
+	/* Data Version */
+	GLOBAL int data_version GLOBAL_VAL(4);
+
+	
+	/* 登録画面設定変数 */
 	GLOBAL float GamenMag[7], GamenMagX[7], GamenMagY[7];
-	/* CADǥޥɤ̤ѿ */
+	/* CADでコマンドを識別する変数 */
 	GLOBAL int mode GLOBAL_VAL(0);
 	GLOBAL int OnlyOne_mode GLOBAL_VAL(0);
 	GLOBAL int Center_set_mode GLOBAL_VAL(0);
 	GLOBAL int Chain2_OnlyOne_mode GLOBAL_VAL(0);
 
 
-	/* OnlyOneCADǡ */
+	/* OnlyOneCADデータ */
 	GLOBAL CAD OnlyOneCAD[13];
-	/* OnlyOneؿѿ */
+	/* OnlyOne関数の変数 */
 	GLOBAL int OnlyOneIndex GLOBAL_VAL(0);
 	GLOBAL int OnlyOneEntry GLOBAL_VAL(0);
 	GLOBAL int RetOnlyOneMode GLOBAL_VAL(0);
 
 
-	/* ⡼ɤΥϥ饤ѿ */
+	/* 選択モードのハイライト変数 */
 	GLOBAL int Already GLOBAL_VAL(0);
-	/* ϰϥ쥯 */
+	/* 範囲セレクト */
 	GLOBAL int RectStart GLOBAL_VAL(0);
 	GLOBAL int StartX GLOBAL_VAL(0);
 	GLOBAL int StartY GLOBAL_VAL(0);
@@ -403,9 +411,9 @@ struct _printer {
 	GLOBAL int EndX GLOBAL_VAL(0);
 	GLOBAL int EndY GLOBAL_VAL(0);
 
-	/* ʿ ž оݥ⡼ѿ */
+	/* 平行 回転 対象モード変数 */
 	GLOBAL int CopyFrag GLOBAL_VAL(0);
-	/* ѹ° */
+	/* 変更属性 */
 	GLOBAL int ModifiedFlag GLOBAL_VAL(0);
 
 
@@ -419,7 +427,7 @@ struct _printer {
 	GLOBAL int Chain2index GLOBAL_VAL(0);
 
 
-	/* ϰ */
+	/* サーチ範囲 */
 	GLOBAL double DC GLOBAL_VAL(3);
 	GLOBAL int DcObj GLOBAL_VAL(15);
 	GLOBAL int (*ReturnFunc)(GtkWidget *widget, int Button, int x, int y);
@@ -427,7 +435,7 @@ struct _printer {
 	GLOBAL int (*KeepReturnFunc)(GtkWidget *widget, int Button, int x, int y);
 
 
-	/* 0 : ǥץ쥤   1 : ץ󥿡 */
+	/* 0 : ディスプレイ   1 : プリンター */
 	GLOBAL int DrawObject GLOBAL_VAL(0);
 
 	GLOBAL double window_left GLOBAL_VAL(0);
@@ -435,7 +443,7 @@ struct _printer {
 	GLOBAL double window_right GLOBAL_VAL(0);
 	GLOBAL double window_bottom GLOBAL_VAL(0);
 
-	/* Ѵ */
+	/* 変換係数 */
 	GLOBAL double ToDeviceK GLOBAL_VAL(0);
 	GLOBAL double ToDevice_X_lo GLOBAL_VAL(0);
 	GLOBAL double ToDevice_X_hi GLOBAL_VAL(0);
@@ -473,7 +481,7 @@ struct _printer {
 
 
 /* -------------------------------------------------------
- * 3 : ؿ (Function)
+ * 3 : 外部関数 (Function)
  * -------------------------------------------------------
  */
 int sagcad_global_init(void);
@@ -483,9 +491,9 @@ long Color_RB_Change(long rgbcol);
 
 int set_window_text(GtkWidget *widget, char *str);
 int set_label_text(GtkWidget *widget, char *str);
-/* եɤ߹ */
+/* 初期設定ファイル読み込み */
 int ConfigRead(void);
-/* ե񤭤 */
+/* 初期設定ファイル書きこみ */
 int ConfigWrite(void);
 
 
@@ -495,7 +503,7 @@ int ConfigWrite(void);
 #endif /* __cplusplus */
 #endif /* __GLOBAL_H__ */
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : global.h
