@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2002 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/01/16
- *    Last                 : 2003/02/04
+ *    Last                 : 2007/11/01
  * ====================================================================
  */
 
@@ -22,9 +22,9 @@
 #endif
 
 #include <gtk/gtk.h>
-//#include <libintl.h>
+#include <libintl.h>
 #include <unistd.h>
-#include <pwd.h>
+//#include <pwd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <locale.h>
@@ -47,7 +47,7 @@
 #include "List_Select.h"
 #include "List_font.h"
 #include "etc.h"
-#include "Trace.h"
+#include "culcfunc.h"
 #include "global.h"
 #include "toolbar.h"
 #include "DrawArea.h"
@@ -58,22 +58,23 @@
 #include "Command.h"
 #include "sgy.h"
 #include "DXF_read.h"
+#include "InputBox.h"
 #include "sagcad.h"
 
 
 /* -------------------------------------------------------------------
- * ץꥱνλ
+ * アプリケーションの終了
  * 
  */
 void file_quit_cmd_callback(gpointer callback_data, guint callback_action, GtkWidget *widget)
 {	
-	gtk_exit(0); 
+	gtk_main_quit(); 
 }
 
 
 
 /* -------------------------------------------------------------------
- * ɥĤ٥
+ * ウインドウ閉じろイベント
  * 
  */
 static gint delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
@@ -109,7 +110,7 @@ static gint delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 
 
 /* -------------------------------------------------------------------
- * 줿٥
+ * キーが押されたイベント
  * 
  */
 static gint key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
@@ -145,10 +146,10 @@ static gint key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer data
 			return TRUE;
 		}
 	}
-	if(event->keyval == 0xff52) MoveUp();			/*  */
-	if(event->keyval == 0xff54) MoveDown();			/*  */
-	if(event->keyval == 0xff53) MoveRight();		/*  */
-	if(event->keyval == 0xff51) MoveLeft();			/*  */
+	if(event->keyval == 0xff52) MoveUp();			/* ↑ */
+	if(event->keyval == 0xff54) MoveDown();			/* ↓ */
+	if(event->keyval == 0xff53) MoveRight();		/* ← */
+	if(event->keyval == 0xff51) MoveLeft();			/* → */
 	
 	if(event->keyval == 0xffab) ZoomUp();			/* + */
 	if(event->keyval == 0xffad) ZoomDown();			/* - */
@@ -176,7 +177,7 @@ static gint key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer data
 
 
 /* -------------------------------------------------------------------
- * ɥĤ٥
+ * ウインドウ閉じろイベント
  * 
  */
 static void destroy(GtkWidget *widget, gpointer data)
@@ -190,7 +191,7 @@ static void destroy(GtkWidget *widget, gpointer data)
 
 
 /* -------------------------------------------------------------------
- * main ؿ
+ * main 関数
  * 
  * 
  */
@@ -215,9 +216,11 @@ int main(int argc, char *argv[])
 	GtkWidget *length_box;
 	GtkWidget *scroll_pitch_box;
 //	GtkWidget *hbox;//work_hbox;
-	GtkWidget *toolbarY1;
-	GtkWidget *toolbarY2;
+	GtkWidget *toolbarY;
 
+	//GtkWidget *image;
+	//GdkPixmap *pixmap;
+	//GdkBitmap *mask;
 //	GdkCursor *cursor;
 
 	int debug = 0;
@@ -230,34 +233,46 @@ int main(int argc, char *argv[])
 
 
 	/* ---------------------------------------------------------------
-	 * GTK+ ν
+	 * GTK+ の初期設定
 	 */
-	/*  */
+	/* ロケール設定 */
 	gtk_set_locale();
-	/* ν */
+	/* 引数の処理 */
 	gtk_init( &argc, &argv );
-	/* rc եɤ߹ */
+	/* rc ファイルを読み込み */
 	gtk_rc_parse( "./gtkrc" );
 
+	/* Set default icon */
+	if (g_file_test ("./sagcad.png", G_FILE_TEST_IS_REGULAR | G_FILE_TEST_IS_SYMLINK)) {
+		g_print("sagcad.c : main() : sagcad.png OK！\n");
+		gtk_window_set_default_icon_from_file ("./sagcad.png", NULL);
+	}
+
+
 
 	/* ---------------------------------------------------------------
-	 * åιݲν 
+	 * メッセージの国際化の準備 
 	 */
+#ifdef ENABLE_NLS
 	setlocale(LC_ALL, "");
 	bindtextdomain(PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset(PACKAGE, "UTF-8");
 	textdomain(PACKAGE);
+#endif
 
 	//g_print("LOCALEDIR = %s", LOCALEDIR);
 
 
+	BeforeStr[0] = '\0';
+
 	/* ---------------------------------------------------------------
-	 * SagCAD ưν 
+	 * SagCAD を起動する前の準備 
 	 */
-	/* ѿν */
+	/* 外部変数の初期化 */
 	sagcad_global_init();
-	/* եɤ߹ */
+	/* 設定ファイルを読み込む */
 	ConfigRead();
-	/* å */
+	/* 初期メッセージ */
 	starting();
 
 	DeleteMemoryDebugLog();
@@ -266,58 +281,57 @@ int main(int argc, char *argv[])
 
 
 	/* -------------------------
-	 * ᥤ󥦥ɥ 
+	 * メインウインドウの生成 
 	 * -------------------------
 	 */
 	MainWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_policy(GTK_WINDOW(MainWindow), TRUE, TRUE, TRUE);
-	gtk_container_border_width(GTK_CONTAINER(MainWindow), 2);
-	SetTitle("NoName.sgy");
+	gtk_window_set_resizable(GTK_WINDOW(MainWindow), TRUE);
+	//gtk_container_set_border_width(GTK_CONTAINER(MainWindow), 2);
+	SetTitle("Untitled.sgy");
 
-	/* ɥɽ */
+	/* ウィンドウの表示位置設定 */
 	if (sagcad_system.WinMode > 0) {
-		gtk_widget_set_uposition (MainWindow, sagcad_system.win_x_pos, sagcad_system.win_y_pos);
-		//g_print("window position = (%d,%d)\n", sagcad_system.win_x_pos, sagcad_system.win_y_pos);
+		gtk_window_move(GTK_WINDOW(MainWindow), 
+					sagcad_system.win_x_pos, sagcad_system.win_y_pos);
+		//g_print("window position = (%d,%d)\n", 
+		//			sagcad_system.win_x_pos, sagcad_system.win_y_pos);
 	}
-	/* ɥ */
-	gtk_widget_set_usize (MainWindow, sagcad_system.win_width, sagcad_system.win_height);
+	/* ウィンドウサイズ設定 */
+	gtk_window_resize(GTK_WINDOW(MainWindow), sagcad_system.win_width, sagcad_system.win_height);
 	gtk_widget_show(MainWindow);
-	/* "delete_event" Υ٥ȥϥɥ */
-	gtk_signal_connect(GTK_OBJECT(MainWindow), "delete_event",	
-					   GTK_SIGNAL_FUNC(delete_event), NULL);
-	/* "destroy" Υ٥ȥϥɥ */
-	gtk_signal_connect(GTK_OBJECT(MainWindow), "destroy",
-					   GTK_SIGNAL_FUNC(destroy), NULL);
-	/* "button_press_event" ٥ȥϥɥ */
-	gtk_signal_connect(GTK_OBJECT(MainWindow), "key_press_event",
-					   GTK_SIGNAL_FUNC(key_press_event), NULL);
+	
+	/* ---------------------------------------------------------------
+	 * シグナルのコールバックを設定
+	 */ 
+	/* "delete_event" のイベントハンドラ設定 */
+	g_signal_connect(G_OBJECT(MainWindow), "delete_event",	
+					   G_CALLBACK(delete_event), NULL);
+	/* "destroy" のイベントハンドラ設定 */
+	g_signal_connect(G_OBJECT(MainWindow), "destroy",
+					   G_CALLBACK(destroy), NULL);
+	/* "button_press_event" イベントハンドラ設定 */
+	g_signal_connect(G_OBJECT(MainWindow), "key_press_event",
+					   G_CALLBACK(key_press_event), NULL);
 
-
-	/* ᥤ󥦥ɥɽǤʤȥ */
+	/* メインウインドウを表示した後でないとダメ */
 	font_open(sagcad_dimension.font_file);
 
-	/* vbox  (Ĥɲ) */
+	/* icon 作成 */
+	//pixmap = gdk_pixmap_create_from_xpm_d(MainWindow->window, 
+	//			 &mask, 
+	//			 &MainWindow->style->bg[GTK_STATE_NORMAL],
+	//			 (gchar **)sagcad_xpm);
+	//image = gtk_image_new_from_pixmap(pixmap, mask);
+	//gtk_window_set_default_icon(gtk_image_get_pixbuf(GTK_IMAGE(image)));
+
+	/* vbox 生成 (縦に追加) */
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(MainWindow), vbox);
 	gtk_widget_show(vbox);
 
-
-
-
-
-#ifdef TEST_HANDLE_BOX
-	handle_toolbar = gtk_handle_box_new();
-	gtk_box_pack_start(GTK_BOX(vbox), handle_toolbar, FALSE, FALSE, 0);
-	gtk_widget_show(handle_toolbar);
-#endif
-
-	/* ġС  (OutMode1) */
-	toolbar = create_toolbar_OutMode1(MainWindow);
-#ifdef TEST_HANDLE_BOX
-	gtk_container_add(GTK_CONTAINER(handle_toolbar), toolbar);
-#else
-	gtk_box_pack_start(GTK_BOX(vbox), toolbar, FALSE, FALSE, 0);
-#endif
+	/* ツールバーの生成  (OutMode1) */
+	toolbar = create_hbox_toolbar(vbox);
+	//gtk_box_pack_start(GTK_BOX(vbox), toolbar, FALSE, FALSE, 0);
 	gtk_widget_show(toolbar);
 
 	separator = gtk_hseparator_new();
@@ -328,111 +342,102 @@ int main(int argc, char *argv[])
 
 
 
-#ifdef TEST_HANDLE_BOX
-	handle_textbar = gtk_handle_box_new();
-	gtk_box_pack_start(GTK_BOX(vbox), handle_textbar, FALSE, FALSE, 0);
-	gtk_widget_show(handle_textbar);
-#endif
 
-	/* text_hbox  (ɲ) */
+	/* text_hbox 生成 (横に追加) */
 	text_hbox = gtk_hbox_new(FALSE, 2);
-#ifdef TEST_HANDLE_BOX
-	gtk_container_add(GTK_CONTAINER(handle_textbar), text_hbox);
-#else
-	gtk_container_border_width(GTK_CONTAINER(text_hbox), 2);
+	gtk_container_set_border_width(GTK_CONTAINER(text_hbox), 2);
 	gtk_box_pack_start(GTK_BOX(vbox), text_hbox, FALSE, FALSE, 0);
-#endif
 	gtk_widget_show(text_hbox);
 
 
 
 
 
-	/* ơС */
+	/* 線ステータスバーの生成 */
 	line_status = create_line_style_box();
 	gtk_box_pack_start(GTK_BOX(text_hbox), line_status, FALSE, FALSE, 0);
 	gtk_widget_show(line_status);
 
-	/* Ψɽܥå */
+	/* 倍率表示ボックスの生成 */
 	mag_box = gtk_button_new();
-	gtk_widget_set_usize (mag_box, 80, 18);
+	gtk_widget_set_size_request(mag_box, 80, TEXT_H_BOX_HEIGHT);
 	gtk_box_pack_start(GTK_BOX(text_hbox), mag_box, FALSE, FALSE, 0);
-	gtk_signal_connect( GTK_OBJECT(mag_box), "clicked", 
-						GTK_SIGNAL_FUNC(mag_box_click), NULL);
+	g_signal_connect( G_OBJECT(mag_box), "clicked", 
+						G_CALLBACK(mag_box_click), NULL);
 	gtk_widget_show(mag_box);
 
-	/* Ψɽ٥ */
+	/* 倍率表示ラベルの生成 */
 	mag = gtk_label_new(" Mag 1 ");
 	gtk_container_add(GTK_CONTAINER(mag_box), mag);
 	gtk_widget_show(mag);
 	
-	/* 쥤䡼ɽܥå */
+	/* レイヤー表示ボックスの生成 */
 	layer_box = gtk_button_new();
-	gtk_widget_set_usize (layer_box, 160, 18);
+	gtk_widget_set_size_request(layer_box, 160, TEXT_H_BOX_HEIGHT);
 	gtk_box_pack_start(GTK_BOX(text_hbox), layer_box, FALSE, FALSE, 0);
-	gtk_signal_connect( GTK_OBJECT(layer_box), "clicked",	
-						GTK_SIGNAL_FUNC(cmd_LayerSet), NULL);
+	g_signal_connect( G_OBJECT(layer_box), "clicked",	
+						G_CALLBACK(cmd_LayerSet), NULL);
 	gtk_widget_show(layer_box);
 	
-	/* 쥤䡼ɽ٥ */
+	/* レイヤー表示ラベルの生成 */
 	layer = gtk_label_new("Layer-1 [ 1 ]");
 	gtk_container_add(GTK_CONTAINER(layer_box), layer);
 	gtk_widget_show(layer);
 	
-	/* Fillet ɽܥå */
+	/* Fillet 表示ボックスの生成 */
 	filletR_box = gtk_button_new();
-	gtk_widget_set_usize (filletR_box, 80, 18);
+	gtk_widget_set_size_request(filletR_box, 80, TEXT_H_BOX_HEIGHT);
 	gtk_box_pack_start(GTK_BOX(text_hbox), filletR_box, FALSE, FALSE, 0);
-	gtk_signal_connect( GTK_OBJECT(filletR_box), "clicked",	
-						GTK_SIGNAL_FUNC(fillet_box_click), NULL);
+	g_signal_connect( G_OBJECT(filletR_box), "clicked",	
+						G_CALLBACK(fillet_box_click), NULL);
 	gtk_widget_show(filletR_box);
 
-	/* Fillet ɽ٥ */
+	/* Fillet 表示ラベルの生成 */
 	FloatOut6(str, sagcad_system.FilletRC, 0);
 	sprintf(str2, " R %s ", str);
 	fillet = gtk_label_new(str2);
 	gtk_container_add(GTK_CONTAINER(filletR_box), fillet);
 	gtk_widget_show(fillet);
 				
-	/* length ɽܥå */
+	/* length 表示ボックスの生成 */
 	length_box = gtk_button_new();
-	gtk_widget_set_usize (length_box, 80, 18);
+	gtk_widget_set_size_request(length_box, 80, TEXT_H_BOX_HEIGHT);
 	gtk_box_pack_start(GTK_BOX(text_hbox), length_box, FALSE, FALSE, 0);
-	gtk_signal_connect( GTK_OBJECT(length_box), "clicked",	
-						GTK_SIGNAL_FUNC(length_box_click), NULL);
+	g_signal_connect( G_OBJECT(length_box), "clicked",	
+						G_CALLBACK(length_box_click), NULL);
 	gtk_widget_show(length_box);
 	
-	/* length ɽ٥ */
+	/* length 表示ラベルの生成 */
 	FloatOut6(str, sagcad_system.Length, 0);
 	sprintf(str2, " L %s ", str);
 	length = gtk_label_new(str2);
 	gtk_container_add(GTK_CONTAINER(length_box), length);
 	gtk_widget_show(length);
 
-	/* scroll_pitch ɽܥå */
+	/* scroll_pitch 表示ボックスの生成 */
 	scroll_pitch_box = gtk_button_new();
-	gtk_widget_set_usize (scroll_pitch_box, 80, 18);
+	gtk_widget_set_size_request(scroll_pitch_box, 80, TEXT_H_BOX_HEIGHT);
 	gtk_box_pack_start(GTK_BOX(text_hbox), scroll_pitch_box, FALSE, FALSE, 0);
-	gtk_signal_connect( GTK_OBJECT(scroll_pitch_box), "clicked",	
-						GTK_SIGNAL_FUNC(scroll_pitch_box_click), NULL);
+	g_signal_connect( G_OBJECT(scroll_pitch_box), "clicked",	
+						G_CALLBACK(scroll_pitch_box_click), NULL);
 	gtk_widget_show(scroll_pitch_box);
 	
-	/* scroll_pitch ɽ٥ */
+	/* scroll_pitch 表示ラベルの生成 */
 	FloatOut6(str, sagcad_system.ScrollPitch, 0);
 	sprintf(str2, " SP %s ", str);
 	scroll_pitch = gtk_label_new(str2);
 	gtk_container_add(GTK_CONTAINER(scroll_pitch_box), scroll_pitch);
 	gtk_widget_show(scroll_pitch);
 	
-	/* Mouse Y ɽܥå */
+	/* Mouse Y 表示ボックスの生成 */
 	MouseY = gtk_label_new("y 0.000");
-	gtk_widget_set_usize (MouseY, 80, 18);
+	gtk_widget_set_size_request(MouseY, 80, TEXT_H_BOX_HEIGHT);
 	gtk_box_pack_end(GTK_BOX(text_hbox), MouseY, FALSE, FALSE, 0);
 	gtk_widget_show(MouseY);
 	
-	/* Mouse X ɽܥå */
+	/* Mouse X 表示ボックスの生成 */
 	MouseX = gtk_label_new("x 0.000");
-	gtk_widget_set_usize (MouseX, 80, 18);
+	gtk_widget_set_size_request(MouseX, 80, TEXT_H_BOX_HEIGHT);
 	gtk_box_pack_end(GTK_BOX(text_hbox), MouseX, FALSE, FALSE, 0);
 	gtk_widget_show(MouseX);
 	
@@ -440,32 +445,26 @@ int main(int argc, char *argv[])
 	gtk_box_pack_start(GTK_BOX(vbox), separator, FALSE, FALSE, 0);
 	gtk_widget_show(separator);
 	
-	/* work_hbox  (ɲ) */
+	/* work_hbox 生成 (横に追加) */
 	work_hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), work_hbox, TRUE, TRUE, 0);
-	gtk_container_border_width(GTK_CONTAINER(work_hbox), 2);
+	gtk_container_set_border_width(GTK_CONTAINER(work_hbox), 2);
 	gtk_widget_show(work_hbox);
 	
-	/* ġС */
-	toolbarY1 = create_toolbar_InMode1(MainWindow);
-	gtk_box_pack_start(GTK_BOX(work_hbox), toolbarY1, FALSE, FALSE, 0);
-	gtk_widget_show(toolbarY1);
-	
-	/* ġС */
-	toolbarY2 = create_toolbar_InMode2(MainWindow);
-	gtk_box_pack_start(GTK_BOX(work_hbox), toolbarY2, FALSE, FALSE, 0);
-	gtk_widget_show(toolbarY2);
+	/* ツールバーの生成 */
+	toolbarY = create_table_toolbar(work_hbox);
+	gtk_widget_show(toolbarY);
 	
 	separator = gtk_vseparator_new();
 	gtk_box_pack_start(GTK_BOX(work_hbox), separator, FALSE, FALSE, 2);
 	gtk_widget_show(separator);
 	
-	/* ɥ󥰥ꥢ */
+	/* ドローイングエリアの生成 */
 	drawing_area = create_drawing_area();
 	gtk_box_pack_start(GTK_BOX(work_hbox), drawing_area, TRUE, TRUE, 0);
 	gtk_widget_show(drawing_area);
 	/* -------------------------------------------------------------------------------
-	   ޥ 
+	   マウスカーソル作成 
 	   GDK_CROSS  GDK_IRON_CROSS  [GDK_CROSSHAIR]  GDK_DIAMOND_CROSS  [GDK_TCROSS]
 	 */
 //	cursor = gdk_cursor_new(GDK_TCROSS);
@@ -481,13 +480,13 @@ int main(int argc, char *argv[])
 	gtk_widget_show(handle_statusbar);
 #endif
 
-	/* ơС */
+	/* ステータスバーの生成 */
 	statusbar = gtk_entry_new();
 #ifdef TEST_HANDLE_BOX
 	gtk_container_add(GTK_CONTAINER(handle_statusbar), statusbar);
 #else
 	gtk_box_pack_start(GTK_BOX(vbox), statusbar, FALSE, FALSE, 0);
-	gtk_entry_set_editable((GtkEntry *)statusbar, FALSE);
+	gtk_editable_set_editable(GTK_EDITABLE(statusbar), FALSE);
 #endif
 	gtk_widget_show(statusbar);
 
@@ -496,56 +495,56 @@ int main(int argc, char *argv[])
 
 
 	/* -----------------------------
-	 * Ͻ
+	 * 開始処理
 	 */
 	ReturnFunc = MouseRet_Non;
 
 
 
-	/* GC */
+	/* GC作成 */
 //	gc = create_gc(drawing_area);
 	ls_gc = create_gc(line_status);
 
-	/* ޥɥ饤Υե򳫤 */
+	/* コマンドラインのファイルを開く */
 	if(argc == 2) {
 		strcpy(NowFile, argv[1]);
 
 		if (strstr(NowFile, ".sgy") != NULL || strstr(NowFile, ".SGY") != NULL) {
-			sprintf(msg, "Reading SGY       ");
+			sprintf(msg, "Reading SGY       ■□□□□□□");
 			StatusMsg(msg);
 			UpDate_widget(MainWindow);
 			sgyFileOpen(NowFile);
 		}
 		else if(strstr(NowFile, ".dxf") != NULL || strstr(NowFile, ".DXF") != NULL) {
-			sprintf(msg, "Reading DXF       ");
+			sprintf(msg, "Reading DXF       ■□□□□□□");
 			StatusMsg(msg);
 			UpDate_widget(MainWindow);
 			DxfFileOpen(NowFile, 0, 0);
 		}
 
-		SetTitle(NowFile);
+		SetTitle(g_locale_to_utf8(NowFile, -1, NULL, NULL, NULL));
 	}
 	else {
-		/* ɥΥȥ */
-		sprintf(NowFile, "%s/NoName.dxf", sagcad_user.CadPath);
+		/* ウインドウのタイトルを設定 */
+		sprintf(NowFile, "%s/Untitled.sgy", sagcad_user.CadPath);
 		SetTitle(NowFile);
 	}
 	/* -----------------------------
-	 * ᥤ󥤥٥ȥ롼
+	 * メインイベントループ
 	 */
 	gtk_main ();
 
 
 	/* -----------------------------
-	 * λ
+	 * 終了処理
 	 */
 
-	/* GC  */
+	/* GC 開放 */
 	delete_gc(gc);
 //	delete_gc(ls_gc);
 
 
-	/* 곫 */
+	/* メモリ開放 */
 	if (debug > 0) g_print("\n--- < Memory Block Free start > ---\n");
 	if (debug > 0) g_print("CAD Data Free ---> ");
 	if (debug > 0) g_print("CAD Data [%d]\n", (int)cad_list_num(&cad_list_info));
@@ -599,7 +598,7 @@ int main(int argc, char *argv[])
 
 
 /* ====================================================================
- * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : sagcad.c
@@ -611,7 +610,7 @@ int main(int argc, char *argv[])
 
 
 /* -------------------------------------------------------------------
- * ȥ
+ * タイトルを設定
  *	
  */
 int SetTitle(char *FileName)
@@ -620,7 +619,7 @@ int SetTitle(char *FileName)
 
 	sprintf(str, " [ %s ] - %s Version ", FileName, Title);
 	strcat(str, VERSION);
-	set_window_text(MainWindow, str);
+	gtk_window_set_title(GTK_WINDOW(MainWindow), str);
 	return 1;
 }
 
@@ -629,7 +628,7 @@ int SetTitle(char *FileName)
 
 
 /* -------------------------------------------------------------------
- * ƥ󥰡å
+ * スターティング　メッセージ
  * 
  */
 int starting(void)
@@ -639,7 +638,7 @@ int starting(void)
 	g_print("\nSagCAD ");
 	g_print(VERSION);
 	g_print("\n");
-	g_print("Copyright (C) 1998-2003 Sagiya Metal Mold Factory,Inc.\n");
+	g_print("Copyright (C) 1998-2007 Sagiya Metal Mold Factory,Inc.\n");
 	g_print("Yutaka Sagiya.\n");
 	g_print("SagCAD comes with NO WARRANTY,\n");
 	g_print("to the extent permitted by law.\n");
@@ -649,7 +648,7 @@ int starting(void)
 	g_print("see the files named COPYING.\n\n");
 	g_print("Report bugs to <kappa@a6s.highway.ne.jp>\n");
 
-#ifdef TEST
+//#ifdef TEST
 	g_print("Font Directry ->");
 	g_print(FONTDIR);
 	g_print("\n");
@@ -665,7 +664,7 @@ int starting(void)
 	g_print("DOCUMENT Directry ->");
 	g_print(DOCDIR);
 	g_print("\n");
-#endif
+//#endif
 	return 1;
 }
 
@@ -674,29 +673,33 @@ int starting(void)
 
 
 /* -------------------------------------------------------------------
- * ǥ󥰡å
+ * エンディング　メッセージ
  * 
  */
 int ending(void)
 {
-	int bar_x, bar_y, x, y, width, height, dummy;
+	int x, y, width, height;
 
-	gdk_window_get_geometry(MainWindow->window, &bar_x, &bar_y, &width, &height, &dummy);
+	gtk_window_get_size(GTK_WINDOW(MainWindow), &width, &height);
 //	g_print("sagcad.c : delete_event() : Bar Size (%d, %d)   Window Size(%d,%d)\n", 
 //			bar_x, bar_y, width, height);
 
-	gdk_window_get_position(MainWindow->window, &x, &y);
+	gtk_window_get_position(GTK_WINDOW(MainWindow), &x, &y);
 //	g_print("sagcad.c : delete_event() : position (%d,%d)\n", x, y);
 
 	if (sagcad_system.WinMode == 2) {
-		sagcad_system.win_x_pos = x - bar_x/* -1*/;
-		sagcad_system.win_y_pos = y - bar_y/* -1*/;
+		sagcad_system.win_x_pos = x;
+		sagcad_system.win_y_pos = y;
 		sagcad_system.win_width = width;
 		sagcad_system.win_height = height;
 		
 		if (sagcad_system.win_x_pos < 10) sagcad_system.win_x_pos = 0;
 		if (sagcad_system.win_y_pos < 10) sagcad_system.win_y_pos = 0;
 		
+		g_print("ending() : %d, %d, %d, %d\n", 
+					sagcad_system.win_x_pos, sagcad_system.win_y_pos, 
+					sagcad_system.win_width, sagcad_system.win_height);
+		
 		ConfigWrite();
 	}
 
